var kA=Object.defineProperty;var CA=(e,t,n)=>t in e?kA(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n;var Fa=(e,t,n)=>CA(e,typeof t!="symbol"?t+"":t,n);(function(){const t=document.createElement("link").relList;if(t&&t.supports&&t.supports("modulepreload"))return;for(const i of document.querySelectorAll('link[rel="modulepreload"]'))r(i);new MutationObserver(i=>{for(const s of i)if(s.type==="childList")for(const o of s.addedNodes)o.tagName==="LINK"&&o.rel==="modulepreload"&&r(o)}).observe(document,{childList:!0,subtree:!0});function n(i){const s={};return i.integrity&&(s.integrity=i.integrity),i.referrerPolicy&&(s.referrerPolicy=i.referrerPolicy),i.crossOrigin==="use-credentials"?s.credentials="include":i.crossOrigin==="anonymous"?s.credentials="omit":s.credentials="same-origin",s}function r(i){if(i.ep)return;i.ep=!0;const s=n(i);fetch(i.href,s)}})();function Of(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}var u1={exports:{}},bc={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var $_;function NA(){if($_)return bc;$_=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.fragment");function n(r,i,s){var o=null;if(s!==void 0&&(o=""+s),i.key!==void 0&&(o=""+i.key),"key"in i){s={};for(var c in i)c!=="key"&&(s[c]=i[c])}else s=i;return i=s.ref,{$$typeof:e,type:r,key:o,ref:i!==void 0?i:null,props:s}}return bc.Fragment=t,bc.jsx=n,bc.jsxs=n,bc}var G_;function OA(){return G_||(G_=1,u1.exports=NA()),u1.exports}var C=OA(),c1={exports:{}},gt={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Y_;function RA(){if(Y_)return gt;Y_=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),i=Symbol.for("react.profiler"),s=Symbol.for("react.consumer"),o=Symbol.for("react.context"),c=Symbol.for("react.forward_ref"),d=Symbol.for("react.suspense"),f=Symbol.for("react.memo"),m=Symbol.for("react.lazy"),p=Symbol.for("react.activity"),v=Symbol.iterator;function _(z){return z===null||typeof z!="object"?null:(z=v&&z[v]||z["@@iterator"],typeof z=="function"?z:null)}var T={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},x=Object.assign,k={};function A(z,J,D){this.props=z,this.context=J,this.refs=k,this.updater=D||T}A.prototype.isReactComponent={},A.prototype.setState=function(z,J){if(typeof z!="object"&&typeof z!="function"&&z!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,z,J,"setState")},A.prototype.forceUpdate=function(z){this.updater.enqueueForceUpdate(this,z,"forceUpdate")};function O(){}O.prototype=A.prototype;function I(z,J,D){this.props=z,this.context=J,this.refs=k,this.updater=D||T}var $=I.prototype=new O;$.constructor=I,x($,A.prototype),$.isPureReactComponent=!0;var V=Array.isArray;function B(){}var Z={H:null,A:null,T:null,S:null},ee=Object.prototype.hasOwnProperty;function te(z,J,D){var Ae=D.ref;return{$$typeof:e,type:z,key:J,ref:Ae!==void 0?Ae:null,props:D}}function Y(z,J){return te(z.type,J,z.props)}function oe(z){return typeof z=="object"&&z!==null&&z.$$typeof===e}function he(z){var J={"=":"=0",":":"=2"};return"$"+z.replace(/[=:]/g,function(D){return J[D]})}var Se=/\/+/g;function fe(z,J){return typeof z=="object"&&z!==null&&z.key!=null?he(""+z.key):J.toString(36)}function de(z){switch(z.status){case"fulfilled":return z.value;case"rejected":throw z.reason;default:switch(typeof z.status=="string"?z.then(B,B):(z.status="pending",z.then(function(J){z.status==="pending"&&(z.status="fulfilled",z.value=J)},function(J){z.status==="pending"&&(z.status="rejected",z.reason=J)})),z.status){case"fulfilled":return z.value;case"rejected":throw z.reason}}throw z}function H(z,J,D,Ae,Le){var ze=typeof z;(ze==="undefined"||ze==="boolean")&&(z=null);var at=!1;if(z===null)at=!0;else switch(ze){case"bigint":case"string":case"number":at=!0;break;case"object":switch(z.$$typeof){case e:case t:at=!0;break;case m:return at=z._init,H(at(z._payload),J,D,Ae,Le)}}if(at)return Le=Le(z),at=Ae===""?"."+fe(z,0):Ae,V(Le)?(D="",at!=null&&(D=at.replace(Se,"$&/")+"/"),H(Le,J,D,"",function(Tt){return Tt})):Le!=null&&(oe(Le)&&(Le=Y(Le,D+(Le.key==null||z&&z.key===Le.key?"":(""+Le.key).replace(Se,"$&/")+"/")+at)),J.push(Le)),1;at=0;var _t=Ae===""?".":Ae+":";if(V(z))for(var pt=0;pt<z.length;pt++)Ae=z[pt],ze=_t+fe(Ae,pt),at+=H(Ae,J,D,ze,Le);else if(pt=_(z),typeof pt=="function")for(z=pt.call(z),pt=0;!(Ae=z.next()).done;)Ae=Ae.value,ze=_t+fe(Ae,pt++),at+=H(Ae,J,D,ze,Le);else if(ze==="object"){if(typeof z.then=="function")return H(de(z),J,D,Ae,Le);throw J=String(z),Error("Objects are not valid as a React child (found: "+(J==="[object Object]"?"object with keys {"+Object.keys(z).join(", ")+"}":J)+"). If you meant to render a collection of children, use an array instead.")}return at}function ie(z,J,D){if(z==null)return z;var Ae=[],Le=0;return H(z,Ae,"","",function(ze){return J.call(D,ze,Le++)}),Ae}function ve(z){if(z._status===-1){var J=z._result;J=J(),J.then(function(D){(z._status===0||z._status===-1)&&(z._status=1,z._result=D)},function(D){(z._status===0||z._status===-1)&&(z._status=2,z._result=D)}),z._status===-1&&(z._status=0,z._result=J)}if(z._status===1)return z._result.default;throw z._result}var xe=typeof reportError=="function"?reportError:function(z){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var J=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof z=="object"&&z!==null&&typeof z.message=="string"?String(z.message):String(z),error:z});if(!window.dispatchEvent(J))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",z);return}console.error(z)},P={map:ie,forEach:function(z,J,D){ie(z,function(){J.apply(this,arguments)},D)},count:function(z){var J=0;return ie(z,function(){J++}),J},toArray:function(z){return ie(z,function(J){return J})||[]},only:function(z){if(!oe(z))throw Error("React.Children.only expected to receive a single React element child.");return z}};return gt.Activity=p,gt.Children=P,gt.Component=A,gt.Fragment=n,gt.Profiler=i,gt.PureComponent=I,gt.StrictMode=r,gt.Suspense=d,gt.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=Z,gt.__COMPILER_RUNTIME={__proto__:null,c:function(z){return Z.H.useMemoCache(z)}},gt.cache=function(z){return function(){return z.apply(null,arguments)}},gt.cacheSignal=function(){return null},gt.cloneElement=function(z,J,D){if(z==null)throw Error("The argument must be a React element, but you passed "+z+".");var Ae=x({},z.props),Le=z.key;if(J!=null)for(ze in J.key!==void 0&&(Le=""+J.key),J)!ee.call(J,ze)||ze==="key"||ze==="__self"||ze==="__source"||ze==="ref"&&J.ref===void 0||(Ae[ze]=J[ze]);var ze=arguments.length-2;if(ze===1)Ae.children=D;else if(1<ze){for(var at=Array(ze),_t=0;_t<ze;_t++)at[_t]=arguments[_t+2];Ae.children=at}return te(z.type,Le,Ae)},gt.createContext=function(z){return z={$$typeof:o,_currentValue:z,_currentValue2:z,_threadCount:0,Provider:null,Consumer:null},z.Provider=z,z.Consumer={$$typeof:s,_context:z},z},gt.createElement=function(z,J,D){var Ae,Le={},ze=null;if(J!=null)for(Ae in J.key!==void 0&&(ze=""+J.key),J)ee.call(J,Ae)&&Ae!=="key"&&Ae!=="__self"&&Ae!=="__source"&&(Le[Ae]=J[Ae]);var at=arguments.length-2;if(at===1)Le.children=D;else if(1<at){for(var _t=Array(at),pt=0;pt<at;pt++)_t[pt]=arguments[pt+2];Le.children=_t}if(z&&z.defaultProps)for(Ae in at=z.defaultProps,at)Le[Ae]===void 0&&(Le[Ae]=at[Ae]);return te(z,ze,Le)},gt.createRef=function(){return{current:null}},gt.forwardRef=function(z){return{$$typeof:c,render:z}},gt.isValidElement=oe,gt.lazy=function(z){return{$$typeof:m,_payload:{_status:-1,_result:z},_init:ve}},gt.memo=function(z,J){return{$$typeof:f,type:z,compare:J===void 0?null:J}},gt.startTransition=function(z){var J=Z.T,D={};Z.T=D;try{var Ae=z(),Le=Z.S;Le!==null&&Le(D,Ae),typeof Ae=="object"&&Ae!==null&&typeof Ae.then=="function"&&Ae.then(B,xe)}catch(ze){xe(ze)}finally{J!==null&&D.types!==null&&(J.types=D.types),Z.T=J}},gt.unstable_useCacheRefresh=function(){return Z.H.useCacheRefresh()},gt.use=function(z){return Z.H.use(z)},gt.useActionState=function(z,J,D){return Z.H.useActionState(z,J,D)},gt.useCallback=function(z,J){return Z.H.useCallback(z,J)},gt.useContext=function(z){return Z.H.useContext(z)},gt.useDebugValue=function(){},gt.useDeferredValue=function(z,J){return Z.H.useDeferredValue(z,J)},gt.useEffect=function(z,J){return Z.H.useEffect(z,J)},gt.useEffectEvent=function(z){return Z.H.useEffectEvent(z)},gt.useId=function(){return Z.H.useId()},gt.useImperativeHandle=function(z,J,D){return Z.H.useImperativeHandle(z,J,D)},gt.useInsertionEffect=function(z,J){return Z.H.useInsertionEffect(z,J)},gt.useLayoutEffect=function(z,J){return Z.H.useLayoutEffect(z,J)},gt.useMemo=function(z,J){return Z.H.useMemo(z,J)},gt.useOptimistic=function(z,J){return Z.H.useOptimistic(z,J)},gt.useReducer=function(z,J,D){return Z.H.useReducer(z,J,D)},gt.useRef=function(z){return Z.H.useRef(z)},gt.useState=function(z){return Z.H.useState(z)},gt.useSyncExternalStore=function(z,J,D){return Z.H.useSyncExternalStore(z,J,D)},gt.useTransition=function(){return Z.H.useTransition()},gt.version="19.2.3",gt}var V_;function Rf(){return V_||(V_=1,c1.exports=RA()),c1.exports}var F=Rf();const ue=Of(F);var d1={exports:{}},vc={},h1={exports:{}},f1={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var K_;function MA(){return K_||(K_=1,(function(e){function t(H,ie){var ve=H.length;H.push(ie);e:for(;0<ve;){var xe=ve-1>>>1,P=H[xe];if(0<i(P,ie))H[xe]=ie,H[ve]=P,ve=xe;else break e}}function n(H){return H.length===0?null:H[0]}function r(H){if(H.length===0)return null;var ie=H[0],ve=H.pop();if(ve!==ie){H[0]=ve;e:for(var xe=0,P=H.length,z=P>>>1;xe<z;){var J=2*(xe+1)-1,D=H[J],Ae=J+1,Le=H[Ae];if(0>i(D,ve))Ae<P&&0>i(Le,D)?(H[xe]=Le,H[Ae]=ve,xe=Ae):(H[xe]=D,H[J]=ve,xe=J);else if(Ae<P&&0>i(Le,ve))H[xe]=Le,H[Ae]=ve,xe=Ae;else break e}}return ie}function i(H,ie){var ve=H.sortIndex-ie.sortIndex;return ve!==0?ve:H.id-ie.id}if(e.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var s=performance;e.unstable_now=function(){return s.now()}}else{var o=Date,c=o.now();e.unstable_now=function(){return o.now()-c}}var d=[],f=[],m=1,p=null,v=3,_=!1,T=!1,x=!1,k=!1,A=typeof setTimeout=="function"?setTimeout:null,O=typeof clearTimeout=="function"?clearTimeout:null,I=typeof setImmediate<"u"?setImmediate:null;function $(H){for(var ie=n(f);ie!==null;){if(ie.callback===null)r(f);else if(ie.startTime<=H)r(f),ie.sortIndex=ie.expirationTime,t(d,ie);else break;ie=n(f)}}function V(H){if(x=!1,$(H),!T)if(n(d)!==null)T=!0,B||(B=!0,he());else{var ie=n(f);ie!==null&&de(V,ie.startTime-H)}}var B=!1,Z=-1,ee=5,te=-1;function Y(){return k?!0:!(e.unstable_now()-te<ee)}function oe(){if(k=!1,B){var H=e.unstable_now();te=H;var ie=!0;try{e:{T=!1,x&&(x=!1,O(Z),Z=-1),_=!0;var ve=v;try{t:{for($(H),p=n(d);p!==null&&!(p.expirationTime>H&&Y());){var xe=p.callback;if(typeof xe=="function"){p.callback=null,v=p.priorityLevel;var P=xe(p.expirationTime<=H);if(H=e.unstable_now(),typeof P=="function"){p.callback=P,$(H),ie=!0;break t}p===n(d)&&r(d),$(H)}else r(d);p=n(d)}if(p!==null)ie=!0;else{var z=n(f);z!==null&&de(V,z.startTime-H),ie=!1}}break e}finally{p=null,v=ve,_=!1}ie=void 0}}finally{ie?he():B=!1}}}var he;if(typeof I=="function")he=function(){I(oe)};else if(typeof MessageChannel<"u"){var Se=new MessageChannel,fe=Se.port2;Se.port1.onmessage=oe,he=function(){fe.postMessage(null)}}else he=function(){A(oe,0)};function de(H,ie){Z=A(function(){H(e.unstable_now())},ie)}e.unstable_IdlePriority=5,e.unstable_ImmediatePriority=1,e.unstable_LowPriority=4,e.unstable_NormalPriority=3,e.unstable_Profiling=null,e.unstable_UserBlockingPriority=2,e.unstable_cancelCallback=function(H){H.callback=null},e.unstable_forceFrameRate=function(H){0>H||125<H?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):ee=0<H?Math.floor(1e3/H):5},e.unstable_getCurrentPriorityLevel=function(){return v},e.unstable_next=function(H){switch(v){case 1:case 2:case 3:var ie=3;break;default:ie=v}var ve=v;v=ie;try{return H()}finally{v=ve}},e.unstable_requestPaint=function(){k=!0},e.unstable_runWithPriority=function(H,ie){switch(H){case 1:case 2:case 3:case 4:case 5:break;default:H=3}var ve=v;v=H;try{return ie()}finally{v=ve}},e.unstable_scheduleCallback=function(H,ie,ve){var xe=e.unstable_now();switch(typeof ve=="object"&&ve!==null?(ve=ve.delay,ve=typeof ve=="number"&&0<ve?xe+ve:xe):ve=xe,H){case 1:var P=-1;break;case 2:P=250;break;case 5:P=1073741823;break;case 4:P=1e4;break;default:P=5e3}return P=ve+P,H={id:m++,callback:ie,priorityLevel:H,startTime:ve,expirationTime:P,sortIndex:-1},ve>xe?(H.sortIndex=ve,t(f,H),n(d)===null&&H===n(f)&&(x?(O(Z),Z=-1):x=!0,de(V,ve-xe))):(H.sortIndex=P,t(d,H),T||_||(T=!0,B||(B=!0,he()))),H},e.unstable_shouldYield=Y,e.unstable_wrapCallback=function(H){var ie=v;return function(){var ve=v;v=ie;try{return H.apply(this,arguments)}finally{v=ve}}}})(f1)),f1}var W_;function IA(){return W_||(W_=1,h1.exports=MA()),h1.exports}var m1={exports:{}},Ar={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var X_;function DA(){if(X_)return Ar;X_=1;var e=Rf();function t(d){var f="https://react.dev/errors/"+d;if(1<arguments.length){f+="?args[]="+encodeURIComponent(arguments[1]);for(var m=2;m<arguments.length;m++)f+="&args[]="+encodeURIComponent(arguments[m])}return"Minified React error #"+d+"; visit "+f+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function n(){}var r={d:{f:n,r:function(){throw Error(t(522))},D:n,C:n,L:n,m:n,X:n,S:n,M:n},p:0,findDOMNode:null},i=Symbol.for("react.portal");function s(d,f,m){var p=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:i,key:p==null?null:""+p,children:d,containerInfo:f,implementation:m}}var o=e.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function c(d,f){if(d==="font")return"";if(typeof f=="string")return f==="use-credentials"?f:""}return Ar.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,Ar.createPortal=function(d,f){var m=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!f||f.nodeType!==1&&f.nodeType!==9&&f.nodeType!==11)throw Error(t(299));return s(d,f,null,m)},Ar.flushSync=function(d){var f=o.T,m=r.p;try{if(o.T=null,r.p=2,d)return d()}finally{o.T=f,r.p=m,r.d.f()}},Ar.preconnect=function(d,f){typeof d=="string"&&(f?(f=f.crossOrigin,f=typeof f=="string"?f==="use-credentials"?f:"":void 0):f=null,r.d.C(d,f))},Ar.prefetchDNS=function(d){typeof d=="string"&&r.d.D(d)},Ar.preinit=function(d,f){if(typeof d=="string"&&f&&typeof f.as=="string"){var m=f.as,p=c(m,f.crossOrigin),v=typeof f.integrity=="string"?f.integrity:void 0,_=typeof f.fetchPriority=="string"?f.fetchPriority:void 0;m==="style"?r.d.S(d,typeof f.precedence=="string"?f.precedence:void 0,{crossOrigin:p,integrity:v,fetchPriority:_}):m==="script"&&r.d.X(d,{crossOrigin:p,integrity:v,fetchPriority:_,nonce:typeof f.nonce=="string"?f.nonce:void 0})}},Ar.preinitModule=function(d,f){if(typeof d=="string")if(typeof f=="object"&&f!==null){if(f.as==null||f.as==="script"){var m=c(f.as,f.crossOrigin);r.d.M(d,{crossOrigin:m,integrity:typeof f.integrity=="string"?f.integrity:void 0,nonce:typeof f.nonce=="string"?f.nonce:void 0})}}else f==null&&r.d.M(d)},Ar.preload=function(d,f){if(typeof d=="string"&&typeof f=="object"&&f!==null&&typeof f.as=="string"){var m=f.as,p=c(m,f.crossOrigin);r.d.L(d,m,{crossOrigin:p,integrity:typeof f.integrity=="string"?f.integrity:void 0,nonce:typeof f.nonce=="string"?f.nonce:void 0,type:typeof f.type=="string"?f.type:void 0,fetchPriority:typeof f.fetchPriority=="string"?f.fetchPriority:void 0,referrerPolicy:typeof f.referrerPolicy=="string"?f.referrerPolicy:void 0,imageSrcSet:typeof f.imageSrcSet=="string"?f.imageSrcSet:void 0,imageSizes:typeof f.imageSizes=="string"?f.imageSizes:void 0,media:typeof f.media=="string"?f.media:void 0})}},Ar.preloadModule=function(d,f){if(typeof d=="string")if(f){var m=c(f.as,f.crossOrigin);r.d.m(d,{as:typeof f.as=="string"&&f.as!=="script"?f.as:void 0,crossOrigin:m,integrity:typeof f.integrity=="string"?f.integrity:void 0})}else r.d.m(d)},Ar.requestFormReset=function(d){r.d.r(d)},Ar.unstable_batchedUpdates=function(d,f){return d(f)},Ar.useFormState=function(d,f,m){return o.H.useFormState(d,f,m)},Ar.useFormStatus=function(){return o.H.useHostTransitionStatus()},Ar.version="19.2.3",Ar}var Q_;function V5(){if(Q_)return m1.exports;Q_=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),m1.exports=DA(),m1.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Z_;function LA(){if(Z_)return vc;Z_=1;var e=IA(),t=Rf(),n=V5();function r(a){var l="https://react.dev/errors/"+a;if(1<arguments.length){l+="?args[]="+encodeURIComponent(arguments[1]);for(var u=2;u<arguments.length;u++)l+="&args[]="+encodeURIComponent(arguments[u])}return"Minified React error #"+a+"; visit "+l+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function i(a){return!(!a||a.nodeType!==1&&a.nodeType!==9&&a.nodeType!==11)}function s(a){var l=a,u=a;if(a.alternate)for(;l.return;)l=l.return;else{a=l;do l=a,(l.flags&4098)!==0&&(u=l.return),a=l.return;while(a)}return l.tag===3?u:null}function o(a){if(a.tag===13){var l=a.memoizedState;if(l===null&&(a=a.alternate,a!==null&&(l=a.memoizedState)),l!==null)return l.dehydrated}return null}function c(a){if(a.tag===31){var l=a.memoizedState;if(l===null&&(a=a.alternate,a!==null&&(l=a.memoizedState)),l!==null)return l.dehydrated}return null}function d(a){if(s(a)!==a)throw Error(r(188))}function f(a){var l=a.alternate;if(!l){if(l=s(a),l===null)throw Error(r(188));return l!==a?null:a}for(var u=a,h=l;;){var g=u.return;if(g===null)break;var b=g.alternate;if(b===null){if(h=g.return,h!==null){u=h;continue}break}if(g.child===b.child){for(b=g.child;b;){if(b===u)return d(g),a;if(b===h)return d(g),l;b=b.sibling}throw Error(r(188))}if(u.return!==h.return)u=g,h=b;else{for(var w=!1,R=g.child;R;){if(R===u){w=!0,u=g,h=b;break}if(R===h){w=!0,h=g,u=b;break}R=R.sibling}if(!w){for(R=b.child;R;){if(R===u){w=!0,u=b,h=g;break}if(R===h){w=!0,h=b,u=g;break}R=R.sibling}if(!w)throw Error(r(189))}}if(u.alternate!==h)throw Error(r(190))}if(u.tag!==3)throw Error(r(188));return u.stateNode.current===u?a:l}function m(a){var l=a.tag;if(l===5||l===26||l===27||l===6)return a;for(a=a.child;a!==null;){if(l=m(a),l!==null)return l;a=a.sibling}return null}var p=Object.assign,v=Symbol.for("react.element"),_=Symbol.for("react.transitional.element"),T=Symbol.for("react.portal"),x=Symbol.for("react.fragment"),k=Symbol.for("react.strict_mode"),A=Symbol.for("react.profiler"),O=Symbol.for("react.consumer"),I=Symbol.for("react.context"),$=Symbol.for("react.forward_ref"),V=Symbol.for("react.suspense"),B=Symbol.for("react.suspense_list"),Z=Symbol.for("react.memo"),ee=Symbol.for("react.lazy"),te=Symbol.for("react.activity"),Y=Symbol.for("react.memo_cache_sentinel"),oe=Symbol.iterator;function he(a){return a===null||typeof a!="object"?null:(a=oe&&a[oe]||a["@@iterator"],typeof a=="function"?a:null)}var Se=Symbol.for("react.client.reference");function fe(a){if(a==null)return null;if(typeof a=="function")return a.$$typeof===Se?null:a.displayName||a.name||null;if(typeof a=="string")return a;switch(a){case x:return"Fragment";case A:return"Profiler";case k:return"StrictMode";case V:return"Suspense";case B:return"SuspenseList";case te:return"Activity"}if(typeof a=="object")switch(a.$$typeof){case T:return"Portal";case I:return a.displayName||"Context";case O:return(a._context.displayName||"Context")+".Consumer";case $:var l=a.render;return a=a.displayName,a||(a=l.displayName||l.name||"",a=a!==""?"ForwardRef("+a+")":"ForwardRef"),a;case Z:return l=a.displayName||null,l!==null?l:fe(a.type)||"Memo";case ee:l=a._payload,a=a._init;try{return fe(a(l))}catch{}}return null}var de=Array.isArray,H=t.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,ie=n.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,ve={pending:!1,data:null,method:null,action:null},xe=[],P=-1;function z(a){return{current:a}}function J(a){0>P||(a.current=xe[P],xe[P]=null,P--)}function D(a,l){P++,xe[P]=a.current,a.current=l}var Ae=z(null),Le=z(null),ze=z(null),at=z(null);function _t(a,l){switch(D(ze,l),D(Le,a),D(Ae,null),l.nodeType){case 9:case 11:a=(a=l.documentElement)&&(a=a.namespaceURI)?f_(a):0;break;default:if(a=l.tagName,l=l.namespaceURI)l=f_(l),a=m_(l,a);else switch(a){case"svg":a=1;break;case"math":a=2;break;default:a=0}}J(Ae),D(Ae,a)}function pt(){J(Ae),J(Le),J(ze)}function Tt(a){a.memoizedState!==null&&D(at,a);var l=Ae.current,u=m_(l,a.type);l!==u&&(D(Le,a),D(Ae,u))}function kn(a){Le.current===a&&(J(Ae),J(Le)),at.current===a&&(J(at),fc._currentValue=ve)}var pr,yt;function ct(a){if(pr===void 0)try{throw Error()}catch(u){var l=u.stack.trim().match(/\n( *(at )?)/);pr=l&&l[1]||"",yt=-1<u.stack.indexOf(`
    at`)?" (<anonymous>)":-1<u.stack.indexOf("@")?"@unknown:0:0":""}return`
`+pr+a+yt}var Ft=!1;function Xe(a,l){if(!a||Ft)return"";Ft=!0;var u=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var h={DetermineComponentFrameRoot:function(){try{if(l){var Te=function(){throw Error()};if(Object.defineProperty(Te.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(Te,[])}catch(pe){var ce=pe}Reflect.construct(a,[],Te)}else{try{Te.call()}catch(pe){ce=pe}a.call(Te.prototype)}}else{try{throw Error()}catch(pe){ce=pe}(Te=a())&&typeof Te.catch=="function"&&Te.catch(function(){})}}catch(pe){if(pe&&ce&&typeof pe.stack=="string")return[pe.stack,ce.stack]}return[null,null]}};h.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var g=Object.getOwnPropertyDescriptor(h.DetermineComponentFrameRoot,"name");g&&g.configurable&&Object.defineProperty(h.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var b=h.DetermineComponentFrameRoot(),w=b[0],R=b[1];if(w&&R){var K=w.split(`
`),le=R.split(`
`);for(g=h=0;h<K.length&&!K[h].includes("DetermineComponentFrameRoot");)h++;for(;g<le.length&&!le[g].includes("DetermineComponentFrameRoot");)g++;if(h===K.length||g===le.length)for(h=K.length-1,g=le.length-1;1<=h&&0<=g&&K[h]!==le[g];)g--;for(;1<=h&&0<=g;h--,g--)if(K[h]!==le[g]){if(h!==1||g!==1)do if(h--,g--,0>g||K[h]!==le[g]){var _e=`
`+K[h].replace(" at new "," at ");return a.displayName&&_e.includes("<anonymous>")&&(_e=_e.replace("<anonymous>",a.displayName)),_e}while(1<=h&&0<=g);break}}}finally{Ft=!1,Error.prepareStackTrace=u}return(u=a?a.displayName||a.name:"")?ct(u):""}function jt(a,l){switch(a.tag){case 26:case 27:case 5:return ct(a.type);case 16:return ct("Lazy");case 13:return a.child!==l&&l!==null?ct("Suspense Fallback"):ct("Suspense");case 19:return ct("SuspenseList");case 0:case 15:return Xe(a.type,!1);case 11:return Xe(a.type.render,!1);case 1:return Xe(a.type,!0);case 31:return ct("Activity");default:return""}}function pn(a){try{var l="",u=null;do l+=jt(a,u),u=a,a=a.return;while(a);return l}catch(h){return`
Error generating stack: `+h.message+`
`+h.stack}}var Pt=Object.prototype.hasOwnProperty,un=e.unstable_scheduleCallback,Ge=e.unstable_cancelCallback,gn=e.unstable_shouldYield,In=e.unstable_requestPaint,Xt=e.unstable_now,En=e.unstable_getCurrentPriorityLevel,me=e.unstable_ImmediatePriority,Ce=e.unstable_UserBlockingPriority,Ye=e.unstable_NormalPriority,dt=e.unstable_LowPriority,Ue=e.unstable_IdlePriority,bt=e.log,Re=e.unstable_setDisableYieldValue,Rt=null,At=null;function kt(a){if(typeof bt=="function"&&Re(a),At&&typeof At.setStrictMode=="function")try{At.setStrictMode(Rt,a)}catch{}}var Zt=Math.clz32?Math.clz32:H0,Zi=Math.log,Mr=Math.LN2;function H0(a){return a>>>=0,a===0?32:31-(Zi(a)/Mr|0)|0}var dl=256,eo=262144,hl=4194304;function $r(a){var l=a&42;if(l!==0)return l;switch(a&-a){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return a&261888;case 262144:case 524288:case 1048576:case 2097152:return a&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return a&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return a}}function W(a,l,u){var h=a.pendingLanes;if(h===0)return 0;var g=0,b=a.suspendedLanes,w=a.pingedLanes;a=a.warmLanes;var R=h&134217727;return R!==0?(h=R&~b,h!==0?g=$r(h):(w&=R,w!==0?g=$r(w):u||(u=R&~a,u!==0&&(g=$r(u))))):(R=h&~b,R!==0?g=$r(R):w!==0?g=$r(w):u||(u=h&~a,u!==0&&(g=$r(u)))),g===0?0:l!==0&&l!==g&&(l&b)===0&&(b=g&-g,u=l&-l,b>=u||b===32&&(u&4194048)!==0)?l:g}function ye(a,l){return(a.pendingLanes&~(a.suspendedLanes&~a.pingedLanes)&l)===0}function Fe(a,l){switch(a){case 1:case 2:case 4:case 8:case 64:return l+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return l+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function mt(){var a=hl;return hl<<=1,(hl&62914560)===0&&(hl=4194304),a}function Tn(a){for(var l=[],u=0;31>u;u++)l.push(a);return l}function cn(a,l){a.pendingLanes|=l,l!==268435456&&(a.suspendedLanes=0,a.pingedLanes=0,a.warmLanes=0)}function Ze(a,l,u,h,g,b){var w=a.pendingLanes;a.pendingLanes=u,a.suspendedLanes=0,a.pingedLanes=0,a.warmLanes=0,a.expiredLanes&=u,a.entangledLanes&=u,a.errorRecoveryDisabledLanes&=u,a.shellSuspendCounter=0;var R=a.entanglements,K=a.expirationTimes,le=a.hiddenUpdates;for(u=w&~u;0<u;){var _e=31-Zt(u),Te=1<<_e;R[_e]=0,K[_e]=-1;var ce=le[_e];if(ce!==null)for(le[_e]=null,_e=0;_e<ce.length;_e++){var pe=ce[_e];pe!==null&&(pe.lane&=-536870913)}u&=~Te}h!==0&&We(a,h,0),b!==0&&g===0&&a.tag!==0&&(a.suspendedLanes|=b&~(w&~l))}function We(a,l,u){a.pendingLanes|=l,a.suspendedLanes&=~l;var h=31-Zt(l);a.entangledLanes|=l,a.entanglements[h]=a.entanglements[h]|1073741824|u&261930}function ht(a,l){var u=a.entangledLanes|=l;for(a=a.entanglements;u;){var h=31-Zt(u),g=1<<h;g&l|a[h]&l&&(a[h]|=l),u&=~g}}function jn(a,l){var u=l&-l;return u=(u&42)!==0?1:Cn(u),(u&(a.suspendedLanes|l))!==0?0:u}function Cn(a){switch(a){case 2:a=1;break;case 8:a=4;break;case 32:a=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:a=128;break;case 268435456:a=134217728;break;default:a=0}return a}function ya(a){return a&=-a,2<a?8<a?(a&134217727)!==0?32:268435456:8:2}function to(){var a=ie.p;return a!==0?a:(a=window.event,a===void 0?32:B_(a.type))}function no(a,l){var u=ie.p;try{return ie.p=a,l()}finally{ie.p=u}}var Ji=Math.random().toString(36).slice(2),qn="__reactFiber$"+Ji,Sr="__reactProps$"+Ji,fs="__reactContainer$"+Ji,Su="__reactEvents$"+Ji,j0="__reactListeners$"+Ji,ro="__reactHandles$"+Ji,q0="__reactResources$"+Ji,fl="__reactMarker$"+Ji;function wu(a){delete a[qn],delete a[Sr],delete a[Su],delete a[j0],delete a[ro]}function Ir(a){var l=a[qn];if(l)return l;for(var u=a.parentNode;u;){if(l=u[fs]||u[qn]){if(u=l.alternate,l.child!==null||u!==null&&u.child!==null)for(a=E_(a);a!==null;){if(u=a[qn])return u;a=E_(a)}return l}a=u,u=a.parentNode}return null}function Ea(a){if(a=a[qn]||a[fs]){var l=a.tag;if(l===5||l===6||l===13||l===31||l===26||l===27||l===3)return a}return null}function ms(a){var l=a.tag;if(l===5||l===26||l===27||l===6)return a.stateNode;throw Error(r(33))}function ps(a){var l=a[q0];return l||(l=a[q0]={hoistableStyles:new Map,hoistableScripts:new Map}),l}function Xn(a){a[fl]=!0}var $0=new Set,ml={};function Ta(a,l){Me(a,l),Me(a+"Capture",l)}function Me(a,l){for(ml[a]=l,a=0;a<l.length;a++)$0.add(l[a])}var nt=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Ct={},Jt={};function $n(a){return Pt.call(Jt,a)?!0:Pt.call(Ct,a)?!1:nt.test(a)?Jt[a]=!0:(Ct[a]=!0,!1)}function wr(a,l,u){if($n(l))if(u===null)a.removeAttribute(l);else{switch(typeof u){case"undefined":case"function":case"symbol":a.removeAttribute(l);return;case"boolean":var h=l.toLowerCase().slice(0,5);if(h!=="data-"&&h!=="aria-"){a.removeAttribute(l);return}}a.setAttribute(l,""+u)}}function oi(a,l,u){if(u===null)a.removeAttribute(l);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":a.removeAttribute(l);return}a.setAttribute(l,""+u)}}function Gr(a,l,u,h){if(h===null)a.removeAttribute(u);else{switch(typeof h){case"undefined":case"function":case"symbol":case"boolean":a.removeAttribute(u);return}a.setAttributeNS(l,u,""+h)}}function bn(a){switch(typeof a){case"bigint":case"boolean":case"number":case"string":case"undefined":return a;case"object":return a;default:return""}}function ui(a){var l=a.type;return(a=a.nodeName)&&a.toLowerCase()==="input"&&(l==="checkbox"||l==="radio")}function G0(a,l,u){var h=Object.getOwnPropertyDescriptor(a.constructor.prototype,l);if(!a.hasOwnProperty(l)&&typeof h<"u"&&typeof h.get=="function"&&typeof h.set=="function"){var g=h.get,b=h.set;return Object.defineProperty(a,l,{configurable:!0,get:function(){return g.call(this)},set:function(w){u=""+w,b.call(this,w)}}),Object.defineProperty(a,l,{enumerable:h.enumerable}),{getValue:function(){return u},setValue:function(w){u=""+w},stopTracking:function(){a._valueTracker=null,delete a[l]}}}}function io(a){if(!a._valueTracker){var l=ui(a)?"checked":"value";a._valueTracker=G0(a,l,""+a[l])}}function Au(a){if(!a)return!1;var l=a._valueTracker;if(!l)return!0;var u=l.getValue(),h="";return a&&(h=ui(a)?a.checked?"true":"false":a.value),a=h,a!==u?(l.setValue(a),!0):!1}function ao(a){if(a=a||(typeof document<"u"?document:void 0),typeof a>"u")return null;try{return a.activeElement||a.body}catch{return a.body}}var om=/[\n"\\]/g;function Yr(a){return a.replace(om,function(l){return"\\"+l.charCodeAt(0).toString(16)+" "})}function ku(a,l,u,h,g,b,w,R){a.name="",w!=null&&typeof w!="function"&&typeof w!="symbol"&&typeof w!="boolean"?a.type=w:a.removeAttribute("type"),l!=null?w==="number"?(l===0&&a.value===""||a.value!=l)&&(a.value=""+bn(l)):a.value!==""+bn(l)&&(a.value=""+bn(l)):w!=="submit"&&w!=="reset"||a.removeAttribute("value"),l!=null?so(a,w,bn(l)):u!=null?so(a,w,bn(u)):h!=null&&a.removeAttribute("value"),g==null&&b!=null&&(a.defaultChecked=!!b),g!=null&&(a.checked=g&&typeof g!="function"&&typeof g!="symbol"),R!=null&&typeof R!="function"&&typeof R!="symbol"&&typeof R!="boolean"?a.name=""+bn(R):a.removeAttribute("name")}function pl(a,l,u,h,g,b,w,R){if(b!=null&&typeof b!="function"&&typeof b!="symbol"&&typeof b!="boolean"&&(a.type=b),l!=null||u!=null){if(!(b!=="submit"&&b!=="reset"||l!=null)){io(a);return}u=u!=null?""+bn(u):"",l=l!=null?""+bn(l):u,R||l===a.value||(a.value=l),a.defaultValue=l}h=h??g,h=typeof h!="function"&&typeof h!="symbol"&&!!h,a.checked=R?a.checked:!!h,a.defaultChecked=!!h,w!=null&&typeof w!="function"&&typeof w!="symbol"&&typeof w!="boolean"&&(a.name=w),io(a)}function so(a,l,u){l==="number"&&ao(a.ownerDocument)===a||a.defaultValue===""+u||(a.defaultValue=""+u)}function gr(a,l,u,h){if(a=a.options,l){l={};for(var g=0;g<u.length;g++)l["$"+u[g]]=!0;for(u=0;u<a.length;u++)g=l.hasOwnProperty("$"+a[u].value),a[u].selected!==g&&(a[u].selected=g),g&&h&&(a[u].defaultSelected=!0)}else{for(u=""+bn(u),l=null,g=0;g<a.length;g++){if(a[g].value===u){a[g].selected=!0,h&&(a[g].defaultSelected=!0);return}l!==null||a[g].disabled||(l=a[g])}l!==null&&(l.selected=!0)}}function Y0(a,l,u){if(l!=null&&(l=""+bn(l),l!==a.value&&(a.value=l),u==null)){a.defaultValue!==l&&(a.defaultValue=l);return}a.defaultValue=u!=null?""+bn(u):""}function lo(a,l,u,h){if(l==null){if(h!=null){if(u!=null)throw Error(r(92));if(de(h)){if(1<h.length)throw Error(r(93));h=h[0]}u=h}u==null&&(u=""),l=u}u=bn(l),a.defaultValue=u,h=a.textContent,h===u&&h!==""&&h!==null&&(a.value=h),io(a)}function ut(a,l){if(l){var u=a.firstChild;if(u&&u===a.lastChild&&u.nodeType===3){u.nodeValue=l;return}}a.textContent=l}var V0=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Qn(a,l,u){var h=l.indexOf("--")===0;u==null||typeof u=="boolean"||u===""?h?a.setProperty(l,""):l==="float"?a.cssFloat="":a[l]="":h?a.setProperty(l,u):typeof u!="number"||u===0||V0.has(l)?l==="float"?a.cssFloat=u:a[l]=(""+u).trim():a[l]=u+"px"}function en(a,l,u){if(l!=null&&typeof l!="object")throw Error(r(62));if(a=a.style,u!=null){for(var h in u)!u.hasOwnProperty(h)||l!=null&&l.hasOwnProperty(h)||(h.indexOf("--")===0?a.setProperty(h,""):h==="float"?a.cssFloat="":a[h]="");for(var g in l)h=l[g],l.hasOwnProperty(g)&&u[g]!==h&&Qn(a,g,h)}else for(var b in l)l.hasOwnProperty(b)&&Qn(a,b,l[b])}function gs(a){if(a.indexOf("-")===-1)return!1;switch(a){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var xa=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Cu=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function bs(a){return Cu.test(""+a)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":a}function Pe(){}var Je=null;function vt(a){return a=a.target||a.srcElement||window,a.correspondingUseElement&&(a=a.correspondingUseElement),a.nodeType===3?a.parentNode:a}var Bt=null,Dn=null;function wi(a){var l=Ea(a);if(l&&(a=l.stateNode)){var u=a[Sr]||null;e:switch(a=l.stateNode,l.type){case"input":if(ku(a,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name),l=u.name,u.type==="radio"&&l!=null){for(u=a;u.parentNode;)u=u.parentNode;for(u=u.querySelectorAll('input[name="'+Yr(""+l)+'"][type="radio"]'),l=0;l<u.length;l++){var h=u[l];if(h!==a&&h.form===a.form){var g=h[Sr]||null;if(!g)throw Error(r(90));ku(h,g.value,g.defaultValue,g.defaultValue,g.checked,g.defaultChecked,g.type,g.name)}}for(l=0;l<u.length;l++)h=u[l],h.form===a.form&&Au(h)}break e;case"textarea":Y0(a,u.value,u.defaultValue);break e;case"select":l=u.value,l!=null&&gr(a,!!u.multiple,l,!1)}}}var Nu=!1;function K0(a,l,u){if(Nu)return a(l,u);Nu=!0;try{var h=a(l);return h}finally{if(Nu=!1,(Bt!==null||Dn!==null)&&(Ld(),Bt&&(l=Bt,a=Dn,Dn=Bt=null,wi(l),a)))for(l=0;l<a.length;l++)wi(a[l])}}function Ou(a,l){var u=a.stateNode;if(u===null)return null;var h=u[Sr]||null;if(h===null)return null;u=h[l];e:switch(l){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(h=!h.disabled)||(a=a.type,h=!(a==="button"||a==="input"||a==="select"||a==="textarea")),a=!h;break e;default:a=!1}if(a)return null;if(u&&typeof u!="function")throw Error(r(231,l,typeof u));return u}var Sa=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),um=!1;if(Sa)try{var Ru={};Object.defineProperty(Ru,"passive",{get:function(){um=!0}}),window.addEventListener("test",Ru,Ru),window.removeEventListener("test",Ru,Ru)}catch{um=!1}var vs=null,cm=null,W0=null;function mv(){if(W0)return W0;var a,l=cm,u=l.length,h,g="value"in vs?vs.value:vs.textContent,b=g.length;for(a=0;a<u&&l[a]===g[a];a++);var w=u-a;for(h=1;h<=w&&l[u-h]===g[b-h];h++);return W0=g.slice(a,1<h?1-h:void 0)}function X0(a){var l=a.keyCode;return"charCode"in a?(a=a.charCode,a===0&&l===13&&(a=13)):a=l,a===10&&(a=13),32<=a||a===13?a:0}function Q0(){return!0}function pv(){return!1}function Vr(a){function l(u,h,g,b,w){this._reactName=u,this._targetInst=g,this.type=h,this.nativeEvent=b,this.target=w,this.currentTarget=null;for(var R in a)a.hasOwnProperty(R)&&(u=a[R],this[R]=u?u(b):b[R]);return this.isDefaultPrevented=(b.defaultPrevented!=null?b.defaultPrevented:b.returnValue===!1)?Q0:pv,this.isPropagationStopped=pv,this}return p(l.prototype,{preventDefault:function(){this.defaultPrevented=!0;var u=this.nativeEvent;u&&(u.preventDefault?u.preventDefault():typeof u.returnValue!="unknown"&&(u.returnValue=!1),this.isDefaultPrevented=Q0)},stopPropagation:function(){var u=this.nativeEvent;u&&(u.stopPropagation?u.stopPropagation():typeof u.cancelBubble!="unknown"&&(u.cancelBubble=!0),this.isPropagationStopped=Q0)},persist:function(){},isPersistent:Q0}),l}var gl={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(a){return a.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Z0=Vr(gl),Mu=p({},gl,{view:0,detail:0}),w9=Vr(Mu),dm,hm,Iu,J0=p({},Mu,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:mm,button:0,buttons:0,relatedTarget:function(a){return a.relatedTarget===void 0?a.fromElement===a.srcElement?a.toElement:a.fromElement:a.relatedTarget},movementX:function(a){return"movementX"in a?a.movementX:(a!==Iu&&(Iu&&a.type==="mousemove"?(dm=a.screenX-Iu.screenX,hm=a.screenY-Iu.screenY):hm=dm=0,Iu=a),dm)},movementY:function(a){return"movementY"in a?a.movementY:hm}}),gv=Vr(J0),A9=p({},J0,{dataTransfer:0}),k9=Vr(A9),C9=p({},Mu,{relatedTarget:0}),fm=Vr(C9),N9=p({},gl,{animationName:0,elapsedTime:0,pseudoElement:0}),O9=Vr(N9),R9=p({},gl,{clipboardData:function(a){return"clipboardData"in a?a.clipboardData:window.clipboardData}}),M9=Vr(R9),I9=p({},gl,{data:0}),bv=Vr(I9),D9={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},L9={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},P9={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function B9(a){var l=this.nativeEvent;return l.getModifierState?l.getModifierState(a):(a=P9[a])?!!l[a]:!1}function mm(){return B9}var U9=p({},Mu,{key:function(a){if(a.key){var l=D9[a.key]||a.key;if(l!=="Unidentified")return l}return a.type==="keypress"?(a=X0(a),a===13?"Enter":String.fromCharCode(a)):a.type==="keydown"||a.type==="keyup"?L9[a.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:mm,charCode:function(a){return a.type==="keypress"?X0(a):0},keyCode:function(a){return a.type==="keydown"||a.type==="keyup"?a.keyCode:0},which:function(a){return a.type==="keypress"?X0(a):a.type==="keydown"||a.type==="keyup"?a.keyCode:0}}),z9=Vr(U9),F9=p({},J0,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),vv=Vr(F9),H9=p({},Mu,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:mm}),j9=Vr(H9),q9=p({},gl,{propertyName:0,elapsedTime:0,pseudoElement:0}),$9=Vr(q9),G9=p({},J0,{deltaX:function(a){return"deltaX"in a?a.deltaX:"wheelDeltaX"in a?-a.wheelDeltaX:0},deltaY:function(a){return"deltaY"in a?a.deltaY:"wheelDeltaY"in a?-a.wheelDeltaY:"wheelDelta"in a?-a.wheelDelta:0},deltaZ:0,deltaMode:0}),Y9=Vr(G9),V9=p({},gl,{newState:0,oldState:0}),K9=Vr(V9),W9=[9,13,27,32],pm=Sa&&"CompositionEvent"in window,Du=null;Sa&&"documentMode"in document&&(Du=document.documentMode);var X9=Sa&&"TextEvent"in window&&!Du,_v=Sa&&(!pm||Du&&8<Du&&11>=Du),yv=" ",Ev=!1;function Tv(a,l){switch(a){case"keyup":return W9.indexOf(l.keyCode)!==-1;case"keydown":return l.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function xv(a){return a=a.detail,typeof a=="object"&&"data"in a?a.data:null}var oo=!1;function Q9(a,l){switch(a){case"compositionend":return xv(l);case"keypress":return l.which!==32?null:(Ev=!0,yv);case"textInput":return a=l.data,a===yv&&Ev?null:a;default:return null}}function Z9(a,l){if(oo)return a==="compositionend"||!pm&&Tv(a,l)?(a=mv(),W0=cm=vs=null,oo=!1,a):null;switch(a){case"paste":return null;case"keypress":if(!(l.ctrlKey||l.altKey||l.metaKey)||l.ctrlKey&&l.altKey){if(l.char&&1<l.char.length)return l.char;if(l.which)return String.fromCharCode(l.which)}return null;case"compositionend":return _v&&l.locale!=="ko"?null:l.data;default:return null}}var J9={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Sv(a){var l=a&&a.nodeName&&a.nodeName.toLowerCase();return l==="input"?!!J9[a.type]:l==="textarea"}function wv(a,l,u,h){Bt?Dn?Dn.push(h):Dn=[h]:Bt=h,l=jd(l,"onChange"),0<l.length&&(u=new Z0("onChange","change",null,u,h),a.push({event:u,listeners:l}))}var Lu=null,Pu=null;function ew(a){l_(a,0)}function ed(a){var l=ms(a);if(Au(l))return a}function Av(a,l){if(a==="change")return l}var kv=!1;if(Sa){var gm;if(Sa){var bm="oninput"in document;if(!bm){var Cv=document.createElement("div");Cv.setAttribute("oninput","return;"),bm=typeof Cv.oninput=="function"}gm=bm}else gm=!1;kv=gm&&(!document.documentMode||9<document.documentMode)}function Nv(){Lu&&(Lu.detachEvent("onpropertychange",Ov),Pu=Lu=null)}function Ov(a){if(a.propertyName==="value"&&ed(Pu)){var l=[];wv(l,Pu,a,vt(a)),K0(ew,l)}}function tw(a,l,u){a==="focusin"?(Nv(),Lu=l,Pu=u,Lu.attachEvent("onpropertychange",Ov)):a==="focusout"&&Nv()}function nw(a){if(a==="selectionchange"||a==="keyup"||a==="keydown")return ed(Pu)}function rw(a,l){if(a==="click")return ed(l)}function iw(a,l){if(a==="input"||a==="change")return ed(l)}function aw(a,l){return a===l&&(a!==0||1/a===1/l)||a!==a&&l!==l}var ci=typeof Object.is=="function"?Object.is:aw;function Bu(a,l){if(ci(a,l))return!0;if(typeof a!="object"||a===null||typeof l!="object"||l===null)return!1;var u=Object.keys(a),h=Object.keys(l);if(u.length!==h.length)return!1;for(h=0;h<u.length;h++){var g=u[h];if(!Pt.call(l,g)||!ci(a[g],l[g]))return!1}return!0}function Rv(a){for(;a&&a.firstChild;)a=a.firstChild;return a}function Mv(a,l){var u=Rv(a);a=0;for(var h;u;){if(u.nodeType===3){if(h=a+u.textContent.length,a<=l&&h>=l)return{node:u,offset:l-a};a=h}e:{for(;u;){if(u.nextSibling){u=u.nextSibling;break e}u=u.parentNode}u=void 0}u=Rv(u)}}function Iv(a,l){return a&&l?a===l?!0:a&&a.nodeType===3?!1:l&&l.nodeType===3?Iv(a,l.parentNode):"contains"in a?a.contains(l):a.compareDocumentPosition?!!(a.compareDocumentPosition(l)&16):!1:!1}function Dv(a){a=a!=null&&a.ownerDocument!=null&&a.ownerDocument.defaultView!=null?a.ownerDocument.defaultView:window;for(var l=ao(a.document);l instanceof a.HTMLIFrameElement;){try{var u=typeof l.contentWindow.location.href=="string"}catch{u=!1}if(u)a=l.contentWindow;else break;l=ao(a.document)}return l}function vm(a){var l=a&&a.nodeName&&a.nodeName.toLowerCase();return l&&(l==="input"&&(a.type==="text"||a.type==="search"||a.type==="tel"||a.type==="url"||a.type==="password")||l==="textarea"||a.contentEditable==="true")}var sw=Sa&&"documentMode"in document&&11>=document.documentMode,uo=null,_m=null,Uu=null,ym=!1;function Lv(a,l,u){var h=u.window===u?u.document:u.nodeType===9?u:u.ownerDocument;ym||uo==null||uo!==ao(h)||(h=uo,"selectionStart"in h&&vm(h)?h={start:h.selectionStart,end:h.selectionEnd}:(h=(h.ownerDocument&&h.ownerDocument.defaultView||window).getSelection(),h={anchorNode:h.anchorNode,anchorOffset:h.anchorOffset,focusNode:h.focusNode,focusOffset:h.focusOffset}),Uu&&Bu(Uu,h)||(Uu=h,h=jd(_m,"onSelect"),0<h.length&&(l=new Z0("onSelect","select",null,l,u),a.push({event:l,listeners:h}),l.target=uo)))}function bl(a,l){var u={};return u[a.toLowerCase()]=l.toLowerCase(),u["Webkit"+a]="webkit"+l,u["Moz"+a]="moz"+l,u}var co={animationend:bl("Animation","AnimationEnd"),animationiteration:bl("Animation","AnimationIteration"),animationstart:bl("Animation","AnimationStart"),transitionrun:bl("Transition","TransitionRun"),transitionstart:bl("Transition","TransitionStart"),transitioncancel:bl("Transition","TransitionCancel"),transitionend:bl("Transition","TransitionEnd")},Em={},Pv={};Sa&&(Pv=document.createElement("div").style,"AnimationEvent"in window||(delete co.animationend.animation,delete co.animationiteration.animation,delete co.animationstart.animation),"TransitionEvent"in window||delete co.transitionend.transition);function vl(a){if(Em[a])return Em[a];if(!co[a])return a;var l=co[a],u;for(u in l)if(l.hasOwnProperty(u)&&u in Pv)return Em[a]=l[u];return a}var Bv=vl("animationend"),Uv=vl("animationiteration"),zv=vl("animationstart"),lw=vl("transitionrun"),ow=vl("transitionstart"),uw=vl("transitioncancel"),Fv=vl("transitionend"),Hv=new Map,Tm="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Tm.push("scrollEnd");function qi(a,l){Hv.set(a,l),Ta(l,[a])}var td=typeof reportError=="function"?reportError:function(a){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var l=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof a=="object"&&a!==null&&typeof a.message=="string"?String(a.message):String(a),error:a});if(!window.dispatchEvent(l))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",a);return}console.error(a)},Ai=[],ho=0,xm=0;function nd(){for(var a=ho,l=xm=ho=0;l<a;){var u=Ai[l];Ai[l++]=null;var h=Ai[l];Ai[l++]=null;var g=Ai[l];Ai[l++]=null;var b=Ai[l];if(Ai[l++]=null,h!==null&&g!==null){var w=h.pending;w===null?g.next=g:(g.next=w.next,w.next=g),h.pending=g}b!==0&&jv(u,g,b)}}function rd(a,l,u,h){Ai[ho++]=a,Ai[ho++]=l,Ai[ho++]=u,Ai[ho++]=h,xm|=h,a.lanes|=h,a=a.alternate,a!==null&&(a.lanes|=h)}function Sm(a,l,u,h){return rd(a,l,u,h),id(a)}function _l(a,l){return rd(a,null,null,l),id(a)}function jv(a,l,u){a.lanes|=u;var h=a.alternate;h!==null&&(h.lanes|=u);for(var g=!1,b=a.return;b!==null;)b.childLanes|=u,h=b.alternate,h!==null&&(h.childLanes|=u),b.tag===22&&(a=b.stateNode,a===null||a._visibility&1||(g=!0)),a=b,b=b.return;return a.tag===3?(b=a.stateNode,g&&l!==null&&(g=31-Zt(u),a=b.hiddenUpdates,h=a[g],h===null?a[g]=[l]:h.push(l),l.lane=u|536870912),b):null}function id(a){if(50<sc)throw sc=0,Ip=null,Error(r(185));for(var l=a.return;l!==null;)a=l,l=a.return;return a.tag===3?a.stateNode:null}var fo={};function cw(a,l,u,h){this.tag=a,this.key=u,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=l,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=h,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function di(a,l,u,h){return new cw(a,l,u,h)}function wm(a){return a=a.prototype,!(!a||!a.isReactComponent)}function wa(a,l){var u=a.alternate;return u===null?(u=di(a.tag,l,a.key,a.mode),u.elementType=a.elementType,u.type=a.type,u.stateNode=a.stateNode,u.alternate=a,a.alternate=u):(u.pendingProps=l,u.type=a.type,u.flags=0,u.subtreeFlags=0,u.deletions=null),u.flags=a.flags&65011712,u.childLanes=a.childLanes,u.lanes=a.lanes,u.child=a.child,u.memoizedProps=a.memoizedProps,u.memoizedState=a.memoizedState,u.updateQueue=a.updateQueue,l=a.dependencies,u.dependencies=l===null?null:{lanes:l.lanes,firstContext:l.firstContext},u.sibling=a.sibling,u.index=a.index,u.ref=a.ref,u.refCleanup=a.refCleanup,u}function qv(a,l){a.flags&=65011714;var u=a.alternate;return u===null?(a.childLanes=0,a.lanes=l,a.child=null,a.subtreeFlags=0,a.memoizedProps=null,a.memoizedState=null,a.updateQueue=null,a.dependencies=null,a.stateNode=null):(a.childLanes=u.childLanes,a.lanes=u.lanes,a.child=u.child,a.subtreeFlags=0,a.deletions=null,a.memoizedProps=u.memoizedProps,a.memoizedState=u.memoizedState,a.updateQueue=u.updateQueue,a.type=u.type,l=u.dependencies,a.dependencies=l===null?null:{lanes:l.lanes,firstContext:l.firstContext}),a}function ad(a,l,u,h,g,b){var w=0;if(h=a,typeof a=="function")wm(a)&&(w=1);else if(typeof a=="string")w=pA(a,u,Ae.current)?26:a==="html"||a==="head"||a==="body"?27:5;else e:switch(a){case te:return a=di(31,u,l,g),a.elementType=te,a.lanes=b,a;case x:return yl(u.children,g,b,l);case k:w=8,g|=24;break;case A:return a=di(12,u,l,g|2),a.elementType=A,a.lanes=b,a;case V:return a=di(13,u,l,g),a.elementType=V,a.lanes=b,a;case B:return a=di(19,u,l,g),a.elementType=B,a.lanes=b,a;default:if(typeof a=="object"&&a!==null)switch(a.$$typeof){case I:w=10;break e;case O:w=9;break e;case $:w=11;break e;case Z:w=14;break e;case ee:w=16,h=null;break e}w=29,u=Error(r(130,a===null?"null":typeof a,"")),h=null}return l=di(w,u,l,g),l.elementType=a,l.type=h,l.lanes=b,l}function yl(a,l,u,h){return a=di(7,a,h,l),a.lanes=u,a}function Am(a,l,u){return a=di(6,a,null,l),a.lanes=u,a}function $v(a){var l=di(18,null,null,0);return l.stateNode=a,l}function km(a,l,u){return l=di(4,a.children!==null?a.children:[],a.key,l),l.lanes=u,l.stateNode={containerInfo:a.containerInfo,pendingChildren:null,implementation:a.implementation},l}var Gv=new WeakMap;function ki(a,l){if(typeof a=="object"&&a!==null){var u=Gv.get(a);return u!==void 0?u:(l={value:a,source:l,stack:pn(l)},Gv.set(a,l),l)}return{value:a,source:l,stack:pn(l)}}var mo=[],po=0,sd=null,zu=0,Ci=[],Ni=0,_s=null,ea=1,ta="";function Aa(a,l){mo[po++]=zu,mo[po++]=sd,sd=a,zu=l}function Yv(a,l,u){Ci[Ni++]=ea,Ci[Ni++]=ta,Ci[Ni++]=_s,_s=a;var h=ea;a=ta;var g=32-Zt(h)-1;h&=~(1<<g),u+=1;var b=32-Zt(l)+g;if(30<b){var w=g-g%5;b=(h&(1<<w)-1).toString(32),h>>=w,g-=w,ea=1<<32-Zt(l)+g|u<<g|h,ta=b+a}else ea=1<<b|u<<g|h,ta=a}function Cm(a){a.return!==null&&(Aa(a,1),Yv(a,1,0))}function Nm(a){for(;a===sd;)sd=mo[--po],mo[po]=null,zu=mo[--po],mo[po]=null;for(;a===_s;)_s=Ci[--Ni],Ci[Ni]=null,ta=Ci[--Ni],Ci[Ni]=null,ea=Ci[--Ni],Ci[Ni]=null}function Vv(a,l){Ci[Ni++]=ea,Ci[Ni++]=ta,Ci[Ni++]=_s,ea=l.id,ta=l.overflow,_s=a}var br=null,xn=null,Ht=!1,ys=null,Oi=!1,Om=Error(r(519));function Es(a){var l=Error(r(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Fu(ki(l,a)),Om}function Kv(a){var l=a.stateNode,u=a.type,h=a.memoizedProps;switch(l[qn]=a,l[Sr]=h,u){case"dialog":It("cancel",l),It("close",l);break;case"iframe":case"object":case"embed":It("load",l);break;case"video":case"audio":for(u=0;u<oc.length;u++)It(oc[u],l);break;case"source":It("error",l);break;case"img":case"image":case"link":It("error",l),It("load",l);break;case"details":It("toggle",l);break;case"input":It("invalid",l),pl(l,h.value,h.defaultValue,h.checked,h.defaultChecked,h.type,h.name,!0);break;case"select":It("invalid",l);break;case"textarea":It("invalid",l),lo(l,h.value,h.defaultValue,h.children)}u=h.children,typeof u!="string"&&typeof u!="number"&&typeof u!="bigint"||l.textContent===""+u||h.suppressHydrationWarning===!0||d_(l.textContent,u)?(h.popover!=null&&(It("beforetoggle",l),It("toggle",l)),h.onScroll!=null&&It("scroll",l),h.onScrollEnd!=null&&It("scrollend",l),h.onClick!=null&&(l.onclick=Pe),l=!0):l=!1,l||Es(a,!0)}function Wv(a){for(br=a.return;br;)switch(br.tag){case 5:case 31:case 13:Oi=!1;return;case 27:case 3:Oi=!0;return;default:br=br.return}}function go(a){if(a!==br)return!1;if(!Ht)return Wv(a),Ht=!0,!1;var l=a.tag,u;if((u=l!==3&&l!==27)&&((u=l===5)&&(u=a.type,u=!(u!=="form"&&u!=="button")||Kp(a.type,a.memoizedProps)),u=!u),u&&xn&&Es(a),Wv(a),l===13){if(a=a.memoizedState,a=a!==null?a.dehydrated:null,!a)throw Error(r(317));xn=y_(a)}else if(l===31){if(a=a.memoizedState,a=a!==null?a.dehydrated:null,!a)throw Error(r(317));xn=y_(a)}else l===27?(l=xn,Ls(a.type)?(a=Jp,Jp=null,xn=a):xn=l):xn=br?Mi(a.stateNode.nextSibling):null;return!0}function El(){xn=br=null,Ht=!1}function Rm(){var a=ys;return a!==null&&(Qr===null?Qr=a:Qr.push.apply(Qr,a),ys=null),a}function Fu(a){ys===null?ys=[a]:ys.push(a)}var Mm=z(null),Tl=null,ka=null;function Ts(a,l,u){D(Mm,l._currentValue),l._currentValue=u}function Ca(a){a._currentValue=Mm.current,J(Mm)}function Im(a,l,u){for(;a!==null;){var h=a.alternate;if((a.childLanes&l)!==l?(a.childLanes|=l,h!==null&&(h.childLanes|=l)):h!==null&&(h.childLanes&l)!==l&&(h.childLanes|=l),a===u)break;a=a.return}}function Dm(a,l,u,h){var g=a.child;for(g!==null&&(g.return=a);g!==null;){var b=g.dependencies;if(b!==null){var w=g.child;b=b.firstContext;e:for(;b!==null;){var R=b;b=g;for(var K=0;K<l.length;K++)if(R.context===l[K]){b.lanes|=u,R=b.alternate,R!==null&&(R.lanes|=u),Im(b.return,u,a),h||(w=null);break e}b=R.next}}else if(g.tag===18){if(w=g.return,w===null)throw Error(r(341));w.lanes|=u,b=w.alternate,b!==null&&(b.lanes|=u),Im(w,u,a),w=null}else w=g.child;if(w!==null)w.return=g;else for(w=g;w!==null;){if(w===a){w=null;break}if(g=w.sibling,g!==null){g.return=w.return,w=g;break}w=w.return}g=w}}function bo(a,l,u,h){a=null;for(var g=l,b=!1;g!==null;){if(!b){if((g.flags&524288)!==0)b=!0;else if((g.flags&262144)!==0)break}if(g.tag===10){var w=g.alternate;if(w===null)throw Error(r(387));if(w=w.memoizedProps,w!==null){var R=g.type;ci(g.pendingProps.value,w.value)||(a!==null?a.push(R):a=[R])}}else if(g===at.current){if(w=g.alternate,w===null)throw Error(r(387));w.memoizedState.memoizedState!==g.memoizedState.memoizedState&&(a!==null?a.push(fc):a=[fc])}g=g.return}a!==null&&Dm(l,a,u,h),l.flags|=262144}function ld(a){for(a=a.firstContext;a!==null;){if(!ci(a.context._currentValue,a.memoizedValue))return!0;a=a.next}return!1}function xl(a){Tl=a,ka=null,a=a.dependencies,a!==null&&(a.firstContext=null)}function vr(a){return Xv(Tl,a)}function od(a,l){return Tl===null&&xl(a),Xv(a,l)}function Xv(a,l){var u=l._currentValue;if(l={context:l,memoizedValue:u,next:null},ka===null){if(a===null)throw Error(r(308));ka=l,a.dependencies={lanes:0,firstContext:l},a.flags|=524288}else ka=ka.next=l;return u}var dw=typeof AbortController<"u"?AbortController:function(){var a=[],l=this.signal={aborted:!1,addEventListener:function(u,h){a.push(h)}};this.abort=function(){l.aborted=!0,a.forEach(function(u){return u()})}},hw=e.unstable_scheduleCallback,fw=e.unstable_NormalPriority,Zn={$$typeof:I,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Lm(){return{controller:new dw,data:new Map,refCount:0}}function Hu(a){a.refCount--,a.refCount===0&&hw(fw,function(){a.controller.abort()})}var ju=null,Pm=0,vo=0,_o=null;function mw(a,l){if(ju===null){var u=ju=[];Pm=0,vo=zp(),_o={status:"pending",value:void 0,then:function(h){u.push(h)}}}return Pm++,l.then(Qv,Qv),l}function Qv(){if(--Pm===0&&ju!==null){_o!==null&&(_o.status="fulfilled");var a=ju;ju=null,vo=0,_o=null;for(var l=0;l<a.length;l++)(0,a[l])()}}function pw(a,l){var u=[],h={status:"pending",value:null,reason:null,then:function(g){u.push(g)}};return a.then(function(){h.status="fulfilled",h.value=l;for(var g=0;g<u.length;g++)(0,u[g])(l)},function(g){for(h.status="rejected",h.reason=g,g=0;g<u.length;g++)(0,u[g])(void 0)}),h}var Zv=H.S;H.S=function(a,l){L3=Xt(),typeof l=="object"&&l!==null&&typeof l.then=="function"&&mw(a,l),Zv!==null&&Zv(a,l)};var Sl=z(null);function Bm(){var a=Sl.current;return a!==null?a:dn.pooledCache}function ud(a,l){l===null?D(Sl,Sl.current):D(Sl,l.pool)}function Jv(){var a=Bm();return a===null?null:{parent:Zn._currentValue,pool:a}}var yo=Error(r(460)),Um=Error(r(474)),cd=Error(r(542)),dd={then:function(){}};function e4(a){return a=a.status,a==="fulfilled"||a==="rejected"}function t4(a,l,u){switch(u=a[u],u===void 0?a.push(l):u!==l&&(l.then(Pe,Pe),l=u),l.status){case"fulfilled":return l.value;case"rejected":throw a=l.reason,r4(a),a;default:if(typeof l.status=="string")l.then(Pe,Pe);else{if(a=dn,a!==null&&100<a.shellSuspendCounter)throw Error(r(482));a=l,a.status="pending",a.then(function(h){if(l.status==="pending"){var g=l;g.status="fulfilled",g.value=h}},function(h){if(l.status==="pending"){var g=l;g.status="rejected",g.reason=h}})}switch(l.status){case"fulfilled":return l.value;case"rejected":throw a=l.reason,r4(a),a}throw Al=l,yo}}function wl(a){try{var l=a._init;return l(a._payload)}catch(u){throw u!==null&&typeof u=="object"&&typeof u.then=="function"?(Al=u,yo):u}}var Al=null;function n4(){if(Al===null)throw Error(r(459));var a=Al;return Al=null,a}function r4(a){if(a===yo||a===cd)throw Error(r(483))}var Eo=null,qu=0;function hd(a){var l=qu;return qu+=1,Eo===null&&(Eo=[]),t4(Eo,a,l)}function $u(a,l){l=l.props.ref,a.ref=l!==void 0?l:null}function fd(a,l){throw l.$$typeof===v?Error(r(525)):(a=Object.prototype.toString.call(l),Error(r(31,a==="[object Object]"?"object with keys {"+Object.keys(l).join(", ")+"}":a)))}function i4(a){function l(ne,X){if(a){var ae=ne.deletions;ae===null?(ne.deletions=[X],ne.flags|=16):ae.push(X)}}function u(ne,X){if(!a)return null;for(;X!==null;)l(ne,X),X=X.sibling;return null}function h(ne){for(var X=new Map;ne!==null;)ne.key!==null?X.set(ne.key,ne):X.set(ne.index,ne),ne=ne.sibling;return X}function g(ne,X){return ne=wa(ne,X),ne.index=0,ne.sibling=null,ne}function b(ne,X,ae){return ne.index=ae,a?(ae=ne.alternate,ae!==null?(ae=ae.index,ae<X?(ne.flags|=67108866,X):ae):(ne.flags|=67108866,X)):(ne.flags|=1048576,X)}function w(ne){return a&&ne.alternate===null&&(ne.flags|=67108866),ne}function R(ne,X,ae,Ee){return X===null||X.tag!==6?(X=Am(ae,ne.mode,Ee),X.return=ne,X):(X=g(X,ae),X.return=ne,X)}function K(ne,X,ae,Ee){var rt=ae.type;return rt===x?_e(ne,X,ae.props.children,Ee,ae.key):X!==null&&(X.elementType===rt||typeof rt=="object"&&rt!==null&&rt.$$typeof===ee&&wl(rt)===X.type)?(X=g(X,ae.props),$u(X,ae),X.return=ne,X):(X=ad(ae.type,ae.key,ae.props,null,ne.mode,Ee),$u(X,ae),X.return=ne,X)}function le(ne,X,ae,Ee){return X===null||X.tag!==4||X.stateNode.containerInfo!==ae.containerInfo||X.stateNode.implementation!==ae.implementation?(X=km(ae,ne.mode,Ee),X.return=ne,X):(X=g(X,ae.children||[]),X.return=ne,X)}function _e(ne,X,ae,Ee,rt){return X===null||X.tag!==7?(X=yl(ae,ne.mode,Ee,rt),X.return=ne,X):(X=g(X,ae),X.return=ne,X)}function Te(ne,X,ae){if(typeof X=="string"&&X!==""||typeof X=="number"||typeof X=="bigint")return X=Am(""+X,ne.mode,ae),X.return=ne,X;if(typeof X=="object"&&X!==null){switch(X.$$typeof){case _:return ae=ad(X.type,X.key,X.props,null,ne.mode,ae),$u(ae,X),ae.return=ne,ae;case T:return X=km(X,ne.mode,ae),X.return=ne,X;case ee:return X=wl(X),Te(ne,X,ae)}if(de(X)||he(X))return X=yl(X,ne.mode,ae,null),X.return=ne,X;if(typeof X.then=="function")return Te(ne,hd(X),ae);if(X.$$typeof===I)return Te(ne,od(ne,X),ae);fd(ne,X)}return null}function ce(ne,X,ae,Ee){var rt=X!==null?X.key:null;if(typeof ae=="string"&&ae!==""||typeof ae=="number"||typeof ae=="bigint")return rt!==null?null:R(ne,X,""+ae,Ee);if(typeof ae=="object"&&ae!==null){switch(ae.$$typeof){case _:return ae.key===rt?K(ne,X,ae,Ee):null;case T:return ae.key===rt?le(ne,X,ae,Ee):null;case ee:return ae=wl(ae),ce(ne,X,ae,Ee)}if(de(ae)||he(ae))return rt!==null?null:_e(ne,X,ae,Ee,null);if(typeof ae.then=="function")return ce(ne,X,hd(ae),Ee);if(ae.$$typeof===I)return ce(ne,X,od(ne,ae),Ee);fd(ne,ae)}return null}function pe(ne,X,ae,Ee,rt){if(typeof Ee=="string"&&Ee!==""||typeof Ee=="number"||typeof Ee=="bigint")return ne=ne.get(ae)||null,R(X,ne,""+Ee,rt);if(typeof Ee=="object"&&Ee!==null){switch(Ee.$$typeof){case _:return ne=ne.get(Ee.key===null?ae:Ee.key)||null,K(X,ne,Ee,rt);case T:return ne=ne.get(Ee.key===null?ae:Ee.key)||null,le(X,ne,Ee,rt);case ee:return Ee=wl(Ee),pe(ne,X,ae,Ee,rt)}if(de(Ee)||he(Ee))return ne=ne.get(ae)||null,_e(X,ne,Ee,rt,null);if(typeof Ee.then=="function")return pe(ne,X,ae,hd(Ee),rt);if(Ee.$$typeof===I)return pe(ne,X,ae,od(X,Ee),rt);fd(X,Ee)}return null}function Qe(ne,X,ae,Ee){for(var rt=null,Gt=null,et=X,xt=X=0,zt=null;et!==null&&xt<ae.length;xt++){et.index>xt?(zt=et,et=null):zt=et.sibling;var Yt=ce(ne,et,ae[xt],Ee);if(Yt===null){et===null&&(et=zt);break}a&&et&&Yt.alternate===null&&l(ne,et),X=b(Yt,X,xt),Gt===null?rt=Yt:Gt.sibling=Yt,Gt=Yt,et=zt}if(xt===ae.length)return u(ne,et),Ht&&Aa(ne,xt),rt;if(et===null){for(;xt<ae.length;xt++)et=Te(ne,ae[xt],Ee),et!==null&&(X=b(et,X,xt),Gt===null?rt=et:Gt.sibling=et,Gt=et);return Ht&&Aa(ne,xt),rt}for(et=h(et);xt<ae.length;xt++)zt=pe(et,ne,xt,ae[xt],Ee),zt!==null&&(a&&zt.alternate!==null&&et.delete(zt.key===null?xt:zt.key),X=b(zt,X,xt),Gt===null?rt=zt:Gt.sibling=zt,Gt=zt);return a&&et.forEach(function(Fs){return l(ne,Fs)}),Ht&&Aa(ne,xt),rt}function ot(ne,X,ae,Ee){if(ae==null)throw Error(r(151));for(var rt=null,Gt=null,et=X,xt=X=0,zt=null,Yt=ae.next();et!==null&&!Yt.done;xt++,Yt=ae.next()){et.index>xt?(zt=et,et=null):zt=et.sibling;var Fs=ce(ne,et,Yt.value,Ee);if(Fs===null){et===null&&(et=zt);break}a&&et&&Fs.alternate===null&&l(ne,et),X=b(Fs,X,xt),Gt===null?rt=Fs:Gt.sibling=Fs,Gt=Fs,et=zt}if(Yt.done)return u(ne,et),Ht&&Aa(ne,xt),rt;if(et===null){for(;!Yt.done;xt++,Yt=ae.next())Yt=Te(ne,Yt.value,Ee),Yt!==null&&(X=b(Yt,X,xt),Gt===null?rt=Yt:Gt.sibling=Yt,Gt=Yt);return Ht&&Aa(ne,xt),rt}for(et=h(et);!Yt.done;xt++,Yt=ae.next())Yt=pe(et,ne,xt,Yt.value,Ee),Yt!==null&&(a&&Yt.alternate!==null&&et.delete(Yt.key===null?xt:Yt.key),X=b(Yt,X,xt),Gt===null?rt=Yt:Gt.sibling=Yt,Gt=Yt);return a&&et.forEach(function(AA){return l(ne,AA)}),Ht&&Aa(ne,xt),rt}function ln(ne,X,ae,Ee){if(typeof ae=="object"&&ae!==null&&ae.type===x&&ae.key===null&&(ae=ae.props.children),typeof ae=="object"&&ae!==null){switch(ae.$$typeof){case _:e:{for(var rt=ae.key;X!==null;){if(X.key===rt){if(rt=ae.type,rt===x){if(X.tag===7){u(ne,X.sibling),Ee=g(X,ae.props.children),Ee.return=ne,ne=Ee;break e}}else if(X.elementType===rt||typeof rt=="object"&&rt!==null&&rt.$$typeof===ee&&wl(rt)===X.type){u(ne,X.sibling),Ee=g(X,ae.props),$u(Ee,ae),Ee.return=ne,ne=Ee;break e}u(ne,X);break}else l(ne,X);X=X.sibling}ae.type===x?(Ee=yl(ae.props.children,ne.mode,Ee,ae.key),Ee.return=ne,ne=Ee):(Ee=ad(ae.type,ae.key,ae.props,null,ne.mode,Ee),$u(Ee,ae),Ee.return=ne,ne=Ee)}return w(ne);case T:e:{for(rt=ae.key;X!==null;){if(X.key===rt)if(X.tag===4&&X.stateNode.containerInfo===ae.containerInfo&&X.stateNode.implementation===ae.implementation){u(ne,X.sibling),Ee=g(X,ae.children||[]),Ee.return=ne,ne=Ee;break e}else{u(ne,X);break}else l(ne,X);X=X.sibling}Ee=km(ae,ne.mode,Ee),Ee.return=ne,ne=Ee}return w(ne);case ee:return ae=wl(ae),ln(ne,X,ae,Ee)}if(de(ae))return Qe(ne,X,ae,Ee);if(he(ae)){if(rt=he(ae),typeof rt!="function")throw Error(r(150));return ae=rt.call(ae),ot(ne,X,ae,Ee)}if(typeof ae.then=="function")return ln(ne,X,hd(ae),Ee);if(ae.$$typeof===I)return ln(ne,X,od(ne,ae),Ee);fd(ne,ae)}return typeof ae=="string"&&ae!==""||typeof ae=="number"||typeof ae=="bigint"?(ae=""+ae,X!==null&&X.tag===6?(u(ne,X.sibling),Ee=g(X,ae),Ee.return=ne,ne=Ee):(u(ne,X),Ee=Am(ae,ne.mode,Ee),Ee.return=ne,ne=Ee),w(ne)):u(ne,X)}return function(ne,X,ae,Ee){try{qu=0;var rt=ln(ne,X,ae,Ee);return Eo=null,rt}catch(et){if(et===yo||et===cd)throw et;var Gt=di(29,et,null,ne.mode);return Gt.lanes=Ee,Gt.return=ne,Gt}finally{}}}var kl=i4(!0),a4=i4(!1),xs=!1;function zm(a){a.updateQueue={baseState:a.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Fm(a,l){a=a.updateQueue,l.updateQueue===a&&(l.updateQueue={baseState:a.baseState,firstBaseUpdate:a.firstBaseUpdate,lastBaseUpdate:a.lastBaseUpdate,shared:a.shared,callbacks:null})}function Ss(a){return{lane:a,tag:0,payload:null,callback:null,next:null}}function ws(a,l,u){var h=a.updateQueue;if(h===null)return null;if(h=h.shared,(Kt&2)!==0){var g=h.pending;return g===null?l.next=l:(l.next=g.next,g.next=l),h.pending=l,l=id(a),jv(a,null,u),l}return rd(a,h,l,u),id(a)}function Gu(a,l,u){if(l=l.updateQueue,l!==null&&(l=l.shared,(u&4194048)!==0)){var h=l.lanes;h&=a.pendingLanes,u|=h,l.lanes=u,ht(a,u)}}function Hm(a,l){var u=a.updateQueue,h=a.alternate;if(h!==null&&(h=h.updateQueue,u===h)){var g=null,b=null;if(u=u.firstBaseUpdate,u!==null){do{var w={lane:u.lane,tag:u.tag,payload:u.payload,callback:null,next:null};b===null?g=b=w:b=b.next=w,u=u.next}while(u!==null);b===null?g=b=l:b=b.next=l}else g=b=l;u={baseState:h.baseState,firstBaseUpdate:g,lastBaseUpdate:b,shared:h.shared,callbacks:h.callbacks},a.updateQueue=u;return}a=u.lastBaseUpdate,a===null?u.firstBaseUpdate=l:a.next=l,u.lastBaseUpdate=l}var jm=!1;function Yu(){if(jm){var a=_o;if(a!==null)throw a}}function Vu(a,l,u,h){jm=!1;var g=a.updateQueue;xs=!1;var b=g.firstBaseUpdate,w=g.lastBaseUpdate,R=g.shared.pending;if(R!==null){g.shared.pending=null;var K=R,le=K.next;K.next=null,w===null?b=le:w.next=le,w=K;var _e=a.alternate;_e!==null&&(_e=_e.updateQueue,R=_e.lastBaseUpdate,R!==w&&(R===null?_e.firstBaseUpdate=le:R.next=le,_e.lastBaseUpdate=K))}if(b!==null){var Te=g.baseState;w=0,_e=le=K=null,R=b;do{var ce=R.lane&-536870913,pe=ce!==R.lane;if(pe?(Ut&ce)===ce:(h&ce)===ce){ce!==0&&ce===vo&&(jm=!0),_e!==null&&(_e=_e.next={lane:0,tag:R.tag,payload:R.payload,callback:null,next:null});e:{var Qe=a,ot=R;ce=l;var ln=u;switch(ot.tag){case 1:if(Qe=ot.payload,typeof Qe=="function"){Te=Qe.call(ln,Te,ce);break e}Te=Qe;break e;case 3:Qe.flags=Qe.flags&-65537|128;case 0:if(Qe=ot.payload,ce=typeof Qe=="function"?Qe.call(ln,Te,ce):Qe,ce==null)break e;Te=p({},Te,ce);break e;case 2:xs=!0}}ce=R.callback,ce!==null&&(a.flags|=64,pe&&(a.flags|=8192),pe=g.callbacks,pe===null?g.callbacks=[ce]:pe.push(ce))}else pe={lane:ce,tag:R.tag,payload:R.payload,callback:R.callback,next:null},_e===null?(le=_e=pe,K=Te):_e=_e.next=pe,w|=ce;if(R=R.next,R===null){if(R=g.shared.pending,R===null)break;pe=R,R=pe.next,pe.next=null,g.lastBaseUpdate=pe,g.shared.pending=null}}while(!0);_e===null&&(K=Te),g.baseState=K,g.firstBaseUpdate=le,g.lastBaseUpdate=_e,b===null&&(g.shared.lanes=0),Os|=w,a.lanes=w,a.memoizedState=Te}}function s4(a,l){if(typeof a!="function")throw Error(r(191,a));a.call(l)}function l4(a,l){var u=a.callbacks;if(u!==null)for(a.callbacks=null,a=0;a<u.length;a++)s4(u[a],l)}var To=z(null),md=z(0);function o4(a,l){a=Ba,D(md,a),D(To,l),Ba=a|l.baseLanes}function qm(){D(md,Ba),D(To,To.current)}function $m(){Ba=md.current,J(To),J(md)}var hi=z(null),Ri=null;function As(a){var l=a.alternate;D(Gn,Gn.current&1),D(hi,a),Ri===null&&(l===null||To.current!==null||l.memoizedState!==null)&&(Ri=a)}function Gm(a){D(Gn,Gn.current),D(hi,a),Ri===null&&(Ri=a)}function u4(a){a.tag===22?(D(Gn,Gn.current),D(hi,a),Ri===null&&(Ri=a)):ks()}function ks(){D(Gn,Gn.current),D(hi,hi.current)}function fi(a){J(hi),Ri===a&&(Ri=null),J(Gn)}var Gn=z(0);function pd(a){for(var l=a;l!==null;){if(l.tag===13){var u=l.memoizedState;if(u!==null&&(u=u.dehydrated,u===null||Qp(u)||Zp(u)))return l}else if(l.tag===19&&(l.memoizedProps.revealOrder==="forwards"||l.memoizedProps.revealOrder==="backwards"||l.memoizedProps.revealOrder==="unstable_legacy-backwards"||l.memoizedProps.revealOrder==="together")){if((l.flags&128)!==0)return l}else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===a)break;for(;l.sibling===null;){if(l.return===null||l.return===a)return null;l=l.return}l.sibling.return=l.return,l=l.sibling}return null}var Na=0,Et=null,an=null,Jn=null,gd=!1,xo=!1,Cl=!1,bd=0,Ku=0,So=null,gw=0;function Un(){throw Error(r(321))}function Ym(a,l){if(l===null)return!1;for(var u=0;u<l.length&&u<a.length;u++)if(!ci(a[u],l[u]))return!1;return!0}function Vm(a,l,u,h,g,b){return Na=b,Et=l,l.memoizedState=null,l.updateQueue=null,l.lanes=0,H.H=a===null||a.memoizedState===null?Y4:op,Cl=!1,b=u(h,g),Cl=!1,xo&&(b=d4(l,u,h,g)),c4(a),b}function c4(a){H.H=Qu;var l=an!==null&&an.next!==null;if(Na=0,Jn=an=Et=null,gd=!1,Ku=0,So=null,l)throw Error(r(300));a===null||er||(a=a.dependencies,a!==null&&ld(a)&&(er=!0))}function d4(a,l,u,h){Et=a;var g=0;do{if(xo&&(So=null),Ku=0,xo=!1,25<=g)throw Error(r(301));if(g+=1,Jn=an=null,a.updateQueue!=null){var b=a.updateQueue;b.lastEffect=null,b.events=null,b.stores=null,b.memoCache!=null&&(b.memoCache.index=0)}H.H=V4,b=l(u,h)}while(xo);return b}function bw(){var a=H.H,l=a.useState()[0];return l=typeof l.then=="function"?Wu(l):l,a=a.useState()[0],(an!==null?an.memoizedState:null)!==a&&(Et.flags|=1024),l}function Km(){var a=bd!==0;return bd=0,a}function Wm(a,l,u){l.updateQueue=a.updateQueue,l.flags&=-2053,a.lanes&=~u}function Xm(a){if(gd){for(a=a.memoizedState;a!==null;){var l=a.queue;l!==null&&(l.pending=null),a=a.next}gd=!1}Na=0,Jn=an=Et=null,xo=!1,Ku=bd=0,So=null}function Dr(){var a={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Jn===null?Et.memoizedState=Jn=a:Jn=Jn.next=a,Jn}function Yn(){if(an===null){var a=Et.alternate;a=a!==null?a.memoizedState:null}else a=an.next;var l=Jn===null?Et.memoizedState:Jn.next;if(l!==null)Jn=l,an=a;else{if(a===null)throw Et.alternate===null?Error(r(467)):Error(r(310));an=a,a={memoizedState:an.memoizedState,baseState:an.baseState,baseQueue:an.baseQueue,queue:an.queue,next:null},Jn===null?Et.memoizedState=Jn=a:Jn=Jn.next=a}return Jn}function vd(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Wu(a){var l=Ku;return Ku+=1,So===null&&(So=[]),a=t4(So,a,l),l=Et,(Jn===null?l.memoizedState:Jn.next)===null&&(l=l.alternate,H.H=l===null||l.memoizedState===null?Y4:op),a}function _d(a){if(a!==null&&typeof a=="object"){if(typeof a.then=="function")return Wu(a);if(a.$$typeof===I)return vr(a)}throw Error(r(438,String(a)))}function Qm(a){var l=null,u=Et.updateQueue;if(u!==null&&(l=u.memoCache),l==null){var h=Et.alternate;h!==null&&(h=h.updateQueue,h!==null&&(h=h.memoCache,h!=null&&(l={data:h.data.map(function(g){return g.slice()}),index:0})))}if(l==null&&(l={data:[],index:0}),u===null&&(u=vd(),Et.updateQueue=u),u.memoCache=l,u=l.data[l.index],u===void 0)for(u=l.data[l.index]=Array(a),h=0;h<a;h++)u[h]=Y;return l.index++,u}function Oa(a,l){return typeof l=="function"?l(a):l}function yd(a){var l=Yn();return Zm(l,an,a)}function Zm(a,l,u){var h=a.queue;if(h===null)throw Error(r(311));h.lastRenderedReducer=u;var g=a.baseQueue,b=h.pending;if(b!==null){if(g!==null){var w=g.next;g.next=b.next,b.next=w}l.baseQueue=g=b,h.pending=null}if(b=a.baseState,g===null)a.memoizedState=b;else{l=g.next;var R=w=null,K=null,le=l,_e=!1;do{var Te=le.lane&-536870913;if(Te!==le.lane?(Ut&Te)===Te:(Na&Te)===Te){var ce=le.revertLane;if(ce===0)K!==null&&(K=K.next={lane:0,revertLane:0,gesture:null,action:le.action,hasEagerState:le.hasEagerState,eagerState:le.eagerState,next:null}),Te===vo&&(_e=!0);else if((Na&ce)===ce){le=le.next,ce===vo&&(_e=!0);continue}else Te={lane:0,revertLane:le.revertLane,gesture:null,action:le.action,hasEagerState:le.hasEagerState,eagerState:le.eagerState,next:null},K===null?(R=K=Te,w=b):K=K.next=Te,Et.lanes|=ce,Os|=ce;Te=le.action,Cl&&u(b,Te),b=le.hasEagerState?le.eagerState:u(b,Te)}else ce={lane:Te,revertLane:le.revertLane,gesture:le.gesture,action:le.action,hasEagerState:le.hasEagerState,eagerState:le.eagerState,next:null},K===null?(R=K=ce,w=b):K=K.next=ce,Et.lanes|=Te,Os|=Te;le=le.next}while(le!==null&&le!==l);if(K===null?w=b:K.next=R,!ci(b,a.memoizedState)&&(er=!0,_e&&(u=_o,u!==null)))throw u;a.memoizedState=b,a.baseState=w,a.baseQueue=K,h.lastRenderedState=b}return g===null&&(h.lanes=0),[a.memoizedState,h.dispatch]}function Jm(a){var l=Yn(),u=l.queue;if(u===null)throw Error(r(311));u.lastRenderedReducer=a;var h=u.dispatch,g=u.pending,b=l.memoizedState;if(g!==null){u.pending=null;var w=g=g.next;do b=a(b,w.action),w=w.next;while(w!==g);ci(b,l.memoizedState)||(er=!0),l.memoizedState=b,l.baseQueue===null&&(l.baseState=b),u.lastRenderedState=b}return[b,h]}function h4(a,l,u){var h=Et,g=Yn(),b=Ht;if(b){if(u===void 0)throw Error(r(407));u=u()}else u=l();var w=!ci((an||g).memoizedState,u);if(w&&(g.memoizedState=u,er=!0),g=g.queue,np(p4.bind(null,h,g,a),[a]),g.getSnapshot!==l||w||Jn!==null&&Jn.memoizedState.tag&1){if(h.flags|=2048,wo(9,{destroy:void 0},m4.bind(null,h,g,u,l),null),dn===null)throw Error(r(349));b||(Na&127)!==0||f4(h,l,u)}return u}function f4(a,l,u){a.flags|=16384,a={getSnapshot:l,value:u},l=Et.updateQueue,l===null?(l=vd(),Et.updateQueue=l,l.stores=[a]):(u=l.stores,u===null?l.stores=[a]:u.push(a))}function m4(a,l,u,h){l.value=u,l.getSnapshot=h,g4(l)&&b4(a)}function p4(a,l,u){return u(function(){g4(l)&&b4(a)})}function g4(a){var l=a.getSnapshot;a=a.value;try{var u=l();return!ci(a,u)}catch{return!0}}function b4(a){var l=_l(a,2);l!==null&&Zr(l,a,2)}function ep(a){var l=Dr();if(typeof a=="function"){var u=a;if(a=u(),Cl){kt(!0);try{u()}finally{kt(!1)}}}return l.memoizedState=l.baseState=a,l.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Oa,lastRenderedState:a},l}function v4(a,l,u,h){return a.baseState=u,Zm(a,an,typeof h=="function"?h:Oa)}function vw(a,l,u,h,g){if(xd(a))throw Error(r(485));if(a=l.action,a!==null){var b={payload:g,action:a,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(w){b.listeners.push(w)}};H.T!==null?u(!0):b.isTransition=!1,h(b),u=l.pending,u===null?(b.next=l.pending=b,_4(l,b)):(b.next=u.next,l.pending=u.next=b)}}function _4(a,l){var u=l.action,h=l.payload,g=a.state;if(l.isTransition){var b=H.T,w={};H.T=w;try{var R=u(g,h),K=H.S;K!==null&&K(w,R),y4(a,l,R)}catch(le){tp(a,l,le)}finally{b!==null&&w.types!==null&&(b.types=w.types),H.T=b}}else try{b=u(g,h),y4(a,l,b)}catch(le){tp(a,l,le)}}function y4(a,l,u){u!==null&&typeof u=="object"&&typeof u.then=="function"?u.then(function(h){E4(a,l,h)},function(h){return tp(a,l,h)}):E4(a,l,u)}function E4(a,l,u){l.status="fulfilled",l.value=u,T4(l),a.state=u,l=a.pending,l!==null&&(u=l.next,u===l?a.pending=null:(u=u.next,l.next=u,_4(a,u)))}function tp(a,l,u){var h=a.pending;if(a.pending=null,h!==null){h=h.next;do l.status="rejected",l.reason=u,T4(l),l=l.next;while(l!==h)}a.action=null}function T4(a){a=a.listeners;for(var l=0;l<a.length;l++)(0,a[l])()}function x4(a,l){return l}function S4(a,l){if(Ht){var u=dn.formState;if(u!==null){e:{var h=Et;if(Ht){if(xn){t:{for(var g=xn,b=Oi;g.nodeType!==8;){if(!b){g=null;break t}if(g=Mi(g.nextSibling),g===null){g=null;break t}}b=g.data,g=b==="F!"||b==="F"?g:null}if(g){xn=Mi(g.nextSibling),h=g.data==="F!";break e}}Es(h)}h=!1}h&&(l=u[0])}}return u=Dr(),u.memoizedState=u.baseState=l,h={pending:null,lanes:0,dispatch:null,lastRenderedReducer:x4,lastRenderedState:l},u.queue=h,u=q4.bind(null,Et,h),h.dispatch=u,h=ep(!1),b=lp.bind(null,Et,!1,h.queue),h=Dr(),g={state:l,dispatch:null,action:a,pending:null},h.queue=g,u=vw.bind(null,Et,g,b,u),g.dispatch=u,h.memoizedState=a,[l,u,!1]}function w4(a){var l=Yn();return A4(l,an,a)}function A4(a,l,u){if(l=Zm(a,l,x4)[0],a=yd(Oa)[0],typeof l=="object"&&l!==null&&typeof l.then=="function")try{var h=Wu(l)}catch(w){throw w===yo?cd:w}else h=l;l=Yn();var g=l.queue,b=g.dispatch;return u!==l.memoizedState&&(Et.flags|=2048,wo(9,{destroy:void 0},_w.bind(null,g,u),null)),[h,b,a]}function _w(a,l){a.action=l}function k4(a){var l=Yn(),u=an;if(u!==null)return A4(l,u,a);Yn(),l=l.memoizedState,u=Yn();var h=u.queue.dispatch;return u.memoizedState=a,[l,h,!1]}function wo(a,l,u,h){return a={tag:a,create:u,deps:h,inst:l,next:null},l=Et.updateQueue,l===null&&(l=vd(),Et.updateQueue=l),u=l.lastEffect,u===null?l.lastEffect=a.next=a:(h=u.next,u.next=a,a.next=h,l.lastEffect=a),a}function C4(){return Yn().memoizedState}function Ed(a,l,u,h){var g=Dr();Et.flags|=a,g.memoizedState=wo(1|l,{destroy:void 0},u,h===void 0?null:h)}function Td(a,l,u,h){var g=Yn();h=h===void 0?null:h;var b=g.memoizedState.inst;an!==null&&h!==null&&Ym(h,an.memoizedState.deps)?g.memoizedState=wo(l,b,u,h):(Et.flags|=a,g.memoizedState=wo(1|l,b,u,h))}function N4(a,l){Ed(8390656,8,a,l)}function np(a,l){Td(2048,8,a,l)}function yw(a){Et.flags|=4;var l=Et.updateQueue;if(l===null)l=vd(),Et.updateQueue=l,l.events=[a];else{var u=l.events;u===null?l.events=[a]:u.push(a)}}function O4(a){var l=Yn().memoizedState;return yw({ref:l,nextImpl:a}),function(){if((Kt&2)!==0)throw Error(r(440));return l.impl.apply(void 0,arguments)}}function R4(a,l){return Td(4,2,a,l)}function M4(a,l){return Td(4,4,a,l)}function I4(a,l){if(typeof l=="function"){a=a();var u=l(a);return function(){typeof u=="function"?u():l(null)}}if(l!=null)return a=a(),l.current=a,function(){l.current=null}}function D4(a,l,u){u=u!=null?u.concat([a]):null,Td(4,4,I4.bind(null,l,a),u)}function rp(){}function L4(a,l){var u=Yn();l=l===void 0?null:l;var h=u.memoizedState;return l!==null&&Ym(l,h[1])?h[0]:(u.memoizedState=[a,l],a)}function P4(a,l){var u=Yn();l=l===void 0?null:l;var h=u.memoizedState;if(l!==null&&Ym(l,h[1]))return h[0];if(h=a(),Cl){kt(!0);try{a()}finally{kt(!1)}}return u.memoizedState=[h,l],h}function ip(a,l,u){return u===void 0||(Na&1073741824)!==0&&(Ut&261930)===0?a.memoizedState=l:(a.memoizedState=u,a=B3(),Et.lanes|=a,Os|=a,u)}function B4(a,l,u,h){return ci(u,l)?u:To.current!==null?(a=ip(a,u,h),ci(a,l)||(er=!0),a):(Na&42)===0||(Na&1073741824)!==0&&(Ut&261930)===0?(er=!0,a.memoizedState=u):(a=B3(),Et.lanes|=a,Os|=a,l)}function U4(a,l,u,h,g){var b=ie.p;ie.p=b!==0&&8>b?b:8;var w=H.T,R={};H.T=R,lp(a,!1,l,u);try{var K=g(),le=H.S;if(le!==null&&le(R,K),K!==null&&typeof K=="object"&&typeof K.then=="function"){var _e=pw(K,h);Xu(a,l,_e,gi(a))}else Xu(a,l,h,gi(a))}catch(Te){Xu(a,l,{then:function(){},status:"rejected",reason:Te},gi())}finally{ie.p=b,w!==null&&R.types!==null&&(w.types=R.types),H.T=w}}function Ew(){}function ap(a,l,u,h){if(a.tag!==5)throw Error(r(476));var g=z4(a).queue;U4(a,g,l,ve,u===null?Ew:function(){return F4(a),u(h)})}function z4(a){var l=a.memoizedState;if(l!==null)return l;l={memoizedState:ve,baseState:ve,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Oa,lastRenderedState:ve},next:null};var u={};return l.next={memoizedState:u,baseState:u,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Oa,lastRenderedState:u},next:null},a.memoizedState=l,a=a.alternate,a!==null&&(a.memoizedState=l),l}function F4(a){var l=z4(a);l.next===null&&(l=a.alternate.memoizedState),Xu(a,l.next.queue,{},gi())}function sp(){return vr(fc)}function H4(){return Yn().memoizedState}function j4(){return Yn().memoizedState}function Tw(a){for(var l=a.return;l!==null;){switch(l.tag){case 24:case 3:var u=gi();a=Ss(u);var h=ws(l,a,u);h!==null&&(Zr(h,l,u),Gu(h,l,u)),l={cache:Lm()},a.payload=l;return}l=l.return}}function xw(a,l,u){var h=gi();u={lane:h,revertLane:0,gesture:null,action:u,hasEagerState:!1,eagerState:null,next:null},xd(a)?$4(l,u):(u=Sm(a,l,u,h),u!==null&&(Zr(u,a,h),G4(u,l,h)))}function q4(a,l,u){var h=gi();Xu(a,l,u,h)}function Xu(a,l,u,h){var g={lane:h,revertLane:0,gesture:null,action:u,hasEagerState:!1,eagerState:null,next:null};if(xd(a))$4(l,g);else{var b=a.alternate;if(a.lanes===0&&(b===null||b.lanes===0)&&(b=l.lastRenderedReducer,b!==null))try{var w=l.lastRenderedState,R=b(w,u);if(g.hasEagerState=!0,g.eagerState=R,ci(R,w))return rd(a,l,g,0),dn===null&&nd(),!1}catch{}finally{}if(u=Sm(a,l,g,h),u!==null)return Zr(u,a,h),G4(u,l,h),!0}return!1}function lp(a,l,u,h){if(h={lane:2,revertLane:zp(),gesture:null,action:h,hasEagerState:!1,eagerState:null,next:null},xd(a)){if(l)throw Error(r(479))}else l=Sm(a,u,h,2),l!==null&&Zr(l,a,2)}function xd(a){var l=a.alternate;return a===Et||l!==null&&l===Et}function $4(a,l){xo=gd=!0;var u=a.pending;u===null?l.next=l:(l.next=u.next,u.next=l),a.pending=l}function G4(a,l,u){if((u&4194048)!==0){var h=l.lanes;h&=a.pendingLanes,u|=h,l.lanes=u,ht(a,u)}}var Qu={readContext:vr,use:_d,useCallback:Un,useContext:Un,useEffect:Un,useImperativeHandle:Un,useLayoutEffect:Un,useInsertionEffect:Un,useMemo:Un,useReducer:Un,useRef:Un,useState:Un,useDebugValue:Un,useDeferredValue:Un,useTransition:Un,useSyncExternalStore:Un,useId:Un,useHostTransitionStatus:Un,useFormState:Un,useActionState:Un,useOptimistic:Un,useMemoCache:Un,useCacheRefresh:Un};Qu.useEffectEvent=Un;var Y4={readContext:vr,use:_d,useCallback:function(a,l){return Dr().memoizedState=[a,l===void 0?null:l],a},useContext:vr,useEffect:N4,useImperativeHandle:function(a,l,u){u=u!=null?u.concat([a]):null,Ed(4194308,4,I4.bind(null,l,a),u)},useLayoutEffect:function(a,l){return Ed(4194308,4,a,l)},useInsertionEffect:function(a,l){Ed(4,2,a,l)},useMemo:function(a,l){var u=Dr();l=l===void 0?null:l;var h=a();if(Cl){kt(!0);try{a()}finally{kt(!1)}}return u.memoizedState=[h,l],h},useReducer:function(a,l,u){var h=Dr();if(u!==void 0){var g=u(l);if(Cl){kt(!0);try{u(l)}finally{kt(!1)}}}else g=l;return h.memoizedState=h.baseState=g,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:a,lastRenderedState:g},h.queue=a,a=a.dispatch=xw.bind(null,Et,a),[h.memoizedState,a]},useRef:function(a){var l=Dr();return a={current:a},l.memoizedState=a},useState:function(a){a=ep(a);var l=a.queue,u=q4.bind(null,Et,l);return l.dispatch=u,[a.memoizedState,u]},useDebugValue:rp,useDeferredValue:function(a,l){var u=Dr();return ip(u,a,l)},useTransition:function(){var a=ep(!1);return a=U4.bind(null,Et,a.queue,!0,!1),Dr().memoizedState=a,[!1,a]},useSyncExternalStore:function(a,l,u){var h=Et,g=Dr();if(Ht){if(u===void 0)throw Error(r(407));u=u()}else{if(u=l(),dn===null)throw Error(r(349));(Ut&127)!==0||f4(h,l,u)}g.memoizedState=u;var b={value:u,getSnapshot:l};return g.queue=b,N4(p4.bind(null,h,b,a),[a]),h.flags|=2048,wo(9,{destroy:void 0},m4.bind(null,h,b,u,l),null),u},useId:function(){var a=Dr(),l=dn.identifierPrefix;if(Ht){var u=ta,h=ea;u=(h&~(1<<32-Zt(h)-1)).toString(32)+u,l="_"+l+"R_"+u,u=bd++,0<u&&(l+="H"+u.toString(32)),l+="_"}else u=gw++,l="_"+l+"r_"+u.toString(32)+"_";return a.memoizedState=l},useHostTransitionStatus:sp,useFormState:S4,useActionState:S4,useOptimistic:function(a){var l=Dr();l.memoizedState=l.baseState=a;var u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return l.queue=u,l=lp.bind(null,Et,!0,u),u.dispatch=l,[a,l]},useMemoCache:Qm,useCacheRefresh:function(){return Dr().memoizedState=Tw.bind(null,Et)},useEffectEvent:function(a){var l=Dr(),u={impl:a};return l.memoizedState=u,function(){if((Kt&2)!==0)throw Error(r(440));return u.impl.apply(void 0,arguments)}}},op={readContext:vr,use:_d,useCallback:L4,useContext:vr,useEffect:np,useImperativeHandle:D4,useInsertionEffect:R4,useLayoutEffect:M4,useMemo:P4,useReducer:yd,useRef:C4,useState:function(){return yd(Oa)},useDebugValue:rp,useDeferredValue:function(a,l){var u=Yn();return B4(u,an.memoizedState,a,l)},useTransition:function(){var a=yd(Oa)[0],l=Yn().memoizedState;return[typeof a=="boolean"?a:Wu(a),l]},useSyncExternalStore:h4,useId:H4,useHostTransitionStatus:sp,useFormState:w4,useActionState:w4,useOptimistic:function(a,l){var u=Yn();return v4(u,an,a,l)},useMemoCache:Qm,useCacheRefresh:j4};op.useEffectEvent=O4;var V4={readContext:vr,use:_d,useCallback:L4,useContext:vr,useEffect:np,useImperativeHandle:D4,useInsertionEffect:R4,useLayoutEffect:M4,useMemo:P4,useReducer:Jm,useRef:C4,useState:function(){return Jm(Oa)},useDebugValue:rp,useDeferredValue:function(a,l){var u=Yn();return an===null?ip(u,a,l):B4(u,an.memoizedState,a,l)},useTransition:function(){var a=Jm(Oa)[0],l=Yn().memoizedState;return[typeof a=="boolean"?a:Wu(a),l]},useSyncExternalStore:h4,useId:H4,useHostTransitionStatus:sp,useFormState:k4,useActionState:k4,useOptimistic:function(a,l){var u=Yn();return an!==null?v4(u,an,a,l):(u.baseState=a,[a,u.queue.dispatch])},useMemoCache:Qm,useCacheRefresh:j4};V4.useEffectEvent=O4;function up(a,l,u,h){l=a.memoizedState,u=u(h,l),u=u==null?l:p({},l,u),a.memoizedState=u,a.lanes===0&&(a.updateQueue.baseState=u)}var cp={enqueueSetState:function(a,l,u){a=a._reactInternals;var h=gi(),g=Ss(h);g.payload=l,u!=null&&(g.callback=u),l=ws(a,g,h),l!==null&&(Zr(l,a,h),Gu(l,a,h))},enqueueReplaceState:function(a,l,u){a=a._reactInternals;var h=gi(),g=Ss(h);g.tag=1,g.payload=l,u!=null&&(g.callback=u),l=ws(a,g,h),l!==null&&(Zr(l,a,h),Gu(l,a,h))},enqueueForceUpdate:function(a,l){a=a._reactInternals;var u=gi(),h=Ss(u);h.tag=2,l!=null&&(h.callback=l),l=ws(a,h,u),l!==null&&(Zr(l,a,u),Gu(l,a,u))}};function K4(a,l,u,h,g,b,w){return a=a.stateNode,typeof a.shouldComponentUpdate=="function"?a.shouldComponentUpdate(h,b,w):l.prototype&&l.prototype.isPureReactComponent?!Bu(u,h)||!Bu(g,b):!0}function W4(a,l,u,h){a=l.state,typeof l.componentWillReceiveProps=="function"&&l.componentWillReceiveProps(u,h),typeof l.UNSAFE_componentWillReceiveProps=="function"&&l.UNSAFE_componentWillReceiveProps(u,h),l.state!==a&&cp.enqueueReplaceState(l,l.state,null)}function Nl(a,l){var u=l;if("ref"in l){u={};for(var h in l)h!=="ref"&&(u[h]=l[h])}if(a=a.defaultProps){u===l&&(u=p({},u));for(var g in a)u[g]===void 0&&(u[g]=a[g])}return u}function X4(a){td(a)}function Q4(a){console.error(a)}function Z4(a){td(a)}function Sd(a,l){try{var u=a.onUncaughtError;u(l.value,{componentStack:l.stack})}catch(h){setTimeout(function(){throw h})}}function J4(a,l,u){try{var h=a.onCaughtError;h(u.value,{componentStack:u.stack,errorBoundary:l.tag===1?l.stateNode:null})}catch(g){setTimeout(function(){throw g})}}function dp(a,l,u){return u=Ss(u),u.tag=3,u.payload={element:null},u.callback=function(){Sd(a,l)},u}function e3(a){return a=Ss(a),a.tag=3,a}function t3(a,l,u,h){var g=u.type.getDerivedStateFromError;if(typeof g=="function"){var b=h.value;a.payload=function(){return g(b)},a.callback=function(){J4(l,u,h)}}var w=u.stateNode;w!==null&&typeof w.componentDidCatch=="function"&&(a.callback=function(){J4(l,u,h),typeof g!="function"&&(Rs===null?Rs=new Set([this]):Rs.add(this));var R=h.stack;this.componentDidCatch(h.value,{componentStack:R!==null?R:""})})}function Sw(a,l,u,h,g){if(u.flags|=32768,h!==null&&typeof h=="object"&&typeof h.then=="function"){if(l=u.alternate,l!==null&&bo(l,u,g,!0),u=hi.current,u!==null){switch(u.tag){case 31:case 13:return Ri===null?Pd():u.alternate===null&&zn===0&&(zn=3),u.flags&=-257,u.flags|=65536,u.lanes=g,h===dd?u.flags|=16384:(l=u.updateQueue,l===null?u.updateQueue=new Set([h]):l.add(h),Pp(a,h,g)),!1;case 22:return u.flags|=65536,h===dd?u.flags|=16384:(l=u.updateQueue,l===null?(l={transitions:null,markerInstances:null,retryQueue:new Set([h])},u.updateQueue=l):(u=l.retryQueue,u===null?l.retryQueue=new Set([h]):u.add(h)),Pp(a,h,g)),!1}throw Error(r(435,u.tag))}return Pp(a,h,g),Pd(),!1}if(Ht)return l=hi.current,l!==null?((l.flags&65536)===0&&(l.flags|=256),l.flags|=65536,l.lanes=g,h!==Om&&(a=Error(r(422),{cause:h}),Fu(ki(a,u)))):(h!==Om&&(l=Error(r(423),{cause:h}),Fu(ki(l,u))),a=a.current.alternate,a.flags|=65536,g&=-g,a.lanes|=g,h=ki(h,u),g=dp(a.stateNode,h,g),Hm(a,g),zn!==4&&(zn=2)),!1;var b=Error(r(520),{cause:h});if(b=ki(b,u),ac===null?ac=[b]:ac.push(b),zn!==4&&(zn=2),l===null)return!0;h=ki(h,u),u=l;do{switch(u.tag){case 3:return u.flags|=65536,a=g&-g,u.lanes|=a,a=dp(u.stateNode,h,a),Hm(u,a),!1;case 1:if(l=u.type,b=u.stateNode,(u.flags&128)===0&&(typeof l.getDerivedStateFromError=="function"||b!==null&&typeof b.componentDidCatch=="function"&&(Rs===null||!Rs.has(b))))return u.flags|=65536,g&=-g,u.lanes|=g,g=e3(g),t3(g,a,u,h),Hm(u,g),!1}u=u.return}while(u!==null);return!1}var hp=Error(r(461)),er=!1;function _r(a,l,u,h){l.child=a===null?a4(l,null,u,h):kl(l,a.child,u,h)}function n3(a,l,u,h,g){u=u.render;var b=l.ref;if("ref"in h){var w={};for(var R in h)R!=="ref"&&(w[R]=h[R])}else w=h;return xl(l),h=Vm(a,l,u,w,b,g),R=Km(),a!==null&&!er?(Wm(a,l,g),Ra(a,l,g)):(Ht&&R&&Cm(l),l.flags|=1,_r(a,l,h,g),l.child)}function r3(a,l,u,h,g){if(a===null){var b=u.type;return typeof b=="function"&&!wm(b)&&b.defaultProps===void 0&&u.compare===null?(l.tag=15,l.type=b,i3(a,l,b,h,g)):(a=ad(u.type,null,h,l,l.mode,g),a.ref=l.ref,a.return=l,l.child=a)}if(b=a.child,!yp(a,g)){var w=b.memoizedProps;if(u=u.compare,u=u!==null?u:Bu,u(w,h)&&a.ref===l.ref)return Ra(a,l,g)}return l.flags|=1,a=wa(b,h),a.ref=l.ref,a.return=l,l.child=a}function i3(a,l,u,h,g){if(a!==null){var b=a.memoizedProps;if(Bu(b,h)&&a.ref===l.ref)if(er=!1,l.pendingProps=h=b,yp(a,g))(a.flags&131072)!==0&&(er=!0);else return l.lanes=a.lanes,Ra(a,l,g)}return fp(a,l,u,h,g)}function a3(a,l,u,h){var g=h.children,b=a!==null?a.memoizedState:null;if(a===null&&l.stateNode===null&&(l.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),h.mode==="hidden"){if((l.flags&128)!==0){if(b=b!==null?b.baseLanes|u:u,a!==null){for(h=l.child=a.child,g=0;h!==null;)g=g|h.lanes|h.childLanes,h=h.sibling;h=g&~b}else h=0,l.child=null;return s3(a,l,b,u,h)}if((u&536870912)!==0)l.memoizedState={baseLanes:0,cachePool:null},a!==null&&ud(l,b!==null?b.cachePool:null),b!==null?o4(l,b):qm(),u4(l);else return h=l.lanes=536870912,s3(a,l,b!==null?b.baseLanes|u:u,u,h)}else b!==null?(ud(l,b.cachePool),o4(l,b),ks(),l.memoizedState=null):(a!==null&&ud(l,null),qm(),ks());return _r(a,l,g,u),l.child}function Zu(a,l){return a!==null&&a.tag===22||l.stateNode!==null||(l.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),l.sibling}function s3(a,l,u,h,g){var b=Bm();return b=b===null?null:{parent:Zn._currentValue,pool:b},l.memoizedState={baseLanes:u,cachePool:b},a!==null&&ud(l,null),qm(),u4(l),a!==null&&bo(a,l,h,!0),l.childLanes=g,null}function wd(a,l){return l=kd({mode:l.mode,children:l.children},a.mode),l.ref=a.ref,a.child=l,l.return=a,l}function l3(a,l,u){return kl(l,a.child,null,u),a=wd(l,l.pendingProps),a.flags|=2,fi(l),l.memoizedState=null,a}function ww(a,l,u){var h=l.pendingProps,g=(l.flags&128)!==0;if(l.flags&=-129,a===null){if(Ht){if(h.mode==="hidden")return a=wd(l,h),l.lanes=536870912,Zu(null,a);if(Gm(l),(a=xn)?(a=__(a,Oi),a=a!==null&&a.data==="&"?a:null,a!==null&&(l.memoizedState={dehydrated:a,treeContext:_s!==null?{id:ea,overflow:ta}:null,retryLane:536870912,hydrationErrors:null},u=$v(a),u.return=l,l.child=u,br=l,xn=null)):a=null,a===null)throw Es(l);return l.lanes=536870912,null}return wd(l,h)}var b=a.memoizedState;if(b!==null){var w=b.dehydrated;if(Gm(l),g)if(l.flags&256)l.flags&=-257,l=l3(a,l,u);else if(l.memoizedState!==null)l.child=a.child,l.flags|=128,l=null;else throw Error(r(558));else if(er||bo(a,l,u,!1),g=(u&a.childLanes)!==0,er||g){if(h=dn,h!==null&&(w=jn(h,u),w!==0&&w!==b.retryLane))throw b.retryLane=w,_l(a,w),Zr(h,a,w),hp;Pd(),l=l3(a,l,u)}else a=b.treeContext,xn=Mi(w.nextSibling),br=l,Ht=!0,ys=null,Oi=!1,a!==null&&Vv(l,a),l=wd(l,h),l.flags|=4096;return l}return a=wa(a.child,{mode:h.mode,children:h.children}),a.ref=l.ref,l.child=a,a.return=l,a}function Ad(a,l){var u=l.ref;if(u===null)a!==null&&a.ref!==null&&(l.flags|=4194816);else{if(typeof u!="function"&&typeof u!="object")throw Error(r(284));(a===null||a.ref!==u)&&(l.flags|=4194816)}}function fp(a,l,u,h,g){return xl(l),u=Vm(a,l,u,h,void 0,g),h=Km(),a!==null&&!er?(Wm(a,l,g),Ra(a,l,g)):(Ht&&h&&Cm(l),l.flags|=1,_r(a,l,u,g),l.child)}function o3(a,l,u,h,g,b){return xl(l),l.updateQueue=null,u=d4(l,h,u,g),c4(a),h=Km(),a!==null&&!er?(Wm(a,l,b),Ra(a,l,b)):(Ht&&h&&Cm(l),l.flags|=1,_r(a,l,u,b),l.child)}function u3(a,l,u,h,g){if(xl(l),l.stateNode===null){var b=fo,w=u.contextType;typeof w=="object"&&w!==null&&(b=vr(w)),b=new u(h,b),l.memoizedState=b.state!==null&&b.state!==void 0?b.state:null,b.updater=cp,l.stateNode=b,b._reactInternals=l,b=l.stateNode,b.props=h,b.state=l.memoizedState,b.refs={},zm(l),w=u.contextType,b.context=typeof w=="object"&&w!==null?vr(w):fo,b.state=l.memoizedState,w=u.getDerivedStateFromProps,typeof w=="function"&&(up(l,u,w,h),b.state=l.memoizedState),typeof u.getDerivedStateFromProps=="function"||typeof b.getSnapshotBeforeUpdate=="function"||typeof b.UNSAFE_componentWillMount!="function"&&typeof b.componentWillMount!="function"||(w=b.state,typeof b.componentWillMount=="function"&&b.componentWillMount(),typeof b.UNSAFE_componentWillMount=="function"&&b.UNSAFE_componentWillMount(),w!==b.state&&cp.enqueueReplaceState(b,b.state,null),Vu(l,h,b,g),Yu(),b.state=l.memoizedState),typeof b.componentDidMount=="function"&&(l.flags|=4194308),h=!0}else if(a===null){b=l.stateNode;var R=l.memoizedProps,K=Nl(u,R);b.props=K;var le=b.context,_e=u.contextType;w=fo,typeof _e=="object"&&_e!==null&&(w=vr(_e));var Te=u.getDerivedStateFromProps;_e=typeof Te=="function"||typeof b.getSnapshotBeforeUpdate=="function",R=l.pendingProps!==R,_e||typeof b.UNSAFE_componentWillReceiveProps!="function"&&typeof b.componentWillReceiveProps!="function"||(R||le!==w)&&W4(l,b,h,w),xs=!1;var ce=l.memoizedState;b.state=ce,Vu(l,h,b,g),Yu(),le=l.memoizedState,R||ce!==le||xs?(typeof Te=="function"&&(up(l,u,Te,h),le=l.memoizedState),(K=xs||K4(l,u,K,h,ce,le,w))?(_e||typeof b.UNSAFE_componentWillMount!="function"&&typeof b.componentWillMount!="function"||(typeof b.componentWillMount=="function"&&b.componentWillMount(),typeof b.UNSAFE_componentWillMount=="function"&&b.UNSAFE_componentWillMount()),typeof b.componentDidMount=="function"&&(l.flags|=4194308)):(typeof b.componentDidMount=="function"&&(l.flags|=4194308),l.memoizedProps=h,l.memoizedState=le),b.props=h,b.state=le,b.context=w,h=K):(typeof b.componentDidMount=="function"&&(l.flags|=4194308),h=!1)}else{b=l.stateNode,Fm(a,l),w=l.memoizedProps,_e=Nl(u,w),b.props=_e,Te=l.pendingProps,ce=b.context,le=u.contextType,K=fo,typeof le=="object"&&le!==null&&(K=vr(le)),R=u.getDerivedStateFromProps,(le=typeof R=="function"||typeof b.getSnapshotBeforeUpdate=="function")||typeof b.UNSAFE_componentWillReceiveProps!="function"&&typeof b.componentWillReceiveProps!="function"||(w!==Te||ce!==K)&&W4(l,b,h,K),xs=!1,ce=l.memoizedState,b.state=ce,Vu(l,h,b,g),Yu();var pe=l.memoizedState;w!==Te||ce!==pe||xs||a!==null&&a.dependencies!==null&&ld(a.dependencies)?(typeof R=="function"&&(up(l,u,R,h),pe=l.memoizedState),(_e=xs||K4(l,u,_e,h,ce,pe,K)||a!==null&&a.dependencies!==null&&ld(a.dependencies))?(le||typeof b.UNSAFE_componentWillUpdate!="function"&&typeof b.componentWillUpdate!="function"||(typeof b.componentWillUpdate=="function"&&b.componentWillUpdate(h,pe,K),typeof b.UNSAFE_componentWillUpdate=="function"&&b.UNSAFE_componentWillUpdate(h,pe,K)),typeof b.componentDidUpdate=="function"&&(l.flags|=4),typeof b.getSnapshotBeforeUpdate=="function"&&(l.flags|=1024)):(typeof b.componentDidUpdate!="function"||w===a.memoizedProps&&ce===a.memoizedState||(l.flags|=4),typeof b.getSnapshotBeforeUpdate!="function"||w===a.memoizedProps&&ce===a.memoizedState||(l.flags|=1024),l.memoizedProps=h,l.memoizedState=pe),b.props=h,b.state=pe,b.context=K,h=_e):(typeof b.componentDidUpdate!="function"||w===a.memoizedProps&&ce===a.memoizedState||(l.flags|=4),typeof b.getSnapshotBeforeUpdate!="function"||w===a.memoizedProps&&ce===a.memoizedState||(l.flags|=1024),h=!1)}return b=h,Ad(a,l),h=(l.flags&128)!==0,b||h?(b=l.stateNode,u=h&&typeof u.getDerivedStateFromError!="function"?null:b.render(),l.flags|=1,a!==null&&h?(l.child=kl(l,a.child,null,g),l.child=kl(l,null,u,g)):_r(a,l,u,g),l.memoizedState=b.state,a=l.child):a=Ra(a,l,g),a}function c3(a,l,u,h){return El(),l.flags|=256,_r(a,l,u,h),l.child}var mp={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function pp(a){return{baseLanes:a,cachePool:Jv()}}function gp(a,l,u){return a=a!==null?a.childLanes&~u:0,l&&(a|=pi),a}function d3(a,l,u){var h=l.pendingProps,g=!1,b=(l.flags&128)!==0,w;if((w=b)||(w=a!==null&&a.memoizedState===null?!1:(Gn.current&2)!==0),w&&(g=!0,l.flags&=-129),w=(l.flags&32)!==0,l.flags&=-33,a===null){if(Ht){if(g?As(l):ks(),(a=xn)?(a=__(a,Oi),a=a!==null&&a.data!=="&"?a:null,a!==null&&(l.memoizedState={dehydrated:a,treeContext:_s!==null?{id:ea,overflow:ta}:null,retryLane:536870912,hydrationErrors:null},u=$v(a),u.return=l,l.child=u,br=l,xn=null)):a=null,a===null)throw Es(l);return Zp(a)?l.lanes=32:l.lanes=536870912,null}var R=h.children;return h=h.fallback,g?(ks(),g=l.mode,R=kd({mode:"hidden",children:R},g),h=yl(h,g,u,null),R.return=l,h.return=l,R.sibling=h,l.child=R,h=l.child,h.memoizedState=pp(u),h.childLanes=gp(a,w,u),l.memoizedState=mp,Zu(null,h)):(As(l),bp(l,R))}var K=a.memoizedState;if(K!==null&&(R=K.dehydrated,R!==null)){if(b)l.flags&256?(As(l),l.flags&=-257,l=vp(a,l,u)):l.memoizedState!==null?(ks(),l.child=a.child,l.flags|=128,l=null):(ks(),R=h.fallback,g=l.mode,h=kd({mode:"visible",children:h.children},g),R=yl(R,g,u,null),R.flags|=2,h.return=l,R.return=l,h.sibling=R,l.child=h,kl(l,a.child,null,u),h=l.child,h.memoizedState=pp(u),h.childLanes=gp(a,w,u),l.memoizedState=mp,l=Zu(null,h));else if(As(l),Zp(R)){if(w=R.nextSibling&&R.nextSibling.dataset,w)var le=w.dgst;w=le,h=Error(r(419)),h.stack="",h.digest=w,Fu({value:h,source:null,stack:null}),l=vp(a,l,u)}else if(er||bo(a,l,u,!1),w=(u&a.childLanes)!==0,er||w){if(w=dn,w!==null&&(h=jn(w,u),h!==0&&h!==K.retryLane))throw K.retryLane=h,_l(a,h),Zr(w,a,h),hp;Qp(R)||Pd(),l=vp(a,l,u)}else Qp(R)?(l.flags|=192,l.child=a.child,l=null):(a=K.treeContext,xn=Mi(R.nextSibling),br=l,Ht=!0,ys=null,Oi=!1,a!==null&&Vv(l,a),l=bp(l,h.children),l.flags|=4096);return l}return g?(ks(),R=h.fallback,g=l.mode,K=a.child,le=K.sibling,h=wa(K,{mode:"hidden",children:h.children}),h.subtreeFlags=K.subtreeFlags&65011712,le!==null?R=wa(le,R):(R=yl(R,g,u,null),R.flags|=2),R.return=l,h.return=l,h.sibling=R,l.child=h,Zu(null,h),h=l.child,R=a.child.memoizedState,R===null?R=pp(u):(g=R.cachePool,g!==null?(K=Zn._currentValue,g=g.parent!==K?{parent:K,pool:K}:g):g=Jv(),R={baseLanes:R.baseLanes|u,cachePool:g}),h.memoizedState=R,h.childLanes=gp(a,w,u),l.memoizedState=mp,Zu(a.child,h)):(As(l),u=a.child,a=u.sibling,u=wa(u,{mode:"visible",children:h.children}),u.return=l,u.sibling=null,a!==null&&(w=l.deletions,w===null?(l.deletions=[a],l.flags|=16):w.push(a)),l.child=u,l.memoizedState=null,u)}function bp(a,l){return l=kd({mode:"visible",children:l},a.mode),l.return=a,a.child=l}function kd(a,l){return a=di(22,a,null,l),a.lanes=0,a}function vp(a,l,u){return kl(l,a.child,null,u),a=bp(l,l.pendingProps.children),a.flags|=2,l.memoizedState=null,a}function h3(a,l,u){a.lanes|=l;var h=a.alternate;h!==null&&(h.lanes|=l),Im(a.return,l,u)}function _p(a,l,u,h,g,b){var w=a.memoizedState;w===null?a.memoizedState={isBackwards:l,rendering:null,renderingStartTime:0,last:h,tail:u,tailMode:g,treeForkCount:b}:(w.isBackwards=l,w.rendering=null,w.renderingStartTime=0,w.last=h,w.tail=u,w.tailMode=g,w.treeForkCount=b)}function f3(a,l,u){var h=l.pendingProps,g=h.revealOrder,b=h.tail;h=h.children;var w=Gn.current,R=(w&2)!==0;if(R?(w=w&1|2,l.flags|=128):w&=1,D(Gn,w),_r(a,l,h,u),h=Ht?zu:0,!R&&a!==null&&(a.flags&128)!==0)e:for(a=l.child;a!==null;){if(a.tag===13)a.memoizedState!==null&&h3(a,u,l);else if(a.tag===19)h3(a,u,l);else if(a.child!==null){a.child.return=a,a=a.child;continue}if(a===l)break e;for(;a.sibling===null;){if(a.return===null||a.return===l)break e;a=a.return}a.sibling.return=a.return,a=a.sibling}switch(g){case"forwards":for(u=l.child,g=null;u!==null;)a=u.alternate,a!==null&&pd(a)===null&&(g=u),u=u.sibling;u=g,u===null?(g=l.child,l.child=null):(g=u.sibling,u.sibling=null),_p(l,!1,g,u,b,h);break;case"backwards":case"unstable_legacy-backwards":for(u=null,g=l.child,l.child=null;g!==null;){if(a=g.alternate,a!==null&&pd(a)===null){l.child=g;break}a=g.sibling,g.sibling=u,u=g,g=a}_p(l,!0,u,null,b,h);break;case"together":_p(l,!1,null,null,void 0,h);break;default:l.memoizedState=null}return l.child}function Ra(a,l,u){if(a!==null&&(l.dependencies=a.dependencies),Os|=l.lanes,(u&l.childLanes)===0)if(a!==null){if(bo(a,l,u,!1),(u&l.childLanes)===0)return null}else return null;if(a!==null&&l.child!==a.child)throw Error(r(153));if(l.child!==null){for(a=l.child,u=wa(a,a.pendingProps),l.child=u,u.return=l;a.sibling!==null;)a=a.sibling,u=u.sibling=wa(a,a.pendingProps),u.return=l;u.sibling=null}return l.child}function yp(a,l){return(a.lanes&l)!==0?!0:(a=a.dependencies,!!(a!==null&&ld(a)))}function Aw(a,l,u){switch(l.tag){case 3:_t(l,l.stateNode.containerInfo),Ts(l,Zn,a.memoizedState.cache),El();break;case 27:case 5:Tt(l);break;case 4:_t(l,l.stateNode.containerInfo);break;case 10:Ts(l,l.type,l.memoizedProps.value);break;case 31:if(l.memoizedState!==null)return l.flags|=128,Gm(l),null;break;case 13:var h=l.memoizedState;if(h!==null)return h.dehydrated!==null?(As(l),l.flags|=128,null):(u&l.child.childLanes)!==0?d3(a,l,u):(As(l),a=Ra(a,l,u),a!==null?a.sibling:null);As(l);break;case 19:var g=(a.flags&128)!==0;if(h=(u&l.childLanes)!==0,h||(bo(a,l,u,!1),h=(u&l.childLanes)!==0),g){if(h)return f3(a,l,u);l.flags|=128}if(g=l.memoizedState,g!==null&&(g.rendering=null,g.tail=null,g.lastEffect=null),D(Gn,Gn.current),h)break;return null;case 22:return l.lanes=0,a3(a,l,u,l.pendingProps);case 24:Ts(l,Zn,a.memoizedState.cache)}return Ra(a,l,u)}function m3(a,l,u){if(a!==null)if(a.memoizedProps!==l.pendingProps)er=!0;else{if(!yp(a,u)&&(l.flags&128)===0)return er=!1,Aw(a,l,u);er=(a.flags&131072)!==0}else er=!1,Ht&&(l.flags&1048576)!==0&&Yv(l,zu,l.index);switch(l.lanes=0,l.tag){case 16:e:{var h=l.pendingProps;if(a=wl(l.elementType),l.type=a,typeof a=="function")wm(a)?(h=Nl(a,h),l.tag=1,l=u3(null,l,a,h,u)):(l.tag=0,l=fp(null,l,a,h,u));else{if(a!=null){var g=a.$$typeof;if(g===$){l.tag=11,l=n3(null,l,a,h,u);break e}else if(g===Z){l.tag=14,l=r3(null,l,a,h,u);break e}}throw l=fe(a)||a,Error(r(306,l,""))}}return l;case 0:return fp(a,l,l.type,l.pendingProps,u);case 1:return h=l.type,g=Nl(h,l.pendingProps),u3(a,l,h,g,u);case 3:e:{if(_t(l,l.stateNode.containerInfo),a===null)throw Error(r(387));h=l.pendingProps;var b=l.memoizedState;g=b.element,Fm(a,l),Vu(l,h,null,u);var w=l.memoizedState;if(h=w.cache,Ts(l,Zn,h),h!==b.cache&&Dm(l,[Zn],u,!0),Yu(),h=w.element,b.isDehydrated)if(b={element:h,isDehydrated:!1,cache:w.cache},l.updateQueue.baseState=b,l.memoizedState=b,l.flags&256){l=c3(a,l,h,u);break e}else if(h!==g){g=ki(Error(r(424)),l),Fu(g),l=c3(a,l,h,u);break e}else{switch(a=l.stateNode.containerInfo,a.nodeType){case 9:a=a.body;break;default:a=a.nodeName==="HTML"?a.ownerDocument.body:a}for(xn=Mi(a.firstChild),br=l,Ht=!0,ys=null,Oi=!0,u=a4(l,null,h,u),l.child=u;u;)u.flags=u.flags&-3|4096,u=u.sibling}else{if(El(),h===g){l=Ra(a,l,u);break e}_r(a,l,h,u)}l=l.child}return l;case 26:return Ad(a,l),a===null?(u=w_(l.type,null,l.pendingProps,null))?l.memoizedState=u:Ht||(u=l.type,a=l.pendingProps,h=qd(ze.current).createElement(u),h[qn]=l,h[Sr]=a,yr(h,u,a),Xn(h),l.stateNode=h):l.memoizedState=w_(l.type,a.memoizedProps,l.pendingProps,a.memoizedState),null;case 27:return Tt(l),a===null&&Ht&&(h=l.stateNode=T_(l.type,l.pendingProps,ze.current),br=l,Oi=!0,g=xn,Ls(l.type)?(Jp=g,xn=Mi(h.firstChild)):xn=g),_r(a,l,l.pendingProps.children,u),Ad(a,l),a===null&&(l.flags|=4194304),l.child;case 5:return a===null&&Ht&&((g=h=xn)&&(h=nA(h,l.type,l.pendingProps,Oi),h!==null?(l.stateNode=h,br=l,xn=Mi(h.firstChild),Oi=!1,g=!0):g=!1),g||Es(l)),Tt(l),g=l.type,b=l.pendingProps,w=a!==null?a.memoizedProps:null,h=b.children,Kp(g,b)?h=null:w!==null&&Kp(g,w)&&(l.flags|=32),l.memoizedState!==null&&(g=Vm(a,l,bw,null,null,u),fc._currentValue=g),Ad(a,l),_r(a,l,h,u),l.child;case 6:return a===null&&Ht&&((a=u=xn)&&(u=rA(u,l.pendingProps,Oi),u!==null?(l.stateNode=u,br=l,xn=null,a=!0):a=!1),a||Es(l)),null;case 13:return d3(a,l,u);case 4:return _t(l,l.stateNode.containerInfo),h=l.pendingProps,a===null?l.child=kl(l,null,h,u):_r(a,l,h,u),l.child;case 11:return n3(a,l,l.type,l.pendingProps,u);case 7:return _r(a,l,l.pendingProps,u),l.child;case 8:return _r(a,l,l.pendingProps.children,u),l.child;case 12:return _r(a,l,l.pendingProps.children,u),l.child;case 10:return h=l.pendingProps,Ts(l,l.type,h.value),_r(a,l,h.children,u),l.child;case 9:return g=l.type._context,h=l.pendingProps.children,xl(l),g=vr(g),h=h(g),l.flags|=1,_r(a,l,h,u),l.child;case 14:return r3(a,l,l.type,l.pendingProps,u);case 15:return i3(a,l,l.type,l.pendingProps,u);case 19:return f3(a,l,u);case 31:return ww(a,l,u);case 22:return a3(a,l,u,l.pendingProps);case 24:return xl(l),h=vr(Zn),a===null?(g=Bm(),g===null&&(g=dn,b=Lm(),g.pooledCache=b,b.refCount++,b!==null&&(g.pooledCacheLanes|=u),g=b),l.memoizedState={parent:h,cache:g},zm(l),Ts(l,Zn,g)):((a.lanes&u)!==0&&(Fm(a,l),Vu(l,null,null,u),Yu()),g=a.memoizedState,b=l.memoizedState,g.parent!==h?(g={parent:h,cache:h},l.memoizedState=g,l.lanes===0&&(l.memoizedState=l.updateQueue.baseState=g),Ts(l,Zn,h)):(h=b.cache,Ts(l,Zn,h),h!==g.cache&&Dm(l,[Zn],u,!0))),_r(a,l,l.pendingProps.children,u),l.child;case 29:throw l.pendingProps}throw Error(r(156,l.tag))}function Ma(a){a.flags|=4}function Ep(a,l,u,h,g){if((l=(a.mode&32)!==0)&&(l=!1),l){if(a.flags|=16777216,(g&335544128)===g)if(a.stateNode.complete)a.flags|=8192;else if(H3())a.flags|=8192;else throw Al=dd,Um}else a.flags&=-16777217}function p3(a,l){if(l.type!=="stylesheet"||(l.state.loading&4)!==0)a.flags&=-16777217;else if(a.flags|=16777216,!O_(l))if(H3())a.flags|=8192;else throw Al=dd,Um}function Cd(a,l){l!==null&&(a.flags|=4),a.flags&16384&&(l=a.tag!==22?mt():536870912,a.lanes|=l,No|=l)}function Ju(a,l){if(!Ht)switch(a.tailMode){case"hidden":l=a.tail;for(var u=null;l!==null;)l.alternate!==null&&(u=l),l=l.sibling;u===null?a.tail=null:u.sibling=null;break;case"collapsed":u=a.tail;for(var h=null;u!==null;)u.alternate!==null&&(h=u),u=u.sibling;h===null?l||a.tail===null?a.tail=null:a.tail.sibling=null:h.sibling=null}}function Sn(a){var l=a.alternate!==null&&a.alternate.child===a.child,u=0,h=0;if(l)for(var g=a.child;g!==null;)u|=g.lanes|g.childLanes,h|=g.subtreeFlags&65011712,h|=g.flags&65011712,g.return=a,g=g.sibling;else for(g=a.child;g!==null;)u|=g.lanes|g.childLanes,h|=g.subtreeFlags,h|=g.flags,g.return=a,g=g.sibling;return a.subtreeFlags|=h,a.childLanes=u,l}function kw(a,l,u){var h=l.pendingProps;switch(Nm(l),l.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Sn(l),null;case 1:return Sn(l),null;case 3:return u=l.stateNode,h=null,a!==null&&(h=a.memoizedState.cache),l.memoizedState.cache!==h&&(l.flags|=2048),Ca(Zn),pt(),u.pendingContext&&(u.context=u.pendingContext,u.pendingContext=null),(a===null||a.child===null)&&(go(l)?Ma(l):a===null||a.memoizedState.isDehydrated&&(l.flags&256)===0||(l.flags|=1024,Rm())),Sn(l),null;case 26:var g=l.type,b=l.memoizedState;return a===null?(Ma(l),b!==null?(Sn(l),p3(l,b)):(Sn(l),Ep(l,g,null,h,u))):b?b!==a.memoizedState?(Ma(l),Sn(l),p3(l,b)):(Sn(l),l.flags&=-16777217):(a=a.memoizedProps,a!==h&&Ma(l),Sn(l),Ep(l,g,a,h,u)),null;case 27:if(kn(l),u=ze.current,g=l.type,a!==null&&l.stateNode!=null)a.memoizedProps!==h&&Ma(l);else{if(!h){if(l.stateNode===null)throw Error(r(166));return Sn(l),null}a=Ae.current,go(l)?Kv(l):(a=T_(g,h,u),l.stateNode=a,Ma(l))}return Sn(l),null;case 5:if(kn(l),g=l.type,a!==null&&l.stateNode!=null)a.memoizedProps!==h&&Ma(l);else{if(!h){if(l.stateNode===null)throw Error(r(166));return Sn(l),null}if(b=Ae.current,go(l))Kv(l);else{var w=qd(ze.current);switch(b){case 1:b=w.createElementNS("http://www.w3.org/2000/svg",g);break;case 2:b=w.createElementNS("http://www.w3.org/1998/Math/MathML",g);break;default:switch(g){case"svg":b=w.createElementNS("http://www.w3.org/2000/svg",g);break;case"math":b=w.createElementNS("http://www.w3.org/1998/Math/MathML",g);break;case"script":b=w.createElement("div"),b.innerHTML="<script><\/script>",b=b.removeChild(b.firstChild);break;case"select":b=typeof h.is=="string"?w.createElement("select",{is:h.is}):w.createElement("select"),h.multiple?b.multiple=!0:h.size&&(b.size=h.size);break;default:b=typeof h.is=="string"?w.createElement(g,{is:h.is}):w.createElement(g)}}b[qn]=l,b[Sr]=h;e:for(w=l.child;w!==null;){if(w.tag===5||w.tag===6)b.appendChild(w.stateNode);else if(w.tag!==4&&w.tag!==27&&w.child!==null){w.child.return=w,w=w.child;continue}if(w===l)break e;for(;w.sibling===null;){if(w.return===null||w.return===l)break e;w=w.return}w.sibling.return=w.return,w=w.sibling}l.stateNode=b;e:switch(yr(b,g,h),g){case"button":case"input":case"select":case"textarea":h=!!h.autoFocus;break e;case"img":h=!0;break e;default:h=!1}h&&Ma(l)}}return Sn(l),Ep(l,l.type,a===null?null:a.memoizedProps,l.pendingProps,u),null;case 6:if(a&&l.stateNode!=null)a.memoizedProps!==h&&Ma(l);else{if(typeof h!="string"&&l.stateNode===null)throw Error(r(166));if(a=ze.current,go(l)){if(a=l.stateNode,u=l.memoizedProps,h=null,g=br,g!==null)switch(g.tag){case 27:case 5:h=g.memoizedProps}a[qn]=l,a=!!(a.nodeValue===u||h!==null&&h.suppressHydrationWarning===!0||d_(a.nodeValue,u)),a||Es(l,!0)}else a=qd(a).createTextNode(h),a[qn]=l,l.stateNode=a}return Sn(l),null;case 31:if(u=l.memoizedState,a===null||a.memoizedState!==null){if(h=go(l),u!==null){if(a===null){if(!h)throw Error(r(318));if(a=l.memoizedState,a=a!==null?a.dehydrated:null,!a)throw Error(r(557));a[qn]=l}else El(),(l.flags&128)===0&&(l.memoizedState=null),l.flags|=4;Sn(l),a=!1}else u=Rm(),a!==null&&a.memoizedState!==null&&(a.memoizedState.hydrationErrors=u),a=!0;if(!a)return l.flags&256?(fi(l),l):(fi(l),null);if((l.flags&128)!==0)throw Error(r(558))}return Sn(l),null;case 13:if(h=l.memoizedState,a===null||a.memoizedState!==null&&a.memoizedState.dehydrated!==null){if(g=go(l),h!==null&&h.dehydrated!==null){if(a===null){if(!g)throw Error(r(318));if(g=l.memoizedState,g=g!==null?g.dehydrated:null,!g)throw Error(r(317));g[qn]=l}else El(),(l.flags&128)===0&&(l.memoizedState=null),l.flags|=4;Sn(l),g=!1}else g=Rm(),a!==null&&a.memoizedState!==null&&(a.memoizedState.hydrationErrors=g),g=!0;if(!g)return l.flags&256?(fi(l),l):(fi(l),null)}return fi(l),(l.flags&128)!==0?(l.lanes=u,l):(u=h!==null,a=a!==null&&a.memoizedState!==null,u&&(h=l.child,g=null,h.alternate!==null&&h.alternate.memoizedState!==null&&h.alternate.memoizedState.cachePool!==null&&(g=h.alternate.memoizedState.cachePool.pool),b=null,h.memoizedState!==null&&h.memoizedState.cachePool!==null&&(b=h.memoizedState.cachePool.pool),b!==g&&(h.flags|=2048)),u!==a&&u&&(l.child.flags|=8192),Cd(l,l.updateQueue),Sn(l),null);case 4:return pt(),a===null&&qp(l.stateNode.containerInfo),Sn(l),null;case 10:return Ca(l.type),Sn(l),null;case 19:if(J(Gn),h=l.memoizedState,h===null)return Sn(l),null;if(g=(l.flags&128)!==0,b=h.rendering,b===null)if(g)Ju(h,!1);else{if(zn!==0||a!==null&&(a.flags&128)!==0)for(a=l.child;a!==null;){if(b=pd(a),b!==null){for(l.flags|=128,Ju(h,!1),a=b.updateQueue,l.updateQueue=a,Cd(l,a),l.subtreeFlags=0,a=u,u=l.child;u!==null;)qv(u,a),u=u.sibling;return D(Gn,Gn.current&1|2),Ht&&Aa(l,h.treeForkCount),l.child}a=a.sibling}h.tail!==null&&Xt()>Id&&(l.flags|=128,g=!0,Ju(h,!1),l.lanes=4194304)}else{if(!g)if(a=pd(b),a!==null){if(l.flags|=128,g=!0,a=a.updateQueue,l.updateQueue=a,Cd(l,a),Ju(h,!0),h.tail===null&&h.tailMode==="hidden"&&!b.alternate&&!Ht)return Sn(l),null}else 2*Xt()-h.renderingStartTime>Id&&u!==536870912&&(l.flags|=128,g=!0,Ju(h,!1),l.lanes=4194304);h.isBackwards?(b.sibling=l.child,l.child=b):(a=h.last,a!==null?a.sibling=b:l.child=b,h.last=b)}return h.tail!==null?(a=h.tail,h.rendering=a,h.tail=a.sibling,h.renderingStartTime=Xt(),a.sibling=null,u=Gn.current,D(Gn,g?u&1|2:u&1),Ht&&Aa(l,h.treeForkCount),a):(Sn(l),null);case 22:case 23:return fi(l),$m(),h=l.memoizedState!==null,a!==null?a.memoizedState!==null!==h&&(l.flags|=8192):h&&(l.flags|=8192),h?(u&536870912)!==0&&(l.flags&128)===0&&(Sn(l),l.subtreeFlags&6&&(l.flags|=8192)):Sn(l),u=l.updateQueue,u!==null&&Cd(l,u.retryQueue),u=null,a!==null&&a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(u=a.memoizedState.cachePool.pool),h=null,l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(h=l.memoizedState.cachePool.pool),h!==u&&(l.flags|=2048),a!==null&&J(Sl),null;case 24:return u=null,a!==null&&(u=a.memoizedState.cache),l.memoizedState.cache!==u&&(l.flags|=2048),Ca(Zn),Sn(l),null;case 25:return null;case 30:return null}throw Error(r(156,l.tag))}function Cw(a,l){switch(Nm(l),l.tag){case 1:return a=l.flags,a&65536?(l.flags=a&-65537|128,l):null;case 3:return Ca(Zn),pt(),a=l.flags,(a&65536)!==0&&(a&128)===0?(l.flags=a&-65537|128,l):null;case 26:case 27:case 5:return kn(l),null;case 31:if(l.memoizedState!==null){if(fi(l),l.alternate===null)throw Error(r(340));El()}return a=l.flags,a&65536?(l.flags=a&-65537|128,l):null;case 13:if(fi(l),a=l.memoizedState,a!==null&&a.dehydrated!==null){if(l.alternate===null)throw Error(r(340));El()}return a=l.flags,a&65536?(l.flags=a&-65537|128,l):null;case 19:return J(Gn),null;case 4:return pt(),null;case 10:return Ca(l.type),null;case 22:case 23:return fi(l),$m(),a!==null&&J(Sl),a=l.flags,a&65536?(l.flags=a&-65537|128,l):null;case 24:return Ca(Zn),null;case 25:return null;default:return null}}function g3(a,l){switch(Nm(l),l.tag){case 3:Ca(Zn),pt();break;case 26:case 27:case 5:kn(l);break;case 4:pt();break;case 31:l.memoizedState!==null&&fi(l);break;case 13:fi(l);break;case 19:J(Gn);break;case 10:Ca(l.type);break;case 22:case 23:fi(l),$m(),a!==null&&J(Sl);break;case 24:Ca(Zn)}}function ec(a,l){try{var u=l.updateQueue,h=u!==null?u.lastEffect:null;if(h!==null){var g=h.next;u=g;do{if((u.tag&a)===a){h=void 0;var b=u.create,w=u.inst;h=b(),w.destroy=h}u=u.next}while(u!==g)}}catch(R){nn(l,l.return,R)}}function Cs(a,l,u){try{var h=l.updateQueue,g=h!==null?h.lastEffect:null;if(g!==null){var b=g.next;h=b;do{if((h.tag&a)===a){var w=h.inst,R=w.destroy;if(R!==void 0){w.destroy=void 0,g=l;var K=u,le=R;try{le()}catch(_e){nn(g,K,_e)}}}h=h.next}while(h!==b)}}catch(_e){nn(l,l.return,_e)}}function b3(a){var l=a.updateQueue;if(l!==null){var u=a.stateNode;try{l4(l,u)}catch(h){nn(a,a.return,h)}}}function v3(a,l,u){u.props=Nl(a.type,a.memoizedProps),u.state=a.memoizedState;try{u.componentWillUnmount()}catch(h){nn(a,l,h)}}function tc(a,l){try{var u=a.ref;if(u!==null){switch(a.tag){case 26:case 27:case 5:var h=a.stateNode;break;case 30:h=a.stateNode;break;default:h=a.stateNode}typeof u=="function"?a.refCleanup=u(h):u.current=h}}catch(g){nn(a,l,g)}}function na(a,l){var u=a.ref,h=a.refCleanup;if(u!==null)if(typeof h=="function")try{h()}catch(g){nn(a,l,g)}finally{a.refCleanup=null,a=a.alternate,a!=null&&(a.refCleanup=null)}else if(typeof u=="function")try{u(null)}catch(g){nn(a,l,g)}else u.current=null}function _3(a){var l=a.type,u=a.memoizedProps,h=a.stateNode;try{e:switch(l){case"button":case"input":case"select":case"textarea":u.autoFocus&&h.focus();break e;case"img":u.src?h.src=u.src:u.srcSet&&(h.srcset=u.srcSet)}}catch(g){nn(a,a.return,g)}}function Tp(a,l,u){try{var h=a.stateNode;Xw(h,a.type,u,l),h[Sr]=l}catch(g){nn(a,a.return,g)}}function y3(a){return a.tag===5||a.tag===3||a.tag===26||a.tag===27&&Ls(a.type)||a.tag===4}function xp(a){e:for(;;){for(;a.sibling===null;){if(a.return===null||y3(a.return))return null;a=a.return}for(a.sibling.return=a.return,a=a.sibling;a.tag!==5&&a.tag!==6&&a.tag!==18;){if(a.tag===27&&Ls(a.type)||a.flags&2||a.child===null||a.tag===4)continue e;a.child.return=a,a=a.child}if(!(a.flags&2))return a.stateNode}}function Sp(a,l,u){var h=a.tag;if(h===5||h===6)a=a.stateNode,l?(u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u).insertBefore(a,l):(l=u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u,l.appendChild(a),u=u._reactRootContainer,u!=null||l.onclick!==null||(l.onclick=Pe));else if(h!==4&&(h===27&&Ls(a.type)&&(u=a.stateNode,l=null),a=a.child,a!==null))for(Sp(a,l,u),a=a.sibling;a!==null;)Sp(a,l,u),a=a.sibling}function Nd(a,l,u){var h=a.tag;if(h===5||h===6)a=a.stateNode,l?u.insertBefore(a,l):u.appendChild(a);else if(h!==4&&(h===27&&Ls(a.type)&&(u=a.stateNode),a=a.child,a!==null))for(Nd(a,l,u),a=a.sibling;a!==null;)Nd(a,l,u),a=a.sibling}function E3(a){var l=a.stateNode,u=a.memoizedProps;try{for(var h=a.type,g=l.attributes;g.length;)l.removeAttributeNode(g[0]);yr(l,h,u),l[qn]=a,l[Sr]=u}catch(b){nn(a,a.return,b)}}var Ia=!1,tr=!1,wp=!1,T3=typeof WeakSet=="function"?WeakSet:Set,cr=null;function Nw(a,l){if(a=a.containerInfo,Yp=Xd,a=Dv(a),vm(a)){if("selectionStart"in a)var u={start:a.selectionStart,end:a.selectionEnd};else e:{u=(u=a.ownerDocument)&&u.defaultView||window;var h=u.getSelection&&u.getSelection();if(h&&h.rangeCount!==0){u=h.anchorNode;var g=h.anchorOffset,b=h.focusNode;h=h.focusOffset;try{u.nodeType,b.nodeType}catch{u=null;break e}var w=0,R=-1,K=-1,le=0,_e=0,Te=a,ce=null;t:for(;;){for(var pe;Te!==u||g!==0&&Te.nodeType!==3||(R=w+g),Te!==b||h!==0&&Te.nodeType!==3||(K=w+h),Te.nodeType===3&&(w+=Te.nodeValue.length),(pe=Te.firstChild)!==null;)ce=Te,Te=pe;for(;;){if(Te===a)break t;if(ce===u&&++le===g&&(R=w),ce===b&&++_e===h&&(K=w),(pe=Te.nextSibling)!==null)break;Te=ce,ce=Te.parentNode}Te=pe}u=R===-1||K===-1?null:{start:R,end:K}}else u=null}u=u||{start:0,end:0}}else u=null;for(Vp={focusedElem:a,selectionRange:u},Xd=!1,cr=l;cr!==null;)if(l=cr,a=l.child,(l.subtreeFlags&1028)!==0&&a!==null)a.return=l,cr=a;else for(;cr!==null;){switch(l=cr,b=l.alternate,a=l.flags,l.tag){case 0:if((a&4)!==0&&(a=l.updateQueue,a=a!==null?a.events:null,a!==null))for(u=0;u<a.length;u++)g=a[u],g.ref.impl=g.nextImpl;break;case 11:case 15:break;case 1:if((a&1024)!==0&&b!==null){a=void 0,u=l,g=b.memoizedProps,b=b.memoizedState,h=u.stateNode;try{var Qe=Nl(u.type,g);a=h.getSnapshotBeforeUpdate(Qe,b),h.__reactInternalSnapshotBeforeUpdate=a}catch(ot){nn(u,u.return,ot)}}break;case 3:if((a&1024)!==0){if(a=l.stateNode.containerInfo,u=a.nodeType,u===9)Xp(a);else if(u===1)switch(a.nodeName){case"HEAD":case"HTML":case"BODY":Xp(a);break;default:a.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((a&1024)!==0)throw Error(r(163))}if(a=l.sibling,a!==null){a.return=l.return,cr=a;break}cr=l.return}}function x3(a,l,u){var h=u.flags;switch(u.tag){case 0:case 11:case 15:La(a,u),h&4&&ec(5,u);break;case 1:if(La(a,u),h&4)if(a=u.stateNode,l===null)try{a.componentDidMount()}catch(w){nn(u,u.return,w)}else{var g=Nl(u.type,l.memoizedProps);l=l.memoizedState;try{a.componentDidUpdate(g,l,a.__reactInternalSnapshotBeforeUpdate)}catch(w){nn(u,u.return,w)}}h&64&&b3(u),h&512&&tc(u,u.return);break;case 3:if(La(a,u),h&64&&(a=u.updateQueue,a!==null)){if(l=null,u.child!==null)switch(u.child.tag){case 27:case 5:l=u.child.stateNode;break;case 1:l=u.child.stateNode}try{l4(a,l)}catch(w){nn(u,u.return,w)}}break;case 27:l===null&&h&4&&E3(u);case 26:case 5:La(a,u),l===null&&h&4&&_3(u),h&512&&tc(u,u.return);break;case 12:La(a,u);break;case 31:La(a,u),h&4&&A3(a,u);break;case 13:La(a,u),h&4&&k3(a,u),h&64&&(a=u.memoizedState,a!==null&&(a=a.dehydrated,a!==null&&(u=Uw.bind(null,u),iA(a,u))));break;case 22:if(h=u.memoizedState!==null||Ia,!h){l=l!==null&&l.memoizedState!==null||tr,g=Ia;var b=tr;Ia=h,(tr=l)&&!b?Pa(a,u,(u.subtreeFlags&8772)!==0):La(a,u),Ia=g,tr=b}break;case 30:break;default:La(a,u)}}function S3(a){var l=a.alternate;l!==null&&(a.alternate=null,S3(l)),a.child=null,a.deletions=null,a.sibling=null,a.tag===5&&(l=a.stateNode,l!==null&&wu(l)),a.stateNode=null,a.return=null,a.dependencies=null,a.memoizedProps=null,a.memoizedState=null,a.pendingProps=null,a.stateNode=null,a.updateQueue=null}var Nn=null,Kr=!1;function Da(a,l,u){for(u=u.child;u!==null;)w3(a,l,u),u=u.sibling}function w3(a,l,u){if(At&&typeof At.onCommitFiberUnmount=="function")try{At.onCommitFiberUnmount(Rt,u)}catch{}switch(u.tag){case 26:tr||na(u,l),Da(a,l,u),u.memoizedState?u.memoizedState.count--:u.stateNode&&(u=u.stateNode,u.parentNode.removeChild(u));break;case 27:tr||na(u,l);var h=Nn,g=Kr;Ls(u.type)&&(Nn=u.stateNode,Kr=!1),Da(a,l,u),cc(u.stateNode),Nn=h,Kr=g;break;case 5:tr||na(u,l);case 6:if(h=Nn,g=Kr,Nn=null,Da(a,l,u),Nn=h,Kr=g,Nn!==null)if(Kr)try{(Nn.nodeType===9?Nn.body:Nn.nodeName==="HTML"?Nn.ownerDocument.body:Nn).removeChild(u.stateNode)}catch(b){nn(u,l,b)}else try{Nn.removeChild(u.stateNode)}catch(b){nn(u,l,b)}break;case 18:Nn!==null&&(Kr?(a=Nn,b_(a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a,u.stateNode),Bo(a)):b_(Nn,u.stateNode));break;case 4:h=Nn,g=Kr,Nn=u.stateNode.containerInfo,Kr=!0,Da(a,l,u),Nn=h,Kr=g;break;case 0:case 11:case 14:case 15:Cs(2,u,l),tr||Cs(4,u,l),Da(a,l,u);break;case 1:tr||(na(u,l),h=u.stateNode,typeof h.componentWillUnmount=="function"&&v3(u,l,h)),Da(a,l,u);break;case 21:Da(a,l,u);break;case 22:tr=(h=tr)||u.memoizedState!==null,Da(a,l,u),tr=h;break;default:Da(a,l,u)}}function A3(a,l){if(l.memoizedState===null&&(a=l.alternate,a!==null&&(a=a.memoizedState,a!==null))){a=a.dehydrated;try{Bo(a)}catch(u){nn(l,l.return,u)}}}function k3(a,l){if(l.memoizedState===null&&(a=l.alternate,a!==null&&(a=a.memoizedState,a!==null&&(a=a.dehydrated,a!==null))))try{Bo(a)}catch(u){nn(l,l.return,u)}}function Ow(a){switch(a.tag){case 31:case 13:case 19:var l=a.stateNode;return l===null&&(l=a.stateNode=new T3),l;case 22:return a=a.stateNode,l=a._retryCache,l===null&&(l=a._retryCache=new T3),l;default:throw Error(r(435,a.tag))}}function Od(a,l){var u=Ow(a);l.forEach(function(h){if(!u.has(h)){u.add(h);var g=zw.bind(null,a,h);h.then(g,g)}})}function Wr(a,l){var u=l.deletions;if(u!==null)for(var h=0;h<u.length;h++){var g=u[h],b=a,w=l,R=w;e:for(;R!==null;){switch(R.tag){case 27:if(Ls(R.type)){Nn=R.stateNode,Kr=!1;break e}break;case 5:Nn=R.stateNode,Kr=!1;break e;case 3:case 4:Nn=R.stateNode.containerInfo,Kr=!0;break e}R=R.return}if(Nn===null)throw Error(r(160));w3(b,w,g),Nn=null,Kr=!1,b=g.alternate,b!==null&&(b.return=null),g.return=null}if(l.subtreeFlags&13886)for(l=l.child;l!==null;)C3(l,a),l=l.sibling}var $i=null;function C3(a,l){var u=a.alternate,h=a.flags;switch(a.tag){case 0:case 11:case 14:case 15:Wr(l,a),Xr(a),h&4&&(Cs(3,a,a.return),ec(3,a),Cs(5,a,a.return));break;case 1:Wr(l,a),Xr(a),h&512&&(tr||u===null||na(u,u.return)),h&64&&Ia&&(a=a.updateQueue,a!==null&&(h=a.callbacks,h!==null&&(u=a.shared.hiddenCallbacks,a.shared.hiddenCallbacks=u===null?h:u.concat(h))));break;case 26:var g=$i;if(Wr(l,a),Xr(a),h&512&&(tr||u===null||na(u,u.return)),h&4){var b=u!==null?u.memoizedState:null;if(h=a.memoizedState,u===null)if(h===null)if(a.stateNode===null){e:{h=a.type,u=a.memoizedProps,g=g.ownerDocument||g;t:switch(h){case"title":b=g.getElementsByTagName("title")[0],(!b||b[fl]||b[qn]||b.namespaceURI==="http://www.w3.org/2000/svg"||b.hasAttribute("itemprop"))&&(b=g.createElement(h),g.head.insertBefore(b,g.querySelector("head > title"))),yr(b,h,u),b[qn]=a,Xn(b),h=b;break e;case"link":var w=C_("link","href",g).get(h+(u.href||""));if(w){for(var R=0;R<w.length;R++)if(b=w[R],b.getAttribute("href")===(u.href==null||u.href===""?null:u.href)&&b.getAttribute("rel")===(u.rel==null?null:u.rel)&&b.getAttribute("title")===(u.title==null?null:u.title)&&b.getAttribute("crossorigin")===(u.crossOrigin==null?null:u.crossOrigin)){w.splice(R,1);break t}}b=g.createElement(h),yr(b,h,u),g.head.appendChild(b);break;case"meta":if(w=C_("meta","content",g).get(h+(u.content||""))){for(R=0;R<w.length;R++)if(b=w[R],b.getAttribute("content")===(u.content==null?null:""+u.content)&&b.getAttribute("name")===(u.name==null?null:u.name)&&b.getAttribute("property")===(u.property==null?null:u.property)&&b.getAttribute("http-equiv")===(u.httpEquiv==null?null:u.httpEquiv)&&b.getAttribute("charset")===(u.charSet==null?null:u.charSet)){w.splice(R,1);break t}}b=g.createElement(h),yr(b,h,u),g.head.appendChild(b);break;default:throw Error(r(468,h))}b[qn]=a,Xn(b),h=b}a.stateNode=h}else N_(g,a.type,a.stateNode);else a.stateNode=k_(g,h,a.memoizedProps);else b!==h?(b===null?u.stateNode!==null&&(u=u.stateNode,u.parentNode.removeChild(u)):b.count--,h===null?N_(g,a.type,a.stateNode):k_(g,h,a.memoizedProps)):h===null&&a.stateNode!==null&&Tp(a,a.memoizedProps,u.memoizedProps)}break;case 27:Wr(l,a),Xr(a),h&512&&(tr||u===null||na(u,u.return)),u!==null&&h&4&&Tp(a,a.memoizedProps,u.memoizedProps);break;case 5:if(Wr(l,a),Xr(a),h&512&&(tr||u===null||na(u,u.return)),a.flags&32){g=a.stateNode;try{ut(g,"")}catch(Qe){nn(a,a.return,Qe)}}h&4&&a.stateNode!=null&&(g=a.memoizedProps,Tp(a,g,u!==null?u.memoizedProps:g)),h&1024&&(wp=!0);break;case 6:if(Wr(l,a),Xr(a),h&4){if(a.stateNode===null)throw Error(r(162));h=a.memoizedProps,u=a.stateNode;try{u.nodeValue=h}catch(Qe){nn(a,a.return,Qe)}}break;case 3:if(Yd=null,g=$i,$i=$d(l.containerInfo),Wr(l,a),$i=g,Xr(a),h&4&&u!==null&&u.memoizedState.isDehydrated)try{Bo(l.containerInfo)}catch(Qe){nn(a,a.return,Qe)}wp&&(wp=!1,N3(a));break;case 4:h=$i,$i=$d(a.stateNode.containerInfo),Wr(l,a),Xr(a),$i=h;break;case 12:Wr(l,a),Xr(a);break;case 31:Wr(l,a),Xr(a),h&4&&(h=a.updateQueue,h!==null&&(a.updateQueue=null,Od(a,h)));break;case 13:Wr(l,a),Xr(a),a.child.flags&8192&&a.memoizedState!==null!=(u!==null&&u.memoizedState!==null)&&(Md=Xt()),h&4&&(h=a.updateQueue,h!==null&&(a.updateQueue=null,Od(a,h)));break;case 22:g=a.memoizedState!==null;var K=u!==null&&u.memoizedState!==null,le=Ia,_e=tr;if(Ia=le||g,tr=_e||K,Wr(l,a),tr=_e,Ia=le,Xr(a),h&8192)e:for(l=a.stateNode,l._visibility=g?l._visibility&-2:l._visibility|1,g&&(u===null||K||Ia||tr||Ol(a)),u=null,l=a;;){if(l.tag===5||l.tag===26){if(u===null){K=u=l;try{if(b=K.stateNode,g)w=b.style,typeof w.setProperty=="function"?w.setProperty("display","none","important"):w.display="none";else{R=K.stateNode;var Te=K.memoizedProps.style,ce=Te!=null&&Te.hasOwnProperty("display")?Te.display:null;R.style.display=ce==null||typeof ce=="boolean"?"":(""+ce).trim()}}catch(Qe){nn(K,K.return,Qe)}}}else if(l.tag===6){if(u===null){K=l;try{K.stateNode.nodeValue=g?"":K.memoizedProps}catch(Qe){nn(K,K.return,Qe)}}}else if(l.tag===18){if(u===null){K=l;try{var pe=K.stateNode;g?v_(pe,!0):v_(K.stateNode,!1)}catch(Qe){nn(K,K.return,Qe)}}}else if((l.tag!==22&&l.tag!==23||l.memoizedState===null||l===a)&&l.child!==null){l.child.return=l,l=l.child;continue}if(l===a)break e;for(;l.sibling===null;){if(l.return===null||l.return===a)break e;u===l&&(u=null),l=l.return}u===l&&(u=null),l.sibling.return=l.return,l=l.sibling}h&4&&(h=a.updateQueue,h!==null&&(u=h.retryQueue,u!==null&&(h.retryQueue=null,Od(a,u))));break;case 19:Wr(l,a),Xr(a),h&4&&(h=a.updateQueue,h!==null&&(a.updateQueue=null,Od(a,h)));break;case 30:break;case 21:break;default:Wr(l,a),Xr(a)}}function Xr(a){var l=a.flags;if(l&2){try{for(var u,h=a.return;h!==null;){if(y3(h)){u=h;break}h=h.return}if(u==null)throw Error(r(160));switch(u.tag){case 27:var g=u.stateNode,b=xp(a);Nd(a,b,g);break;case 5:var w=u.stateNode;u.flags&32&&(ut(w,""),u.flags&=-33);var R=xp(a);Nd(a,R,w);break;case 3:case 4:var K=u.stateNode.containerInfo,le=xp(a);Sp(a,le,K);break;default:throw Error(r(161))}}catch(_e){nn(a,a.return,_e)}a.flags&=-3}l&4096&&(a.flags&=-4097)}function N3(a){if(a.subtreeFlags&1024)for(a=a.child;a!==null;){var l=a;N3(l),l.tag===5&&l.flags&1024&&l.stateNode.reset(),a=a.sibling}}function La(a,l){if(l.subtreeFlags&8772)for(l=l.child;l!==null;)x3(a,l.alternate,l),l=l.sibling}function Ol(a){for(a=a.child;a!==null;){var l=a;switch(l.tag){case 0:case 11:case 14:case 15:Cs(4,l,l.return),Ol(l);break;case 1:na(l,l.return);var u=l.stateNode;typeof u.componentWillUnmount=="function"&&v3(l,l.return,u),Ol(l);break;case 27:cc(l.stateNode);case 26:case 5:na(l,l.return),Ol(l);break;case 22:l.memoizedState===null&&Ol(l);break;case 30:Ol(l);break;default:Ol(l)}a=a.sibling}}function Pa(a,l,u){for(u=u&&(l.subtreeFlags&8772)!==0,l=l.child;l!==null;){var h=l.alternate,g=a,b=l,w=b.flags;switch(b.tag){case 0:case 11:case 15:Pa(g,b,u),ec(4,b);break;case 1:if(Pa(g,b,u),h=b,g=h.stateNode,typeof g.componentDidMount=="function")try{g.componentDidMount()}catch(le){nn(h,h.return,le)}if(h=b,g=h.updateQueue,g!==null){var R=h.stateNode;try{var K=g.shared.hiddenCallbacks;if(K!==null)for(g.shared.hiddenCallbacks=null,g=0;g<K.length;g++)s4(K[g],R)}catch(le){nn(h,h.return,le)}}u&&w&64&&b3(b),tc(b,b.return);break;case 27:E3(b);case 26:case 5:Pa(g,b,u),u&&h===null&&w&4&&_3(b),tc(b,b.return);break;case 12:Pa(g,b,u);break;case 31:Pa(g,b,u),u&&w&4&&A3(g,b);break;case 13:Pa(g,b,u),u&&w&4&&k3(g,b);break;case 22:b.memoizedState===null&&Pa(g,b,u),tc(b,b.return);break;case 30:break;default:Pa(g,b,u)}l=l.sibling}}function Ap(a,l){var u=null;a!==null&&a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(u=a.memoizedState.cachePool.pool),a=null,l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),a!==u&&(a!=null&&a.refCount++,u!=null&&Hu(u))}function kp(a,l){a=null,l.alternate!==null&&(a=l.alternate.memoizedState.cache),l=l.memoizedState.cache,l!==a&&(l.refCount++,a!=null&&Hu(a))}function Gi(a,l,u,h){if(l.subtreeFlags&10256)for(l=l.child;l!==null;)O3(a,l,u,h),l=l.sibling}function O3(a,l,u,h){var g=l.flags;switch(l.tag){case 0:case 11:case 15:Gi(a,l,u,h),g&2048&&ec(9,l);break;case 1:Gi(a,l,u,h);break;case 3:Gi(a,l,u,h),g&2048&&(a=null,l.alternate!==null&&(a=l.alternate.memoizedState.cache),l=l.memoizedState.cache,l!==a&&(l.refCount++,a!=null&&Hu(a)));break;case 12:if(g&2048){Gi(a,l,u,h),a=l.stateNode;try{var b=l.memoizedProps,w=b.id,R=b.onPostCommit;typeof R=="function"&&R(w,l.alternate===null?"mount":"update",a.passiveEffectDuration,-0)}catch(K){nn(l,l.return,K)}}else Gi(a,l,u,h);break;case 31:Gi(a,l,u,h);break;case 13:Gi(a,l,u,h);break;case 23:break;case 22:b=l.stateNode,w=l.alternate,l.memoizedState!==null?b._visibility&2?Gi(a,l,u,h):nc(a,l):b._visibility&2?Gi(a,l,u,h):(b._visibility|=2,Ao(a,l,u,h,(l.subtreeFlags&10256)!==0||!1)),g&2048&&Ap(w,l);break;case 24:Gi(a,l,u,h),g&2048&&kp(l.alternate,l);break;default:Gi(a,l,u,h)}}function Ao(a,l,u,h,g){for(g=g&&((l.subtreeFlags&10256)!==0||!1),l=l.child;l!==null;){var b=a,w=l,R=u,K=h,le=w.flags;switch(w.tag){case 0:case 11:case 15:Ao(b,w,R,K,g),ec(8,w);break;case 23:break;case 22:var _e=w.stateNode;w.memoizedState!==null?_e._visibility&2?Ao(b,w,R,K,g):nc(b,w):(_e._visibility|=2,Ao(b,w,R,K,g)),g&&le&2048&&Ap(w.alternate,w);break;case 24:Ao(b,w,R,K,g),g&&le&2048&&kp(w.alternate,w);break;default:Ao(b,w,R,K,g)}l=l.sibling}}function nc(a,l){if(l.subtreeFlags&10256)for(l=l.child;l!==null;){var u=a,h=l,g=h.flags;switch(h.tag){case 22:nc(u,h),g&2048&&Ap(h.alternate,h);break;case 24:nc(u,h),g&2048&&kp(h.alternate,h);break;default:nc(u,h)}l=l.sibling}}var rc=8192;function ko(a,l,u){if(a.subtreeFlags&rc)for(a=a.child;a!==null;)R3(a,l,u),a=a.sibling}function R3(a,l,u){switch(a.tag){case 26:ko(a,l,u),a.flags&rc&&a.memoizedState!==null&&gA(u,$i,a.memoizedState,a.memoizedProps);break;case 5:ko(a,l,u);break;case 3:case 4:var h=$i;$i=$d(a.stateNode.containerInfo),ko(a,l,u),$i=h;break;case 22:a.memoizedState===null&&(h=a.alternate,h!==null&&h.memoizedState!==null?(h=rc,rc=16777216,ko(a,l,u),rc=h):ko(a,l,u));break;default:ko(a,l,u)}}function M3(a){var l=a.alternate;if(l!==null&&(a=l.child,a!==null)){l.child=null;do l=a.sibling,a.sibling=null,a=l;while(a!==null)}}function ic(a){var l=a.deletions;if((a.flags&16)!==0){if(l!==null)for(var u=0;u<l.length;u++){var h=l[u];cr=h,D3(h,a)}M3(a)}if(a.subtreeFlags&10256)for(a=a.child;a!==null;)I3(a),a=a.sibling}function I3(a){switch(a.tag){case 0:case 11:case 15:ic(a),a.flags&2048&&Cs(9,a,a.return);break;case 3:ic(a);break;case 12:ic(a);break;case 22:var l=a.stateNode;a.memoizedState!==null&&l._visibility&2&&(a.return===null||a.return.tag!==13)?(l._visibility&=-3,Rd(a)):ic(a);break;default:ic(a)}}function Rd(a){var l=a.deletions;if((a.flags&16)!==0){if(l!==null)for(var u=0;u<l.length;u++){var h=l[u];cr=h,D3(h,a)}M3(a)}for(a=a.child;a!==null;){switch(l=a,l.tag){case 0:case 11:case 15:Cs(8,l,l.return),Rd(l);break;case 22:u=l.stateNode,u._visibility&2&&(u._visibility&=-3,Rd(l));break;default:Rd(l)}a=a.sibling}}function D3(a,l){for(;cr!==null;){var u=cr;switch(u.tag){case 0:case 11:case 15:Cs(8,u,l);break;case 23:case 22:if(u.memoizedState!==null&&u.memoizedState.cachePool!==null){var h=u.memoizedState.cachePool.pool;h!=null&&h.refCount++}break;case 24:Hu(u.memoizedState.cache)}if(h=u.child,h!==null)h.return=u,cr=h;else e:for(u=a;cr!==null;){h=cr;var g=h.sibling,b=h.return;if(S3(h),h===u){cr=null;break e}if(g!==null){g.return=b,cr=g;break e}cr=b}}}var Rw={getCacheForType:function(a){var l=vr(Zn),u=l.data.get(a);return u===void 0&&(u=a(),l.data.set(a,u)),u},cacheSignal:function(){return vr(Zn).controller.signal}},Mw=typeof WeakMap=="function"?WeakMap:Map,Kt=0,dn=null,Mt=null,Ut=0,tn=0,mi=null,Ns=!1,Co=!1,Cp=!1,Ba=0,zn=0,Os=0,Rl=0,Np=0,pi=0,No=0,ac=null,Qr=null,Op=!1,Md=0,L3=0,Id=1/0,Dd=null,Rs=null,sr=0,Ms=null,Oo=null,Ua=0,Rp=0,Mp=null,P3=null,sc=0,Ip=null;function gi(){return(Kt&2)!==0&&Ut!==0?Ut&-Ut:H.T!==null?zp():to()}function B3(){if(pi===0)if((Ut&536870912)===0||Ht){var a=eo;eo<<=1,(eo&3932160)===0&&(eo=262144),pi=a}else pi=536870912;return a=hi.current,a!==null&&(a.flags|=32),pi}function Zr(a,l,u){(a===dn&&(tn===2||tn===9)||a.cancelPendingCommit!==null)&&(Ro(a,0),Is(a,Ut,pi,!1)),cn(a,u),((Kt&2)===0||a!==dn)&&(a===dn&&((Kt&2)===0&&(Rl|=u),zn===4&&Is(a,Ut,pi,!1)),ra(a))}function U3(a,l,u){if((Kt&6)!==0)throw Error(r(327));var h=!u&&(l&127)===0&&(l&a.expiredLanes)===0||ye(a,l),g=h?Lw(a,l):Lp(a,l,!0),b=h;do{if(g===0){Co&&!h&&Is(a,l,0,!1);break}else{if(u=a.current.alternate,b&&!Iw(u)){g=Lp(a,l,!1),b=!1;continue}if(g===2){if(b=l,a.errorRecoveryDisabledLanes&b)var w=0;else w=a.pendingLanes&-536870913,w=w!==0?w:w&536870912?536870912:0;if(w!==0){l=w;e:{var R=a;g=ac;var K=R.current.memoizedState.isDehydrated;if(K&&(Ro(R,w).flags|=256),w=Lp(R,w,!1),w!==2){if(Cp&&!K){R.errorRecoveryDisabledLanes|=b,Rl|=b,g=4;break e}b=Qr,Qr=g,b!==null&&(Qr===null?Qr=b:Qr.push.apply(Qr,b))}g=w}if(b=!1,g!==2)continue}}if(g===1){Ro(a,0),Is(a,l,0,!0);break}e:{switch(h=a,b=g,b){case 0:case 1:throw Error(r(345));case 4:if((l&4194048)!==l)break;case 6:Is(h,l,pi,!Ns);break e;case 2:Qr=null;break;case 3:case 5:break;default:throw Error(r(329))}if((l&62914560)===l&&(g=Md+300-Xt(),10<g)){if(Is(h,l,pi,!Ns),W(h,0,!0)!==0)break e;Ua=l,h.timeoutHandle=p_(z3.bind(null,h,u,Qr,Dd,Op,l,pi,Rl,No,Ns,b,"Throttled",-0,0),g);break e}z3(h,u,Qr,Dd,Op,l,pi,Rl,No,Ns,b,null,-0,0)}}break}while(!0);ra(a)}function z3(a,l,u,h,g,b,w,R,K,le,_e,Te,ce,pe){if(a.timeoutHandle=-1,Te=l.subtreeFlags,Te&8192||(Te&16785408)===16785408){Te={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Pe},R3(l,b,Te);var Qe=(b&62914560)===b?Md-Xt():(b&4194048)===b?L3-Xt():0;if(Qe=bA(Te,Qe),Qe!==null){Ua=b,a.cancelPendingCommit=Qe(V3.bind(null,a,l,b,u,h,g,w,R,K,_e,Te,null,ce,pe)),Is(a,b,w,!le);return}}V3(a,l,b,u,h,g,w,R,K)}function Iw(a){for(var l=a;;){var u=l.tag;if((u===0||u===11||u===15)&&l.flags&16384&&(u=l.updateQueue,u!==null&&(u=u.stores,u!==null)))for(var h=0;h<u.length;h++){var g=u[h],b=g.getSnapshot;g=g.value;try{if(!ci(b(),g))return!1}catch{return!1}}if(u=l.child,l.subtreeFlags&16384&&u!==null)u.return=l,l=u;else{if(l===a)break;for(;l.sibling===null;){if(l.return===null||l.return===a)return!0;l=l.return}l.sibling.return=l.return,l=l.sibling}}return!0}function Is(a,l,u,h){l&=~Np,l&=~Rl,a.suspendedLanes|=l,a.pingedLanes&=~l,h&&(a.warmLanes|=l),h=a.expirationTimes;for(var g=l;0<g;){var b=31-Zt(g),w=1<<b;h[b]=-1,g&=~w}u!==0&&We(a,u,l)}function Ld(){return(Kt&6)===0?(lc(0),!1):!0}function Dp(){if(Mt!==null){if(tn===0)var a=Mt.return;else a=Mt,ka=Tl=null,Xm(a),Eo=null,qu=0,a=Mt;for(;a!==null;)g3(a.alternate,a),a=a.return;Mt=null}}function Ro(a,l){var u=a.timeoutHandle;u!==-1&&(a.timeoutHandle=-1,Jw(u)),u=a.cancelPendingCommit,u!==null&&(a.cancelPendingCommit=null,u()),Ua=0,Dp(),dn=a,Mt=u=wa(a.current,null),Ut=l,tn=0,mi=null,Ns=!1,Co=ye(a,l),Cp=!1,No=pi=Np=Rl=Os=zn=0,Qr=ac=null,Op=!1,(l&8)!==0&&(l|=l&32);var h=a.entangledLanes;if(h!==0)for(a=a.entanglements,h&=l;0<h;){var g=31-Zt(h),b=1<<g;l|=a[g],h&=~b}return Ba=l,nd(),u}function F3(a,l){Et=null,H.H=Qu,l===yo||l===cd?(l=n4(),tn=3):l===Um?(l=n4(),tn=4):tn=l===hp?8:l!==null&&typeof l=="object"&&typeof l.then=="function"?6:1,mi=l,Mt===null&&(zn=1,Sd(a,ki(l,a.current)))}function H3(){var a=hi.current;return a===null?!0:(Ut&4194048)===Ut?Ri===null:(Ut&62914560)===Ut||(Ut&536870912)!==0?a===Ri:!1}function j3(){var a=H.H;return H.H=Qu,a===null?Qu:a}function q3(){var a=H.A;return H.A=Rw,a}function Pd(){zn=4,Ns||(Ut&4194048)!==Ut&&hi.current!==null||(Co=!0),(Os&134217727)===0&&(Rl&134217727)===0||dn===null||Is(dn,Ut,pi,!1)}function Lp(a,l,u){var h=Kt;Kt|=2;var g=j3(),b=q3();(dn!==a||Ut!==l)&&(Dd=null,Ro(a,l)),l=!1;var w=zn;e:do try{if(tn!==0&&Mt!==null){var R=Mt,K=mi;switch(tn){case 8:Dp(),w=6;break e;case 3:case 2:case 9:case 6:hi.current===null&&(l=!0);var le=tn;if(tn=0,mi=null,Mo(a,R,K,le),u&&Co){w=0;break e}break;default:le=tn,tn=0,mi=null,Mo(a,R,K,le)}}Dw(),w=zn;break}catch(_e){F3(a,_e)}while(!0);return l&&a.shellSuspendCounter++,ka=Tl=null,Kt=h,H.H=g,H.A=b,Mt===null&&(dn=null,Ut=0,nd()),w}function Dw(){for(;Mt!==null;)$3(Mt)}function Lw(a,l){var u=Kt;Kt|=2;var h=j3(),g=q3();dn!==a||Ut!==l?(Dd=null,Id=Xt()+500,Ro(a,l)):Co=ye(a,l);e:do try{if(tn!==0&&Mt!==null){l=Mt;var b=mi;t:switch(tn){case 1:tn=0,mi=null,Mo(a,l,b,1);break;case 2:case 9:if(e4(b)){tn=0,mi=null,G3(l);break}l=function(){tn!==2&&tn!==9||dn!==a||(tn=7),ra(a)},b.then(l,l);break e;case 3:tn=7;break e;case 4:tn=5;break e;case 7:e4(b)?(tn=0,mi=null,G3(l)):(tn=0,mi=null,Mo(a,l,b,7));break;case 5:var w=null;switch(Mt.tag){case 26:w=Mt.memoizedState;case 5:case 27:var R=Mt;if(w?O_(w):R.stateNode.complete){tn=0,mi=null;var K=R.sibling;if(K!==null)Mt=K;else{var le=R.return;le!==null?(Mt=le,Bd(le)):Mt=null}break t}}tn=0,mi=null,Mo(a,l,b,5);break;case 6:tn=0,mi=null,Mo(a,l,b,6);break;case 8:Dp(),zn=6;break e;default:throw Error(r(462))}}Pw();break}catch(_e){F3(a,_e)}while(!0);return ka=Tl=null,H.H=h,H.A=g,Kt=u,Mt!==null?0:(dn=null,Ut=0,nd(),zn)}function Pw(){for(;Mt!==null&&!gn();)$3(Mt)}function $3(a){var l=m3(a.alternate,a,Ba);a.memoizedProps=a.pendingProps,l===null?Bd(a):Mt=l}function G3(a){var l=a,u=l.alternate;switch(l.tag){case 15:case 0:l=o3(u,l,l.pendingProps,l.type,void 0,Ut);break;case 11:l=o3(u,l,l.pendingProps,l.type.render,l.ref,Ut);break;case 5:Xm(l);default:g3(u,l),l=Mt=qv(l,Ba),l=m3(u,l,Ba)}a.memoizedProps=a.pendingProps,l===null?Bd(a):Mt=l}function Mo(a,l,u,h){ka=Tl=null,Xm(l),Eo=null,qu=0;var g=l.return;try{if(Sw(a,g,l,u,Ut)){zn=1,Sd(a,ki(u,a.current)),Mt=null;return}}catch(b){if(g!==null)throw Mt=g,b;zn=1,Sd(a,ki(u,a.current)),Mt=null;return}l.flags&32768?(Ht||h===1?a=!0:Co||(Ut&536870912)!==0?a=!1:(Ns=a=!0,(h===2||h===9||h===3||h===6)&&(h=hi.current,h!==null&&h.tag===13&&(h.flags|=16384))),Y3(l,a)):Bd(l)}function Bd(a){var l=a;do{if((l.flags&32768)!==0){Y3(l,Ns);return}a=l.return;var u=kw(l.alternate,l,Ba);if(u!==null){Mt=u;return}if(l=l.sibling,l!==null){Mt=l;return}Mt=l=a}while(l!==null);zn===0&&(zn=5)}function Y3(a,l){do{var u=Cw(a.alternate,a);if(u!==null){u.flags&=32767,Mt=u;return}if(u=a.return,u!==null&&(u.flags|=32768,u.subtreeFlags=0,u.deletions=null),!l&&(a=a.sibling,a!==null)){Mt=a;return}Mt=a=u}while(a!==null);zn=6,Mt=null}function V3(a,l,u,h,g,b,w,R,K){a.cancelPendingCommit=null;do Ud();while(sr!==0);if((Kt&6)!==0)throw Error(r(327));if(l!==null){if(l===a.current)throw Error(r(177));if(b=l.lanes|l.childLanes,b|=xm,Ze(a,u,b,w,R,K),a===dn&&(Mt=dn=null,Ut=0),Oo=l,Ms=a,Ua=u,Rp=b,Mp=g,P3=h,(l.subtreeFlags&10256)!==0||(l.flags&10256)!==0?(a.callbackNode=null,a.callbackPriority=0,Fw(Ye,function(){return Z3(),null})):(a.callbackNode=null,a.callbackPriority=0),h=(l.flags&13878)!==0,(l.subtreeFlags&13878)!==0||h){h=H.T,H.T=null,g=ie.p,ie.p=2,w=Kt,Kt|=4;try{Nw(a,l,u)}finally{Kt=w,ie.p=g,H.T=h}}sr=1,K3(),W3(),X3()}}function K3(){if(sr===1){sr=0;var a=Ms,l=Oo,u=(l.flags&13878)!==0;if((l.subtreeFlags&13878)!==0||u){u=H.T,H.T=null;var h=ie.p;ie.p=2;var g=Kt;Kt|=4;try{C3(l,a);var b=Vp,w=Dv(a.containerInfo),R=b.focusedElem,K=b.selectionRange;if(w!==R&&R&&R.ownerDocument&&Iv(R.ownerDocument.documentElement,R)){if(K!==null&&vm(R)){var le=K.start,_e=K.end;if(_e===void 0&&(_e=le),"selectionStart"in R)R.selectionStart=le,R.selectionEnd=Math.min(_e,R.value.length);else{var Te=R.ownerDocument||document,ce=Te&&Te.defaultView||window;if(ce.getSelection){var pe=ce.getSelection(),Qe=R.textContent.length,ot=Math.min(K.start,Qe),ln=K.end===void 0?ot:Math.min(K.end,Qe);!pe.extend&&ot>ln&&(w=ln,ln=ot,ot=w);var ne=Mv(R,ot),X=Mv(R,ln);if(ne&&X&&(pe.rangeCount!==1||pe.anchorNode!==ne.node||pe.anchorOffset!==ne.offset||pe.focusNode!==X.node||pe.focusOffset!==X.offset)){var ae=Te.createRange();ae.setStart(ne.node,ne.offset),pe.removeAllRanges(),ot>ln?(pe.addRange(ae),pe.extend(X.node,X.offset)):(ae.setEnd(X.node,X.offset),pe.addRange(ae))}}}}for(Te=[],pe=R;pe=pe.parentNode;)pe.nodeType===1&&Te.push({element:pe,left:pe.scrollLeft,top:pe.scrollTop});for(typeof R.focus=="function"&&R.focus(),R=0;R<Te.length;R++){var Ee=Te[R];Ee.element.scrollLeft=Ee.left,Ee.element.scrollTop=Ee.top}}Xd=!!Yp,Vp=Yp=null}finally{Kt=g,ie.p=h,H.T=u}}a.current=l,sr=2}}function W3(){if(sr===2){sr=0;var a=Ms,l=Oo,u=(l.flags&8772)!==0;if((l.subtreeFlags&8772)!==0||u){u=H.T,H.T=null;var h=ie.p;ie.p=2;var g=Kt;Kt|=4;try{x3(a,l.alternate,l)}finally{Kt=g,ie.p=h,H.T=u}}sr=3}}function X3(){if(sr===4||sr===3){sr=0,In();var a=Ms,l=Oo,u=Ua,h=P3;(l.subtreeFlags&10256)!==0||(l.flags&10256)!==0?sr=5:(sr=0,Oo=Ms=null,Q3(a,a.pendingLanes));var g=a.pendingLanes;if(g===0&&(Rs=null),ya(u),l=l.stateNode,At&&typeof At.onCommitFiberRoot=="function")try{At.onCommitFiberRoot(Rt,l,void 0,(l.current.flags&128)===128)}catch{}if(h!==null){l=H.T,g=ie.p,ie.p=2,H.T=null;try{for(var b=a.onRecoverableError,w=0;w<h.length;w++){var R=h[w];b(R.value,{componentStack:R.stack})}}finally{H.T=l,ie.p=g}}(Ua&3)!==0&&Ud(),ra(a),g=a.pendingLanes,(u&261930)!==0&&(g&42)!==0?a===Ip?sc++:(sc=0,Ip=a):sc=0,lc(0)}}function Q3(a,l){(a.pooledCacheLanes&=l)===0&&(l=a.pooledCache,l!=null&&(a.pooledCache=null,Hu(l)))}function Ud(){return K3(),W3(),X3(),Z3()}function Z3(){if(sr!==5)return!1;var a=Ms,l=Rp;Rp=0;var u=ya(Ua),h=H.T,g=ie.p;try{ie.p=32>u?32:u,H.T=null,u=Mp,Mp=null;var b=Ms,w=Ua;if(sr=0,Oo=Ms=null,Ua=0,(Kt&6)!==0)throw Error(r(331));var R=Kt;if(Kt|=4,I3(b.current),O3(b,b.current,w,u),Kt=R,lc(0,!1),At&&typeof At.onPostCommitFiberRoot=="function")try{At.onPostCommitFiberRoot(Rt,b)}catch{}return!0}finally{ie.p=g,H.T=h,Q3(a,l)}}function J3(a,l,u){l=ki(u,l),l=dp(a.stateNode,l,2),a=ws(a,l,2),a!==null&&(cn(a,2),ra(a))}function nn(a,l,u){if(a.tag===3)J3(a,a,u);else for(;l!==null;){if(l.tag===3){J3(l,a,u);break}else if(l.tag===1){var h=l.stateNode;if(typeof l.type.getDerivedStateFromError=="function"||typeof h.componentDidCatch=="function"&&(Rs===null||!Rs.has(h))){a=ki(u,a),u=e3(2),h=ws(l,u,2),h!==null&&(t3(u,h,l,a),cn(h,2),ra(h));break}}l=l.return}}function Pp(a,l,u){var h=a.pingCache;if(h===null){h=a.pingCache=new Mw;var g=new Set;h.set(l,g)}else g=h.get(l),g===void 0&&(g=new Set,h.set(l,g));g.has(u)||(Cp=!0,g.add(u),a=Bw.bind(null,a,l,u),l.then(a,a))}function Bw(a,l,u){var h=a.pingCache;h!==null&&h.delete(l),a.pingedLanes|=a.suspendedLanes&u,a.warmLanes&=~u,dn===a&&(Ut&u)===u&&(zn===4||zn===3&&(Ut&62914560)===Ut&&300>Xt()-Md?(Kt&2)===0&&Ro(a,0):Np|=u,No===Ut&&(No=0)),ra(a)}function e_(a,l){l===0&&(l=mt()),a=_l(a,l),a!==null&&(cn(a,l),ra(a))}function Uw(a){var l=a.memoizedState,u=0;l!==null&&(u=l.retryLane),e_(a,u)}function zw(a,l){var u=0;switch(a.tag){case 31:case 13:var h=a.stateNode,g=a.memoizedState;g!==null&&(u=g.retryLane);break;case 19:h=a.stateNode;break;case 22:h=a.stateNode._retryCache;break;default:throw Error(r(314))}h!==null&&h.delete(l),e_(a,u)}function Fw(a,l){return un(a,l)}var zd=null,Io=null,Bp=!1,Fd=!1,Up=!1,Ds=0;function ra(a){a!==Io&&a.next===null&&(Io===null?zd=Io=a:Io=Io.next=a),Fd=!0,Bp||(Bp=!0,jw())}function lc(a,l){if(!Up&&Fd){Up=!0;do for(var u=!1,h=zd;h!==null;){if(a!==0){var g=h.pendingLanes;if(g===0)var b=0;else{var w=h.suspendedLanes,R=h.pingedLanes;b=(1<<31-Zt(42|a)+1)-1,b&=g&~(w&~R),b=b&201326741?b&201326741|1:b?b|2:0}b!==0&&(u=!0,i_(h,b))}else b=Ut,b=W(h,h===dn?b:0,h.cancelPendingCommit!==null||h.timeoutHandle!==-1),(b&3)===0||ye(h,b)||(u=!0,i_(h,b));h=h.next}while(u);Up=!1}}function Hw(){t_()}function t_(){Fd=Bp=!1;var a=0;Ds!==0&&Zw()&&(a=Ds);for(var l=Xt(),u=null,h=zd;h!==null;){var g=h.next,b=n_(h,l);b===0?(h.next=null,u===null?zd=g:u.next=g,g===null&&(Io=u)):(u=h,(a!==0||(b&3)!==0)&&(Fd=!0)),h=g}sr!==0&&sr!==5||lc(a),Ds!==0&&(Ds=0)}function n_(a,l){for(var u=a.suspendedLanes,h=a.pingedLanes,g=a.expirationTimes,b=a.pendingLanes&-62914561;0<b;){var w=31-Zt(b),R=1<<w,K=g[w];K===-1?((R&u)===0||(R&h)!==0)&&(g[w]=Fe(R,l)):K<=l&&(a.expiredLanes|=R),b&=~R}if(l=dn,u=Ut,u=W(a,a===l?u:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),h=a.callbackNode,u===0||a===l&&(tn===2||tn===9)||a.cancelPendingCommit!==null)return h!==null&&h!==null&&Ge(h),a.callbackNode=null,a.callbackPriority=0;if((u&3)===0||ye(a,u)){if(l=u&-u,l===a.callbackPriority)return l;switch(h!==null&&Ge(h),ya(u)){case 2:case 8:u=Ce;break;case 32:u=Ye;break;case 268435456:u=Ue;break;default:u=Ye}return h=r_.bind(null,a),u=un(u,h),a.callbackPriority=l,a.callbackNode=u,l}return h!==null&&h!==null&&Ge(h),a.callbackPriority=2,a.callbackNode=null,2}function r_(a,l){if(sr!==0&&sr!==5)return a.callbackNode=null,a.callbackPriority=0,null;var u=a.callbackNode;if(Ud()&&a.callbackNode!==u)return null;var h=Ut;return h=W(a,a===dn?h:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),h===0?null:(U3(a,h,l),n_(a,Xt()),a.callbackNode!=null&&a.callbackNode===u?r_.bind(null,a):null)}function i_(a,l){if(Ud())return null;U3(a,l,!0)}function jw(){eA(function(){(Kt&6)!==0?un(me,Hw):t_()})}function zp(){if(Ds===0){var a=vo;a===0&&(a=dl,dl<<=1,(dl&261888)===0&&(dl=256)),Ds=a}return Ds}function a_(a){return a==null||typeof a=="symbol"||typeof a=="boolean"?null:typeof a=="function"?a:bs(""+a)}function s_(a,l){var u=l.ownerDocument.createElement("input");return u.name=l.name,u.value=l.value,a.id&&u.setAttribute("form",a.id),l.parentNode.insertBefore(u,l),a=new FormData(a),u.parentNode.removeChild(u),a}function qw(a,l,u,h,g){if(l==="submit"&&u&&u.stateNode===g){var b=a_((g[Sr]||null).action),w=h.submitter;w&&(l=(l=w[Sr]||null)?a_(l.formAction):w.getAttribute("formAction"),l!==null&&(b=l,w=null));var R=new Z0("action","action",null,h,g);a.push({event:R,listeners:[{instance:null,listener:function(){if(h.defaultPrevented){if(Ds!==0){var K=w?s_(g,w):new FormData(g);ap(u,{pending:!0,data:K,method:g.method,action:b},null,K)}}else typeof b=="function"&&(R.preventDefault(),K=w?s_(g,w):new FormData(g),ap(u,{pending:!0,data:K,method:g.method,action:b},b,K))},currentTarget:g}]})}}for(var Fp=0;Fp<Tm.length;Fp++){var Hp=Tm[Fp],$w=Hp.toLowerCase(),Gw=Hp[0].toUpperCase()+Hp.slice(1);qi($w,"on"+Gw)}qi(Bv,"onAnimationEnd"),qi(Uv,"onAnimationIteration"),qi(zv,"onAnimationStart"),qi("dblclick","onDoubleClick"),qi("focusin","onFocus"),qi("focusout","onBlur"),qi(lw,"onTransitionRun"),qi(ow,"onTransitionStart"),qi(uw,"onTransitionCancel"),qi(Fv,"onTransitionEnd"),Me("onMouseEnter",["mouseout","mouseover"]),Me("onMouseLeave",["mouseout","mouseover"]),Me("onPointerEnter",["pointerout","pointerover"]),Me("onPointerLeave",["pointerout","pointerover"]),Ta("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Ta("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Ta("onBeforeInput",["compositionend","keypress","textInput","paste"]),Ta("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Ta("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Ta("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var oc="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Yw=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(oc));function l_(a,l){l=(l&4)!==0;for(var u=0;u<a.length;u++){var h=a[u],g=h.event;h=h.listeners;e:{var b=void 0;if(l)for(var w=h.length-1;0<=w;w--){var R=h[w],K=R.instance,le=R.currentTarget;if(R=R.listener,K!==b&&g.isPropagationStopped())break e;b=R,g.currentTarget=le;try{b(g)}catch(_e){td(_e)}g.currentTarget=null,b=K}else for(w=0;w<h.length;w++){if(R=h[w],K=R.instance,le=R.currentTarget,R=R.listener,K!==b&&g.isPropagationStopped())break e;b=R,g.currentTarget=le;try{b(g)}catch(_e){td(_e)}g.currentTarget=null,b=K}}}}function It(a,l){var u=l[Su];u===void 0&&(u=l[Su]=new Set);var h=a+"__bubble";u.has(h)||(o_(l,a,2,!1),u.add(h))}function jp(a,l,u){var h=0;l&&(h|=4),o_(u,a,h,l)}var Hd="_reactListening"+Math.random().toString(36).slice(2);function qp(a){if(!a[Hd]){a[Hd]=!0,$0.forEach(function(u){u!=="selectionchange"&&(Yw.has(u)||jp(u,!1,a),jp(u,!0,a))});var l=a.nodeType===9?a:a.ownerDocument;l===null||l[Hd]||(l[Hd]=!0,jp("selectionchange",!1,l))}}function o_(a,l,u,h){switch(B_(l)){case 2:var g=yA;break;case 8:g=EA;break;default:g=i1}u=g.bind(null,l,u,a),g=void 0,!um||l!=="touchstart"&&l!=="touchmove"&&l!=="wheel"||(g=!0),h?g!==void 0?a.addEventListener(l,u,{capture:!0,passive:g}):a.addEventListener(l,u,!0):g!==void 0?a.addEventListener(l,u,{passive:g}):a.addEventListener(l,u,!1)}function $p(a,l,u,h,g){var b=h;if((l&1)===0&&(l&2)===0&&h!==null)e:for(;;){if(h===null)return;var w=h.tag;if(w===3||w===4){var R=h.stateNode.containerInfo;if(R===g)break;if(w===4)for(w=h.return;w!==null;){var K=w.tag;if((K===3||K===4)&&w.stateNode.containerInfo===g)return;w=w.return}for(;R!==null;){if(w=Ir(R),w===null)return;if(K=w.tag,K===5||K===6||K===26||K===27){h=b=w;continue e}R=R.parentNode}}h=h.return}K0(function(){var le=b,_e=vt(u),Te=[];e:{var ce=Hv.get(a);if(ce!==void 0){var pe=Z0,Qe=a;switch(a){case"keypress":if(X0(u)===0)break e;case"keydown":case"keyup":pe=z9;break;case"focusin":Qe="focus",pe=fm;break;case"focusout":Qe="blur",pe=fm;break;case"beforeblur":case"afterblur":pe=fm;break;case"click":if(u.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":pe=gv;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":pe=k9;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":pe=j9;break;case Bv:case Uv:case zv:pe=O9;break;case Fv:pe=$9;break;case"scroll":case"scrollend":pe=w9;break;case"wheel":pe=Y9;break;case"copy":case"cut":case"paste":pe=M9;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":pe=vv;break;case"toggle":case"beforetoggle":pe=K9}var ot=(l&4)!==0,ln=!ot&&(a==="scroll"||a==="scrollend"),ne=ot?ce!==null?ce+"Capture":null:ce;ot=[];for(var X=le,ae;X!==null;){var Ee=X;if(ae=Ee.stateNode,Ee=Ee.tag,Ee!==5&&Ee!==26&&Ee!==27||ae===null||ne===null||(Ee=Ou(X,ne),Ee!=null&&ot.push(uc(X,Ee,ae))),ln)break;X=X.return}0<ot.length&&(ce=new pe(ce,Qe,null,u,_e),Te.push({event:ce,listeners:ot}))}}if((l&7)===0){e:{if(ce=a==="mouseover"||a==="pointerover",pe=a==="mouseout"||a==="pointerout",ce&&u!==Je&&(Qe=u.relatedTarget||u.fromElement)&&(Ir(Qe)||Qe[fs]))break e;if((pe||ce)&&(ce=_e.window===_e?_e:(ce=_e.ownerDocument)?ce.defaultView||ce.parentWindow:window,pe?(Qe=u.relatedTarget||u.toElement,pe=le,Qe=Qe?Ir(Qe):null,Qe!==null&&(ln=s(Qe),ot=Qe.tag,Qe!==ln||ot!==5&&ot!==27&&ot!==6)&&(Qe=null)):(pe=null,Qe=le),pe!==Qe)){if(ot=gv,Ee="onMouseLeave",ne="onMouseEnter",X="mouse",(a==="pointerout"||a==="pointerover")&&(ot=vv,Ee="onPointerLeave",ne="onPointerEnter",X="pointer"),ln=pe==null?ce:ms(pe),ae=Qe==null?ce:ms(Qe),ce=new ot(Ee,X+"leave",pe,u,_e),ce.target=ln,ce.relatedTarget=ae,Ee=null,Ir(_e)===le&&(ot=new ot(ne,X+"enter",Qe,u,_e),ot.target=ae,ot.relatedTarget=ln,Ee=ot),ln=Ee,pe&&Qe)t:{for(ot=Vw,ne=pe,X=Qe,ae=0,Ee=ne;Ee;Ee=ot(Ee))ae++;Ee=0;for(var rt=X;rt;rt=ot(rt))Ee++;for(;0<ae-Ee;)ne=ot(ne),ae--;for(;0<Ee-ae;)X=ot(X),Ee--;for(;ae--;){if(ne===X||X!==null&&ne===X.alternate){ot=ne;break t}ne=ot(ne),X=ot(X)}ot=null}else ot=null;pe!==null&&u_(Te,ce,pe,ot,!1),Qe!==null&&ln!==null&&u_(Te,ln,Qe,ot,!0)}}e:{if(ce=le?ms(le):window,pe=ce.nodeName&&ce.nodeName.toLowerCase(),pe==="select"||pe==="input"&&ce.type==="file")var Gt=Av;else if(Sv(ce))if(kv)Gt=iw;else{Gt=nw;var et=tw}else pe=ce.nodeName,!pe||pe.toLowerCase()!=="input"||ce.type!=="checkbox"&&ce.type!=="radio"?le&&gs(le.elementType)&&(Gt=Av):Gt=rw;if(Gt&&(Gt=Gt(a,le))){wv(Te,Gt,u,_e);break e}et&&et(a,ce,le),a==="focusout"&&le&&ce.type==="number"&&le.memoizedProps.value!=null&&so(ce,"number",ce.value)}switch(et=le?ms(le):window,a){case"focusin":(Sv(et)||et.contentEditable==="true")&&(uo=et,_m=le,Uu=null);break;case"focusout":Uu=_m=uo=null;break;case"mousedown":ym=!0;break;case"contextmenu":case"mouseup":case"dragend":ym=!1,Lv(Te,u,_e);break;case"selectionchange":if(sw)break;case"keydown":case"keyup":Lv(Te,u,_e)}var xt;if(pm)e:{switch(a){case"compositionstart":var zt="onCompositionStart";break e;case"compositionend":zt="onCompositionEnd";break e;case"compositionupdate":zt="onCompositionUpdate";break e}zt=void 0}else oo?Tv(a,u)&&(zt="onCompositionEnd"):a==="keydown"&&u.keyCode===229&&(zt="onCompositionStart");zt&&(_v&&u.locale!=="ko"&&(oo||zt!=="onCompositionStart"?zt==="onCompositionEnd"&&oo&&(xt=mv()):(vs=_e,cm="value"in vs?vs.value:vs.textContent,oo=!0)),et=jd(le,zt),0<et.length&&(zt=new bv(zt,a,null,u,_e),Te.push({event:zt,listeners:et}),xt?zt.data=xt:(xt=xv(u),xt!==null&&(zt.data=xt)))),(xt=X9?Q9(a,u):Z9(a,u))&&(zt=jd(le,"onBeforeInput"),0<zt.length&&(et=new bv("onBeforeInput","beforeinput",null,u,_e),Te.push({event:et,listeners:zt}),et.data=xt)),qw(Te,a,le,u,_e)}l_(Te,l)})}function uc(a,l,u){return{instance:a,listener:l,currentTarget:u}}function jd(a,l){for(var u=l+"Capture",h=[];a!==null;){var g=a,b=g.stateNode;if(g=g.tag,g!==5&&g!==26&&g!==27||b===null||(g=Ou(a,u),g!=null&&h.unshift(uc(a,g,b)),g=Ou(a,l),g!=null&&h.push(uc(a,g,b))),a.tag===3)return h;a=a.return}return[]}function Vw(a){if(a===null)return null;do a=a.return;while(a&&a.tag!==5&&a.tag!==27);return a||null}function u_(a,l,u,h,g){for(var b=l._reactName,w=[];u!==null&&u!==h;){var R=u,K=R.alternate,le=R.stateNode;if(R=R.tag,K!==null&&K===h)break;R!==5&&R!==26&&R!==27||le===null||(K=le,g?(le=Ou(u,b),le!=null&&w.unshift(uc(u,le,K))):g||(le=Ou(u,b),le!=null&&w.push(uc(u,le,K)))),u=u.return}w.length!==0&&a.push({event:l,listeners:w})}var Kw=/\r\n?/g,Ww=/\u0000|\uFFFD/g;function c_(a){return(typeof a=="string"?a:""+a).replace(Kw,`
`).replace(Ww,"")}function d_(a,l){return l=c_(l),c_(a)===l}function sn(a,l,u,h,g,b){switch(u){case"children":typeof h=="string"?l==="body"||l==="textarea"&&h===""||ut(a,h):(typeof h=="number"||typeof h=="bigint")&&l!=="body"&&ut(a,""+h);break;case"className":oi(a,"class",h);break;case"tabIndex":oi(a,"tabindex",h);break;case"dir":case"role":case"viewBox":case"width":case"height":oi(a,u,h);break;case"style":en(a,h,b);break;case"data":if(l!=="object"){oi(a,"data",h);break}case"src":case"href":if(h===""&&(l!=="a"||u!=="href")){a.removeAttribute(u);break}if(h==null||typeof h=="function"||typeof h=="symbol"||typeof h=="boolean"){a.removeAttribute(u);break}h=bs(""+h),a.setAttribute(u,h);break;case"action":case"formAction":if(typeof h=="function"){a.setAttribute(u,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof b=="function"&&(u==="formAction"?(l!=="input"&&sn(a,l,"name",g.name,g,null),sn(a,l,"formEncType",g.formEncType,g,null),sn(a,l,"formMethod",g.formMethod,g,null),sn(a,l,"formTarget",g.formTarget,g,null)):(sn(a,l,"encType",g.encType,g,null),sn(a,l,"method",g.method,g,null),sn(a,l,"target",g.target,g,null)));if(h==null||typeof h=="symbol"||typeof h=="boolean"){a.removeAttribute(u);break}h=bs(""+h),a.setAttribute(u,h);break;case"onClick":h!=null&&(a.onclick=Pe);break;case"onScroll":h!=null&&It("scroll",a);break;case"onScrollEnd":h!=null&&It("scrollend",a);break;case"dangerouslySetInnerHTML":if(h!=null){if(typeof h!="object"||!("__html"in h))throw Error(r(61));if(u=h.__html,u!=null){if(g.children!=null)throw Error(r(60));a.innerHTML=u}}break;case"multiple":a.multiple=h&&typeof h!="function"&&typeof h!="symbol";break;case"muted":a.muted=h&&typeof h!="function"&&typeof h!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(h==null||typeof h=="function"||typeof h=="boolean"||typeof h=="symbol"){a.removeAttribute("xlink:href");break}u=bs(""+h),a.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",u);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":h!=null&&typeof h!="function"&&typeof h!="symbol"?a.setAttribute(u,""+h):a.removeAttribute(u);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":h&&typeof h!="function"&&typeof h!="symbol"?a.setAttribute(u,""):a.removeAttribute(u);break;case"capture":case"download":h===!0?a.setAttribute(u,""):h!==!1&&h!=null&&typeof h!="function"&&typeof h!="symbol"?a.setAttribute(u,h):a.removeAttribute(u);break;case"cols":case"rows":case"size":case"span":h!=null&&typeof h!="function"&&typeof h!="symbol"&&!isNaN(h)&&1<=h?a.setAttribute(u,h):a.removeAttribute(u);break;case"rowSpan":case"start":h==null||typeof h=="function"||typeof h=="symbol"||isNaN(h)?a.removeAttribute(u):a.setAttribute(u,h);break;case"popover":It("beforetoggle",a),It("toggle",a),wr(a,"popover",h);break;case"xlinkActuate":Gr(a,"http://www.w3.org/1999/xlink","xlink:actuate",h);break;case"xlinkArcrole":Gr(a,"http://www.w3.org/1999/xlink","xlink:arcrole",h);break;case"xlinkRole":Gr(a,"http://www.w3.org/1999/xlink","xlink:role",h);break;case"xlinkShow":Gr(a,"http://www.w3.org/1999/xlink","xlink:show",h);break;case"xlinkTitle":Gr(a,"http://www.w3.org/1999/xlink","xlink:title",h);break;case"xlinkType":Gr(a,"http://www.w3.org/1999/xlink","xlink:type",h);break;case"xmlBase":Gr(a,"http://www.w3.org/XML/1998/namespace","xml:base",h);break;case"xmlLang":Gr(a,"http://www.w3.org/XML/1998/namespace","xml:lang",h);break;case"xmlSpace":Gr(a,"http://www.w3.org/XML/1998/namespace","xml:space",h);break;case"is":wr(a,"is",h);break;case"innerText":case"textContent":break;default:(!(2<u.length)||u[0]!=="o"&&u[0]!=="O"||u[1]!=="n"&&u[1]!=="N")&&(u=xa.get(u)||u,wr(a,u,h))}}function Gp(a,l,u,h,g,b){switch(u){case"style":en(a,h,b);break;case"dangerouslySetInnerHTML":if(h!=null){if(typeof h!="object"||!("__html"in h))throw Error(r(61));if(u=h.__html,u!=null){if(g.children!=null)throw Error(r(60));a.innerHTML=u}}break;case"children":typeof h=="string"?ut(a,h):(typeof h=="number"||typeof h=="bigint")&&ut(a,""+h);break;case"onScroll":h!=null&&It("scroll",a);break;case"onScrollEnd":h!=null&&It("scrollend",a);break;case"onClick":h!=null&&(a.onclick=Pe);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!ml.hasOwnProperty(u))e:{if(u[0]==="o"&&u[1]==="n"&&(g=u.endsWith("Capture"),l=u.slice(2,g?u.length-7:void 0),b=a[Sr]||null,b=b!=null?b[u]:null,typeof b=="function"&&a.removeEventListener(l,b,g),typeof h=="function")){typeof b!="function"&&b!==null&&(u in a?a[u]=null:a.hasAttribute(u)&&a.removeAttribute(u)),a.addEventListener(l,h,g);break e}u in a?a[u]=h:h===!0?a.setAttribute(u,""):wr(a,u,h)}}}function yr(a,l,u){switch(l){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":It("error",a),It("load",a);var h=!1,g=!1,b;for(b in u)if(u.hasOwnProperty(b)){var w=u[b];if(w!=null)switch(b){case"src":h=!0;break;case"srcSet":g=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,l));default:sn(a,l,b,w,u,null)}}g&&sn(a,l,"srcSet",u.srcSet,u,null),h&&sn(a,l,"src",u.src,u,null);return;case"input":It("invalid",a);var R=b=w=g=null,K=null,le=null;for(h in u)if(u.hasOwnProperty(h)){var _e=u[h];if(_e!=null)switch(h){case"name":g=_e;break;case"type":w=_e;break;case"checked":K=_e;break;case"defaultChecked":le=_e;break;case"value":b=_e;break;case"defaultValue":R=_e;break;case"children":case"dangerouslySetInnerHTML":if(_e!=null)throw Error(r(137,l));break;default:sn(a,l,h,_e,u,null)}}pl(a,b,R,K,le,w,g,!1);return;case"select":It("invalid",a),h=w=b=null;for(g in u)if(u.hasOwnProperty(g)&&(R=u[g],R!=null))switch(g){case"value":b=R;break;case"defaultValue":w=R;break;case"multiple":h=R;default:sn(a,l,g,R,u,null)}l=b,u=w,a.multiple=!!h,l!=null?gr(a,!!h,l,!1):u!=null&&gr(a,!!h,u,!0);return;case"textarea":It("invalid",a),b=g=h=null;for(w in u)if(u.hasOwnProperty(w)&&(R=u[w],R!=null))switch(w){case"value":h=R;break;case"defaultValue":g=R;break;case"children":b=R;break;case"dangerouslySetInnerHTML":if(R!=null)throw Error(r(91));break;default:sn(a,l,w,R,u,null)}lo(a,h,g,b);return;case"option":for(K in u)if(u.hasOwnProperty(K)&&(h=u[K],h!=null))switch(K){case"selected":a.selected=h&&typeof h!="function"&&typeof h!="symbol";break;default:sn(a,l,K,h,u,null)}return;case"dialog":It("beforetoggle",a),It("toggle",a),It("cancel",a),It("close",a);break;case"iframe":case"object":It("load",a);break;case"video":case"audio":for(h=0;h<oc.length;h++)It(oc[h],a);break;case"image":It("error",a),It("load",a);break;case"details":It("toggle",a);break;case"embed":case"source":case"link":It("error",a),It("load",a);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(le in u)if(u.hasOwnProperty(le)&&(h=u[le],h!=null))switch(le){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,l));default:sn(a,l,le,h,u,null)}return;default:if(gs(l)){for(_e in u)u.hasOwnProperty(_e)&&(h=u[_e],h!==void 0&&Gp(a,l,_e,h,u,void 0));return}}for(R in u)u.hasOwnProperty(R)&&(h=u[R],h!=null&&sn(a,l,R,h,u,null))}function Xw(a,l,u,h){switch(l){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var g=null,b=null,w=null,R=null,K=null,le=null,_e=null;for(pe in u){var Te=u[pe];if(u.hasOwnProperty(pe)&&Te!=null)switch(pe){case"checked":break;case"value":break;case"defaultValue":K=Te;default:h.hasOwnProperty(pe)||sn(a,l,pe,null,h,Te)}}for(var ce in h){var pe=h[ce];if(Te=u[ce],h.hasOwnProperty(ce)&&(pe!=null||Te!=null))switch(ce){case"type":b=pe;break;case"name":g=pe;break;case"checked":le=pe;break;case"defaultChecked":_e=pe;break;case"value":w=pe;break;case"defaultValue":R=pe;break;case"children":case"dangerouslySetInnerHTML":if(pe!=null)throw Error(r(137,l));break;default:pe!==Te&&sn(a,l,ce,pe,h,Te)}}ku(a,w,R,K,le,_e,b,g);return;case"select":pe=w=R=ce=null;for(b in u)if(K=u[b],u.hasOwnProperty(b)&&K!=null)switch(b){case"value":break;case"multiple":pe=K;default:h.hasOwnProperty(b)||sn(a,l,b,null,h,K)}for(g in h)if(b=h[g],K=u[g],h.hasOwnProperty(g)&&(b!=null||K!=null))switch(g){case"value":ce=b;break;case"defaultValue":R=b;break;case"multiple":w=b;default:b!==K&&sn(a,l,g,b,h,K)}l=R,u=w,h=pe,ce!=null?gr(a,!!u,ce,!1):!!h!=!!u&&(l!=null?gr(a,!!u,l,!0):gr(a,!!u,u?[]:"",!1));return;case"textarea":pe=ce=null;for(R in u)if(g=u[R],u.hasOwnProperty(R)&&g!=null&&!h.hasOwnProperty(R))switch(R){case"value":break;case"children":break;default:sn(a,l,R,null,h,g)}for(w in h)if(g=h[w],b=u[w],h.hasOwnProperty(w)&&(g!=null||b!=null))switch(w){case"value":ce=g;break;case"defaultValue":pe=g;break;case"children":break;case"dangerouslySetInnerHTML":if(g!=null)throw Error(r(91));break;default:g!==b&&sn(a,l,w,g,h,b)}Y0(a,ce,pe);return;case"option":for(var Qe in u)if(ce=u[Qe],u.hasOwnProperty(Qe)&&ce!=null&&!h.hasOwnProperty(Qe))switch(Qe){case"selected":a.selected=!1;break;default:sn(a,l,Qe,null,h,ce)}for(K in h)if(ce=h[K],pe=u[K],h.hasOwnProperty(K)&&ce!==pe&&(ce!=null||pe!=null))switch(K){case"selected":a.selected=ce&&typeof ce!="function"&&typeof ce!="symbol";break;default:sn(a,l,K,ce,h,pe)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var ot in u)ce=u[ot],u.hasOwnProperty(ot)&&ce!=null&&!h.hasOwnProperty(ot)&&sn(a,l,ot,null,h,ce);for(le in h)if(ce=h[le],pe=u[le],h.hasOwnProperty(le)&&ce!==pe&&(ce!=null||pe!=null))switch(le){case"children":case"dangerouslySetInnerHTML":if(ce!=null)throw Error(r(137,l));break;default:sn(a,l,le,ce,h,pe)}return;default:if(gs(l)){for(var ln in u)ce=u[ln],u.hasOwnProperty(ln)&&ce!==void 0&&!h.hasOwnProperty(ln)&&Gp(a,l,ln,void 0,h,ce);for(_e in h)ce=h[_e],pe=u[_e],!h.hasOwnProperty(_e)||ce===pe||ce===void 0&&pe===void 0||Gp(a,l,_e,ce,h,pe);return}}for(var ne in u)ce=u[ne],u.hasOwnProperty(ne)&&ce!=null&&!h.hasOwnProperty(ne)&&sn(a,l,ne,null,h,ce);for(Te in h)ce=h[Te],pe=u[Te],!h.hasOwnProperty(Te)||ce===pe||ce==null&&pe==null||sn(a,l,Te,ce,h,pe)}function h_(a){switch(a){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function Qw(){if(typeof performance.getEntriesByType=="function"){for(var a=0,l=0,u=performance.getEntriesByType("resource"),h=0;h<u.length;h++){var g=u[h],b=g.transferSize,w=g.initiatorType,R=g.duration;if(b&&R&&h_(w)){for(w=0,R=g.responseEnd,h+=1;h<u.length;h++){var K=u[h],le=K.startTime;if(le>R)break;var _e=K.transferSize,Te=K.initiatorType;_e&&h_(Te)&&(K=K.responseEnd,w+=_e*(K<R?1:(R-le)/(K-le)))}if(--h,l+=8*(b+w)/(g.duration/1e3),a++,10<a)break}}if(0<a)return l/a/1e6}return navigator.connection&&(a=navigator.connection.downlink,typeof a=="number")?a:5}var Yp=null,Vp=null;function qd(a){return a.nodeType===9?a:a.ownerDocument}function f_(a){switch(a){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function m_(a,l){if(a===0)switch(l){case"svg":return 1;case"math":return 2;default:return 0}return a===1&&l==="foreignObject"?0:a}function Kp(a,l){return a==="textarea"||a==="noscript"||typeof l.children=="string"||typeof l.children=="number"||typeof l.children=="bigint"||typeof l.dangerouslySetInnerHTML=="object"&&l.dangerouslySetInnerHTML!==null&&l.dangerouslySetInnerHTML.__html!=null}var Wp=null;function Zw(){var a=window.event;return a&&a.type==="popstate"?a===Wp?!1:(Wp=a,!0):(Wp=null,!1)}var p_=typeof setTimeout=="function"?setTimeout:void 0,Jw=typeof clearTimeout=="function"?clearTimeout:void 0,g_=typeof Promise=="function"?Promise:void 0,eA=typeof queueMicrotask=="function"?queueMicrotask:typeof g_<"u"?function(a){return g_.resolve(null).then(a).catch(tA)}:p_;function tA(a){setTimeout(function(){throw a})}function Ls(a){return a==="head"}function b_(a,l){var u=l,h=0;do{var g=u.nextSibling;if(a.removeChild(u),g&&g.nodeType===8)if(u=g.data,u==="/$"||u==="/&"){if(h===0){a.removeChild(g),Bo(l);return}h--}else if(u==="$"||u==="$?"||u==="$~"||u==="$!"||u==="&")h++;else if(u==="html")cc(a.ownerDocument.documentElement);else if(u==="head"){u=a.ownerDocument.head,cc(u);for(var b=u.firstChild;b;){var w=b.nextSibling,R=b.nodeName;b[fl]||R==="SCRIPT"||R==="STYLE"||R==="LINK"&&b.rel.toLowerCase()==="stylesheet"||u.removeChild(b),b=w}}else u==="body"&&cc(a.ownerDocument.body);u=g}while(u);Bo(l)}function v_(a,l){var u=a;a=0;do{var h=u.nextSibling;if(u.nodeType===1?l?(u._stashedDisplay=u.style.display,u.style.display="none"):(u.style.display=u._stashedDisplay||"",u.getAttribute("style")===""&&u.removeAttribute("style")):u.nodeType===3&&(l?(u._stashedText=u.nodeValue,u.nodeValue=""):u.nodeValue=u._stashedText||""),h&&h.nodeType===8)if(u=h.data,u==="/$"){if(a===0)break;a--}else u!=="$"&&u!=="$?"&&u!=="$~"&&u!=="$!"||a++;u=h}while(u)}function Xp(a){var l=a.firstChild;for(l&&l.nodeType===10&&(l=l.nextSibling);l;){var u=l;switch(l=l.nextSibling,u.nodeName){case"HTML":case"HEAD":case"BODY":Xp(u),wu(u);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(u.rel.toLowerCase()==="stylesheet")continue}a.removeChild(u)}}function nA(a,l,u,h){for(;a.nodeType===1;){var g=u;if(a.nodeName.toLowerCase()!==l.toLowerCase()){if(!h&&(a.nodeName!=="INPUT"||a.type!=="hidden"))break}else if(h){if(!a[fl])switch(l){case"meta":if(!a.hasAttribute("itemprop"))break;return a;case"link":if(b=a.getAttribute("rel"),b==="stylesheet"&&a.hasAttribute("data-precedence"))break;if(b!==g.rel||a.getAttribute("href")!==(g.href==null||g.href===""?null:g.href)||a.getAttribute("crossorigin")!==(g.crossOrigin==null?null:g.crossOrigin)||a.getAttribute("title")!==(g.title==null?null:g.title))break;return a;case"style":if(a.hasAttribute("data-precedence"))break;return a;case"script":if(b=a.getAttribute("src"),(b!==(g.src==null?null:g.src)||a.getAttribute("type")!==(g.type==null?null:g.type)||a.getAttribute("crossorigin")!==(g.crossOrigin==null?null:g.crossOrigin))&&b&&a.hasAttribute("async")&&!a.hasAttribute("itemprop"))break;return a;default:return a}}else if(l==="input"&&a.type==="hidden"){var b=g.name==null?null:""+g.name;if(g.type==="hidden"&&a.getAttribute("name")===b)return a}else return a;if(a=Mi(a.nextSibling),a===null)break}return null}function rA(a,l,u){if(l==="")return null;for(;a.nodeType!==3;)if((a.nodeType!==1||a.nodeName!=="INPUT"||a.type!=="hidden")&&!u||(a=Mi(a.nextSibling),a===null))return null;return a}function __(a,l){for(;a.nodeType!==8;)if((a.nodeType!==1||a.nodeName!=="INPUT"||a.type!=="hidden")&&!l||(a=Mi(a.nextSibling),a===null))return null;return a}function Qp(a){return a.data==="$?"||a.data==="$~"}function Zp(a){return a.data==="$!"||a.data==="$?"&&a.ownerDocument.readyState!=="loading"}function iA(a,l){var u=a.ownerDocument;if(a.data==="$~")a._reactRetry=l;else if(a.data!=="$?"||u.readyState!=="loading")l();else{var h=function(){l(),u.removeEventListener("DOMContentLoaded",h)};u.addEventListener("DOMContentLoaded",h),a._reactRetry=h}}function Mi(a){for(;a!=null;a=a.nextSibling){var l=a.nodeType;if(l===1||l===3)break;if(l===8){if(l=a.data,l==="$"||l==="$!"||l==="$?"||l==="$~"||l==="&"||l==="F!"||l==="F")break;if(l==="/$"||l==="/&")return null}}return a}var Jp=null;function y_(a){a=a.nextSibling;for(var l=0;a;){if(a.nodeType===8){var u=a.data;if(u==="/$"||u==="/&"){if(l===0)return Mi(a.nextSibling);l--}else u!=="$"&&u!=="$!"&&u!=="$?"&&u!=="$~"&&u!=="&"||l++}a=a.nextSibling}return null}function E_(a){a=a.previousSibling;for(var l=0;a;){if(a.nodeType===8){var u=a.data;if(u==="$"||u==="$!"||u==="$?"||u==="$~"||u==="&"){if(l===0)return a;l--}else u!=="/$"&&u!=="/&"||l++}a=a.previousSibling}return null}function T_(a,l,u){switch(l=qd(u),a){case"html":if(a=l.documentElement,!a)throw Error(r(452));return a;case"head":if(a=l.head,!a)throw Error(r(453));return a;case"body":if(a=l.body,!a)throw Error(r(454));return a;default:throw Error(r(451))}}function cc(a){for(var l=a.attributes;l.length;)a.removeAttributeNode(l[0]);wu(a)}var Ii=new Map,x_=new Set;function $d(a){return typeof a.getRootNode=="function"?a.getRootNode():a.nodeType===9?a:a.ownerDocument}var za=ie.d;ie.d={f:aA,r:sA,D:lA,C:oA,L:uA,m:cA,X:hA,S:dA,M:fA};function aA(){var a=za.f(),l=Ld();return a||l}function sA(a){var l=Ea(a);l!==null&&l.tag===5&&l.type==="form"?F4(l):za.r(a)}var Do=typeof document>"u"?null:document;function S_(a,l,u){var h=Do;if(h&&typeof l=="string"&&l){var g=Yr(l);g='link[rel="'+a+'"][href="'+g+'"]',typeof u=="string"&&(g+='[crossorigin="'+u+'"]'),x_.has(g)||(x_.add(g),a={rel:a,crossOrigin:u,href:l},h.querySelector(g)===null&&(l=h.createElement("link"),yr(l,"link",a),Xn(l),h.head.appendChild(l)))}}function lA(a){za.D(a),S_("dns-prefetch",a,null)}function oA(a,l){za.C(a,l),S_("preconnect",a,l)}function uA(a,l,u){za.L(a,l,u);var h=Do;if(h&&a&&l){var g='link[rel="preload"][as="'+Yr(l)+'"]';l==="image"&&u&&u.imageSrcSet?(g+='[imagesrcset="'+Yr(u.imageSrcSet)+'"]',typeof u.imageSizes=="string"&&(g+='[imagesizes="'+Yr(u.imageSizes)+'"]')):g+='[href="'+Yr(a)+'"]';var b=g;switch(l){case"style":b=Lo(a);break;case"script":b=Po(a)}Ii.has(b)||(a=p({rel:"preload",href:l==="image"&&u&&u.imageSrcSet?void 0:a,as:l},u),Ii.set(b,a),h.querySelector(g)!==null||l==="style"&&h.querySelector(dc(b))||l==="script"&&h.querySelector(hc(b))||(l=h.createElement("link"),yr(l,"link",a),Xn(l),h.head.appendChild(l)))}}function cA(a,l){za.m(a,l);var u=Do;if(u&&a){var h=l&&typeof l.as=="string"?l.as:"script",g='link[rel="modulepreload"][as="'+Yr(h)+'"][href="'+Yr(a)+'"]',b=g;switch(h){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":b=Po(a)}if(!Ii.has(b)&&(a=p({rel:"modulepreload",href:a},l),Ii.set(b,a),u.querySelector(g)===null)){switch(h){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(u.querySelector(hc(b)))return}h=u.createElement("link"),yr(h,"link",a),Xn(h),u.head.appendChild(h)}}}function dA(a,l,u){za.S(a,l,u);var h=Do;if(h&&a){var g=ps(h).hoistableStyles,b=Lo(a);l=l||"default";var w=g.get(b);if(!w){var R={loading:0,preload:null};if(w=h.querySelector(dc(b)))R.loading=5;else{a=p({rel:"stylesheet",href:a,"data-precedence":l},u),(u=Ii.get(b))&&e1(a,u);var K=w=h.createElement("link");Xn(K),yr(K,"link",a),K._p=new Promise(function(le,_e){K.onload=le,K.onerror=_e}),K.addEventListener("load",function(){R.loading|=1}),K.addEventListener("error",function(){R.loading|=2}),R.loading|=4,Gd(w,l,h)}w={type:"stylesheet",instance:w,count:1,state:R},g.set(b,w)}}}function hA(a,l){za.X(a,l);var u=Do;if(u&&a){var h=ps(u).hoistableScripts,g=Po(a),b=h.get(g);b||(b=u.querySelector(hc(g)),b||(a=p({src:a,async:!0},l),(l=Ii.get(g))&&t1(a,l),b=u.createElement("script"),Xn(b),yr(b,"link",a),u.head.appendChild(b)),b={type:"script",instance:b,count:1,state:null},h.set(g,b))}}function fA(a,l){za.M(a,l);var u=Do;if(u&&a){var h=ps(u).hoistableScripts,g=Po(a),b=h.get(g);b||(b=u.querySelector(hc(g)),b||(a=p({src:a,async:!0,type:"module"},l),(l=Ii.get(g))&&t1(a,l),b=u.createElement("script"),Xn(b),yr(b,"link",a),u.head.appendChild(b)),b={type:"script",instance:b,count:1,state:null},h.set(g,b))}}function w_(a,l,u,h){var g=(g=ze.current)?$d(g):null;if(!g)throw Error(r(446));switch(a){case"meta":case"title":return null;case"style":return typeof u.precedence=="string"&&typeof u.href=="string"?(l=Lo(u.href),u=ps(g).hoistableStyles,h=u.get(l),h||(h={type:"style",instance:null,count:0,state:null},u.set(l,h)),h):{type:"void",instance:null,count:0,state:null};case"link":if(u.rel==="stylesheet"&&typeof u.href=="string"&&typeof u.precedence=="string"){a=Lo(u.href);var b=ps(g).hoistableStyles,w=b.get(a);if(w||(g=g.ownerDocument||g,w={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},b.set(a,w),(b=g.querySelector(dc(a)))&&!b._p&&(w.instance=b,w.state.loading=5),Ii.has(a)||(u={rel:"preload",as:"style",href:u.href,crossOrigin:u.crossOrigin,integrity:u.integrity,media:u.media,hrefLang:u.hrefLang,referrerPolicy:u.referrerPolicy},Ii.set(a,u),b||mA(g,a,u,w.state))),l&&h===null)throw Error(r(528,""));return w}if(l&&h!==null)throw Error(r(529,""));return null;case"script":return l=u.async,u=u.src,typeof u=="string"&&l&&typeof l!="function"&&typeof l!="symbol"?(l=Po(u),u=ps(g).hoistableScripts,h=u.get(l),h||(h={type:"script",instance:null,count:0,state:null},u.set(l,h)),h):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,a))}}function Lo(a){return'href="'+Yr(a)+'"'}function dc(a){return'link[rel="stylesheet"]['+a+"]"}function A_(a){return p({},a,{"data-precedence":a.precedence,precedence:null})}function mA(a,l,u,h){a.querySelector('link[rel="preload"][as="style"]['+l+"]")?h.loading=1:(l=a.createElement("link"),h.preload=l,l.addEventListener("load",function(){return h.loading|=1}),l.addEventListener("error",function(){return h.loading|=2}),yr(l,"link",u),Xn(l),a.head.appendChild(l))}function Po(a){return'[src="'+Yr(a)+'"]'}function hc(a){return"script[async]"+a}function k_(a,l,u){if(l.count++,l.instance===null)switch(l.type){case"style":var h=a.querySelector('style[data-href~="'+Yr(u.href)+'"]');if(h)return l.instance=h,Xn(h),h;var g=p({},u,{"data-href":u.href,"data-precedence":u.precedence,href:null,precedence:null});return h=(a.ownerDocument||a).createElement("style"),Xn(h),yr(h,"style",g),Gd(h,u.precedence,a),l.instance=h;case"stylesheet":g=Lo(u.href);var b=a.querySelector(dc(g));if(b)return l.state.loading|=4,l.instance=b,Xn(b),b;h=A_(u),(g=Ii.get(g))&&e1(h,g),b=(a.ownerDocument||a).createElement("link"),Xn(b);var w=b;return w._p=new Promise(function(R,K){w.onload=R,w.onerror=K}),yr(b,"link",h),l.state.loading|=4,Gd(b,u.precedence,a),l.instance=b;case"script":return b=Po(u.src),(g=a.querySelector(hc(b)))?(l.instance=g,Xn(g),g):(h=u,(g=Ii.get(b))&&(h=p({},u),t1(h,g)),a=a.ownerDocument||a,g=a.createElement("script"),Xn(g),yr(g,"link",h),a.head.appendChild(g),l.instance=g);case"void":return null;default:throw Error(r(443,l.type))}else l.type==="stylesheet"&&(l.state.loading&4)===0&&(h=l.instance,l.state.loading|=4,Gd(h,u.precedence,a));return l.instance}function Gd(a,l,u){for(var h=u.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),g=h.length?h[h.length-1]:null,b=g,w=0;w<h.length;w++){var R=h[w];if(R.dataset.precedence===l)b=R;else if(b!==g)break}b?b.parentNode.insertBefore(a,b.nextSibling):(l=u.nodeType===9?u.head:u,l.insertBefore(a,l.firstChild))}function e1(a,l){a.crossOrigin==null&&(a.crossOrigin=l.crossOrigin),a.referrerPolicy==null&&(a.referrerPolicy=l.referrerPolicy),a.title==null&&(a.title=l.title)}function t1(a,l){a.crossOrigin==null&&(a.crossOrigin=l.crossOrigin),a.referrerPolicy==null&&(a.referrerPolicy=l.referrerPolicy),a.integrity==null&&(a.integrity=l.integrity)}var Yd=null;function C_(a,l,u){if(Yd===null){var h=new Map,g=Yd=new Map;g.set(u,h)}else g=Yd,h=g.get(u),h||(h=new Map,g.set(u,h));if(h.has(a))return h;for(h.set(a,null),u=u.getElementsByTagName(a),g=0;g<u.length;g++){var b=u[g];if(!(b[fl]||b[qn]||a==="link"&&b.getAttribute("rel")==="stylesheet")&&b.namespaceURI!=="http://www.w3.org/2000/svg"){var w=b.getAttribute(l)||"";w=a+w;var R=h.get(w);R?R.push(b):h.set(w,[b])}}return h}function N_(a,l,u){a=a.ownerDocument||a,a.head.insertBefore(u,l==="title"?a.querySelector("head > title"):null)}function pA(a,l,u){if(u===1||l.itemProp!=null)return!1;switch(a){case"meta":case"title":return!0;case"style":if(typeof l.precedence!="string"||typeof l.href!="string"||l.href==="")break;return!0;case"link":if(typeof l.rel!="string"||typeof l.href!="string"||l.href===""||l.onLoad||l.onError)break;switch(l.rel){case"stylesheet":return a=l.disabled,typeof l.precedence=="string"&&a==null;default:return!0}case"script":if(l.async&&typeof l.async!="function"&&typeof l.async!="symbol"&&!l.onLoad&&!l.onError&&l.src&&typeof l.src=="string")return!0}return!1}function O_(a){return!(a.type==="stylesheet"&&(a.state.loading&3)===0)}function gA(a,l,u,h){if(u.type==="stylesheet"&&(typeof h.media!="string"||matchMedia(h.media).matches!==!1)&&(u.state.loading&4)===0){if(u.instance===null){var g=Lo(h.href),b=l.querySelector(dc(g));if(b){l=b._p,l!==null&&typeof l=="object"&&typeof l.then=="function"&&(a.count++,a=Vd.bind(a),l.then(a,a)),u.state.loading|=4,u.instance=b,Xn(b);return}b=l.ownerDocument||l,h=A_(h),(g=Ii.get(g))&&e1(h,g),b=b.createElement("link"),Xn(b);var w=b;w._p=new Promise(function(R,K){w.onload=R,w.onerror=K}),yr(b,"link",h),u.instance=b}a.stylesheets===null&&(a.stylesheets=new Map),a.stylesheets.set(u,l),(l=u.state.preload)&&(u.state.loading&3)===0&&(a.count++,u=Vd.bind(a),l.addEventListener("load",u),l.addEventListener("error",u))}}var n1=0;function bA(a,l){return a.stylesheets&&a.count===0&&Wd(a,a.stylesheets),0<a.count||0<a.imgCount?function(u){var h=setTimeout(function(){if(a.stylesheets&&Wd(a,a.stylesheets),a.unsuspend){var b=a.unsuspend;a.unsuspend=null,b()}},6e4+l);0<a.imgBytes&&n1===0&&(n1=62500*Qw());var g=setTimeout(function(){if(a.waitingForImages=!1,a.count===0&&(a.stylesheets&&Wd(a,a.stylesheets),a.unsuspend)){var b=a.unsuspend;a.unsuspend=null,b()}},(a.imgBytes>n1?50:800)+l);return a.unsuspend=u,function(){a.unsuspend=null,clearTimeout(h),clearTimeout(g)}}:null}function Vd(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Wd(this,this.stylesheets);else if(this.unsuspend){var a=this.unsuspend;this.unsuspend=null,a()}}}var Kd=null;function Wd(a,l){a.stylesheets=null,a.unsuspend!==null&&(a.count++,Kd=new Map,l.forEach(vA,a),Kd=null,Vd.call(a))}function vA(a,l){if(!(l.state.loading&4)){var u=Kd.get(a);if(u)var h=u.get(null);else{u=new Map,Kd.set(a,u);for(var g=a.querySelectorAll("link[data-precedence],style[data-precedence]"),b=0;b<g.length;b++){var w=g[b];(w.nodeName==="LINK"||w.getAttribute("media")!=="not all")&&(u.set(w.dataset.precedence,w),h=w)}h&&u.set(null,h)}g=l.instance,w=g.getAttribute("data-precedence"),b=u.get(w)||h,b===h&&u.set(null,g),u.set(w,g),this.count++,h=Vd.bind(this),g.addEventListener("load",h),g.addEventListener("error",h),b?b.parentNode.insertBefore(g,b.nextSibling):(a=a.nodeType===9?a.head:a,a.insertBefore(g,a.firstChild)),l.state.loading|=4}}var fc={$$typeof:I,Provider:null,Consumer:null,_currentValue:ve,_currentValue2:ve,_threadCount:0};function _A(a,l,u,h,g,b,w,R,K){this.tag=1,this.containerInfo=a,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Tn(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Tn(0),this.hiddenUpdates=Tn(null),this.identifierPrefix=h,this.onUncaughtError=g,this.onCaughtError=b,this.onRecoverableError=w,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=K,this.incompleteTransitions=new Map}function R_(a,l,u,h,g,b,w,R,K,le,_e,Te){return a=new _A(a,l,u,w,K,le,_e,Te,R),l=1,b===!0&&(l|=24),b=di(3,null,null,l),a.current=b,b.stateNode=a,l=Lm(),l.refCount++,a.pooledCache=l,l.refCount++,b.memoizedState={element:h,isDehydrated:u,cache:l},zm(b),a}function M_(a){return a?(a=fo,a):fo}function I_(a,l,u,h,g,b){g=M_(g),h.context===null?h.context=g:h.pendingContext=g,h=Ss(l),h.payload={element:u},b=b===void 0?null:b,b!==null&&(h.callback=b),u=ws(a,h,l),u!==null&&(Zr(u,a,l),Gu(u,a,l))}function D_(a,l){if(a=a.memoizedState,a!==null&&a.dehydrated!==null){var u=a.retryLane;a.retryLane=u!==0&&u<l?u:l}}function r1(a,l){D_(a,l),(a=a.alternate)&&D_(a,l)}function L_(a){if(a.tag===13||a.tag===31){var l=_l(a,67108864);l!==null&&Zr(l,a,67108864),r1(a,67108864)}}function P_(a){if(a.tag===13||a.tag===31){var l=gi();l=Cn(l);var u=_l(a,l);u!==null&&Zr(u,a,l),r1(a,l)}}var Xd=!0;function yA(a,l,u,h){var g=H.T;H.T=null;var b=ie.p;try{ie.p=2,i1(a,l,u,h)}finally{ie.p=b,H.T=g}}function EA(a,l,u,h){var g=H.T;H.T=null;var b=ie.p;try{ie.p=8,i1(a,l,u,h)}finally{ie.p=b,H.T=g}}function i1(a,l,u,h){if(Xd){var g=a1(h);if(g===null)$p(a,l,h,Qd,u),U_(a,h);else if(xA(g,a,l,u,h))h.stopPropagation();else if(U_(a,h),l&4&&-1<TA.indexOf(a)){for(;g!==null;){var b=Ea(g);if(b!==null)switch(b.tag){case 3:if(b=b.stateNode,b.current.memoizedState.isDehydrated){var w=$r(b.pendingLanes);if(w!==0){var R=b;for(R.pendingLanes|=2,R.entangledLanes|=2;w;){var K=1<<31-Zt(w);R.entanglements[1]|=K,w&=~K}ra(b),(Kt&6)===0&&(Id=Xt()+500,lc(0))}}break;case 31:case 13:R=_l(b,2),R!==null&&Zr(R,b,2),Ld(),r1(b,2)}if(b=a1(h),b===null&&$p(a,l,h,Qd,u),b===g)break;g=b}g!==null&&h.stopPropagation()}else $p(a,l,h,null,u)}}function a1(a){return a=vt(a),s1(a)}var Qd=null;function s1(a){if(Qd=null,a=Ir(a),a!==null){var l=s(a);if(l===null)a=null;else{var u=l.tag;if(u===13){if(a=o(l),a!==null)return a;a=null}else if(u===31){if(a=c(l),a!==null)return a;a=null}else if(u===3){if(l.stateNode.current.memoizedState.isDehydrated)return l.tag===3?l.stateNode.containerInfo:null;a=null}else l!==a&&(a=null)}}return Qd=a,null}function B_(a){switch(a){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(En()){case me:return 2;case Ce:return 8;case Ye:case dt:return 32;case Ue:return 268435456;default:return 32}default:return 32}}var l1=!1,Ps=null,Bs=null,Us=null,mc=new Map,pc=new Map,zs=[],TA="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function U_(a,l){switch(a){case"focusin":case"focusout":Ps=null;break;case"dragenter":case"dragleave":Bs=null;break;case"mouseover":case"mouseout":Us=null;break;case"pointerover":case"pointerout":mc.delete(l.pointerId);break;case"gotpointercapture":case"lostpointercapture":pc.delete(l.pointerId)}}function gc(a,l,u,h,g,b){return a===null||a.nativeEvent!==b?(a={blockedOn:l,domEventName:u,eventSystemFlags:h,nativeEvent:b,targetContainers:[g]},l!==null&&(l=Ea(l),l!==null&&L_(l)),a):(a.eventSystemFlags|=h,l=a.targetContainers,g!==null&&l.indexOf(g)===-1&&l.push(g),a)}function xA(a,l,u,h,g){switch(l){case"focusin":return Ps=gc(Ps,a,l,u,h,g),!0;case"dragenter":return Bs=gc(Bs,a,l,u,h,g),!0;case"mouseover":return Us=gc(Us,a,l,u,h,g),!0;case"pointerover":var b=g.pointerId;return mc.set(b,gc(mc.get(b)||null,a,l,u,h,g)),!0;case"gotpointercapture":return b=g.pointerId,pc.set(b,gc(pc.get(b)||null,a,l,u,h,g)),!0}return!1}function z_(a){var l=Ir(a.target);if(l!==null){var u=s(l);if(u!==null){if(l=u.tag,l===13){if(l=o(u),l!==null){a.blockedOn=l,no(a.priority,function(){P_(u)});return}}else if(l===31){if(l=c(u),l!==null){a.blockedOn=l,no(a.priority,function(){P_(u)});return}}else if(l===3&&u.stateNode.current.memoizedState.isDehydrated){a.blockedOn=u.tag===3?u.stateNode.containerInfo:null;return}}}a.blockedOn=null}function Zd(a){if(a.blockedOn!==null)return!1;for(var l=a.targetContainers;0<l.length;){var u=a1(a.nativeEvent);if(u===null){u=a.nativeEvent;var h=new u.constructor(u.type,u);Je=h,u.target.dispatchEvent(h),Je=null}else return l=Ea(u),l!==null&&L_(l),a.blockedOn=u,!1;l.shift()}return!0}function F_(a,l,u){Zd(a)&&u.delete(l)}function SA(){l1=!1,Ps!==null&&Zd(Ps)&&(Ps=null),Bs!==null&&Zd(Bs)&&(Bs=null),Us!==null&&Zd(Us)&&(Us=null),mc.forEach(F_),pc.forEach(F_)}function Jd(a,l){a.blockedOn===l&&(a.blockedOn=null,l1||(l1=!0,e.unstable_scheduleCallback(e.unstable_NormalPriority,SA)))}var eh=null;function H_(a){eh!==a&&(eh=a,e.unstable_scheduleCallback(e.unstable_NormalPriority,function(){eh===a&&(eh=null);for(var l=0;l<a.length;l+=3){var u=a[l],h=a[l+1],g=a[l+2];if(typeof h!="function"){if(s1(h||u)===null)continue;break}var b=Ea(u);b!==null&&(a.splice(l,3),l-=3,ap(b,{pending:!0,data:g,method:u.method,action:h},h,g))}}))}function Bo(a){function l(K){return Jd(K,a)}Ps!==null&&Jd(Ps,a),Bs!==null&&Jd(Bs,a),Us!==null&&Jd(Us,a),mc.forEach(l),pc.forEach(l);for(var u=0;u<zs.length;u++){var h=zs[u];h.blockedOn===a&&(h.blockedOn=null)}for(;0<zs.length&&(u=zs[0],u.blockedOn===null);)z_(u),u.blockedOn===null&&zs.shift();if(u=(a.ownerDocument||a).$$reactFormReplay,u!=null)for(h=0;h<u.length;h+=3){var g=u[h],b=u[h+1],w=g[Sr]||null;if(typeof b=="function")w||H_(u);else if(w){var R=null;if(b&&b.hasAttribute("formAction")){if(g=b,w=b[Sr]||null)R=w.formAction;else if(s1(g)!==null)continue}else R=w.action;typeof R=="function"?u[h+1]=R:(u.splice(h,3),h-=3),H_(u)}}}function j_(){function a(b){b.canIntercept&&b.info==="react-transition"&&b.intercept({handler:function(){return new Promise(function(w){return g=w})},focusReset:"manual",scroll:"manual"})}function l(){g!==null&&(g(),g=null),h||setTimeout(u,20)}function u(){if(!h&&!navigation.transition){var b=navigation.currentEntry;b&&b.url!=null&&navigation.navigate(b.url,{state:b.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var h=!1,g=null;return navigation.addEventListener("navigate",a),navigation.addEventListener("navigatesuccess",l),navigation.addEventListener("navigateerror",l),setTimeout(u,100),function(){h=!0,navigation.removeEventListener("navigate",a),navigation.removeEventListener("navigatesuccess",l),navigation.removeEventListener("navigateerror",l),g!==null&&(g(),g=null)}}}function o1(a){this._internalRoot=a}th.prototype.render=o1.prototype.render=function(a){var l=this._internalRoot;if(l===null)throw Error(r(409));var u=l.current,h=gi();I_(u,h,a,l,null,null)},th.prototype.unmount=o1.prototype.unmount=function(){var a=this._internalRoot;if(a!==null){this._internalRoot=null;var l=a.containerInfo;I_(a.current,2,null,a,null,null),Ld(),l[fs]=null}};function th(a){this._internalRoot=a}th.prototype.unstable_scheduleHydration=function(a){if(a){var l=to();a={blockedOn:null,target:a,priority:l};for(var u=0;u<zs.length&&l!==0&&l<zs[u].priority;u++);zs.splice(u,0,a),u===0&&z_(a)}};var q_=t.version;if(q_!=="19.2.3")throw Error(r(527,q_,"19.2.3"));ie.findDOMNode=function(a){var l=a._reactInternals;if(l===void 0)throw typeof a.render=="function"?Error(r(188)):(a=Object.keys(a).join(","),Error(r(268,a)));return a=f(l),a=a!==null?m(a):null,a=a===null?null:a.stateNode,a};var wA={bundleType:0,version:"19.2.3",rendererPackageName:"react-dom",currentDispatcherRef:H,reconcilerVersion:"19.2.3"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var nh=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!nh.isDisabled&&nh.supportsFiber)try{Rt=nh.inject(wA),At=nh}catch{}}return vc.createRoot=function(a,l){if(!i(a))throw Error(r(299));var u=!1,h="",g=X4,b=Q4,w=Z4;return l!=null&&(l.unstable_strictMode===!0&&(u=!0),l.identifierPrefix!==void 0&&(h=l.identifierPrefix),l.onUncaughtError!==void 0&&(g=l.onUncaughtError),l.onCaughtError!==void 0&&(b=l.onCaughtError),l.onRecoverableError!==void 0&&(w=l.onRecoverableError)),l=R_(a,1,!1,null,null,u,h,null,g,b,w,j_),a[fs]=l.current,qp(a),new o1(l)},vc.hydrateRoot=function(a,l,u){if(!i(a))throw Error(r(299));var h=!1,g="",b=X4,w=Q4,R=Z4,K=null;return u!=null&&(u.unstable_strictMode===!0&&(h=!0),u.identifierPrefix!==void 0&&(g=u.identifierPrefix),u.onUncaughtError!==void 0&&(b=u.onUncaughtError),u.onCaughtError!==void 0&&(w=u.onCaughtError),u.onRecoverableError!==void 0&&(R=u.onRecoverableError),u.formState!==void 0&&(K=u.formState)),l=R_(a,1,!0,l,u??null,h,g,K,b,w,R,j_),l.context=M_(null),u=l.current,h=gi(),h=Cn(h),g=Ss(h),g.callback=null,ws(u,g,h),u=h,l.current.lanes=u,cn(l,u),ra(l),a[fs]=l.current,qp(a),new th(l)},vc.version="19.2.3",vc}var J_;function PA(){if(J_)return d1.exports;J_=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),d1.exports=LA(),d1.exports}var BA=PA();const K5=F.createContext({theme:"system",resolvedTheme:"light",setTheme:()=>{},toggleTheme:()=>{}}),W5=()=>F.useContext(K5),Bg="cycls_theme_preference",ey=()=>typeof window>"u"?"light":window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light",ty=()=>{if(typeof window>"u")return"system";try{return localStorage.getItem(Bg)||"system"}catch{return"system"}},ny=(e,t)=>{const n=document.documentElement;n.classList.remove("light","dark"),n.removeAttribute("data-theme"),e==="system"?n.setAttribute("data-resolved-theme",t):(n.classList.add(e),n.setAttribute("data-theme",e),n.setAttribute("data-resolved-theme",e))},p1=({children:e})=>{const[t,n]=F.useState(()=>ty()),[r,i]=F.useState(()=>{const d=ty();return d==="system"?ey():d});F.useEffect(()=>{const d=window.matchMedia("(prefers-color-scheme: dark)"),f=m=>{if(t==="system"){const p=m.matches?"dark":"light";i(p),ny("system",p)}};return d.addEventListener("change",f),()=>d.removeEventListener("change",f)},[t]),F.useEffect(()=>{const d=t==="system"?ey():t;ny(t,d),requestAnimationFrame(()=>{i(d)})},[t]);const s=F.useCallback(d=>{n(d);try{d==="system"?localStorage.removeItem(Bg):localStorage.setItem(Bg,d)}catch{}},[]),o=F.useCallback(()=>{s(r==="dark"?"light":"dark")},[r,s]),c={theme:t,resolvedTheme:r,setTheme:s,toggleTheme:o};return C.jsx(K5.Provider,{value:c,children:e})},X5=({className:e=""})=>{const{resolvedTheme:t,toggleTheme:n}=W5(),r=t==="dark";return C.jsx("button",{onClick:n,className:`
        theme-toggle
        inline-flex items-center justify-center
        rounded-xl p-2
        hover:bg-[var(--bg-hover)] active:bg-[var(--bg-active)]
        focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20
        transition-colors duration-200
        ${e}
      `,"aria-label":r?"Switch to light mode":"Switch to dark mode",title:r?"Light mode":"Dark mode",children:r?C.jsxs("svg",{className:"theme-toggle-icon w-5 h-5 text-[var(--text-primary)]",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.7",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("circle",{cx:"12",cy:"12",r:"4"}),C.jsx("path",{d:"M12 2v2"}),C.jsx("path",{d:"M12 20v2"}),C.jsx("path",{d:"M4.93 4.93l1.41 1.41"}),C.jsx("path",{d:"M17.66 17.66l1.41 1.41"}),C.jsx("path",{d:"M2 12h2"}),C.jsx("path",{d:"M20 12h2"}),C.jsx("path",{d:"M6.34 17.66l-1.41 1.41"}),C.jsx("path",{d:"M19.07 4.93l-1.41 1.41"})]}):C.jsx("svg",{className:"theme-toggle-icon w-5 h-5 text-[var(--text-primary)]",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.7",strokeLinecap:"round",strokeLinejoin:"round",children:C.jsx("path",{d:"M12 3a6 6 0 0 0 9 9 9 9 0 1 1-9-9Z"})})})},Ug=F.createContext(!1),UA=()=>F.useContext(Ug);/**
 * react-router v7.12.0
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */var ry="popstate";function zA(e={}){function t(r,i){let{pathname:s,search:o,hash:c}=r.location;return zg("",{pathname:s,search:o,hash:c},i.state&&i.state.usr||null,i.state&&i.state.key||"default")}function n(r,i){return typeof i=="string"?i:s0(i)}return HA(t,n,null,e)}function Rn(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function Fi(e,t){if(!e){typeof console<"u"&&console.warn(t);try{throw new Error(t)}catch{}}}function FA(){return Math.random().toString(36).substring(2,10)}function iy(e,t){return{usr:e.state,key:e.key,idx:t}}function zg(e,t,n=null,r){return{pathname:typeof e=="string"?e:e.pathname,search:"",hash:"",...typeof t=="string"?hu(t):t,state:n,key:t&&t.key||r||FA()}}function s0({pathname:e="/",search:t="",hash:n=""}){return t&&t!=="?"&&(e+=t.charAt(0)==="?"?t:"?"+t),n&&n!=="#"&&(e+=n.charAt(0)==="#"?n:"#"+n),e}function hu(e){let t={};if(e){let n=e.indexOf("#");n>=0&&(t.hash=e.substring(n),e=e.substring(0,n));let r=e.indexOf("?");r>=0&&(t.search=e.substring(r),e=e.substring(0,r)),e&&(t.pathname=e)}return t}function HA(e,t,n,r={}){let{window:i=document.defaultView,v5Compat:s=!1}=r,o=i.history,c="POP",d=null,f=m();f==null&&(f=0,o.replaceState({...o.state,idx:f},""));function m(){return(o.state||{idx:null}).idx}function p(){c="POP";let k=m(),A=k==null?null:k-f;f=k,d&&d({action:c,location:x.location,delta:A})}function v(k,A){c="PUSH";let O=zg(x.location,k,A);f=m()+1;let I=iy(O,f),$=x.createHref(O);try{o.pushState(I,"",$)}catch(V){if(V instanceof DOMException&&V.name==="DataCloneError")throw V;i.location.assign($)}s&&d&&d({action:c,location:x.location,delta:1})}function _(k,A){c="REPLACE";let O=zg(x.location,k,A);f=m();let I=iy(O,f),$=x.createHref(O);o.replaceState(I,"",$),s&&d&&d({action:c,location:x.location,delta:0})}function T(k){return jA(k)}let x={get action(){return c},get location(){return e(i,o)},listen(k){if(d)throw new Error("A history only accepts one active listener");return i.addEventListener(ry,p),d=k,()=>{i.removeEventListener(ry,p),d=null}},createHref(k){return t(i,k)},createURL:T,encodeLocation(k){let A=T(k);return{pathname:A.pathname,search:A.search,hash:A.hash}},push:v,replace:_,go(k){return o.go(k)}};return x}function jA(e,t=!1){let n="http://localhost";typeof window<"u"&&(n=window.location.origin!=="null"?window.location.origin:window.location.href),Rn(n,"No window.location.(origin|href) available to create URL");let r=typeof e=="string"?e:s0(e);return r=r.replace(/ $/,"%20"),!t&&r.startsWith("//")&&(r=n+r),new URL(r,n)}function Q5(e,t,n="/"){return qA(e,t,n,!1)}function qA(e,t,n,r){let i=typeof t=="string"?hu(t):t,s=rs(i.pathname||"/",n);if(s==null)return null;let o=Z5(e);$A(o);let c=null;for(let d=0;c==null&&d<o.length;++d){let f=tk(s);c=JA(o[d],f,r)}return c}function Z5(e,t=[],n=[],r="",i=!1){let s=(o,c,d=i,f)=>{let m={relativePath:f===void 0?o.path||"":f,caseSensitive:o.caseSensitive===!0,childrenIndex:c,route:o};if(m.relativePath.startsWith("/")){if(!m.relativePath.startsWith(r)&&d)return;Rn(m.relativePath.startsWith(r),`Absolute route path "${m.relativePath}" nested under path "${r}" is not valid. An absolute child route path must start with the combined path of all its parent routes.`),m.relativePath=m.relativePath.slice(r.length)}let p=Ja([r,m.relativePath]),v=n.concat(m);o.children&&o.children.length>0&&(Rn(o.index!==!0,`Index routes must not have child routes. Please remove all child routes from route path "${p}".`),Z5(o.children,t,v,p,d)),!(o.path==null&&!o.index)&&t.push({path:p,score:QA(p,o.index),routesMeta:v})};return e.forEach((o,c)=>{var d;if(o.path===""||!((d=o.path)!=null&&d.includes("?")))s(o,c);else for(let f of J5(o.path))s(o,c,!0,f)}),t}function J5(e){let t=e.split("/");if(t.length===0)return[];let[n,...r]=t,i=n.endsWith("?"),s=n.replace(/\?$/,"");if(r.length===0)return i?[s,""]:[s];let o=J5(r.join("/")),c=[];return c.push(...o.map(d=>d===""?s:[s,d].join("/"))),i&&c.push(...o),c.map(d=>e.startsWith("/")&&d===""?"/":d)}function $A(e){e.sort((t,n)=>t.score!==n.score?n.score-t.score:ZA(t.routesMeta.map(r=>r.childrenIndex),n.routesMeta.map(r=>r.childrenIndex)))}var GA=/^:[\w-]+$/,YA=3,VA=2,KA=1,WA=10,XA=-2,ay=e=>e==="*";function QA(e,t){let n=e.split("/"),r=n.length;return n.some(ay)&&(r+=XA),t&&(r+=VA),n.filter(i=>!ay(i)).reduce((i,s)=>i+(GA.test(s)?YA:s===""?KA:WA),r)}function ZA(e,t){return e.length===t.length&&e.slice(0,-1).every((r,i)=>r===t[i])?e[e.length-1]-t[t.length-1]:0}function JA(e,t,n=!1){let{routesMeta:r}=e,i={},s="/",o=[];for(let c=0;c<r.length;++c){let d=r[c],f=c===r.length-1,m=s==="/"?t:t.slice(s.length)||"/",p=Wh({path:d.relativePath,caseSensitive:d.caseSensitive,end:f},m),v=d.route;if(!p&&f&&n&&!r[r.length-1].route.index&&(p=Wh({path:d.relativePath,caseSensitive:d.caseSensitive,end:!1},m)),!p)return null;Object.assign(i,p.params),o.push({params:i,pathname:Ja([s,p.pathname]),pathnameBase:ak(Ja([s,p.pathnameBase])),route:v}),p.pathnameBase!=="/"&&(s=Ja([s,p.pathnameBase]))}return o}function Wh(e,t){typeof e=="string"&&(e={path:e,caseSensitive:!1,end:!0});let[n,r]=ek(e.path,e.caseSensitive,e.end),i=t.match(n);if(!i)return null;let s=i[0],o=s.replace(/(.)\/+$/,"$1"),c=i.slice(1);return{params:r.reduce((f,{paramName:m,isOptional:p},v)=>{if(m==="*"){let T=c[v]||"";o=s.slice(0,s.length-T.length).replace(/(.)\/+$/,"$1")}const _=c[v];return p&&!_?f[m]=void 0:f[m]=(_||"").replace(/%2F/g,"/"),f},{}),pathname:s,pathnameBase:o,pattern:e}}function ek(e,t=!1,n=!0){Fi(e==="*"||!e.endsWith("*")||e.endsWith("/*"),`Route path "${e}" will be treated as if it were "${e.replace(/\*$/,"/*")}" because the \`*\` character must always follow a \`/\` in the pattern. To get rid of this warning, please change the route path to "${e.replace(/\*$/,"/*")}".`);let r=[],i="^"+e.replace(/\/*\*?$/,"").replace(/^\/*/,"/").replace(/[\\.*+^${}|()[\]]/g,"\\$&").replace(/\/:([\w-]+)(\?)?/g,(o,c,d)=>(r.push({paramName:c,isOptional:d!=null}),d?"/?([^\\/]+)?":"/([^\\/]+)")).replace(/\/([\w-]+)\?(\/|$)/g,"(/$1)?$2");return e.endsWith("*")?(r.push({paramName:"*"}),i+=e==="*"||e==="/*"?"(.*)$":"(?:\\/(.+)|\\/*)$"):n?i+="\\/*$":e!==""&&e!=="/"&&(i+="(?:(?=\\/|$))"),[new RegExp(i,t?void 0:"i"),r]}function tk(e){try{return e.split("/").map(t=>decodeURIComponent(t).replace(/\//g,"%2F")).join("/")}catch(t){return Fi(!1,`The URL path "${e}" could not be decoded because it is a malformed URL segment. This is probably due to a bad percent encoding (${t}).`),e}}function rs(e,t){if(t==="/")return e;if(!e.toLowerCase().startsWith(t.toLowerCase()))return null;let n=t.endsWith("/")?t.length-1:t.length,r=e.charAt(n);return r&&r!=="/"?null:e.slice(n)||"/"}var e8=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,nk=e=>e8.test(e);function rk(e,t="/"){let{pathname:n,search:r="",hash:i=""}=typeof e=="string"?hu(e):e,s;if(n)if(nk(n))s=n;else{if(n.includes("//")){let o=n;n=n.replace(/\/\/+/g,"/"),Fi(!1,`Pathnames cannot have embedded double slashes - normalizing ${o} -> ${n}`)}n.startsWith("/")?s=sy(n.substring(1),"/"):s=sy(n,t)}else s=t;return{pathname:s,search:sk(r),hash:lk(i)}}function sy(e,t){let n=t.replace(/\/+$/,"").split("/");return e.split("/").forEach(i=>{i===".."?n.length>1&&n.pop():i!=="."&&n.push(i)}),n.length>1?n.join("/"):"/"}function g1(e,t,n,r){return`Cannot include a '${e}' character in a manually specified \`to.${t}\` field [${JSON.stringify(r)}].  Please separate it out to the \`to.${n}\` field. Alternatively you may provide the full path as a string in <Link to="..."> and the router will parse it for you.`}function ik(e){return e.filter((t,n)=>n===0||t.route.path&&t.route.path.length>0)}function Zb(e){let t=ik(e);return t.map((n,r)=>r===t.length-1?n.pathname:n.pathnameBase)}function Jb(e,t,n,r=!1){let i;typeof e=="string"?i=hu(e):(i={...e},Rn(!i.pathname||!i.pathname.includes("?"),g1("?","pathname","search",i)),Rn(!i.pathname||!i.pathname.includes("#"),g1("#","pathname","hash",i)),Rn(!i.search||!i.search.includes("#"),g1("#","search","hash",i)));let s=e===""||i.pathname==="",o=s?"/":i.pathname,c;if(o==null)c=n;else{let p=t.length-1;if(!r&&o.startsWith("..")){let v=o.split("/");for(;v[0]==="..";)v.shift(),p-=1;i.pathname=v.join("/")}c=p>=0?t[p]:"/"}let d=rk(i,c),f=o&&o!=="/"&&o.endsWith("/"),m=(s||o===".")&&n.endsWith("/");return!d.pathname.endsWith("/")&&(f||m)&&(d.pathname+="/"),d}var Ja=e=>e.join("/").replace(/\/\/+/g,"/"),ak=e=>e.replace(/\/+$/,"").replace(/^\/*/,"/"),sk=e=>!e||e==="?"?"":e.startsWith("?")?e:"?"+e,lk=e=>!e||e==="#"?"":e.startsWith("#")?e:"#"+e,ok=class{constructor(e,t,n,r=!1){this.status=e,this.statusText=t||"",this.internal=r,n instanceof Error?(this.data=n.toString(),this.error=n):this.data=n}};function uk(e){return e!=null&&typeof e.status=="number"&&typeof e.statusText=="string"&&typeof e.internal=="boolean"&&"data"in e}function ck(e){return e.map(t=>t.route.path).filter(Boolean).join("/").replace(/\/\/*/g,"/")||"/"}var t8=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";function n8(e,t){let n=e;if(typeof n!="string"||!e8.test(n))return{absoluteURL:void 0,isExternal:!1,to:n};let r=n,i=!1;if(t8)try{let s=new URL(window.location.href),o=n.startsWith("//")?new URL(s.protocol+n):new URL(n),c=rs(o.pathname,t);o.origin===s.origin&&c!=null?n=c+o.search+o.hash:i=!0}catch{Fi(!1,`<Link to="${n}"> contains an invalid URL which will probably break when clicked - please update to a valid URL path.`)}return{absoluteURL:r,isExternal:i,to:n}}Object.getOwnPropertyNames(Object.prototype).sort().join("\0");var r8=["POST","PUT","PATCH","DELETE"];new Set(r8);var dk=["GET",...r8];new Set(dk);var fu=F.createContext(null);fu.displayName="DataRouter";var Mf=F.createContext(null);Mf.displayName="DataRouterState";var hk=F.createContext(!1),i8=F.createContext({isTransitioning:!1});i8.displayName="ViewTransition";var fk=F.createContext(new Map);fk.displayName="Fetchers";var mk=F.createContext(null);mk.displayName="Await";var xi=F.createContext(null);xi.displayName="Navigation";var y0=F.createContext(null);y0.displayName="Location";var ma=F.createContext({outlet:null,matches:[],isDataRoute:!1});ma.displayName="Route";var e2=F.createContext(null);e2.displayName="RouteError";var a8="REACT_ROUTER_ERROR",pk="REDIRECT",gk="ROUTE_ERROR_RESPONSE";function bk(e){if(e.startsWith(`${a8}:${pk}:{`))try{let t=JSON.parse(e.slice(28));if(typeof t=="object"&&t&&typeof t.status=="number"&&typeof t.statusText=="string"&&typeof t.location=="string"&&typeof t.reloadDocument=="boolean"&&typeof t.replace=="boolean")return t}catch{}}function vk(e){if(e.startsWith(`${a8}:${gk}:{`))try{let t=JSON.parse(e.slice(40));if(typeof t=="object"&&t&&typeof t.status=="number"&&typeof t.statusText=="string")return new ok(t.status,t.statusText,t.data)}catch{}}function _k(e,{relative:t}={}){Rn(mu(),"useHref() may be used only in the context of a <Router> component.");let{basename:n,navigator:r}=F.useContext(xi),{hash:i,pathname:s,search:o}=E0(e,{relative:t}),c=s;return n!=="/"&&(c=s==="/"?n:Ja([n,s])),r.createHref({pathname:c,search:o,hash:i})}function mu(){return F.useContext(y0)!=null}function us(){return Rn(mu(),"useLocation() may be used only in the context of a <Router> component."),F.useContext(y0).location}var s8="You should call navigate() in a React.useEffect(), not when your component is first rendered.";function l8(e){F.useContext(xi).static||F.useLayoutEffect(e)}function o8(){let{isDataRoute:e}=F.useContext(ma);return e?Mk():yk()}function yk(){Rn(mu(),"useNavigate() may be used only in the context of a <Router> component.");let e=F.useContext(fu),{basename:t,navigator:n}=F.useContext(xi),{matches:r}=F.useContext(ma),{pathname:i}=us(),s=JSON.stringify(Zb(r)),o=F.useRef(!1);return l8(()=>{o.current=!0}),F.useCallback((d,f={})=>{if(Fi(o.current,s8),!o.current)return;if(typeof d=="number"){n.go(d);return}let m=Jb(d,JSON.parse(s),i,f.relative==="path");e==null&&t!=="/"&&(m.pathname=m.pathname==="/"?t:Ja([t,m.pathname])),(f.replace?n.replace:n.push)(m,f.state,f)},[t,n,s,i,e])}F.createContext(null);function E0(e,{relative:t}={}){let{matches:n}=F.useContext(ma),{pathname:r}=us(),i=JSON.stringify(Zb(n));return F.useMemo(()=>Jb(e,JSON.parse(i),r,t==="path"),[e,i,r,t])}function Ek(e,t){return u8(e,t)}function u8(e,t,n,r,i){var O;Rn(mu(),"useRoutes() may be used only in the context of a <Router> component.");let{navigator:s}=F.useContext(xi),{matches:o}=F.useContext(ma),c=o[o.length-1],d=c?c.params:{},f=c?c.pathname:"/",m=c?c.pathnameBase:"/",p=c&&c.route;{let I=p&&p.path||"";d8(f,!p||I.endsWith("*")||I.endsWith("*?"),`You rendered descendant <Routes> (or called \`useRoutes()\`) at "${f}" (under <Route path="${I}">) but the parent route path has no trailing "*". This means if you navigate deeper, the parent won't match anymore and therefore the child routes will never render.

Please change the parent <Route path="${I}"> to <Route path="${I==="/"?"*":`${I}/*`}">.`)}let v=us(),_;if(t){let I=typeof t=="string"?hu(t):t;Rn(m==="/"||((O=I.pathname)==null?void 0:O.startsWith(m)),`When overriding the location using \`<Routes location>\` or \`useRoutes(routes, location)\`, the location pathname must begin with the portion of the URL pathname that was matched by all parent routes. The current pathname base is "${m}" but pathname "${I.pathname}" was given in the \`location\` prop.`),_=I}else _=v;let T=_.pathname||"/",x=T;if(m!=="/"){let I=m.replace(/^\//,"").split("/");x="/"+T.replace(/^\//,"").split("/").slice(I.length).join("/")}let k=Q5(e,{pathname:x});Fi(p||k!=null,`No routes matched location "${_.pathname}${_.search}${_.hash}" `),Fi(k==null||k[k.length-1].route.element!==void 0||k[k.length-1].route.Component!==void 0||k[k.length-1].route.lazy!==void 0,`Matched leaf route at location "${_.pathname}${_.search}${_.hash}" does not have an element or Component. This means it will render an <Outlet /> with a null value by default resulting in an "empty" page.`);let A=Ak(k&&k.map(I=>Object.assign({},I,{params:Object.assign({},d,I.params),pathname:Ja([m,s.encodeLocation?s.encodeLocation(I.pathname.replace(/\?/g,"%3F").replace(/#/g,"%23")).pathname:I.pathname]),pathnameBase:I.pathnameBase==="/"?m:Ja([m,s.encodeLocation?s.encodeLocation(I.pathnameBase.replace(/\?/g,"%3F").replace(/#/g,"%23")).pathname:I.pathnameBase])})),o,n,r,i);return t&&A?F.createElement(y0.Provider,{value:{location:{pathname:"/",search:"",hash:"",state:null,key:"default",..._},navigationType:"POP"}},A):A}function Tk(){let e=Rk(),t=uk(e)?`${e.status} ${e.statusText}`:e instanceof Error?e.message:JSON.stringify(e),n=e instanceof Error?e.stack:null,r="rgba(200,200,200, 0.5)",i={padding:"0.5rem",backgroundColor:r},s={padding:"2px 4px",backgroundColor:r},o=null;return console.error("Error handled by React Router default ErrorBoundary:",e),o=F.createElement(F.Fragment,null,F.createElement("p",null,"💿 Hey developer 👋"),F.createElement("p",null,"You can provide a way better UX than this when your app throws errors by providing your own ",F.createElement("code",{style:s},"ErrorBoundary")," or"," ",F.createElement("code",{style:s},"errorElement")," prop on your route.")),F.createElement(F.Fragment,null,F.createElement("h2",null,"Unexpected Application Error!"),F.createElement("h3",{style:{fontStyle:"italic"}},t),n?F.createElement("pre",{style:i},n):null,o)}var xk=F.createElement(Tk,null),c8=class extends F.Component{constructor(e){super(e),this.state={location:e.location,revalidation:e.revalidation,error:e.error}}static getDerivedStateFromError(e){return{error:e}}static getDerivedStateFromProps(e,t){return t.location!==e.location||t.revalidation!=="idle"&&e.revalidation==="idle"?{error:e.error,location:e.location,revalidation:e.revalidation}:{error:e.error!==void 0?e.error:t.error,location:t.location,revalidation:e.revalidation||t.revalidation}}componentDidCatch(e,t){this.props.onError?this.props.onError(e,t):console.error("React Router caught the following error during render",e)}render(){let e=this.state.error;if(this.context&&typeof e=="object"&&e&&"digest"in e&&typeof e.digest=="string"){const n=vk(e.digest);n&&(e=n)}let t=e!==void 0?F.createElement(ma.Provider,{value:this.props.routeContext},F.createElement(e2.Provider,{value:e,children:this.props.component})):this.props.children;return this.context?F.createElement(Sk,{error:e},t):t}};c8.contextType=hk;var b1=new WeakMap;function Sk({children:e,error:t}){let{basename:n}=F.useContext(xi);if(typeof t=="object"&&t&&"digest"in t&&typeof t.digest=="string"){let r=bk(t.digest);if(r){let i=b1.get(t);if(i)throw i;let s=n8(r.location,n);if(t8&&!b1.get(t))if(s.isExternal||r.reloadDocument)window.location.href=s.absoluteURL||s.to;else{const o=Promise.resolve().then(()=>window.__reactRouterDataRouter.navigate(s.to,{replace:r.replace}));throw b1.set(t,o),o}return F.createElement("meta",{httpEquiv:"refresh",content:`0;url=${s.absoluteURL||s.to}`})}}return e}function wk({routeContext:e,match:t,children:n}){let r=F.useContext(fu);return r&&r.static&&r.staticContext&&(t.route.errorElement||t.route.ErrorBoundary)&&(r.staticContext._deepestRenderedBoundaryId=t.route.id),F.createElement(ma.Provider,{value:e},n)}function Ak(e,t=[],n=null,r=null,i=null){if(e==null){if(!n)return null;if(n.errors)e=n.matches;else if(t.length===0&&!n.initialized&&n.matches.length>0)e=n.matches;else return null}let s=e,o=n==null?void 0:n.errors;if(o!=null){let m=s.findIndex(p=>p.route.id&&(o==null?void 0:o[p.route.id])!==void 0);Rn(m>=0,`Could not find a matching route for errors on route IDs: ${Object.keys(o).join(",")}`),s=s.slice(0,Math.min(s.length,m+1))}let c=!1,d=-1;if(n)for(let m=0;m<s.length;m++){let p=s[m];if((p.route.HydrateFallback||p.route.hydrateFallbackElement)&&(d=m),p.route.id){let{loaderData:v,errors:_}=n,T=p.route.loader&&!v.hasOwnProperty(p.route.id)&&(!_||_[p.route.id]===void 0);if(p.route.lazy||T){c=!0,d>=0?s=s.slice(0,d+1):s=[s[0]];break}}}let f=n&&r?(m,p)=>{var v,_;r(m,{location:n.location,params:((_=(v=n.matches)==null?void 0:v[0])==null?void 0:_.params)??{},unstable_pattern:ck(n.matches),errorInfo:p})}:void 0;return s.reduceRight((m,p,v)=>{let _,T=!1,x=null,k=null;n&&(_=o&&p.route.id?o[p.route.id]:void 0,x=p.route.errorElement||xk,c&&(d<0&&v===0?(d8("route-fallback",!1,"No `HydrateFallback` element provided to render during initial hydration"),T=!0,k=null):d===v&&(T=!0,k=p.route.hydrateFallbackElement||null)));let A=t.concat(s.slice(0,v+1)),O=()=>{let I;return _?I=x:T?I=k:p.route.Component?I=F.createElement(p.route.Component,null):p.route.element?I=p.route.element:I=m,F.createElement(wk,{match:p,routeContext:{outlet:m,matches:A,isDataRoute:n!=null},children:I})};return n&&(p.route.ErrorBoundary||p.route.errorElement||v===0)?F.createElement(c8,{location:n.location,revalidation:n.revalidation,component:x,error:_,children:O(),routeContext:{outlet:null,matches:A,isDataRoute:!0},onError:f}):O()},null)}function t2(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function kk(e){let t=F.useContext(fu);return Rn(t,t2(e)),t}function Ck(e){let t=F.useContext(Mf);return Rn(t,t2(e)),t}function Nk(e){let t=F.useContext(ma);return Rn(t,t2(e)),t}function n2(e){let t=Nk(e),n=t.matches[t.matches.length-1];return Rn(n.route.id,`${e} can only be used on routes that contain a unique "id"`),n.route.id}function Ok(){return n2("useRouteId")}function Rk(){var r;let e=F.useContext(e2),t=Ck("useRouteError"),n=n2("useRouteError");return e!==void 0?e:(r=t.errors)==null?void 0:r[n]}function Mk(){let{router:e}=kk("useNavigate"),t=n2("useNavigate"),n=F.useRef(!1);return l8(()=>{n.current=!0}),F.useCallback(async(i,s={})=>{Fi(n.current,s8),n.current&&(typeof i=="number"?await e.navigate(i):await e.navigate(i,{fromRouteId:t,...s}))},[e,t])}var ly={};function d8(e,t,n){!t&&!ly[e]&&(ly[e]=!0,Fi(!1,n))}F.memo(Ik);function Ik({routes:e,future:t,state:n,onError:r}){return u8(e,void 0,n,r,t)}function h8({to:e,replace:t,state:n,relative:r}){Rn(mu(),"<Navigate> may be used only in the context of a <Router> component.");let{static:i}=F.useContext(xi);Fi(!i,"<Navigate> must not be used on the initial render in a <StaticRouter>. This is a no-op, but you should modify your code so the <Navigate> is only ever rendered in response to some user interaction or state change.");let{matches:s}=F.useContext(ma),{pathname:o}=us(),c=o8(),d=Jb(e,Zb(s),o,r==="path"),f=JSON.stringify(d);return F.useEffect(()=>{c(JSON.parse(f),{replace:t,state:n,relative:r})},[c,f,r,t,n]),null}function Dh(e){Rn(!1,"A <Route> is only ever to be used as the child of <Routes> element, never rendered directly. Please wrap your <Route> in a <Routes>.")}function Dk({basename:e="/",children:t=null,location:n,navigationType:r="POP",navigator:i,static:s=!1,unstable_useTransitions:o}){Rn(!mu(),"You cannot render a <Router> inside another <Router>. You should never have more than one in your app.");let c=e.replace(/^\/*/,"/"),d=F.useMemo(()=>({basename:c,navigator:i,static:s,unstable_useTransitions:o,future:{}}),[c,i,s,o]);typeof n=="string"&&(n=hu(n));let{pathname:f="/",search:m="",hash:p="",state:v=null,key:_="default"}=n,T=F.useMemo(()=>{let x=rs(f,c);return x==null?null:{location:{pathname:x,search:m,hash:p,state:v,key:_},navigationType:r}},[c,f,m,p,v,_,r]);return Fi(T!=null,`<Router basename="${c}"> is not able to match the URL "${f}${m}${p}" because it does not start with the basename, so the <Router> won't render anything.`),T==null?null:F.createElement(xi.Provider,{value:d},F.createElement(y0.Provider,{children:t,value:T}))}function Lk({children:e,location:t}){return Ek(Fg(e),t)}function Fg(e,t=[]){let n=[];return F.Children.forEach(e,(r,i)=>{if(!F.isValidElement(r))return;let s=[...t,i];if(r.type===F.Fragment){n.push.apply(n,Fg(r.props.children,s));return}Rn(r.type===Dh,`[${typeof r.type=="string"?r.type:r.type.name}] is not a <Route> component. All component children of <Routes> must be a <Route> or <React.Fragment>`),Rn(!r.props.index||!r.props.children,"An index route cannot have child routes.");let o={id:r.props.id||s.join("-"),caseSensitive:r.props.caseSensitive,element:r.props.element,Component:r.props.Component,index:r.props.index,path:r.props.path,middleware:r.props.middleware,loader:r.props.loader,action:r.props.action,hydrateFallbackElement:r.props.hydrateFallbackElement,HydrateFallback:r.props.HydrateFallback,errorElement:r.props.errorElement,ErrorBoundary:r.props.ErrorBoundary,hasErrorBoundary:r.props.hasErrorBoundary===!0||r.props.ErrorBoundary!=null||r.props.errorElement!=null,shouldRevalidate:r.props.shouldRevalidate,handle:r.props.handle,lazy:r.props.lazy};r.props.children&&(o.children=Fg(r.props.children,s)),n.push(o)}),n}var Lh="get",Ph="application/x-www-form-urlencoded";function If(e){return typeof HTMLElement<"u"&&e instanceof HTMLElement}function Pk(e){return If(e)&&e.tagName.toLowerCase()==="button"}function Bk(e){return If(e)&&e.tagName.toLowerCase()==="form"}function Uk(e){return If(e)&&e.tagName.toLowerCase()==="input"}function zk(e){return!!(e.metaKey||e.altKey||e.ctrlKey||e.shiftKey)}function Fk(e,t){return e.button===0&&(!t||t==="_self")&&!zk(e)}var rh=null;function Hk(){if(rh===null)try{new FormData(document.createElement("form"),0),rh=!1}catch{rh=!0}return rh}var jk=new Set(["application/x-www-form-urlencoded","multipart/form-data","text/plain"]);function v1(e){return e!=null&&!jk.has(e)?(Fi(!1,`"${e}" is not a valid \`encType\` for \`<Form>\`/\`<fetcher.Form>\` and will default to "${Ph}"`),null):e}function qk(e,t){let n,r,i,s,o;if(Bk(e)){let c=e.getAttribute("action");r=c?rs(c,t):null,n=e.getAttribute("method")||Lh,i=v1(e.getAttribute("enctype"))||Ph,s=new FormData(e)}else if(Pk(e)||Uk(e)&&(e.type==="submit"||e.type==="image")){let c=e.form;if(c==null)throw new Error('Cannot submit a <button> or <input type="submit"> without a <form>');let d=e.getAttribute("formaction")||c.getAttribute("action");if(r=d?rs(d,t):null,n=e.getAttribute("formmethod")||c.getAttribute("method")||Lh,i=v1(e.getAttribute("formenctype"))||v1(c.getAttribute("enctype"))||Ph,s=new FormData(c,e),!Hk()){let{name:f,type:m,value:p}=e;if(m==="image"){let v=f?`${f}.`:"";s.append(`${v}x`,"0"),s.append(`${v}y`,"0")}else f&&s.append(f,p)}}else{if(If(e))throw new Error('Cannot submit element that is not <form>, <button>, or <input type="submit|image">');n=Lh,r=null,i=Ph,o=e}return s&&i==="text/plain"&&(o=s,s=void 0),{action:r,method:n.toLowerCase(),encType:i,formData:s,body:o}}Object.getOwnPropertyNames(Object.prototype).sort().join("\0");function r2(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function $k(e,t,n,r){let i=typeof e=="string"?new URL(e,typeof window>"u"?"server://singlefetch/":window.location.origin):e;return n?i.pathname.endsWith("/")?i.pathname=`${i.pathname}_.${r}`:i.pathname=`${i.pathname}.${r}`:i.pathname==="/"?i.pathname=`_root.${r}`:t&&rs(i.pathname,t)==="/"?i.pathname=`${t.replace(/\/$/,"")}/_root.${r}`:i.pathname=`${i.pathname.replace(/\/$/,"")}.${r}`,i}async function Gk(e,t){if(e.id in t)return t[e.id];try{let n=await import(e.module);return t[e.id]=n,n}catch(n){return console.error(`Error loading route module \`${e.module}\`, reloading page...`),console.error(n),window.__reactRouterContext&&window.__reactRouterContext.isSpaMode,window.location.reload(),new Promise(()=>{})}}function Yk(e){return e==null?!1:e.href==null?e.rel==="preload"&&typeof e.imageSrcSet=="string"&&typeof e.imageSizes=="string":typeof e.rel=="string"&&typeof e.href=="string"}async function Vk(e,t,n){let r=await Promise.all(e.map(async i=>{let s=t.routes[i.route.id];if(s){let o=await Gk(s,n);return o.links?o.links():[]}return[]}));return Qk(r.flat(1).filter(Yk).filter(i=>i.rel==="stylesheet"||i.rel==="preload").map(i=>i.rel==="stylesheet"?{...i,rel:"prefetch",as:"style"}:{...i,rel:"prefetch"}))}function oy(e,t,n,r,i,s){let o=(d,f)=>n[f]?d.route.id!==n[f].route.id:!0,c=(d,f)=>{var m;return n[f].pathname!==d.pathname||((m=n[f].route.path)==null?void 0:m.endsWith("*"))&&n[f].params["*"]!==d.params["*"]};return s==="assets"?t.filter((d,f)=>o(d,f)||c(d,f)):s==="data"?t.filter((d,f)=>{var p;let m=r.routes[d.route.id];if(!m||!m.hasLoader)return!1;if(o(d,f)||c(d,f))return!0;if(d.route.shouldRevalidate){let v=d.route.shouldRevalidate({currentUrl:new URL(i.pathname+i.search+i.hash,window.origin),currentParams:((p=n[0])==null?void 0:p.params)||{},nextUrl:new URL(e,window.origin),nextParams:d.params,defaultShouldRevalidate:!0});if(typeof v=="boolean")return v}return!0}):[]}function Kk(e,t,{includeHydrateFallback:n}={}){return Wk(e.map(r=>{let i=t.routes[r.route.id];if(!i)return[];let s=[i.module];return i.clientActionModule&&(s=s.concat(i.clientActionModule)),i.clientLoaderModule&&(s=s.concat(i.clientLoaderModule)),n&&i.hydrateFallbackModule&&(s=s.concat(i.hydrateFallbackModule)),i.imports&&(s=s.concat(i.imports)),s}).flat(1))}function Wk(e){return[...new Set(e)]}function Xk(e){let t={},n=Object.keys(e).sort();for(let r of n)t[r]=e[r];return t}function Qk(e,t){let n=new Set;return new Set(t),e.reduce((r,i)=>{let s=JSON.stringify(Xk(i));return n.has(s)||(n.add(s),r.push({key:s,link:i})),r},[])}function f8(){let e=F.useContext(fu);return r2(e,"You must render this element inside a <DataRouterContext.Provider> element"),e}function Zk(){let e=F.useContext(Mf);return r2(e,"You must render this element inside a <DataRouterStateContext.Provider> element"),e}var i2=F.createContext(void 0);i2.displayName="FrameworkContext";function m8(){let e=F.useContext(i2);return r2(e,"You must render this element inside a <HydratedRouter> element"),e}function Jk(e,t){let n=F.useContext(i2),[r,i]=F.useState(!1),[s,o]=F.useState(!1),{onFocus:c,onBlur:d,onMouseEnter:f,onMouseLeave:m,onTouchStart:p}=t,v=F.useRef(null);F.useEffect(()=>{if(e==="render"&&o(!0),e==="viewport"){let x=A=>{A.forEach(O=>{o(O.isIntersecting)})},k=new IntersectionObserver(x,{threshold:.5});return v.current&&k.observe(v.current),()=>{k.disconnect()}}},[e]),F.useEffect(()=>{if(r){let x=setTimeout(()=>{o(!0)},100);return()=>{clearTimeout(x)}}},[r]);let _=()=>{i(!0)},T=()=>{i(!1),o(!1)};return n?e!=="intent"?[s,v,{}]:[s,v,{onFocus:_c(c,_),onBlur:_c(d,T),onMouseEnter:_c(f,_),onMouseLeave:_c(m,T),onTouchStart:_c(p,_)}]:[!1,v,{}]}function _c(e,t){return n=>{e&&e(n),n.defaultPrevented||t(n)}}function eC({page:e,...t}){let{router:n}=f8(),r=F.useMemo(()=>Q5(n.routes,e,n.basename),[n.routes,e,n.basename]);return r?F.createElement(nC,{page:e,matches:r,...t}):null}function tC(e){let{manifest:t,routeModules:n}=m8(),[r,i]=F.useState([]);return F.useEffect(()=>{let s=!1;return Vk(e,t,n).then(o=>{s||i(o)}),()=>{s=!0}},[e,t,n]),r}function nC({page:e,matches:t,...n}){let r=us(),{future:i,manifest:s,routeModules:o}=m8(),{basename:c}=f8(),{loaderData:d,matches:f}=Zk(),m=F.useMemo(()=>oy(e,t,f,s,r,"data"),[e,t,f,s,r]),p=F.useMemo(()=>oy(e,t,f,s,r,"assets"),[e,t,f,s,r]),v=F.useMemo(()=>{if(e===r.pathname+r.search+r.hash)return[];let x=new Set,k=!1;if(t.forEach(O=>{var $;let I=s.routes[O.route.id];!I||!I.hasLoader||(!m.some(V=>V.route.id===O.route.id)&&O.route.id in d&&(($=o[O.route.id])!=null&&$.shouldRevalidate)||I.hasClientLoader?k=!0:x.add(O.route.id))}),x.size===0)return[];let A=$k(e,c,i.unstable_trailingSlashAwareDataRequests,"data");return k&&x.size>0&&A.searchParams.set("_routes",t.filter(O=>x.has(O.route.id)).map(O=>O.route.id).join(",")),[A.pathname+A.search]},[c,i.unstable_trailingSlashAwareDataRequests,d,r,s,m,t,e,o]),_=F.useMemo(()=>Kk(p,s),[p,s]),T=tC(p);return F.createElement(F.Fragment,null,v.map(x=>F.createElement("link",{key:x,rel:"prefetch",as:"fetch",href:x,...n})),_.map(x=>F.createElement("link",{key:x,rel:"modulepreload",href:x,...n})),T.map(({key:x,link:k})=>F.createElement("link",{key:x,nonce:n.nonce,...k})))}function rC(...e){return t=>{e.forEach(n=>{typeof n=="function"?n(t):n!=null&&(n.current=t)})}}var iC=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";try{iC&&(window.__reactRouterVersion="7.12.0")}catch{}function aC({basename:e,children:t,unstable_useTransitions:n,window:r}){let i=F.useRef();i.current==null&&(i.current=zA({window:r,v5Compat:!0}));let s=i.current,[o,c]=F.useState({action:s.action,location:s.location}),d=F.useCallback(f=>{n===!1?c(f):F.startTransition(()=>c(f))},[n]);return F.useLayoutEffect(()=>s.listen(d),[s,d]),F.createElement(Dk,{basename:e,children:t,location:o.location,navigationType:o.action,navigator:s,unstable_useTransitions:n})}var p8=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,g8=F.forwardRef(function({onClick:t,discover:n="render",prefetch:r="none",relative:i,reloadDocument:s,replace:o,state:c,target:d,to:f,preventScrollReset:m,viewTransition:p,unstable_defaultShouldRevalidate:v,..._},T){let{basename:x,unstable_useTransitions:k}=F.useContext(xi),A=typeof f=="string"&&p8.test(f),O=n8(f,x);f=O.to;let I=_k(f,{relative:i}),[$,V,B]=Jk(r,_),Z=uC(f,{replace:o,state:c,target:d,preventScrollReset:m,relative:i,viewTransition:p,unstable_defaultShouldRevalidate:v,unstable_useTransitions:k});function ee(Y){t&&t(Y),Y.defaultPrevented||Z(Y)}let te=F.createElement("a",{..._,...B,href:O.absoluteURL||I,onClick:O.isExternal||s?t:ee,ref:rC(T,V),target:d,"data-discover":!A&&n==="render"?"true":void 0});return $&&!A?F.createElement(F.Fragment,null,te,F.createElement(eC,{page:I})):te});g8.displayName="Link";var sC=F.forwardRef(function({"aria-current":t="page",caseSensitive:n=!1,className:r="",end:i=!1,style:s,to:o,viewTransition:c,children:d,...f},m){let p=E0(o,{relative:f.relative}),v=us(),_=F.useContext(Mf),{navigator:T,basename:x}=F.useContext(xi),k=_!=null&&mC(p)&&c===!0,A=T.encodeLocation?T.encodeLocation(p).pathname:p.pathname,O=v.pathname,I=_&&_.navigation&&_.navigation.location?_.navigation.location.pathname:null;n||(O=O.toLowerCase(),I=I?I.toLowerCase():null,A=A.toLowerCase()),I&&x&&(I=rs(I,x)||I);const $=A!=="/"&&A.endsWith("/")?A.length-1:A.length;let V=O===A||!i&&O.startsWith(A)&&O.charAt($)==="/",B=I!=null&&(I===A||!i&&I.startsWith(A)&&I.charAt(A.length)==="/"),Z={isActive:V,isPending:B,isTransitioning:k},ee=V?t:void 0,te;typeof r=="function"?te=r(Z):te=[r,V?"active":null,B?"pending":null,k?"transitioning":null].filter(Boolean).join(" ");let Y=typeof s=="function"?s(Z):s;return F.createElement(g8,{...f,"aria-current":ee,className:te,ref:m,style:Y,to:o,viewTransition:c},typeof d=="function"?d(Z):d)});sC.displayName="NavLink";var lC=F.forwardRef(({discover:e="render",fetcherKey:t,navigate:n,reloadDocument:r,replace:i,state:s,method:o=Lh,action:c,onSubmit:d,relative:f,preventScrollReset:m,viewTransition:p,unstable_defaultShouldRevalidate:v,..._},T)=>{let{unstable_useTransitions:x}=F.useContext(xi),k=hC(),A=fC(c,{relative:f}),O=o.toLowerCase()==="get"?"get":"post",I=typeof c=="string"&&p8.test(c),$=V=>{if(d&&d(V),V.defaultPrevented)return;V.preventDefault();let B=V.nativeEvent.submitter,Z=(B==null?void 0:B.getAttribute("formmethod"))||o,ee=()=>k(B||V.currentTarget,{fetcherKey:t,method:Z,navigate:n,replace:i,state:s,relative:f,preventScrollReset:m,viewTransition:p,unstable_defaultShouldRevalidate:v});x&&n!==!1?F.startTransition(()=>ee()):ee()};return F.createElement("form",{ref:T,method:O,action:A,onSubmit:r?d:$,..._,"data-discover":!I&&e==="render"?"true":void 0})});lC.displayName="Form";function oC(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function b8(e){let t=F.useContext(fu);return Rn(t,oC(e)),t}function uC(e,{target:t,replace:n,state:r,preventScrollReset:i,relative:s,viewTransition:o,unstable_defaultShouldRevalidate:c,unstable_useTransitions:d}={}){let f=o8(),m=us(),p=E0(e,{relative:s});return F.useCallback(v=>{if(Fk(v,t)){v.preventDefault();let _=n!==void 0?n:s0(m)===s0(p),T=()=>f(e,{replace:_,state:r,preventScrollReset:i,relative:s,viewTransition:o,unstable_defaultShouldRevalidate:c});d?F.startTransition(()=>T()):T()}},[m,f,p,n,r,t,e,i,s,o,c,d])}var cC=0,dC=()=>`__${String(++cC)}__`;function hC(){let{router:e}=b8("useSubmit"),{basename:t}=F.useContext(xi),n=Ok(),r=e.fetch,i=e.navigate;return F.useCallback(async(s,o={})=>{let{action:c,method:d,encType:f,formData:m,body:p}=qk(s,t);if(o.navigate===!1){let v=o.fetcherKey||dC();await r(v,n,o.action||c,{unstable_defaultShouldRevalidate:o.unstable_defaultShouldRevalidate,preventScrollReset:o.preventScrollReset,formData:m,body:p,formMethod:o.method||d,formEncType:o.encType||f,flushSync:o.flushSync})}else await i(o.action||c,{unstable_defaultShouldRevalidate:o.unstable_defaultShouldRevalidate,preventScrollReset:o.preventScrollReset,formData:m,body:p,formMethod:o.method||d,formEncType:o.encType||f,replace:o.replace,state:o.state,fromRouteId:n,flushSync:o.flushSync,viewTransition:o.viewTransition})},[r,i,t,n])}function fC(e,{relative:t}={}){let{basename:n}=F.useContext(xi),r=F.useContext(ma);Rn(r,"useFormAction must be used inside a RouteContext");let[i]=r.matches.slice(-1),s={...E0(e||".",{relative:t})},o=us();if(e==null){s.search=o.search;let c=new URLSearchParams(s.search),d=c.getAll("index");if(d.some(m=>m==="")){c.delete("index"),d.filter(p=>p).forEach(p=>c.append("index",p));let m=c.toString();s.search=m?`?${m}`:""}}return(!e||e===".")&&i.route.index&&(s.search=s.search?s.search.replace(/^\?/,"?index&"):"?index"),n!=="/"&&(s.pathname=s.pathname==="/"?n:Ja([n,s.pathname])),s0(s)}function mC(e,{relative:t}={}){let n=F.useContext(i8);Rn(n!=null,"`useViewTransitionState` must be used within `react-router-dom`'s `RouterProvider`.  Did you accidentally import `RouterProvider` from `react-router`?");let{basename:r}=b8("useViewTransitionState"),i=E0(e,{relative:t});if(!n.isTransitioning)return!1;let s=rs(n.currentLocation.pathname,r)||n.currentLocation.pathname,o=rs(n.nextLocation.pathname,r)||n.nextLocation.pathname;return Wh(i.pathname,o)!=null||Wh(i.pathname,s)!=null}var Fl,pC=(Fl=class extends Error{constructor(n){super(new.target.formatMessage(new.target.kind,n.message,n.code,n.docsUrl),{cause:n.cause});Fa(this,"clerkError",!0);Fa(this,"code");Fa(this,"longMessage");Fa(this,"docsUrl");Fa(this,"cause");Object.setPrototypeOf(this,Fl.prototype),this.code=n.code,this.docsUrl=n.docsUrl,this.longMessage=n.longMessage,this.cause=n.cause}get name(){return this.constructor.name}toString(){return`[${this.name}]
Message:${this.message}`}static formatMessage(n,r,i,s){const o="Clerk:",c=new RegExp(o.replace(" ","\\s*"),"i");return r=r.replace(c,""),r=`${o} ${r.trim()}

(code="${i}")

`,s&&(r+=`

Docs: ${s}`),r}},Fa(Fl,"kind","ClerkError"),Fl);const gC=Object.freeze({InvalidProxyUrlErrorMessage:"The proxyUrl passed to Clerk is invalid. The expected value for proxyUrl is an absolute URL or a relative path with a leading '/'. (key={{url}})",InvalidPublishableKeyErrorMessage:"The publishableKey passed to Clerk is invalid. You can get your Publishable key at https://dashboard.clerk.com/last-active?path=api-keys. (key={{key}})",MissingPublishableKeyErrorMessage:"Missing publishableKey. You can get your key at https://dashboard.clerk.com/last-active?path=api-keys.",MissingSecretKeyErrorMessage:"Missing secretKey. You can get your key at https://dashboard.clerk.com/last-active?path=api-keys.",MissingClerkProvider:"{{source}} can only be used within the <ClerkProvider /> component. Learn more: https://clerk.com/docs/components/clerk-provider"});function v8({packageName:e,customMessages:t}){let n=e;function r(s,o){if(!o)return`${n}: ${s}`;let c=s;const d=s.matchAll(/{{([a-zA-Z0-9-_]+)}}/g);for(const f of d){const m=(o[f[1]]||"").toString();c=c.replace(`{{${f[1]}}}`,m)}return`${n}: ${c}`}const i={...gC,...t};return{setPackageName({packageName:s}){return typeof s=="string"&&(n=s),this},setMessages({customMessages:s}){return Object.assign(i,s||{}),this},throwInvalidPublishableKeyError(s){throw new Error(r(i.InvalidPublishableKeyErrorMessage,s))},throwInvalidProxyUrl(s){throw new Error(r(i.InvalidProxyUrlErrorMessage,s))},throwMissingPublishableKeyError(){throw new Error(r(i.MissingPublishableKeyErrorMessage))},throwMissingSecretKeyError(){throw new Error(r(i.MissingSecretKeyErrorMessage))},throwMissingClerkProviderError(s){throw new Error(r(i.MissingClerkProvider,s))},throw(s){throw new Error(r(s))}}}var Hl,Hg=(Hl=class extends pC{constructor(n,r){super({...r,message:n});Fa(this,"clerkRuntimeError",!0);Object.setPrototypeOf(this,Hl.prototype)}},Fa(Hl,"kind","ClerkRuntimeError"),Hl);const bC={strict_mfa:{afterMinutes:10,level:"multi_factor"},strict:{afterMinutes:10,level:"second_factor"},moderate:{afterMinutes:60,level:"second_factor"},lax:{afterMinutes:1440,level:"second_factor"}},vC=new Set(["first_factor","second_factor","multi_factor"]),_C=new Set(["strict_mfa","strict","moderate","lax"]),yC=e=>typeof e=="number"&&e>0,EC=e=>vC.has(e),TC=e=>_C.has(e),_1=e=>e.replace(/^(org:)*/,"org:"),xC=(e,t)=>{const{orgId:n,orgRole:r,orgPermissions:i}=t;return!e.role&&!e.permission||!n||!r||!i?null:e.permission?i.includes(_1(e.permission)):e.role?_1(r)===_1(e.role):null},uy=(e,t)=>{const{org:n,user:r}=wC(e),[i,s]=t.split(":"),o=s||i;return i==="org"?n.includes(o):i==="user"?r.includes(o):[...n,...r].includes(o)},SC=(e,t)=>{const{features:n,plans:r}=t;return e.feature&&n?uy(n,e.feature):e.plan&&r?uy(r,e.plan):null},wC=e=>{const t=e?e.split(",").map(n=>n.trim()):[];return{org:t.filter(n=>n.split(":")[0].includes("o")).map(n=>n.split(":")[1]),user:t.filter(n=>n.split(":")[0].includes("u")).map(n=>n.split(":")[1])}},AC=e=>{if(!e)return!1;const t=i=>typeof i=="string"?bC[i]:i,n=typeof e=="string"&&TC(e),r=typeof e=="object"&&EC(e.level)&&yC(e.afterMinutes);return n||r?t.bind(null,e):!1},kC=(e,{factorVerificationAge:t})=>{if(!e.reverification||!t)return null;const n=AC(e.reverification);if(!n)return null;const{level:r,afterMinutes:i}=n(),[s,o]=t,c=s!==-1?i>s:null,d=o!==-1?i>o:null;switch(r){case"first_factor":return c;case"second_factor":return o!==-1?d:c;case"multi_factor":return o===-1?c:c&&d}},CC=e=>t=>{if(!e.userId)return!1;const n=SC(t,e),r=xC(t,e),i=kC(t,e);return[n||r,i].some(s=>s===null)?[n||r,i].some(s=>s===!0):[n||r,i].every(s=>s===!0)},NC=({authObject:{sessionId:e,sessionStatus:t,userId:n,actor:r,orgId:i,orgRole:s,orgSlug:o,signOut:c,getToken:d,has:f,sessionClaims:m},options:{treatPendingAsSignedOut:p=!0}})=>{if(e===void 0&&n===void 0)return{isLoaded:!1,isSignedIn:void 0,sessionId:e,sessionClaims:void 0,userId:n,actor:void 0,orgId:void 0,orgRole:void 0,orgSlug:void 0,has:void 0,signOut:c,getToken:d};if(e===null&&n===null)return{isLoaded:!0,isSignedIn:!1,sessionId:e,userId:n,sessionClaims:null,actor:null,orgId:null,orgRole:null,orgSlug:null,has:()=>!1,signOut:c,getToken:d};if(p&&t==="pending")return{isLoaded:!0,isSignedIn:!1,sessionId:null,userId:null,sessionClaims:null,actor:null,orgId:null,orgRole:null,orgSlug:null,has:()=>!1,signOut:c,getToken:d};if(e&&m&&n&&i&&s)return{isLoaded:!0,isSignedIn:!0,sessionId:e,sessionClaims:m,userId:n,actor:r||null,orgId:i,orgRole:s,orgSlug:o||null,has:f,signOut:c,getToken:d};if(e&&m&&n&&!i)return{isLoaded:!0,isSignedIn:!0,sessionId:e,sessionClaims:m,userId:n,actor:r||null,orgId:null,orgRole:null,orgSlug:null,has:f,signOut:c,getToken:d}},OC=[".lcl.dev",".stg.dev",".lclstage.dev",".stgstage.dev",".dev.lclclerk.com",".stg.lclclerk.com",".accounts.lclclerk.com","accountsstage.dev","accounts.dev"],_8=e=>typeof atob<"u"&&typeof atob=="function"?atob(e):typeof global<"u"&&global.Buffer?new global.Buffer(e,"base64").toString():e,y8="pk_live_",RC="pk_test_";function E8(e){if(!e.endsWith("$"))return!1;const t=e.slice(0,-1);return t.includes("$")?!1:t.includes(".")}function cy(e,t={}){if(e=e||"",!e||!jg(e)){if(t.fatal&&!e)throw new Error("Publishable key is missing. Ensure that your publishable key is correctly configured. Double-check your environment configuration for your keys, or access them here: https://dashboard.clerk.com/last-active?path=api-keys");if(t.fatal&&!jg(e))throw new Error("Publishable key not valid.");return null}const n=e.startsWith(y8)?"production":"development";let r;try{r=_8(e.split("_")[2])}catch{if(t.fatal)throw new Error("Publishable key not valid: Failed to decode key.");return null}if(!E8(r)){if(t.fatal)throw new Error("Publishable key not valid: Decoded key has invalid format.");return null}let i=r.slice(0,-1);return t.proxyUrl?i=t.proxyUrl:n!=="development"&&t.domain&&t.isSatellite&&(i=`clerk.${t.domain}`),{instanceType:n,frontendApi:i}}function jg(e=""){try{if(!(e.startsWith(y8)||e.startsWith(RC)))return!1;const t=e.split("_");if(t.length!==3)return!1;const n=t[2];return n?E8(_8(n)):!1}catch{return!1}}function MC(){const e=new Map;return{isDevOrStagingUrl:t=>{if(!t)return!1;const n=typeof t=="string"?t:t.hostname;let r=e.get(n);return r===void 0&&(r=OC.some(i=>n.endsWith(i)),e.set(n,r)),r}}}const IC="METHOD_CALLED",DC=.1;function a2(e,t){return{event:IC,eventSamplingRate:DC,payload:{method:e,...t}}}var y1={exports:{}},E1={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var dy;function LC(){if(dy)return E1;dy=1;var e=Rf();function t(p,v){return p===v&&(p!==0||1/p===1/v)||p!==p&&v!==v}var n=typeof Object.is=="function"?Object.is:t,r=e.useState,i=e.useEffect,s=e.useLayoutEffect,o=e.useDebugValue;function c(p,v){var _=v(),T=r({inst:{value:_,getSnapshot:v}}),x=T[0].inst,k=T[1];return s(function(){x.value=_,x.getSnapshot=v,d(x)&&k({inst:x})},[p,_,v]),i(function(){return d(x)&&k({inst:x}),p(function(){d(x)&&k({inst:x})})},[p]),o(_),_}function d(p){var v=p.getSnapshot;p=p.value;try{var _=v();return!n(p,_)}catch{return!0}}function f(p,v){return v()}var m=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?f:c;return E1.useSyncExternalStore=e.useSyncExternalStore!==void 0?e.useSyncExternalStore:m,E1}var hy;function PC(){return hy||(hy=1,y1.exports=LC()),y1.exports}var BC=PC();const T8=0,x8=1,S8=2,fy=3;var my=Object.prototype.hasOwnProperty;function qg(e,t){var n,r;if(e===t)return!0;if(e&&t&&(n=e.constructor)===t.constructor){if(n===Date)return e.getTime()===t.getTime();if(n===RegExp)return e.toString()===t.toString();if(n===Array){if((r=e.length)===t.length)for(;r--&&qg(e[r],t[r]););return r===-1}if(!n||typeof e=="object"){r=0;for(n in e)if(my.call(e,n)&&++r&&!my.call(t,n)||!(n in t)||!qg(e[n],t[n]))return!1;return Object.keys(t).length===r}}return e!==e&&t!==t}const Ka=new WeakMap,Zs=()=>{},Cr=Zs(),Xh=Object,qt=e=>e===Cr,Vi=e=>typeof e=="function",is=(e,t)=>({...e,...t}),w8=e=>Vi(e.then),T1={},ih={},s2="undefined",T0=typeof window!=s2,$g=typeof document!=s2,UC=T0&&"Deno"in window,zC=()=>T0&&typeof window.requestAnimationFrame!=s2,A8=(e,t)=>{const n=Ka.get(e);return[()=>!qt(t)&&e.get(t)||T1,r=>{if(!qt(t)){const i=e.get(t);t in ih||(ih[t]=i),n[5](t,is(i,r),i||T1)}},n[6],()=>!qt(t)&&t in ih?ih[t]:!qt(t)&&e.get(t)||T1]};let Gg=!0;const FC=()=>Gg,[Yg,Vg]=T0&&window.addEventListener?[window.addEventListener.bind(window),window.removeEventListener.bind(window)]:[Zs,Zs],HC=()=>{const e=$g&&document.visibilityState;return qt(e)||e!=="hidden"},jC=e=>($g&&document.addEventListener("visibilitychange",e),Yg("focus",e),()=>{$g&&document.removeEventListener("visibilitychange",e),Vg("focus",e)}),qC=e=>{const t=()=>{Gg=!0,e()},n=()=>{Gg=!1};return Yg("online",t),Yg("offline",n),()=>{Vg("online",t),Vg("offline",n)}},$C={isOnline:FC,isVisible:HC},GC={initFocus:jC,initReconnect:qC},py=!ue.useId,l0=!T0||UC,YC=e=>zC()?window.requestAnimationFrame(e):setTimeout(e,1),Bh=l0?F.useEffect:F.useLayoutEffect,x1=typeof navigator<"u"&&navigator.connection,gy=!l0&&x1&&(["slow-2g","2g"].includes(x1.effectiveType)||x1.saveData),ah=new WeakMap,VC=e=>Xh.prototype.toString.call(e),S1=(e,t)=>e===`[object ${t}]`;let KC=0;const Kg=e=>{const t=typeof e,n=VC(e),r=S1(n,"Date"),i=S1(n,"RegExp"),s=S1(n,"Object");let o,c;if(Xh(e)===e&&!r&&!i){if(o=ah.get(e),o)return o;if(o=++KC+"~",ah.set(e,o),Array.isArray(e)){for(o="@",c=0;c<e.length;c++)o+=Kg(e[c])+",";ah.set(e,o)}if(s){o="#";const d=Xh.keys(e).sort();for(;!qt(c=d.pop());)qt(e[c])||(o+=c+":"+Kg(e[c])+",");ah.set(e,o)}}else o=r?e.toJSON():t=="symbol"?e.toString():t=="string"?JSON.stringify(e):""+e;return o},l2=e=>{if(Vi(e))try{e=e()}catch{e=""}const t=e;return e=typeof e=="string"?e:(Array.isArray(e)?e.length:e)?Kg(e):"",[e,t]};let WC=0;const Wg=()=>++WC;async function k8(...e){const[t,n,r,i]=e,s=is({populateCache:!0,throwOnError:!0},typeof i=="boolean"?{revalidate:i}:i||{});let o=s.populateCache;const c=s.rollbackOnError;let d=s.optimisticData;const f=v=>typeof c=="function"?c(v):c!==!1,m=s.throwOnError;if(Vi(n)){const v=n,_=[],T=t.keys();for(const x of T)!/^\$(inf|sub)\$/.test(x)&&v(t.get(x)._k)&&_.push(x);return Promise.all(_.map(p))}return p(n);async function p(v){const[_]=l2(v);if(!_)return;const[T,x]=A8(t,_),[k,A,O,I]=Ka.get(t),$=()=>{const fe=k[_];return(Vi(s.revalidate)?s.revalidate(T().data,v):s.revalidate!==!1)&&(delete O[_],delete I[_],fe&&fe[0])?fe[0](S8).then(()=>T().data):T().data};if(e.length<3)return $();let V=r,B,Z=!1;const ee=Wg();A[_]=[ee,0];const te=!qt(d),Y=T(),oe=Y.data,he=Y._c,Se=qt(he)?oe:he;if(te&&(d=Vi(d)?d(Se,oe):d,x({data:d,_c:Se})),Vi(V))try{V=V(Se)}catch(fe){B=fe,Z=!0}if(V&&w8(V))if(V=await V.catch(fe=>{B=fe,Z=!0}),ee!==A[_][0]){if(Z)throw B;return V}else Z&&te&&f(B)&&(o=!0,x({data:Se,_c:Cr}));if(o&&!Z)if(Vi(o)){const fe=o(V,Se);x({data:fe,error:Cr,_c:Cr})}else x({data:V,error:Cr,_c:Cr});if(A[_][1]=Wg(),Promise.resolve($()).then(()=>{x({_c:Cr})}),Z){if(m)throw B;return}return V}}const by=(e,t)=>{for(const n in e)e[n][0]&&e[n][0](t)},C8=(e,t)=>{if(!Ka.has(e)){const n=is(GC,t),r=Object.create(null),i=k8.bind(Cr,e);let s=Zs;const o=Object.create(null),c=(m,p)=>{const v=o[m]||[];return o[m]=v,v.push(p),()=>v.splice(v.indexOf(p),1)},d=(m,p,v)=>{e.set(m,p);const _=o[m];if(_)for(const T of _)T(p,v)},f=()=>{if(!Ka.has(e)&&(Ka.set(e,[r,Object.create(null),Object.create(null),Object.create(null),i,d,c]),!l0)){const m=n.initFocus(setTimeout.bind(Cr,by.bind(Cr,r,T8))),p=n.initReconnect(setTimeout.bind(Cr,by.bind(Cr,r,x8)));s=()=>{m&&m(),p&&p(),Ka.delete(e)}}};return f(),[e,i,f,s]}return[e,Ka.get(e)[4]]},XC=(e,t,n,r,i)=>{const s=n.errorRetryCount,o=i.retryCount,c=~~((Math.random()+.5)*(1<<(o<8?o:8)))*n.errorRetryInterval;!qt(s)&&o>s||setTimeout(r,c,i)},QC=qg,[o2,ZC]=C8(new Map),N8=is({onLoadingSlow:Zs,onSuccess:Zs,onError:Zs,onErrorRetry:XC,onDiscarded:Zs,revalidateOnFocus:!0,revalidateOnReconnect:!0,revalidateIfStale:!0,shouldRetryOnError:!0,errorRetryInterval:gy?1e4:5e3,focusThrottleInterval:5*1e3,dedupingInterval:2*1e3,loadingTimeout:gy?5e3:3e3,compare:QC,isPaused:()=>!1,cache:o2,mutate:ZC,fallback:{}},$C),O8=(e,t)=>{const n=is(e,t);if(t){const{use:r,fallback:i}=e,{use:s,fallback:o}=t;r&&s&&(n.use=r.concat(s)),i&&o&&(n.fallback=is(i,o))}return n},Xg=F.createContext({}),JC=e=>{const{value:t}=e,n=F.useContext(Xg),r=Vi(t),i=F.useMemo(()=>r?t(n):t,[r,n,t]),s=F.useMemo(()=>r?i:O8(n,i),[r,n,i]),o=i&&i.provider,c=F.useRef(Cr);o&&!c.current&&(c.current=C8(o(s.cache||o2),i));const d=c.current;return d&&(s.cache=d[0],s.mutate=d[1]),Bh(()=>{if(d)return d[2]&&d[2](),d[3]},[]),F.createElement(Xg.Provider,is(e,{value:s}))},eN="$inf$",R8=T0&&window.__SWR_DEVTOOLS_USE__,tN=R8?window.__SWR_DEVTOOLS_USE__:[],nN=()=>{R8&&(window.__SWR_DEVTOOLS_REACT__=ue)},rN=e=>Vi(e[1])?[e[0],e[1],e[2]||{}]:[e[0],null,(e[1]===null?e[2]:e[1])||{}],iN=()=>is(N8,F.useContext(Xg)),aN=e=>(t,n,r)=>e(t,n&&((...s)=>{const[o]=l2(t),[,,,c]=Ka.get(o2);if(o.startsWith(eN))return n(...s);const d=c[o];return qt(d)?n(...s):(delete c[o],d)}),r),sN=tN.concat(aN),lN=e=>function(...n){const r=iN(),[i,s,o]=rN(n),c=O8(r,o);let d=e;const{use:f}=c,m=(f||[]).concat(sN);for(let p=m.length;p--;)d=m[p](d);return d(i,s||c.fetcher||null,c)},oN=(e,t,n)=>{const r=t[e]||(t[e]=[]);return r.push(n),()=>{const i=r.indexOf(n);i>=0&&(r[i]=r[r.length-1],r.pop())}};nN();const w1=ue.use||(e=>{switch(e.status){case"pending":throw e;case"fulfilled":return e.value;case"rejected":throw e.reason;default:throw e.status="pending",e.then(t=>{e.status="fulfilled",e.value=t},t=>{e.status="rejected",e.reason=t}),e}}),A1={dedupe:!0},uN=(e,t,n)=>{const{cache:r,compare:i,suspense:s,fallbackData:o,revalidateOnMount:c,revalidateIfStale:d,refreshInterval:f,refreshWhenHidden:m,refreshWhenOffline:p,keepPreviousData:v}=n,[_,T,x,k]=Ka.get(r),[A,O]=l2(e),I=F.useRef(!1),$=F.useRef(!1),V=F.useRef(A),B=F.useRef(t),Z=F.useRef(n),ee=()=>Z.current,te=()=>ee().isVisible()&&ee().isOnline(),[Y,oe,he,Se]=A8(r,A),fe=F.useRef({}).current,de=qt(o)?qt(n.fallback)?Cr:n.fallback[A]:o,H=(yt,ct)=>{for(const Ft in fe){const Xe=Ft;if(Xe==="data"){if(!i(yt[Xe],ct[Xe])&&(!qt(yt[Xe])||!i(Le,ct[Xe])))return!1}else if(ct[Xe]!==yt[Xe])return!1}return!0},ie=F.useMemo(()=>{const yt=!A||!t?!1:qt(c)?ee().isPaused()||s?!1:d!==!1:c,ct=un=>{const Ge=is(un);return delete Ge._k,yt?{isValidating:!0,isLoading:!0,...Ge}:Ge},Ft=Y(),Xe=Se(),jt=ct(Ft),pn=Ft===Xe?jt:ct(Xe);let Pt=jt;return[()=>{const un=ct(Y());return H(un,Pt)?(Pt.data=un.data,Pt.isLoading=un.isLoading,Pt.isValidating=un.isValidating,Pt.error=un.error,Pt):(Pt=un,un)},()=>pn]},[r,A]),ve=BC.useSyncExternalStore(F.useCallback(yt=>he(A,(ct,Ft)=>{H(Ft,ct)||yt()}),[r,A]),ie[0],ie[1]),xe=!I.current,P=_[A]&&_[A].length>0,z=ve.data,J=qt(z)?de&&w8(de)?w1(de):de:z,D=ve.error,Ae=F.useRef(J),Le=v?qt(z)?qt(Ae.current)?J:Ae.current:z:J,ze=P&&!qt(D)?!1:xe&&!qt(c)?c:ee().isPaused()?!1:s?qt(J)?!1:d:qt(J)||d,at=!!(A&&t&&xe&&ze),_t=qt(ve.isValidating)?at:ve.isValidating,pt=qt(ve.isLoading)?at:ve.isLoading,Tt=F.useCallback(async yt=>{const ct=B.current;if(!A||!ct||$.current||ee().isPaused())return!1;let Ft,Xe,jt=!0;const pn=yt||{},Pt=!x[A]||!pn.dedupe,un=()=>py?!$.current&&A===V.current&&I.current:A===V.current,Ge={isValidating:!1,isLoading:!1},gn=()=>{oe(Ge)},In=()=>{const En=x[A];En&&En[1]===Xe&&delete x[A]},Xt={isValidating:!0};qt(Y().data)&&(Xt.isLoading=!0);try{if(Pt&&(oe(Xt),n.loadingTimeout&&qt(Y().data)&&setTimeout(()=>{jt&&un()&&ee().onLoadingSlow(A,n)},n.loadingTimeout),x[A]=[ct(O),Wg()]),[Ft,Xe]=x[A],Ft=await Ft,Pt&&setTimeout(In,n.dedupingInterval),!x[A]||x[A][1]!==Xe)return Pt&&un()&&ee().onDiscarded(A),!1;Ge.error=Cr;const En=T[A];if(!qt(En)&&(Xe<=En[0]||Xe<=En[1]||En[1]===0))return gn(),Pt&&un()&&ee().onDiscarded(A),!1;const me=Y().data;Ge.data=i(me,Ft)?me:Ft,Pt&&un()&&ee().onSuccess(Ft,A,n)}catch(En){In();const me=ee(),{shouldRetryOnError:Ce}=me;me.isPaused()||(Ge.error=En,Pt&&un()&&(me.onError(En,A,me),(Ce===!0||Vi(Ce)&&Ce(En))&&(!ee().revalidateOnFocus||!ee().revalidateOnReconnect||te())&&me.onErrorRetry(En,A,me,Ye=>{const dt=_[A];dt&&dt[0]&&dt[0](fy,Ye)},{retryCount:(pn.retryCount||0)+1,dedupe:!0})))}return jt=!1,gn(),!0},[A,r]),kn=F.useCallback((...yt)=>k8(r,V.current,...yt),[]);if(Bh(()=>{B.current=t,Z.current=n,qt(z)||(Ae.current=z)}),Bh(()=>{if(!A)return;const yt=Tt.bind(Cr,A1);let ct=0;ee().revalidateOnFocus&&(ct=Date.now()+ee().focusThrottleInterval);const Xe=oN(A,_,(jt,pn={})=>{if(jt==T8){const Pt=Date.now();ee().revalidateOnFocus&&Pt>ct&&te()&&(ct=Pt+ee().focusThrottleInterval,yt())}else if(jt==x8)ee().revalidateOnReconnect&&te()&&yt();else{if(jt==S8)return Tt();if(jt==fy)return Tt(pn)}});return $.current=!1,V.current=A,I.current=!0,oe({_k:O}),ze&&(x[A]||(qt(J)||l0?yt():YC(yt))),()=>{$.current=!0,Xe()}},[A]),Bh(()=>{let yt;function ct(){const Xe=Vi(f)?f(Y().data):f;Xe&&yt!==-1&&(yt=setTimeout(Ft,Xe))}function Ft(){!Y().error&&(m||ee().isVisible())&&(p||ee().isOnline())?Tt(A1).then(ct):ct()}return ct(),()=>{yt&&(clearTimeout(yt),yt=-1)}},[f,m,p,A]),F.useDebugValue(Le),s&&qt(J)&&A){if(!py&&l0)throw new Error("Fallback data is required when using Suspense in SSR.");B.current=t,Z.current=n,$.current=!1;const yt=k[A];if(!qt(yt)){const ct=kn(yt);w1(ct)}if(qt(D)){const ct=Tt(A1);qt(Le)||(ct.status="fulfilled",ct.value=!0),w1(ct)}else throw D}return{mutate:kn,get data(){return fe.data=!0,Le},get error(){return fe.error=!0,D},get isValidating(){return fe.isValidating=!0,_t},get isLoading(){return fe.isLoading=!0,pt}}},cN=Xh.defineProperty(JC,"defaultValue",{value:N8}),dN=lN(uN);var vy=Object.prototype.hasOwnProperty;function _y(e,t,n){for(n of e.keys())if(Vc(n,t))return n}function Vc(e,t){var n,r,i;if(e===t)return!0;if(e&&t&&(n=e.constructor)===t.constructor){if(n===Date)return e.getTime()===t.getTime();if(n===RegExp)return e.toString()===t.toString();if(n===Array){if((r=e.length)===t.length)for(;r--&&Vc(e[r],t[r]););return r===-1}if(n===Set){if(e.size!==t.size)return!1;for(r of e)if(i=r,i&&typeof i=="object"&&(i=_y(t,i),!i)||!t.has(i))return!1;return!0}if(n===Map){if(e.size!==t.size)return!1;for(r of e)if(i=r[0],i&&typeof i=="object"&&(i=_y(t,i),!i)||!Vc(r[1],t.get(i)))return!1;return!0}if(n===ArrayBuffer)e=new Uint8Array(e),t=new Uint8Array(t);else if(n===DataView){if((r=e.byteLength)===t.byteLength)for(;r--&&e.getInt8(r)===t.getInt8(r););return r===-1}if(ArrayBuffer.isView(e)){if((r=e.byteLength)===t.byteLength)for(;r--&&e[r]===t[r];);return r===-1}if(!n||typeof e=="object"){r=0;for(n in e)if(vy.call(e,n)&&++r&&!vy.call(t,n)||!(n in t)||!Vc(e[n],t[n]))return!1;return Object.keys(t).length===r}}return e!==e&&t!==t}function hN(e,t){if(!e)throw typeof t=="string"?new Error(t):new Error(`${t.displayName} not found`)}const cs=(e,t)=>{const{assertCtxFn:n=hN}={},r=ue.createContext(void 0);return r.displayName=e,[r,()=>{const o=ue.useContext(r);return n(o,`${e} not found`),o.value},()=>{const o=ue.useContext(r);return o?o.value:{}}]};function fN({swrConfig:e,children:t}){return ue.createElement(cN,{value:e},t)}const[M8,Df]=cs("ClerkInstanceContext"),[mN,I8]=cs("UserContext"),[pN]=cs("ClientContext"),[gN]=cs("SessionContext");ue.createContext({});const[bN]=cs("CheckoutContext"),vN=({children:e,...t})=>ue.createElement(bN.Provider,{value:{value:t}},e),[_N,yN]=cs("OrganizationContext"),EN=({children:e,organization:t,swrConfig:n})=>ue.createElement(fN,{swrConfig:n},ue.createElement(_N.Provider,{value:{value:{organization:t}}},e));function Lf(e){if(!ue.useContext(M8)){if(typeof e=="function"){e();return}throw new Error(`${e} can only be used within the <ClerkProvider /> component.

Possible fixes:
1. Ensure that the <ClerkProvider /> is correctly wrapping your application where this component is used.
2. Check for multiple versions of the \`@clerk/shared\` package in your project. Use a tool like \`npm ls @clerk/shared\` to identify multiple versions, and update your dependencies to only rely on one.

Learn more: https://clerk.com/docs/components/clerk-provider`.trim())}}const TN="billing-subscription",xN={SUBSCRIPTION_KEY:TN};function SN(e){return{queryKey:[e.stablePrefix,e.authenticated,e.tracked,e.untracked],invalidationKey:[e.stablePrefix,e.authenticated,e.tracked],stableKey:e.stablePrefix,authenticated:e.authenticated}}const wN=()=>(Lf("useClerk"),Df());typeof window<"u"?ue.useLayoutEffect:ue.useEffect;const yy="useUser";function AN(){var t;Lf(yy);const e=I8();return(t=Df().telemetry)==null||t.record(a2(yy)),e===void 0?{isLoaded:!1,isSignedIn:void 0,user:void 0}:e===null?{isLoaded:!0,isSignedIn:!1,user:null}:{isLoaded:!0,isSignedIn:!0,user:e}}const Ey=Vc;function kN(e){const{userId:t,orgId:n,for:r}=e;return F.useMemo(()=>{const i=r==="organization"?n:void 0;return SN({stablePrefix:xN.SUBSCRIPTION_KEY,authenticated:!0,tracked:{userId:t,orgId:i},untracked:{args:{orgId:i}}})},[t,n,r])}const Ty="useSubscription";function CN(e){var m;Lf(Ty);const t=Df(),n=I8(),{organization:r}=yN(),i=t.__unstable__environment;(m=t.telemetry)==null||m.record(a2(Ty));const s=(e==null?void 0:e.for)==="organization"?i==null?void 0:i.commerceSettings.billing.organization.enabled:i==null?void 0:i.commerceSettings.billing.user.enabled,o=((e==null?void 0:e.enabled)??!0)&&s,{queryKey:c}=kN({userId:n==null?void 0:n.id,orgId:r==null?void 0:r.id,for:e==null?void 0:e.for}),d=dN(o?{queryKey:c}:null,({queryKey:p})=>{const v=p[3].args;return p[2].userId?t.billing.getSubscription(v):null},{dedupingInterval:1e3*60,keepPreviousData:e==null?void 0:e.keepPreviousData}),f=F.useCallback(()=>{d.mutate()},[d]);return{data:d.data,error:d.error,isLoading:d.isLoading,isFetching:d.isValidating,revalidate:f}}const NN=e=>{const t=F.useRef(e);return F.useEffect(()=>{t.current=e},[e]),t.current},bi=(e,t,n)=>{const r=!!n,i=F.useRef(n);F.useEffect(()=>{i.current=n},[n]),F.useEffect(()=>{if(!r||!e)return()=>{};const s=(...o)=>{i.current&&i.current(...o)};return e.on(t,s),()=>{e.off(t,s)}},[r,t,e,i])},D8=ue.createContext(null);D8.displayName="ElementsContext";const ON=(e,t)=>{if(!e)throw new Error(`Could not find Elements context; You need to wrap the part of your app that ${t} in an <Elements> provider.`);return e},Qh=e=>e!==null&&typeof e=="object",RN=(e,t,n)=>Qh(e)?Object.keys(e).reduce((r,i)=>{const s=!Qh(t)||!L8(e[i],t[i]);return n.includes(i)?(s&&console.warn(`Unsupported prop change: options.${i} is not a mutable property.`),r):s?{...r||{},[i]:e[i]}:r},null):null,xy="[object Object]",L8=(e,t)=>{if(!Qh(e)||!Qh(t))return e===t;const n=Array.isArray(e);if(n!==Array.isArray(t))return!1;const r=Object.prototype.toString.call(e)===xy;if(r!==(Object.prototype.toString.call(t)===xy))return!1;if(!r&&!n)return e===t;const i=Object.keys(e),s=Object.keys(t);if(i.length!==s.length)return!1;const o={};for(let p=0;p<i.length;p+=1)o[i[p]]=!0;for(let p=0;p<s.length;p+=1)o[s[p]]=!0;const c=Object.keys(o);if(c.length!==i.length)return!1;const d=e,f=t,m=p=>L8(d[p],f[p]);return c.every(m)},Sy=e=>ON(ue.useContext(D8),e),MN=e=>e.charAt(0).toUpperCase()+e.slice(1),IN=(e,t)=>{const n=`${MN(e)}Element`,s=t?o=>{Sy(`mounts <${n}>`);const{id:c,className:d}=o;return ue.createElement("div",{id:c,className:d})}:({id:o,className:c,fallback:d,options:f={},onBlur:m,onFocus:p,onReady:v,onChange:_,onEscape:T,onClick:x,onLoadError:k,onLoaderStart:A,onNetworksChange:O,onConfirm:I,onCancel:$,onShippingAddressChange:V,onShippingRateChange:B})=>{const Z=Sy(`mounts <${n}>`),ee="elements"in Z?Z.elements:null,[te,Y]=ue.useState(null),oe=ue.useRef(null),he=ue.useRef(null),[Se,fe]=F.useState(!1);bi(te,"blur",m),bi(te,"focus",p),bi(te,"escape",T),bi(te,"click",x),bi(te,"loaderror",k),bi(te,"loaderstart",A),bi(te,"networkschange",O),bi(te,"confirm",I),bi(te,"cancel",$),bi(te,"shippingaddresschange",V),bi(te,"shippingratechange",B),bi(te,"change",_);let de;v&&(de=()=>{fe(!0),v(te)}),bi(te,"ready",de),ue.useLayoutEffect(()=>{if(oe.current===null&&he.current!==null&&ee){let ie=null;ee&&(ie=ee.create(e,f)),oe.current=ie,Y(ie),ie&&ie.mount(he.current)}},[ee,f]);const H=NN(f);return ue.useEffect(()=>{if(!oe.current)return;const ie=RN(f,H,["paymentRequest"]);ie&&"update"in oe.current&&oe.current.update(ie)},[f,H]),ue.useLayoutEffect(()=>()=>{if(oe.current&&typeof oe.current.destroy=="function")try{oe.current.destroy(),oe.current=null}catch{}},[]),ue.createElement(ue.Fragment,null,!Se&&d,ue.createElement("div",{id:o,style:{height:Se?"unset":"0px",visibility:Se?"visible":"hidden"},className:c,ref:he}))};return s.displayName=n,s.__elementType=e,s};IN("payment",typeof window>"u");cs("PaymentElementContext");cs("StripeUtilsContext");var Ki=v8({packageName:"@clerk/clerk-react"});function DN(e){Ki.setMessages(e).setPackageName(e)}var[LN,PN]=cs("AuthContext"),BN=M8,P8=Df,UN="You've added multiple <ClerkProvider> components in your React component tree. Wrap your components in a single <ClerkProvider>.",zN=e=>`You've passed multiple children components to <${e}/>. You can only pass a single child component or text.`,FN="Invalid state. Feel free to submit a bug or reach out to support here: https://clerk.com/support",k1="Unsupported usage of isSatellite, domain or proxyUrl. The usage of isSatellite, domain or proxyUrl as function is not supported in non-browser environments.",HN="<UserProfile.Page /> component needs to be a direct child of `<UserProfile />` or `<UserButton />`.",jN="<UserProfile.Link /> component needs to be a direct child of `<UserProfile />` or `<UserButton />`.",qN="<OrganizationProfile.Page /> component needs to be a direct child of `<OrganizationProfile />` or `<OrganizationSwitcher />`.",$N="<OrganizationProfile.Link /> component needs to be a direct child of `<OrganizationProfile />` or `<OrganizationSwitcher />`.",GN=e=>`<${e} /> can only accept <${e}.Page /> and <${e}.Link /> as its children. Any other provided component will be ignored. Additionally, please ensure that the component is rendered in a client component.`,YN=e=>`Missing props. <${e}.Page /> component requires the following props: url, label, labelIcon, alongside with children to be rendered inside the page.`,VN=e=>`Missing props. <${e}.Link /> component requires the following props: url, label and labelIcon.`,KN="<UserButton /> can only accept <UserButton.UserProfilePage />, <UserButton.UserProfileLink /> and <UserButton.MenuItems /> as its children. Any other provided component will be ignored. Additionally, please ensure that the component is rendered in a client component.",WN="<UserButton.MenuItems /> component can only accept <UserButton.Action /> and <UserButton.Link /> as its children. Any other provided component will be ignored. Additionally, please ensure that the component is rendered in a client component.",XN="<UserButton.MenuItems /> component needs to be a direct child of `<UserButton />`.",QN="<UserButton.Action /> component needs to be a direct child of `<UserButton.MenuItems />`.",ZN="<UserButton.Link /> component needs to be a direct child of `<UserButton.MenuItems />`.",JN="Missing props. <UserButton.Link /> component requires the following props: href, label and labelIcon.",eO="Missing props. <UserButton.Action /> component requires the following props: label.",Pf=e=>{Lf(()=>{Ki.throwMissingClerkProviderError({source:e})})},B8=e=>new Promise(t=>{const n=r=>{["ready","degraded"].includes(r)&&(t(),e.off("status",n))};e.on("status",n,{notify:!0})}),tO=e=>async t=>(await B8(e),e.session?e.session.getToken(t):null),nO=e=>async(...t)=>(await B8(e),e.signOut(...t)),x0=(e={})=>{var t;Pf("useAuth");const{treatPendingAsSignedOut:n,...r}=e??{},i=r;let o=PN();o.sessionId===void 0&&o.userId===void 0&&(o=i??{});const c=P8(),d=F.useCallback(tO(c),[c]),f=F.useCallback(nO(c),[c]);return(t=c.telemetry)==null||t.record(a2("useAuth",{treatPendingAsSignedOut:n})),rO({...o,getToken:d,signOut:f},{treatPendingAsSignedOut:n})};function rO(e,{treatPendingAsSignedOut:t=!0}={}){const{userId:n,orgId:r,orgRole:i,has:s,signOut:o,getToken:c,orgPermissions:d,factorVerificationAge:f,sessionClaims:m}=e??{},p=F.useCallback(_=>s?s(_):CC({userId:n,orgId:r,orgRole:i,orgPermissions:d,factorVerificationAge:f,features:(m==null?void 0:m.fea)||"",plans:(m==null?void 0:m.pla)||""})(_),[s,n,r,i,d,f,m]),v=NC({authObject:{...e,getToken:c,signOut:o,has:p},options:{treatPendingAsSignedOut:t}});return v||Ki.throw(FN)}var rn=(e,t)=>{const r=(typeof t=="string"?t:t==null?void 0:t.component)||e.displayName||e.name||"Component";e.displayName=r;const i=typeof t=="string"?void 0:t,s=o=>{Pf(r||"withClerk");const c=P8();return!c.loaded&&!(i!=null&&i.renderWhileLoading)?null:ue.createElement(e,{...o,component:r,clerk:c})};return s.displayName=`withClerk(${r})`,s};const iO=()=>{try{return!1}catch{}return!1},aO=()=>{try{return!1}catch{}return!1},sO=()=>{try{return!0}catch{}return!1},wy=new Set,u2=(e,t,n)=>{const r=aO()||sO(),i=e;wy.has(i)||r||(wy.add(i),console.warn(`Clerk - DEPRECATION WARNING: "${e}" is deprecated and will be removed in the next major release.
${t}`))};var lO=({children:e,treatPendingAsSignedOut:t})=>{Pf("SignedIn");const{userId:n}=x0({treatPendingAsSignedOut:t});return n?e:null},oO=({children:e,treatPendingAsSignedOut:t})=>{Pf("SignedOut");const{userId:n}=x0({treatPendingAsSignedOut:t});return n===null?e:null};rn(({clerk:e,...t})=>{const{client:n,session:r}=e,i=n.signedInSessions?n.signedInSessions.length>0:n.activeSessions&&n.activeSessions.length>0;return ue.useEffect(()=>{r===null&&i?e.redirectToAfterSignOut():e.redirectToSignIn(t)},[]),null},"RedirectToSignIn");rn(({clerk:e,...t})=>(ue.useEffect(()=>{e.redirectToSignUp(t)},[]),null),"RedirectToSignUp");rn(({clerk:e,...t})=>(ue.useEffect(()=>{e.redirectToTasks(t)},[]),null),"RedirectToTasks");rn(({clerk:e})=>(ue.useEffect(()=>{u2("RedirectToUserProfile","Use the `redirectToUserProfile()` method instead."),e.redirectToUserProfile()},[]),null),"RedirectToUserProfile");rn(({clerk:e})=>(ue.useEffect(()=>{u2("RedirectToOrganizationProfile","Use the `redirectToOrganizationProfile()` method instead."),e.redirectToOrganizationProfile()},[]),null),"RedirectToOrganizationProfile");rn(({clerk:e})=>(ue.useEffect(()=>{u2("RedirectToCreateOrganization","Use the `redirectToCreateOrganization()` method instead."),e.redirectToCreateOrganization()},[]),null),"RedirectToCreateOrganization");rn(({clerk:e,...t})=>(ue.useEffect(()=>{e.handleRedirectCallback(t)},[]),null),"AuthenticateWithRedirectCallback");function C1(e,t,n){if(typeof e=="function")return e(t);if(typeof e<"u")return e;if(typeof n<"u")return n}const zr=e=>{iO()&&console.error(`Clerk: ${e}`)};var uO=V5();const Ay=(e,...t)=>{const n={...e};for(const r of t)delete n[r];return n};var Vl=e=>t=>{try{return ue.Children.only(e)}catch{return Ki.throw(zN(t))}},Kl=(e,t)=>(e||(e=t),typeof e=="string"&&(e=ue.createElement("button",null,e)),e),Wl=e=>(...t)=>{if(e&&typeof e=="function")return e(...t)};function cO(e){return typeof e=="function"}var sh=new Map;function dO(e,t,n=1){ue.useEffect(()=>{const r=sh.get(e)||0;return r==n?Ki.throw(t):(sh.set(e,r+1),()=>{sh.set(e,(sh.get(e)||1)-1)})},[])}function hO(e,t,n){const r=e.displayName||e.name||t||"Component",i=s=>(dO(t,n),ue.createElement(e,{...s}));return i.displayName=`withMaxAllowedInstancesGuard(${r})`,i}var Kc=e=>{const[t,n]=F.useState(new Map);return e.map(r=>({id:r.id,mount:i=>n(s=>new Map(s).set(String(r.id),i)),unmount:()=>n(i=>{const s=new Map(i);return s.set(String(r.id),null),s}),portal:()=>{const i=t.get(String(r.id));return i?uO.createPortal(r.component,i):null}}))},Ur=(e,t)=>!!e&&ue.isValidElement(e)&&(e==null?void 0:e.type)===t,U8=(e,t)=>H8({children:e,reorderItemsLabels:["account","security","billing","apiKeys"],LinkComponent:w0,PageComponent:S0,MenuItemsComponent:Uf,componentName:"UserProfile"},t),z8=(e,t)=>H8({children:e,reorderItemsLabels:["general","members","billing","apiKeys"],LinkComponent:Ff,PageComponent:zf,componentName:"OrganizationProfile"},t),F8=e=>{const t=[],n=[Ff,zf,Uf,S0,w0];return ue.Children.forEach(e,r=>{n.some(i=>Ur(r,i))||t.push(r)}),t},H8=(e,t)=>{const{children:n,LinkComponent:r,PageComponent:i,MenuItemsComponent:s,reorderItemsLabels:o,componentName:c}=e,{allowForAnyChildren:d=!1}=t||{},f=[];ue.Children.forEach(n,O=>{if(!Ur(O,i)&&!Ur(O,r)&&!Ur(O,s)){O&&!d&&zr(GN(c));return}const{props:I}=O,{children:$,label:V,url:B,labelIcon:Z}=I;if(Ur(O,i))if(ky(I,o))f.push({label:V});else if(N1(I))f.push({label:V,labelIcon:Z,children:$,url:B});else{zr(YN(c));return}if(Ur(O,r))if(O1(I))f.push({label:V,labelIcon:Z,url:B});else{zr(VN(c));return}});const m=[],p=[],v=[];f.forEach((O,I)=>{if(N1(O)){m.push({component:O.children,id:I}),p.push({component:O.labelIcon,id:I});return}O1(O)&&v.push({component:O.labelIcon,id:I})});const _=Kc(m),T=Kc(p),x=Kc(v),k=[],A=[];return f.forEach((O,I)=>{if(ky(O,o)){k.push({label:O.label});return}if(N1(O)){const{portal:$,mount:V,unmount:B}=_.find(Y=>Y.id===I),{portal:Z,mount:ee,unmount:te}=T.find(Y=>Y.id===I);k.push({label:O.label,url:O.url,mount:V,unmount:B,mountIcon:ee,unmountIcon:te}),A.push($),A.push(Z);return}if(O1(O)){const{portal:$,mount:V,unmount:B}=x.find(Z=>Z.id===I);k.push({label:O.label,url:O.url,mountIcon:V,unmountIcon:B}),A.push($);return}}),{customPages:k,customPagesPortals:A}},ky=(e,t)=>{const{children:n,label:r,url:i,labelIcon:s}=e;return!n&&!i&&!s&&t.some(o=>o===r)},N1=e=>{const{children:t,label:n,url:r,labelIcon:i}=e;return!!t&&!!r&&!!i&&!!n},O1=e=>{const{children:t,label:n,url:r,labelIcon:i}=e;return!t&&!!r&&!!i&&!!n},fO=(e,t)=>{var n;return mO({children:e,reorderItemsLabels:["manageAccount","signOut"],MenuItemsComponent:Uf,MenuActionComponent:q8,MenuLinkComponent:$8,UserProfileLinkComponent:w0,UserProfilePageComponent:S0,allowForAnyChildren:(n=t==null?void 0:t.allowForAnyChildren)!=null?n:!1})},mO=({children:e,MenuItemsComponent:t,MenuActionComponent:n,MenuLinkComponent:r,UserProfileLinkComponent:i,UserProfilePageComponent:s,reorderItemsLabels:o,allowForAnyChildren:c=!1})=>{const d=[],f=[],m=[];ue.Children.forEach(e,x=>{if(!Ur(x,t)&&!Ur(x,i)&&!Ur(x,s)){x&&!c&&zr(KN);return}if(Ur(x,i)||Ur(x,s))return;const{props:k}=x;ue.Children.forEach(k.children,A=>{if(!Ur(A,n)&&!Ur(A,r)){A&&zr(WN);return}const{props:O}=A,{label:I,labelIcon:$,href:V,onClick:B,open:Z}=O;if(Ur(A,n))if(Cy(O,o))d.push({label:I});else if(R1(O)){const ee={label:I,labelIcon:$};if(B!==void 0)d.push({...ee,onClick:B});else if(Z!==void 0)d.push({...ee,open:Z.startsWith("/")?Z:`/${Z}`});else{zr("Custom menu item must have either onClick or open property");return}}else{zr(eO);return}if(Ur(A,r))if(M1(O))d.push({label:I,labelIcon:$,href:V});else{zr(JN);return}})});const p=[],v=[];d.forEach((x,k)=>{R1(x)&&p.push({component:x.labelIcon,id:k}),M1(x)&&v.push({component:x.labelIcon,id:k})});const _=Kc(p),T=Kc(v);return d.forEach((x,k)=>{if(Cy(x,o)&&f.push({label:x.label}),R1(x)){const{portal:A,mount:O,unmount:I}=_.find(V=>V.id===k),$={label:x.label,mountIcon:O,unmountIcon:I};"onClick"in x?$.onClick=x.onClick:"open"in x&&($.open=x.open),f.push($),m.push(A)}if(M1(x)){const{portal:A,mount:O,unmount:I}=T.find($=>$.id===k);f.push({label:x.label,href:x.href,mountIcon:O,unmountIcon:I}),m.push(A)}}),{customMenuItems:f,customMenuItemsPortals:m}},Cy=(e,t)=>{const{children:n,label:r,onClick:i,labelIcon:s}=e;return!n&&!i&&!s&&t.some(o=>o===r)},R1=e=>{const{label:t,labelIcon:n,onClick:r,open:i}=e;return!!n&&!!t&&(typeof r=="function"||typeof i=="string")},M1=e=>{const{label:t,href:n,labelIcon:r}=e;return!!n&&!!r&&!!t},pO=e=>{const t=e==null?void 0:e.isReady;return n=>new Promise((r,i)=>{const{root:s=document==null?void 0:document.body,selector:o,timeout:c=0}=n;if(!s){i(new Error("No root element provided"));return}let d=s;if(o&&(d=s==null?void 0:s.querySelector(o)),t(d,o)){r();return}const f=new MutationObserver(m=>{for(const p of m)if(!d&&o&&(d=s==null?void 0:s.querySelector(o)),(e.childList&&p.type==="childList"||e.attributes&&p.type==="attributes")&&t(d,o)){f.disconnect(),r();return}});f.observe(s,e),c>0&&setTimeout(()=>{f.disconnect(),i(new Error(`Timeout waiting for ${o}`))},c)})},gO=pO({childList:!0,subtree:!0,isReady:(e,t)=>{var n;return!!(e!=null&&e.childElementCount)&&((n=e==null?void 0:e.matches)==null?void 0:n.call(e,t))&&e.childElementCount>0}});function jr(e,t){const n=F.useRef(),[r,i]=F.useState("rendering");return F.useEffect(()=>{if(!e)throw new Error("Clerk: no component name provided, unable to detect mount.");if(typeof window<"u"&&!n.current){const s=`[data-clerk-component="${e}"]`,o=t==null?void 0:t.selector;n.current=gO({selector:o?s+o:s}).then(()=>{i("rendered")}).catch(()=>{i("error")})}},[e,t==null?void 0:t.selector]),r}var lh=e=>"mount"in e,Ny=e=>"open"in e,Oy=e=>e==null?void 0:e.map(({mountIcon:t,unmountIcon:n,...r})=>r),xr=class extends ue.PureComponent{constructor(){super(...arguments),this.rootRef=ue.createRef()}componentDidUpdate(e){var t,n,r,i;if(!lh(e)||!lh(this.props))return;const s=Ay(e.props,"customPages","customMenuItems","children"),o=Ay(this.props.props,"customPages","customMenuItems","children"),c=((t=s.customPages)==null?void 0:t.length)!==((n=o.customPages)==null?void 0:n.length),d=((r=s.customMenuItems)==null?void 0:r.length)!==((i=o.customMenuItems)==null?void 0:i.length),f=Oy(e.props.customMenuItems),m=Oy(this.props.props.customMenuItems);(!Ey(s,o)||!Ey(f,m)||c||d)&&this.rootRef.current&&this.props.updateProps({node:this.rootRef.current,props:this.props.props})}componentDidMount(){this.rootRef.current&&(lh(this.props)&&this.props.mount(this.rootRef.current,this.props.props),Ny(this.props)&&this.props.open(this.props.props))}componentWillUnmount(){this.rootRef.current&&(lh(this.props)&&this.props.unmount(this.rootRef.current),Ny(this.props)&&this.props.close())}render(){const{hideRootHtmlElement:e=!1}=this.props,t={ref:this.rootRef,...this.props.rootProps,...this.props.component&&{"data-clerk-component":this.props.component}};return ue.createElement(ue.Fragment,null,!e&&ue.createElement("div",{...t}),this.props.children)}},Bf=e=>{var t,n;return ue.createElement(ue.Fragment,null,(t=e==null?void 0:e.customPagesPortals)==null?void 0:t.map((r,i)=>F.createElement(r,{key:i})),(n=e==null?void 0:e.customMenuItemsPortals)==null?void 0:n.map((r,i)=>F.createElement(r,{key:i})))},bO=rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountSignIn,unmount:e.unmountSignIn,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"SignIn",renderWhileLoading:!0}),vO=rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountSignUp,unmount:e.unmountSignUp,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"SignUp",renderWhileLoading:!0});function S0({children:e}){return zr(HN),ue.createElement(ue.Fragment,null,e)}function w0({children:e}){return zr(jN),ue.createElement(ue.Fragment,null,e)}var _O=rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}},{customPages:c,customPagesPortals:d}=U8(r.children);return ue.createElement(ue.Fragment,null,s&&n,ue.createElement(xr,{component:t,mount:e.mountUserProfile,unmount:e.unmountUserProfile,updateProps:e.__unstable__updateProps,props:{...r,customPages:c},rootProps:o},ue.createElement(Bf,{customPagesPortals:d})))},{component:"UserProfile",renderWhileLoading:!0});Object.assign(_O,{Page:S0,Link:w0});var j8=F.createContext({mount:()=>{},unmount:()=>{},updateProps:()=>{}}),yO=rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}},{customPages:c,customPagesPortals:d}=U8(r.children,{allowForAnyChildren:!!r.__experimental_asProvider}),f={...r.userProfileProps,customPages:c},{customMenuItems:m,customMenuItemsPortals:p}=fO(r.children,{allowForAnyChildren:!!r.__experimental_asProvider}),v=F8(r.children),_={mount:e.mountUserButton,unmount:e.unmountUserButton,updateProps:e.__unstable__updateProps,props:{...r,userProfileProps:f,customMenuItems:m}},T={customPagesPortals:d,customMenuItemsPortals:p};return ue.createElement(j8.Provider,{value:_},s&&n,e.loaded&&ue.createElement(xr,{component:t,..._,hideRootHtmlElement:!!r.__experimental_asProvider,rootProps:o},r.__experimental_asProvider?v:null,ue.createElement(Bf,{...T})))},{component:"UserButton",renderWhileLoading:!0});function Uf({children:e}){return zr(XN),ue.createElement(ue.Fragment,null,e)}function q8({children:e}){return zr(QN),ue.createElement(ue.Fragment,null,e)}function $8({children:e}){return zr(ZN),ue.createElement(ue.Fragment,null,e)}function EO(e){const t=F.useContext(j8),n={...t,props:{...t.props,...e}};return ue.createElement(xr,{...n})}var TO=Object.assign(yO,{UserProfilePage:S0,UserProfileLink:w0,MenuItems:Uf,Action:q8,Link:$8,__experimental_Outlet:EO});function zf({children:e}){return zr(qN),ue.createElement(ue.Fragment,null,e)}function Ff({children:e}){return zr($N),ue.createElement(ue.Fragment,null,e)}var xO=rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}},{customPages:c,customPagesPortals:d}=z8(r.children);return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountOrganizationProfile,unmount:e.unmountOrganizationProfile,updateProps:e.__unstable__updateProps,props:{...r,customPages:c},rootProps:o},ue.createElement(Bf,{customPagesPortals:d})))},{component:"OrganizationProfile",renderWhileLoading:!0});Object.assign(xO,{Page:zf,Link:Ff});rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountCreateOrganization,unmount:e.unmountCreateOrganization,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"CreateOrganization",renderWhileLoading:!0});var G8=F.createContext({mount:()=>{},unmount:()=>{},updateProps:()=>{}}),SO=rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}},{customPages:c,customPagesPortals:d}=z8(r.children,{allowForAnyChildren:!!r.__experimental_asProvider}),f={...r.organizationProfileProps,customPages:c},m=F8(r.children),p={mount:e.mountOrganizationSwitcher,unmount:e.unmountOrganizationSwitcher,updateProps:e.__unstable__updateProps,props:{...r,organizationProfileProps:f},rootProps:o,component:t};return e.__experimental_prefetchOrganizationSwitcher(),ue.createElement(G8.Provider,{value:p},ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{...p,hideRootHtmlElement:!!r.__experimental_asProvider},r.__experimental_asProvider?m:null,ue.createElement(Bf,{customPagesPortals:d}))))},{component:"OrganizationSwitcher",renderWhileLoading:!0});function wO(e){const t=F.useContext(G8),n={...t,props:{...t.props,...e}};return ue.createElement(xr,{...n})}Object.assign(SO,{OrganizationProfilePage:zf,OrganizationProfileLink:Ff,__experimental_Outlet:wO});rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountOrganizationList,unmount:e.unmountOrganizationList,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"OrganizationList",renderWhileLoading:!0});rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,open:e.openGoogleOneTap,close:e.closeGoogleOneTap,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"GoogleOneTap",renderWhileLoading:!0});rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountWaitlist,unmount:e.unmountWaitlist,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"Waitlist",renderWhileLoading:!0});var AO=rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t,{selector:'[data-component-status="ready"]'})==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountPricingTable,unmount:e.unmountPricingTable,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"PricingTable",renderWhileLoading:!0});rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountAPIKeys,unmount:e.unmountAPIKeys,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"ApiKeys",renderWhileLoading:!0});rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountUserAvatar,unmount:e.unmountUserAvatar,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"UserAvatar",renderWhileLoading:!0});rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountTaskChooseOrganization,unmount:e.unmountTaskChooseOrganization,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"TaskChooseOrganization",renderWhileLoading:!0});rn(({clerk:e,component:t,fallback:n,...r})=>{const s=jr(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return ue.createElement(ue.Fragment,null,s&&n,e.loaded&&ue.createElement(xr,{component:t,mount:e.mountTaskResetPassword,unmount:e.unmountTaskResetPassword,updateProps:e.__unstable__updateProps,props:r,rootProps:o}))},{component:"TaskResetPassword",renderWhileLoading:!0});var Y8=e=>{throw TypeError(e)},c2=(e,t,n)=>t.has(e)||Y8("Cannot "+n),wn=(e,t,n)=>(c2(e,t,"read from private field"),n?n.call(e):t.get(e)),Ys=(e,t,n)=>t.has(e)?Y8("Cannot add the same private member more than once"):t instanceof WeakSet?t.add(e):t.set(e,n),Ml=(e,t,n,r)=>(c2(e,t,"write to private field"),t.set(e,n),n),I1=(e,t,n)=>(c2(e,t,"access private method"),n);const kO={initialDelay:125,maxDelayBetweenRetries:0,factor:2,shouldRetry:(e,t)=>t<5,retryImmediately:!1,jitter:!0},CO=100,V8=async e=>new Promise(t=>setTimeout(t,e)),K8=(e,t)=>t?e*(1+Math.random()):e,NO=e=>{let t=0;const n=()=>{const r=e.initialDelay,i=e.factor;let s=r*Math.pow(i,t);return s=K8(s,e.jitter),Math.min(e.maxDelayBetweenRetries||s,s)};return async()=>{await V8(n()),t++}},OO=async(e,t={})=>{let n=0;const{shouldRetry:r,initialDelay:i,maxDelayBetweenRetries:s,factor:o,retryImmediately:c,jitter:d,onBeforeRetry:f}={...kO,...t},m=NO({initialDelay:i,maxDelayBetweenRetries:s,factor:o,jitter:d});for(;;)try{return await e()}catch(p){if(n++,!r(p,n))throw p;f&&await f(n),c&&n===1?await V8(K8(CO,d)):await m()}},RO="loadScript cannot be called when document does not exist",MO="loadScript cannot be called without a src";async function IO(e="",t){const{async:n,defer:r,beforeLoad:i,crossOrigin:s,nonce:o}=t||{};return OO(()=>new Promise((d,f)=>{e||f(new Error(MO)),(!document||!document.body)&&f(new Error(RO));const m=document.createElement("script");s&&m.setAttribute("crossorigin",s),m.async=n||!1,m.defer=r||!1,m.addEventListener("load",()=>{m.remove(),d(m)}),m.addEventListener("error",p=>{m.remove(),f(p.error??new Error(`failed to load script: ${e}`))}),m.src=e,m.nonce=o,i==null||i(m),document.body.appendChild(m)}),{shouldRetry:(d,f)=>f<=5})}function DO(e){return e?LO(e)||W8(e):!0}function LO(e){return/^http(s)?:\/\//.test(e||"")}function W8(e){return e.startsWith("/")}function PO(e){return e?W8(e)?new URL(e,window.location.origin).toString():e:""}function BO(e){if(!e)return"";let t;if(e.match(/^(clerk\.)+\w*$/))t=/(clerk\.)*(?=clerk\.)/;else{if(e.match(/\.clerk.accounts/))return e;t=/^(clerk\.)*/gi}return`clerk.${e.replace(t,"")}`}const UO=(e,t="5.120.0")=>{if(e)return e;const n=zO(t);return n?n==="snapshot"?"5.120.0":n:FO(t)},zO=e=>{var t;return(t=e.trim().replace(/^v/,"").match(/-(.+?)(\.|$)/))==null?void 0:t[1]},FO=e=>e.trim().replace(/^v/,"").split(".")[0],X8="failed_to_load_clerk_js",HO="failed_to_load_clerk_js_timeout",Qg="Failed to load Clerk",{isDevOrStagingUrl:jO}=MC(),Q8=v8({packageName:"@clerk/shared"});function qO(e){Q8.setPackageName({packageName:e})}function Zg(){if(typeof window>"u"||!window.Clerk)return!1;const e=window.Clerk;return typeof e=="object"&&typeof e.load=="function"}function $O(e){if(typeof window>"u"||!window.performance)return!1;const t=performance.getEntriesByName(e,"resource");if(t.length===0)return!1;const n=t[t.length-1];return n.transferSize===0&&n.decodedBodySize===0&&(n.responseEnd===0||n.responseEnd>0&&n.responseStart>0||"responseStatus"in n&&(n.responseStatus>=400||n.responseStatus===0))}function Ry(e,t){return new Promise((n,r)=>{let i=!1;const s=(m,p)=>{clearTimeout(m),clearInterval(p)};t==null||t.addEventListener("error",()=>{s(d,f),r(new Hg(Qg,{code:X8}))});const o=()=>{i||Zg()&&(i=!0,s(d,f),n(null))},d=setTimeout(()=>{i||(i=!0,s(d,f),Zg()?n(null):r(new Hg(Qg,{code:HO})))},e);o();const f=setInterval(()=>{if(i){clearInterval(f);return}o()},100)})}const GO=async e=>{const t=(e==null?void 0:e.scriptLoadTimeout)??15e3;if(Zg())return null;if(!(e!=null&&e.publishableKey))return Q8.throwMissingPublishableKeyError(),null;const n=YO(e),r=document.querySelector("script[data-clerk-js-script]");if(r)if($O(n))r.remove();else try{return await Ry(t,r),null}catch{r.remove()}const i=Ry(t);return IO(n,{async:!0,crossOrigin:"anonymous",nonce:e.nonce,beforeLoad:KO(e)}).catch(s=>{throw new Hg(Qg+(s.message?`, ${s.message}`:""),{code:X8,cause:s})}),i},YO=e=>{var m,p;const{clerkJSUrl:t,clerkJSVariant:n,clerkJSVersion:r,proxyUrl:i,domain:s,publishableKey:o}=e;if(t)return t;let c="";i&&DO(i)?c=PO(i).replace(/http(s)?:\/\//,""):s&&!jO(((m=cy(o))==null?void 0:m.frontendApi)||"")?c=BO(s):c=((p=cy(o))==null?void 0:p.frontendApi)||"";const d=n?`${n.replace(/\.+$/,"")}.`:"",f=UO(r);return`https://${c}/npm/@clerk/clerk-js@${f}/dist/clerk.${d}browser.js`},VO=e=>{const t={};return e.publishableKey&&(t["data-clerk-publishable-key"]=e.publishableKey),e.proxyUrl&&(t["data-clerk-proxy-url"]=e.proxyUrl),e.domain&&(t["data-clerk-domain"]=e.domain),e.nonce&&(t.nonce=e.nonce),t},KO=e=>t=>{const n=VO(e);for(const r in n)t.setAttribute(r,n[r])},WO=(e,t,n)=>!e&&n?XO(n):QO(t),XO=e=>{const t=e.userId,n=e.user,r=e.sessionId,i=e.sessionStatus,s=e.sessionClaims;return{userId:t,user:n,sessionId:r,session:e.session,sessionStatus:i,sessionClaims:s,organization:e.organization,orgId:e.orgId,orgRole:e.orgRole,orgPermissions:e.orgPermissions,orgSlug:e.orgSlug,actor:e.actor,factorVerificationAge:e.factorVerificationAge}},QO=e=>{var T,x,k,A;const t=e.user?e.user.id:e.user,n=e.user,r=e.session?e.session.id:e.session,i=e.session,s=(T=e.session)==null?void 0:T.status,o=e.session?(k=(x=e.session.lastActiveToken)==null?void 0:x.jwt)==null?void 0:k.claims:null,c=e.session?e.session.factorVerificationAge:null,d=i==null?void 0:i.actor,f=e.organization,m=e.organization?e.organization.id:e.organization,p=f==null?void 0:f.slug,v=f&&((A=n==null?void 0:n.organizationMemberships)==null?void 0:A.find(O=>O.organization.id===m)),_=v&&v.permissions;return{userId:t,user:n,sessionId:r,session:i,sessionStatus:s,sessionClaims:o,organization:f,orgId:m,orgRole:v&&v.role,orgSlug:p,orgPermissions:_,actor:d,factorVerificationAge:c}};function Zh(){return typeof window<"u"}const My=(e,t,n,r,i)=>{const{notify:s}=i||{};let o=e.get(n);o||(o=[],e.set(n,o)),o.push(r),s&&t.has(n)&&r(t.get(n))},Iy=(e,t,n)=>(e.get(t)||[]).map(r=>r(n)),Dy=(e,t,n)=>{const r=e.get(t);r&&(n?r.splice(r.indexOf(n)>>>0,1):e.set(t,[]))},ZO=()=>{const e=new Map,t=new Map,n=new Map;return{on:(...i)=>My(e,t,...i),prioritizedOn:(...i)=>My(n,t,...i),emit:(i,s)=>{t.set(i,s),Iy(n,i,s),Iy(e,i,s)},off:(...i)=>Dy(e,...i),prioritizedOff:(...i)=>Dy(n,...i),internal:{retrieveListeners:i=>e.get(i)||[]}}},oh={Status:"status"},JO=()=>ZO();typeof window<"u"&&!window.global&&(window.global=typeof global>"u"?window:global);rn(({clerk:e,children:t,...n})=>{const{appearance:r,signUpFallbackRedirectUrl:i,forceRedirectUrl:s,fallbackRedirectUrl:o,signUpForceRedirectUrl:c,mode:d,initialValues:f,withSignUp:m,oauthFlow:p,...v}=n;t=Kl(t,"Sign in");const _=Vl(t)("SignInButton"),T=()=>{const A={forceRedirectUrl:s,fallbackRedirectUrl:o,signUpFallbackRedirectUrl:i,signUpForceRedirectUrl:c,initialValues:f,withSignUp:m,oauthFlow:p};return d==="modal"?e.openSignIn({...A,appearance:r}):e.redirectToSignIn({...A,signInFallbackRedirectUrl:o,signInForceRedirectUrl:s})},k={...v,onClick:async A=>(_&&typeof _=="object"&&"props"in _&&await Wl(_.props.onClick)(A),T())};return ue.cloneElement(_,k)},{component:"SignInButton",renderWhileLoading:!0});rn(({clerk:e,children:t,...n})=>{const{redirectUrl:r,...i}=n;t=Kl(t,"Sign in with Metamask");const s=Vl(t)("SignInWithMetamaskButton"),o=async()=>{async function f(){await e.authenticateWithMetamask({redirectUrl:r||void 0})}f()},d={...i,onClick:async f=>(await Wl(s.props.onClick)(f),o())};return ue.cloneElement(s,d)},{component:"SignInWithMetamask",renderWhileLoading:!0});rn(({clerk:e,children:t,...n})=>{const{redirectUrl:r="/",signOutOptions:i,...s}=n;t=Kl(t,"Sign out");const o=Vl(t)("SignOutButton"),c=()=>e.signOut({redirectUrl:r,...i}),f={...s,onClick:async m=>(await Wl(o.props.onClick)(m),c())};return ue.cloneElement(o,f)},{component:"SignOutButton",renderWhileLoading:!0});rn(({clerk:e,children:t,...n})=>{const{appearance:r,unsafeMetadata:i,fallbackRedirectUrl:s,forceRedirectUrl:o,signInFallbackRedirectUrl:c,signInForceRedirectUrl:d,mode:f,initialValues:m,oauthFlow:p,...v}=n;t=Kl(t,"Sign up");const _=Vl(t)("SignUpButton"),T=()=>{const A={fallbackRedirectUrl:s,forceRedirectUrl:o,signInFallbackRedirectUrl:c,signInForceRedirectUrl:d,initialValues:m,oauthFlow:p};return f==="modal"?e.openSignUp({...A,appearance:r,unsafeMetadata:i}):e.redirectToSignUp({...A,signUpFallbackRedirectUrl:s,signUpForceRedirectUrl:o})},k={...v,onClick:async A=>(_&&typeof _=="object"&&"props"in _&&await Wl(_.props.onClick)(A),T())};return ue.cloneElement(_,k)},{component:"SignUpButton",renderWhileLoading:!0});var eR=()=>({fields:{identifier:null,password:null,code:null},raw:null,global:null}),tR=()=>({fields:{firstName:null,lastName:null,emailAddress:null,phoneNumber:null,password:null,username:null,code:null,captcha:null,legalAccepted:null},raw:null,global:null}),nR=class{constructor(e){this.isomorphicClerk=e,this.signInSignalProxy=this.buildSignInProxy(),this.signUpSignalProxy=this.buildSignUpProxy()}signInSignal(){return this.signInSignalProxy}signUpSignal(){return this.signUpSignalProxy}buildSignInProxy(){const e=this.gateProperty.bind(this),t=()=>this.client.signIn.__internal_future;return{errors:eR(),fetchStatus:"idle",signIn:{status:"needs_identifier",availableStrategies:[],isTransferable:!1,get id(){return e(t,"id",void 0)},get supportedFirstFactors(){return e(t,"supportedFirstFactors",[])},get supportedSecondFactors(){return e(t,"supportedSecondFactors",[])},get secondFactorVerification(){return e(t,"secondFactorVerification",{status:null,error:null,expireAt:null,externalVerificationRedirectURL:null,nonce:null,attempts:null,message:null,strategy:null,verifiedAtClient:null,verifiedFromTheSameClient:()=>!1,__internal_toSnapshot:()=>{throw new Error("__internal_toSnapshot called before Clerk is loaded")},pathRoot:"",reload:()=>{throw new Error("__internal_toSnapshot called before Clerk is loaded")}})},get identifier(){return e(t,"identifier",null)},get createdSessionId(){return e(t,"createdSessionId",null)},get userData(){return e(t,"userData",{})},get firstFactorVerification(){return e(t,"firstFactorVerification",{status:null,error:null,expireAt:null,externalVerificationRedirectURL:null,nonce:null,attempts:null,message:null,strategy:null,verifiedAtClient:null,verifiedFromTheSameClient:()=>!1,__internal_toSnapshot:()=>{throw new Error("__internal_toSnapshot called before Clerk is loaded")},pathRoot:"",reload:()=>{throw new Error("__internal_toSnapshot called before Clerk is loaded")}})},create:this.gateMethod(t,"create"),password:this.gateMethod(t,"password"),sso:this.gateMethod(t,"sso"),finalize:this.gateMethod(t,"finalize"),emailCode:this.wrapMethods(()=>t().emailCode,["sendCode","verifyCode"]),emailLink:this.wrapStruct(()=>t().emailLink,["sendLink","waitForVerification"],["verification"],{verification:null}),resetPasswordEmailCode:this.wrapMethods(()=>t().resetPasswordEmailCode,["sendCode","verifyCode","submitPassword"]),phoneCode:this.wrapMethods(()=>t().phoneCode,["sendCode","verifyCode"]),mfa:this.wrapMethods(()=>t().mfa,["sendPhoneCode","verifyPhoneCode","verifyTOTP","verifyBackupCode"]),ticket:this.gateMethod(t,"ticket"),passkey:this.gateMethod(t,"passkey"),web3:this.gateMethod(t,"web3")}}}buildSignUpProxy(){const e=this.gateProperty.bind(this),t=this.gateMethod.bind(this),n=this.wrapMethods.bind(this),r=()=>this.client.signUp.__internal_future;return{errors:tR(),fetchStatus:"idle",signUp:{get id(){return e(r,"id",void 0)},get requiredFields(){return e(r,"requiredFields",[])},get optionalFields(){return e(r,"optionalFields",[])},get missingFields(){return e(r,"missingFields",[])},get username(){return e(r,"username",null)},get firstName(){return e(r,"firstName",null)},get lastName(){return e(r,"lastName",null)},get emailAddress(){return e(r,"emailAddress",null)},get phoneNumber(){return e(r,"phoneNumber",null)},get web3Wallet(){return e(r,"web3Wallet",null)},get hasPassword(){return e(r,"hasPassword",!1)},get unsafeMetadata(){return e(r,"unsafeMetadata",{})},get createdSessionId(){return e(r,"createdSessionId",null)},get createdUserId(){return e(r,"createdUserId",null)},get abandonAt(){return e(r,"abandonAt",null)},get legalAcceptedAt(){return e(r,"legalAcceptedAt",null)},get locale(){return e(r,"locale",null)},get status(){return e(r,"status","missing_requirements")},get unverifiedFields(){return e(r,"unverifiedFields",[])},get isTransferable(){return e(r,"isTransferable",!1)},create:t(r,"create"),update:t(r,"update"),sso:t(r,"sso"),password:t(r,"password"),ticket:t(r,"ticket"),web3:t(r,"web3"),finalize:t(r,"finalize"),verifications:n(()=>r().verifications,["sendEmailCode","verifyEmailCode","sendPhoneCode","verifyPhoneCode"])}}}__internal_effect(e){throw new Error("__internal_effect called before Clerk is loaded")}__internal_computed(e){throw new Error("__internal_computed called before Clerk is loaded")}get client(){const e=this.isomorphicClerk.client;if(!e)throw new Error("Clerk client not ready");return e}gateProperty(e,t,n){return!Zh()||!this.isomorphicClerk.loaded?n:e()[t]}gateMethod(e,t){return(async(...n)=>{if(!Zh())return Ki.throw(`Attempted to call a method (${t}) that is not supported on the server.`);this.isomorphicClerk.loaded||await new Promise(i=>this.isomorphicClerk.addOnLoaded(i));const r=e();return r[t].apply(r,n)})}wrapMethods(e,t){return Object.fromEntries(t.map(n=>[n,this.gateMethod(e,n)]))}wrapStruct(e,t,n,r){const i={};for(const s of t)i[s]=this.gateMethod(e,s);for(const s of n)Object.defineProperty(i,s,{get:()=>this.gateProperty(e,s,r[s]),enumerable:!0});return i}};typeof globalThis.__BUILD_DISABLE_RHC__>"u"&&(globalThis.__BUILD_DISABLE_RHC__=!1);var rR={name:"@clerk/clerk-react",version:"5.59.4",environment:"production"},Uh,qo,$o,Vs,ia,zh,Qs,Pc,Fh,Z8=class J8{constructor(t){Ys(this,Pc),this.clerkjs=null,this.preopenOneTap=null,this.preopenUserVerification=null,this.preopenEnableOrganizationsPrompt=null,this.preopenSignIn=null,this.preopenCheckout=null,this.preopenPlanDetails=null,this.preopenSubscriptionDetails=null,this.preopenSignUp=null,this.preopenUserProfile=null,this.preopenOrganizationProfile=null,this.preopenCreateOrganization=null,this.preOpenWaitlist=null,this.premountSignInNodes=new Map,this.premountSignUpNodes=new Map,this.premountUserAvatarNodes=new Map,this.premountUserProfileNodes=new Map,this.premountUserButtonNodes=new Map,this.premountOrganizationProfileNodes=new Map,this.premountCreateOrganizationNodes=new Map,this.premountOrganizationSwitcherNodes=new Map,this.premountOrganizationListNodes=new Map,this.premountMethodCalls=new Map,this.premountWaitlistNodes=new Map,this.premountPricingTableNodes=new Map,this.premountAPIKeysNodes=new Map,this.premountOAuthConsentNodes=new Map,this.premountTaskChooseOrganizationNodes=new Map,this.premountTaskResetPasswordNodes=new Map,this.premountAddListenerCalls=new Map,this.loadedListeners=[],Ys(this,Uh,"loading"),Ys(this,qo),Ys(this,$o),Ys(this,Vs),Ys(this,ia,JO()),Ys(this,zh),this.buildSignInUrl=i=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildSignInUrl(i))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildSignInUrl",s)},this.buildSignUpUrl=i=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildSignUpUrl(i))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildSignUpUrl",s)},this.buildAfterSignInUrl=(...i)=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildAfterSignInUrl(...i))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildAfterSignInUrl",s)},this.buildAfterSignUpUrl=(...i)=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildAfterSignUpUrl(...i))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildAfterSignUpUrl",s)},this.buildAfterSignOutUrl=()=>{const i=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildAfterSignOutUrl())||""};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("buildAfterSignOutUrl",i)},this.buildNewSubscriptionRedirectUrl=()=>{const i=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildNewSubscriptionRedirectUrl())||""};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("buildNewSubscriptionRedirectUrl",i)},this.buildAfterMultiSessionSingleSignOutUrl=()=>{const i=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildAfterMultiSessionSingleSignOutUrl())||""};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("buildAfterMultiSessionSingleSignOutUrl",i)},this.buildUserProfileUrl=()=>{const i=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildUserProfileUrl())||""};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("buildUserProfileUrl",i)},this.buildCreateOrganizationUrl=()=>{const i=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildCreateOrganizationUrl())||""};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("buildCreateOrganizationUrl",i)},this.buildOrganizationProfileUrl=()=>{const i=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildOrganizationProfileUrl())||""};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("buildOrganizationProfileUrl",i)},this.buildWaitlistUrl=()=>{const i=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildWaitlistUrl())||""};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("buildWaitlistUrl",i)},this.buildTasksUrl=()=>{const i=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildTasksUrl())||""};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("buildTasksUrl",i)},this.buildUrlWithAuth=i=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildUrlWithAuth(i))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildUrlWithAuth",s)},this.handleUnauthenticated=async()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.handleUnauthenticated()};this.clerkjs&&this.loaded?i():this.premountMethodCalls.set("handleUnauthenticated",i)},this.on=(...i)=>{var s;if((s=this.clerkjs)!=null&&s.on)return this.clerkjs.on(...i);wn(this,ia).on(...i)},this.off=(...i)=>{var s;if((s=this.clerkjs)!=null&&s.off)return this.clerkjs.off(...i);wn(this,ia).off(...i)},this.addOnLoaded=i=>{this.loadedListeners.push(i),this.loaded&&this.emitLoaded()},this.emitLoaded=()=>{this.loadedListeners.forEach(i=>i()),this.loadedListeners=[]},this.beforeLoad=i=>{if(!i)throw new Error("Failed to hydrate latest Clerk JS")},this.hydrateClerkJS=i=>{var s,o;if(!i)throw new Error("Failed to hydrate latest Clerk JS");return this.clerkjs=i,this.premountMethodCalls.forEach(c=>c()),this.premountAddListenerCalls.forEach((c,d)=>{c.nativeUnsubscribe=i.addListener(d)}),(s=wn(this,ia).internal.retrieveListeners("status"))==null||s.forEach(c=>{this.on("status",c,{notify:!0})}),(o=wn(this,ia).internal.retrieveListeners("queryClientStatus"))==null||o.forEach(c=>{this.on("queryClientStatus",c,{notify:!0})}),this.preopenSignIn!==null&&i.openSignIn(this.preopenSignIn),this.preopenCheckout!==null&&i.__internal_openCheckout(this.preopenCheckout),this.preopenPlanDetails!==null&&i.__internal_openPlanDetails(this.preopenPlanDetails),this.preopenSubscriptionDetails!==null&&i.__internal_openSubscriptionDetails(this.preopenSubscriptionDetails),this.preopenSignUp!==null&&i.openSignUp(this.preopenSignUp),this.preopenUserProfile!==null&&i.openUserProfile(this.preopenUserProfile),this.preopenUserVerification!==null&&i.__internal_openReverification(this.preopenUserVerification),this.preopenOneTap!==null&&i.openGoogleOneTap(this.preopenOneTap),this.preopenOrganizationProfile!==null&&i.openOrganizationProfile(this.preopenOrganizationProfile),this.preopenCreateOrganization!==null&&i.openCreateOrganization(this.preopenCreateOrganization),this.preOpenWaitlist!==null&&i.openWaitlist(this.preOpenWaitlist),this.preopenEnableOrganizationsPrompt&&i.__internal_openEnableOrganizationsPrompt(this.preopenEnableOrganizationsPrompt),this.premountSignInNodes.forEach((c,d)=>{i.mountSignIn(d,c)}),this.premountSignUpNodes.forEach((c,d)=>{i.mountSignUp(d,c)}),this.premountUserProfileNodes.forEach((c,d)=>{i.mountUserProfile(d,c)}),this.premountUserAvatarNodes.forEach((c,d)=>{i.mountUserAvatar(d,c)}),this.premountUserButtonNodes.forEach((c,d)=>{i.mountUserButton(d,c)}),this.premountOrganizationListNodes.forEach((c,d)=>{i.mountOrganizationList(d,c)}),this.premountWaitlistNodes.forEach((c,d)=>{i.mountWaitlist(d,c)}),this.premountPricingTableNodes.forEach((c,d)=>{i.mountPricingTable(d,c)}),this.premountAPIKeysNodes.forEach((c,d)=>{i.mountAPIKeys(d,c)}),this.premountOAuthConsentNodes.forEach((c,d)=>{i.__internal_mountOAuthConsent(d,c)}),this.premountTaskChooseOrganizationNodes.forEach((c,d)=>{i.mountTaskChooseOrganization(d,c)}),this.premountTaskResetPasswordNodes.forEach((c,d)=>{i.mountTaskResetPassword(d,c)}),typeof this.clerkjs.status>"u"&&wn(this,ia).emit(oh.Status,"ready"),this.emitLoaded(),this.clerkjs},this.__experimental_checkout=(...i)=>{var s;return(s=this.clerkjs)==null?void 0:s.__experimental_checkout(...i)},this.__unstable__updateProps=async i=>{const s=await I1(this,Pc,Fh).call(this);if(s&&"__unstable__updateProps"in s)return s.__unstable__updateProps(i)},this.setActive=i=>this.clerkjs?this.clerkjs.setActive(i):Promise.reject(),this.openSignIn=i=>{this.clerkjs&&this.loaded?this.clerkjs.openSignIn(i):this.preopenSignIn=i},this.closeSignIn=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeSignIn():this.preopenSignIn=null},this.__internal_openCheckout=i=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_openCheckout(i):this.preopenCheckout=i},this.__internal_closeCheckout=()=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_closeCheckout():this.preopenCheckout=null},this.__internal_openPlanDetails=i=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_openPlanDetails(i):this.preopenPlanDetails=i},this.__internal_closePlanDetails=()=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_closePlanDetails():this.preopenPlanDetails=null},this.__internal_openSubscriptionDetails=i=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_openSubscriptionDetails(i):this.preopenSubscriptionDetails=i??null},this.__internal_closeSubscriptionDetails=()=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_closeSubscriptionDetails():this.preopenSubscriptionDetails=null},this.__internal_openReverification=i=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_openReverification(i):this.preopenUserVerification=i},this.__internal_closeReverification=()=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_closeReverification():this.preopenUserVerification=null},this.__internal_openEnableOrganizationsPrompt=i=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_openEnableOrganizationsPrompt(i):this.preopenEnableOrganizationsPrompt=i},this.__internal_closeEnableOrganizationsPrompt=()=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_closeEnableOrganizationsPrompt():this.preopenEnableOrganizationsPrompt=null},this.openGoogleOneTap=i=>{this.clerkjs&&this.loaded?this.clerkjs.openGoogleOneTap(i):this.preopenOneTap=i},this.closeGoogleOneTap=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeGoogleOneTap():this.preopenOneTap=null},this.openUserProfile=i=>{this.clerkjs&&this.loaded?this.clerkjs.openUserProfile(i):this.preopenUserProfile=i},this.closeUserProfile=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeUserProfile():this.preopenUserProfile=null},this.openOrganizationProfile=i=>{this.clerkjs&&this.loaded?this.clerkjs.openOrganizationProfile(i):this.preopenOrganizationProfile=i},this.closeOrganizationProfile=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeOrganizationProfile():this.preopenOrganizationProfile=null},this.openCreateOrganization=i=>{this.clerkjs&&this.loaded?this.clerkjs.openCreateOrganization(i):this.preopenCreateOrganization=i},this.closeCreateOrganization=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeCreateOrganization():this.preopenCreateOrganization=null},this.openWaitlist=i=>{this.clerkjs&&this.loaded?this.clerkjs.openWaitlist(i):this.preOpenWaitlist=i},this.closeWaitlist=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeWaitlist():this.preOpenWaitlist=null},this.openSignUp=i=>{this.clerkjs&&this.loaded?this.clerkjs.openSignUp(i):this.preopenSignUp=i},this.closeSignUp=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeSignUp():this.preopenSignUp=null},this.mountSignIn=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountSignIn(i,s):this.premountSignInNodes.set(i,s)},this.unmountSignIn=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountSignIn(i):this.premountSignInNodes.delete(i)},this.mountSignUp=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountSignUp(i,s):this.premountSignUpNodes.set(i,s)},this.unmountSignUp=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountSignUp(i):this.premountSignUpNodes.delete(i)},this.mountUserAvatar=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountUserAvatar(i,s):this.premountUserAvatarNodes.set(i,s)},this.unmountUserAvatar=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountUserAvatar(i):this.premountUserAvatarNodes.delete(i)},this.mountUserProfile=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountUserProfile(i,s):this.premountUserProfileNodes.set(i,s)},this.unmountUserProfile=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountUserProfile(i):this.premountUserProfileNodes.delete(i)},this.mountOrganizationProfile=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountOrganizationProfile(i,s):this.premountOrganizationProfileNodes.set(i,s)},this.unmountOrganizationProfile=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountOrganizationProfile(i):this.premountOrganizationProfileNodes.delete(i)},this.mountCreateOrganization=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountCreateOrganization(i,s):this.premountCreateOrganizationNodes.set(i,s)},this.unmountCreateOrganization=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountCreateOrganization(i):this.premountCreateOrganizationNodes.delete(i)},this.mountOrganizationSwitcher=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountOrganizationSwitcher(i,s):this.premountOrganizationSwitcherNodes.set(i,s)},this.unmountOrganizationSwitcher=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountOrganizationSwitcher(i):this.premountOrganizationSwitcherNodes.delete(i)},this.__experimental_prefetchOrganizationSwitcher=()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.__experimental_prefetchOrganizationSwitcher()};this.clerkjs&&this.loaded?i():this.premountMethodCalls.set("__experimental_prefetchOrganizationSwitcher",i)},this.mountOrganizationList=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountOrganizationList(i,s):this.premountOrganizationListNodes.set(i,s)},this.unmountOrganizationList=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountOrganizationList(i):this.premountOrganizationListNodes.delete(i)},this.mountUserButton=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountUserButton(i,s):this.premountUserButtonNodes.set(i,s)},this.unmountUserButton=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountUserButton(i):this.premountUserButtonNodes.delete(i)},this.mountWaitlist=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountWaitlist(i,s):this.premountWaitlistNodes.set(i,s)},this.unmountWaitlist=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountWaitlist(i):this.premountWaitlistNodes.delete(i)},this.mountPricingTable=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountPricingTable(i,s):this.premountPricingTableNodes.set(i,s)},this.unmountPricingTable=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountPricingTable(i):this.premountPricingTableNodes.delete(i)},this.mountAPIKeys=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountAPIKeys(i,s):this.premountAPIKeysNodes.set(i,s)},this.unmountAPIKeys=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountAPIKeys(i):this.premountAPIKeysNodes.delete(i)},this.__internal_mountOAuthConsent=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_mountOAuthConsent(i,s):this.premountOAuthConsentNodes.set(i,s)},this.__internal_unmountOAuthConsent=i=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_unmountOAuthConsent(i):this.premountOAuthConsentNodes.delete(i)},this.mountTaskChooseOrganization=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountTaskChooseOrganization(i,s):this.premountTaskChooseOrganizationNodes.set(i,s)},this.unmountTaskChooseOrganization=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountTaskChooseOrganization(i):this.premountTaskChooseOrganizationNodes.delete(i)},this.mountTaskResetPassword=(i,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountTaskResetPassword(i,s):this.premountTaskResetPasswordNodes.set(i,s)},this.unmountTaskResetPassword=i=>{this.clerkjs&&this.loaded?this.clerkjs.unmountTaskResetPassword(i):this.premountTaskResetPasswordNodes.delete(i)},this.addListener=i=>{if(this.clerkjs)return this.clerkjs.addListener(i);{const s=()=>{var o;const c=this.premountAddListenerCalls.get(i);c&&((o=c.nativeUnsubscribe)==null||o.call(c),this.premountAddListenerCalls.delete(i))};return this.premountAddListenerCalls.set(i,{unsubscribe:s,nativeUnsubscribe:void 0}),s}},this.navigate=i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.navigate(i)};this.clerkjs&&this.loaded?s():this.premountMethodCalls.set("navigate",s)},this.redirectWithAuth=async(...i)=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.redirectWithAuth(...i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("redirectWithAuth",s)},this.redirectToSignIn=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.redirectToSignIn(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("redirectToSignIn",s)},this.redirectToSignUp=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.redirectToSignUp(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("redirectToSignUp",s)},this.redirectToUserProfile=async()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToUserProfile()};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("redirectToUserProfile",i)},this.redirectToAfterSignUp=()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToAfterSignUp()};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("redirectToAfterSignUp",i)},this.redirectToAfterSignIn=()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToAfterSignIn()};this.clerkjs&&this.loaded?i():this.premountMethodCalls.set("redirectToAfterSignIn",i)},this.redirectToAfterSignOut=()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToAfterSignOut()};this.clerkjs&&this.loaded?i():this.premountMethodCalls.set("redirectToAfterSignOut",i)},this.redirectToOrganizationProfile=async()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToOrganizationProfile()};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("redirectToOrganizationProfile",i)},this.redirectToCreateOrganization=async()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToCreateOrganization()};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("redirectToCreateOrganization",i)},this.redirectToWaitlist=async()=>{const i=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToWaitlist()};if(this.clerkjs&&this.loaded)return i();this.premountMethodCalls.set("redirectToWaitlist",i)},this.redirectToTasks=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.redirectToTasks(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("redirectToTasks",s)},this.handleRedirectCallback=async i=>{var s;const o=()=>{var c;return(c=this.clerkjs)==null?void 0:c.handleRedirectCallback(i)};this.clerkjs&&this.loaded?(s=o())==null||s.catch(()=>{}):this.premountMethodCalls.set("handleRedirectCallback",o)},this.handleGoogleOneTapCallback=async(i,s)=>{var o;const c=()=>{var d;return(d=this.clerkjs)==null?void 0:d.handleGoogleOneTapCallback(i,s)};this.clerkjs&&this.loaded?(o=c())==null||o.catch(()=>{}):this.premountMethodCalls.set("handleGoogleOneTapCallback",c)},this.handleEmailLinkVerification=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.handleEmailLinkVerification(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("handleEmailLinkVerification",s)},this.authenticateWithMetamask=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithMetamask(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithMetamask",s)},this.authenticateWithCoinbaseWallet=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithCoinbaseWallet(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithCoinbaseWallet",s)},this.authenticateWithBase=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithBase(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithBase",s)},this.authenticateWithOKXWallet=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithOKXWallet(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithOKXWallet",s)},this.authenticateWithSolana=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithSolana(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithSolana",s)},this.authenticateWithWeb3=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithWeb3(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithWeb3",s)},this.authenticateWithGoogleOneTap=async i=>(await I1(this,Pc,Fh).call(this)).authenticateWithGoogleOneTap(i),this.__internal_loadStripeJs=async()=>(await I1(this,Pc,Fh).call(this)).__internal_loadStripeJs(),this.createOrganization=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.createOrganization(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("createOrganization",s)},this.getOrganization=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.getOrganization(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("getOrganization",s)},this.joinWaitlist=async i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.joinWaitlist(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("joinWaitlist",s)},this.signOut=async(...i)=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.signOut(...i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("signOut",s)},this.__internal_attemptToEnableEnvironmentSetting=i=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.__internal_attemptToEnableEnvironmentSetting(i)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("__internal_attemptToEnableEnvironmentSetting",s)};const{Clerk:n=null,publishableKey:r}=t||{};Ml(this,Vs,r),Ml(this,$o,t==null?void 0:t.proxyUrl),Ml(this,qo,t==null?void 0:t.domain),this.options=t,this.Clerk=n,this.mode=Zh()?"browser":"server",Ml(this,zh,new nR(this)),this.options.sdkMetadata||(this.options.sdkMetadata=rR),wn(this,ia).emit(oh.Status,"loading"),wn(this,ia).prioritizedOn(oh.Status,i=>Ml(this,Uh,i)),wn(this,Vs)&&this.loadClerkJS()}get publishableKey(){return wn(this,Vs)}get loaded(){var t;return((t=this.clerkjs)==null?void 0:t.loaded)||!1}get status(){var t;return this.clerkjs?((t=this.clerkjs)==null?void 0:t.status)||(this.clerkjs.loaded?"ready":"loading"):wn(this,Uh)}static getOrCreateInstance(t){return(!Zh()||!wn(this,Qs)||t.Clerk&&wn(this,Qs).Clerk!==t.Clerk||wn(this,Qs).publishableKey!==t.publishableKey)&&Ml(this,Qs,new J8(t)),wn(this,Qs)}static clearInstance(){Ml(this,Qs,null)}get domain(){return typeof window<"u"&&window.location?C1(wn(this,qo),new URL(window.location.href),""):typeof wn(this,qo)=="function"?Ki.throw(k1):wn(this,qo)||""}get proxyUrl(){return typeof window<"u"&&window.location?C1(wn(this,$o),new URL(window.location.href),""):typeof wn(this,$o)=="function"?Ki.throw(k1):wn(this,$o)||""}__internal_getOption(t){var n,r;return(n=this.clerkjs)!=null&&n.__internal_getOption?(r=this.clerkjs)==null?void 0:r.__internal_getOption(t):this.options[t]}get sdkMetadata(){var t;return((t=this.clerkjs)==null?void 0:t.sdkMetadata)||this.options.sdkMetadata||void 0}get instanceType(){var t;return(t=this.clerkjs)==null?void 0:t.instanceType}get frontendApi(){var t;return((t=this.clerkjs)==null?void 0:t.frontendApi)||""}get isStandardBrowser(){var t;return((t=this.clerkjs)==null?void 0:t.isStandardBrowser)||this.options.standardBrowser||!1}get __internal_queryClient(){var t;return(t=this.clerkjs)==null?void 0:t.__internal_queryClient}get isSatellite(){return typeof window<"u"&&window.location?C1(this.options.isSatellite,new URL(window.location.href),!1):typeof this.options.isSatellite=="function"?Ki.throw(k1):!1}async loadClerkJS(){var t;if(!(this.mode!=="browser"||this.loaded)){typeof window<"u"&&(window.__clerk_publishable_key=wn(this,Vs),window.__clerk_proxy_url=this.proxyUrl,window.__clerk_domain=this.domain);try{if(this.Clerk){let n;cO(this.Clerk)?(n=new this.Clerk(wn(this,Vs),{proxyUrl:this.proxyUrl,domain:this.domain}),this.beforeLoad(n),await n.load(this.options)):(n=this.Clerk,n.loaded||(this.beforeLoad(n),await n.load(this.options))),global.Clerk=n}else if(!__BUILD_DISABLE_RHC__){if(global.Clerk||await GO({...this.options,publishableKey:wn(this,Vs),proxyUrl:this.proxyUrl,domain:this.domain,nonce:this.options.nonce}),!global.Clerk)throw new Error("Failed to download latest ClerkJS. Contact support@clerk.com.");this.beforeLoad(global.Clerk),await global.Clerk.load(this.options)}return(t=global.Clerk)!=null&&t.loaded?this.hydrateClerkJS(global.Clerk):void 0}catch(n){const r=n;wn(this,ia).emit(oh.Status,"error"),console.error(r.stack||r.message||r);return}}}get version(){var t;return(t=this.clerkjs)==null?void 0:t.version}get client(){if(this.clerkjs)return this.clerkjs.client}get session(){if(this.clerkjs)return this.clerkjs.session}get user(){if(this.clerkjs)return this.clerkjs.user}get organization(){if(this.clerkjs)return this.clerkjs.organization}get telemetry(){if(this.clerkjs)return this.clerkjs.telemetry}get __unstable__environment(){if(this.clerkjs)return this.clerkjs.__unstable__environment}get isSignedIn(){return this.clerkjs?this.clerkjs.isSignedIn:!1}get billing(){var t;return(t=this.clerkjs)==null?void 0:t.billing}get __internal_state(){return this.loaded&&this.clerkjs?this.clerkjs.__internal_state:wn(this,zh)}get apiKeys(){var t;return(t=this.clerkjs)==null?void 0:t.apiKeys}__unstable__setEnvironment(...t){if(this.clerkjs&&"__unstable__setEnvironment"in this.clerkjs)this.clerkjs.__unstable__setEnvironment(t);else return}};Uh=new WeakMap;qo=new WeakMap;$o=new WeakMap;Vs=new WeakMap;ia=new WeakMap;zh=new WeakMap;Qs=new WeakMap;Pc=new WeakSet;Fh=function(){return new Promise(e=>{this.addOnLoaded(()=>e(this.clerkjs))})};Ys(Z8,Qs);var Ly=Z8;function iR(e){const{isomorphicClerkOptions:t,initialState:n,children:r}=e,{isomorphicClerk:i,clerkStatus:s}=aR(t),[o,c]=ue.useState({client:i.client,session:i.session,user:i.user,organization:i.organization});ue.useEffect(()=>i.addListener(he=>c({...he})),[]);const d=WO(i.loaded,o,n),f=ue.useMemo(()=>({value:i}),[s]),m=ue.useMemo(()=>({value:o.client}),[o.client]),{sessionId:p,sessionStatus:v,sessionClaims:_,session:T,userId:x,user:k,orgId:A,actor:O,organization:I,orgRole:$,orgSlug:V,orgPermissions:B,factorVerificationAge:Z}=d,ee=ue.useMemo(()=>({value:{sessionId:p,sessionStatus:v,sessionClaims:_,userId:x,actor:O,orgId:A,orgRole:$,orgSlug:V,orgPermissions:B,factorVerificationAge:Z}}),[p,v,x,O,A,$,V,Z,_==null?void 0:_.__raw]),te=ue.useMemo(()=>({value:T}),[p,T]),Y=ue.useMemo(()=>({value:k}),[x,k]),oe=ue.useMemo(()=>({value:{organization:I}}),[A,I]);return ue.createElement(BN.Provider,{value:f},ue.createElement(pN.Provider,{value:m},ue.createElement(gN.Provider,{value:te},ue.createElement(EN,{...oe.value},ue.createElement(LN.Provider,{value:ee},ue.createElement(mN.Provider,{value:Y},ue.createElement(vN,{value:void 0},r)))))))}var aR=e=>{const t=ue.useRef(Ly.getOrCreateInstance(e)),[n,r]=ue.useState(t.current.status);return ue.useEffect(()=>{t.current.__unstable__updateProps({appearance:e.appearance})},[e.appearance]),ue.useEffect(()=>{t.current.__unstable__updateProps({options:e})},[e.localization]),ue.useEffect(()=>(t.current.on("status",r),()=>{t.current&&t.current.off("status",r),Ly.clearInstance()}),[]),{isomorphicClerk:t.current,clerkStatus:n}};function sR(e){const{initialState:t,children:n,__internal_bypassMissingPublishableKey:r,...i}=e,{publishableKey:s="",Clerk:o}=i;return!o&&!r&&(s?s&&!jg(s)&&Ki.throwInvalidPublishableKeyError({key:s}):Ki.throwMissingPublishableKeyError()),ue.createElement(iR,{initialState:t,isomorphicClerkOptions:i},n)}var e7=hO(sR,"ClerkProvider",UN);e7.displayName="ClerkProvider";DN({packageName:"@clerk/clerk-react"});qO("@clerk/clerk-react");function Py(e){const t=[],n=String(e||"");let r=n.indexOf(","),i=0,s=!1;for(;!s;){r===-1&&(r=n.length,s=!0);const o=n.slice(i,r).trim();(o||!s)&&t.push(o),i=r+1,r=n.indexOf(",",i)}return t}function t7(e,t){const n={};return(e[e.length-1]===""?[...e,""]:e).join((n.padRight?" ":"")+","+(n.padLeft===!1?"":" ")).trim()}const lR=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,oR=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,uR={};function By(e,t){return(uR.jsx?oR:lR).test(e)}const cR=/[ \t\n\f\r]/g;function dR(e){return typeof e=="object"?e.type==="text"?Uy(e.value):!1:Uy(e)}function Uy(e){return e.replace(cR,"")===""}class A0{constructor(t,n,r){this.normal=n,this.property=t,r&&(this.space=r)}}A0.prototype.normal={};A0.prototype.property={};A0.prototype.space=void 0;function n7(e,t){const n={},r={};for(const i of e)Object.assign(n,i.property),Object.assign(r,i.normal);return new A0(n,r,t)}function o0(e){return e.toLowerCase()}class si{constructor(t,n){this.attribute=n,this.property=t}}si.prototype.attribute="";si.prototype.booleanish=!1;si.prototype.boolean=!1;si.prototype.commaOrSpaceSeparated=!1;si.prototype.commaSeparated=!1;si.prototype.defined=!1;si.prototype.mustUseProperty=!1;si.prototype.number=!1;si.prototype.overloadedBoolean=!1;si.prototype.property="";si.prototype.spaceSeparated=!1;si.prototype.space=void 0;let hR=0;const St=Xl(),nr=Xl(),Jg=Xl(),De=Xl(),vn=Xl(),eu=Xl(),vi=Xl();function Xl(){return 2**++hR}const eb=Object.freeze(Object.defineProperty({__proto__:null,boolean:St,booleanish:nr,commaOrSpaceSeparated:vi,commaSeparated:eu,number:De,overloadedBoolean:Jg,spaceSeparated:vn},Symbol.toStringTag,{value:"Module"})),D1=Object.keys(eb);class d2 extends si{constructor(t,n,r,i){let s=-1;if(super(t,n),zy(this,"space",i),typeof r=="number")for(;++s<D1.length;){const o=D1[s];zy(this,D1[s],(r&eb[o])===eb[o])}}}d2.prototype.defined=!0;function zy(e,t,n){n&&(e[t]=n)}function pu(e){const t={},n={};for(const[r,i]of Object.entries(e.properties)){const s=new d2(r,e.transform(e.attributes||{},r),i,e.space);e.mustUseProperty&&e.mustUseProperty.includes(r)&&(s.mustUseProperty=!0),t[r]=s,n[o0(r)]=r,n[o0(s.attribute)]=r}return new A0(t,n,e.space)}const r7=pu({properties:{ariaActiveDescendant:null,ariaAtomic:nr,ariaAutoComplete:null,ariaBusy:nr,ariaChecked:nr,ariaColCount:De,ariaColIndex:De,ariaColSpan:De,ariaControls:vn,ariaCurrent:null,ariaDescribedBy:vn,ariaDetails:null,ariaDisabled:nr,ariaDropEffect:vn,ariaErrorMessage:null,ariaExpanded:nr,ariaFlowTo:vn,ariaGrabbed:nr,ariaHasPopup:null,ariaHidden:nr,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:vn,ariaLevel:De,ariaLive:null,ariaModal:nr,ariaMultiLine:nr,ariaMultiSelectable:nr,ariaOrientation:null,ariaOwns:vn,ariaPlaceholder:null,ariaPosInSet:De,ariaPressed:nr,ariaReadOnly:nr,ariaRelevant:null,ariaRequired:nr,ariaRoleDescription:vn,ariaRowCount:De,ariaRowIndex:De,ariaRowSpan:De,ariaSelected:nr,ariaSetSize:De,ariaSort:null,ariaValueMax:De,ariaValueMin:De,ariaValueNow:De,ariaValueText:null,role:null},transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()}});function i7(e,t){return t in e?e[t]:t}function a7(e,t){return i7(e,t.toLowerCase())}const fR=pu({attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:eu,acceptCharset:vn,accessKey:vn,action:null,allow:null,allowFullScreen:St,allowPaymentRequest:St,allowUserMedia:St,alt:null,as:null,async:St,autoCapitalize:null,autoComplete:vn,autoFocus:St,autoPlay:St,blocking:vn,capture:null,charSet:null,checked:St,cite:null,className:vn,cols:De,colSpan:null,content:null,contentEditable:nr,controls:St,controlsList:vn,coords:De|eu,crossOrigin:null,data:null,dateTime:null,decoding:null,default:St,defer:St,dir:null,dirName:null,disabled:St,download:Jg,draggable:nr,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:St,formTarget:null,headers:vn,height:De,hidden:Jg,high:De,href:null,hrefLang:null,htmlFor:vn,httpEquiv:vn,id:null,imageSizes:null,imageSrcSet:null,inert:St,inputMode:null,integrity:null,is:null,isMap:St,itemId:null,itemProp:vn,itemRef:vn,itemScope:St,itemType:vn,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:St,low:De,manifest:null,max:null,maxLength:De,media:null,method:null,min:null,minLength:De,multiple:St,muted:St,name:null,nonce:null,noModule:St,noValidate:St,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:St,optimum:De,pattern:null,ping:vn,placeholder:null,playsInline:St,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:St,referrerPolicy:null,rel:vn,required:St,reversed:St,rows:De,rowSpan:De,sandbox:vn,scope:null,scoped:St,seamless:St,selected:St,shadowRootClonable:St,shadowRootDelegatesFocus:St,shadowRootMode:null,shape:null,size:De,sizes:null,slot:null,span:De,spellCheck:nr,src:null,srcDoc:null,srcLang:null,srcSet:null,start:De,step:null,style:null,tabIndex:De,target:null,title:null,translate:null,type:null,typeMustMatch:St,useMap:null,value:nr,width:De,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:vn,axis:null,background:null,bgColor:null,border:De,borderColor:null,bottomMargin:De,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:St,declare:St,event:null,face:null,frame:null,frameBorder:null,hSpace:De,leftMargin:De,link:null,longDesc:null,lowSrc:null,marginHeight:De,marginWidth:De,noResize:St,noHref:St,noShade:St,noWrap:St,object:null,profile:null,prompt:null,rev:null,rightMargin:De,rules:null,scheme:null,scrolling:nr,standby:null,summary:null,text:null,topMargin:De,valueType:null,version:null,vAlign:null,vLink:null,vSpace:De,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:St,disableRemotePlayback:St,prefix:null,property:null,results:De,security:null,unselectable:null},space:"html",transform:a7}),mR=pu({attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},properties:{about:vi,accentHeight:De,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:De,amplitude:De,arabicForm:null,ascent:De,attributeName:null,attributeType:null,azimuth:De,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:De,by:null,calcMode:null,capHeight:De,className:vn,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:De,diffuseConstant:De,direction:null,display:null,dur:null,divisor:De,dominantBaseline:null,download:St,dx:null,dy:null,edgeMode:null,editable:null,elevation:De,enableBackground:null,end:null,event:null,exponent:De,externalResourcesRequired:null,fill:null,fillOpacity:De,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:eu,g2:eu,glyphName:eu,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:De,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:De,horizOriginX:De,horizOriginY:De,id:null,ideographic:De,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:De,k:De,k1:De,k2:De,k3:De,k4:De,kernelMatrix:vi,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:De,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:De,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:De,overlineThickness:De,paintOrder:null,panose1:null,path:null,pathLength:De,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:vn,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:De,pointsAtY:De,pointsAtZ:De,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:vi,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:vi,rev:vi,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:vi,requiredFeatures:vi,requiredFonts:vi,requiredFormats:vi,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:De,specularExponent:De,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:De,strikethroughThickness:De,string:null,stroke:null,strokeDashArray:vi,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:De,strokeOpacity:De,strokeWidth:null,style:null,surfaceScale:De,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:vi,tabIndex:De,tableValues:null,target:null,targetX:De,targetY:De,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:vi,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:De,underlineThickness:De,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:De,values:null,vAlphabetic:De,vMathematical:De,vectorEffect:null,vHanging:De,vIdeographic:De,version:null,vertAdvY:De,vertOriginX:De,vertOriginY:De,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:De,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",transform:i7}),s7=pu({properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()}}),l7=pu({attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},space:"xmlns",transform:a7}),o7=pu({properties:{xmlBase:null,xmlLang:null,xmlSpace:null},space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()}}),pR={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},gR=/[A-Z]/g,Fy=/-[a-z]/g,bR=/^data[-\w.:]+$/i;function Hf(e,t){const n=o0(t);let r=t,i=si;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&bR.test(t)){if(t.charAt(4)==="-"){const s=t.slice(5).replace(Fy,_R);r="data"+s.charAt(0).toUpperCase()+s.slice(1)}else{const s=t.slice(4);if(!Fy.test(s)){let o=s.replace(gR,vR);o.charAt(0)!=="-"&&(o="-"+o),t="data"+o}}i=d2}return new i(r,t)}function vR(e){return"-"+e.toLowerCase()}function _R(e){return e.charAt(1).toUpperCase()}const k0=n7([r7,fR,s7,l7,o7],"html"),ol=n7([r7,mR,s7,l7,o7],"svg");function Hy(e){const t=String(e||"").trim();return t?t.split(/[ \t\n\r\f]+/g):[]}function u7(e){return e.join(" ").trim()}var Uo={},L1,jy;function yR(){if(jy)return L1;jy=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,n=/^\s*/,r=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,i=/^:\s*/,s=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,o=/^[;\s]*/,c=/^\s+|\s+$/g,d=`
`,f="/",m="*",p="",v="comment",_="declaration";function T(k,A){if(typeof k!="string")throw new TypeError("First argument must be a string");if(!k)return[];A=A||{};var O=1,I=1;function $(fe){var de=fe.match(t);de&&(O+=de.length);var H=fe.lastIndexOf(d);I=~H?fe.length-H:I+fe.length}function V(){var fe={line:O,column:I};return function(de){return de.position=new B(fe),te(),de}}function B(fe){this.start=fe,this.end={line:O,column:I},this.source=A.source}B.prototype.content=k;function Z(fe){var de=new Error(A.source+":"+O+":"+I+": "+fe);if(de.reason=fe,de.filename=A.source,de.line=O,de.column=I,de.source=k,!A.silent)throw de}function ee(fe){var de=fe.exec(k);if(de){var H=de[0];return $(H),k=k.slice(H.length),de}}function te(){ee(n)}function Y(fe){var de;for(fe=fe||[];de=oe();)de!==!1&&fe.push(de);return fe}function oe(){var fe=V();if(!(f!=k.charAt(0)||m!=k.charAt(1))){for(var de=2;p!=k.charAt(de)&&(m!=k.charAt(de)||f!=k.charAt(de+1));)++de;if(de+=2,p===k.charAt(de-1))return Z("End of comment missing");var H=k.slice(2,de-2);return I+=2,$(H),k=k.slice(de),I+=2,fe({type:v,comment:H})}}function he(){var fe=V(),de=ee(r);if(de){if(oe(),!ee(i))return Z("property missing ':'");var H=ee(s),ie=fe({type:_,property:x(de[0].replace(e,p)),value:H?x(H[0].replace(e,p)):p});return ee(o),ie}}function Se(){var fe=[];Y(fe);for(var de;de=he();)de!==!1&&(fe.push(de),Y(fe));return fe}return te(),Se()}function x(k){return k?k.replace(c,p):p}return L1=T,L1}var qy;function ER(){if(qy)return Uo;qy=1;var e=Uo&&Uo.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(Uo,"__esModule",{value:!0}),Uo.default=n;const t=e(yR());function n(r,i){let s=null;if(!r||typeof r!="string")return s;const o=(0,t.default)(r),c=typeof i=="function";return o.forEach(d=>{if(d.type!=="declaration")return;const{property:f,value:m}=d;c?i(f,m,d):m&&(s=s||{},s[f]=m)}),s}return Uo}var yc={},$y;function TR(){if($y)return yc;$y=1,Object.defineProperty(yc,"__esModule",{value:!0}),yc.camelCase=void 0;var e=/^--[a-zA-Z0-9_-]+$/,t=/-([a-z])/g,n=/^[^-]+$/,r=/^-(webkit|moz|ms|o|khtml)-/,i=/^-(ms)-/,s=function(f){return!f||n.test(f)||e.test(f)},o=function(f,m){return m.toUpperCase()},c=function(f,m){return"".concat(m,"-")},d=function(f,m){return m===void 0&&(m={}),s(f)?f:(f=f.toLowerCase(),m.reactCompat?f=f.replace(i,c):f=f.replace(r,c),f.replace(t,o))};return yc.camelCase=d,yc}var Ec,Gy;function xR(){if(Gy)return Ec;Gy=1;var e=Ec&&Ec.__importDefault||function(i){return i&&i.__esModule?i:{default:i}},t=e(ER()),n=TR();function r(i,s){var o={};return!i||typeof i!="string"||(0,t.default)(i,function(c,d){c&&d&&(o[(0,n.camelCase)(c,s)]=d)}),o}return r.default=r,Ec=r,Ec}var SR=xR();const wR=Of(SR),jf=c7("end"),pa=c7("start");function c7(e){return t;function t(n){const r=n&&n.position&&n.position[e]||{};if(typeof r.line=="number"&&r.line>0&&typeof r.column=="number"&&r.column>0)return{line:r.line,column:r.column,offset:typeof r.offset=="number"&&r.offset>-1?r.offset:void 0}}}function AR(e){const t=pa(e),n=jf(e);if(t&&n)return{start:t,end:n}}function Wc(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?Yy(e.position):"start"in e||"end"in e?Yy(e):"line"in e||"column"in e?tb(e):""}function tb(e){return Vy(e&&e.line)+":"+Vy(e&&e.column)}function Yy(e){return tb(e&&e.start)+"-"+tb(e&&e.end)}function Vy(e){return e&&typeof e=="number"?e:1}class Or extends Error{constructor(t,n,r){super(),typeof n=="string"&&(r=n,n=void 0);let i="",s={},o=!1;if(n&&("line"in n&&"column"in n?s={place:n}:"start"in n&&"end"in n?s={place:n}:"type"in n?s={ancestors:[n],place:n.position}:s={...n}),typeof t=="string"?i=t:!s.cause&&t&&(o=!0,i=t.message,s.cause=t),!s.ruleId&&!s.source&&typeof r=="string"){const d=r.indexOf(":");d===-1?s.ruleId=r:(s.source=r.slice(0,d),s.ruleId=r.slice(d+1))}if(!s.place&&s.ancestors&&s.ancestors){const d=s.ancestors[s.ancestors.length-1];d&&(s.place=d.position)}const c=s.place&&"start"in s.place?s.place.start:s.place;this.ancestors=s.ancestors||void 0,this.cause=s.cause||void 0,this.column=c?c.column:void 0,this.fatal=void 0,this.file="",this.message=i,this.line=c?c.line:void 0,this.name=Wc(s.place)||"1:1",this.place=s.place||void 0,this.reason=this.message,this.ruleId=s.ruleId||void 0,this.source=s.source||void 0,this.stack=o&&s.cause&&typeof s.cause.stack=="string"?s.cause.stack:"",this.actual=void 0,this.expected=void 0,this.note=void 0,this.url=void 0}}Or.prototype.file="";Or.prototype.name="";Or.prototype.reason="";Or.prototype.message="";Or.prototype.stack="";Or.prototype.column=void 0;Or.prototype.line=void 0;Or.prototype.ancestors=void 0;Or.prototype.cause=void 0;Or.prototype.fatal=void 0;Or.prototype.place=void 0;Or.prototype.ruleId=void 0;Or.prototype.source=void 0;const h2={}.hasOwnProperty,kR=new Map,CR=/[A-Z]/g,NR=new Set(["table","tbody","thead","tfoot","tr"]),OR=new Set(["td","th"]),d7="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function RR(e,t){if(!t||t.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const n=t.filePath||void 0;let r;if(t.development){if(typeof t.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");r=zR(n,t.jsxDEV)}else{if(typeof t.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof t.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");r=UR(n,t.jsx,t.jsxs)}const i={Fragment:t.Fragment,ancestors:[],components:t.components||{},create:r,elementAttributeNameCase:t.elementAttributeNameCase||"react",evaluater:t.createEvaluater?t.createEvaluater():void 0,filePath:n,ignoreInvalidStyle:t.ignoreInvalidStyle||!1,passKeys:t.passKeys!==!1,passNode:t.passNode||!1,schema:t.space==="svg"?ol:k0,stylePropertyNameCase:t.stylePropertyNameCase||"dom",tableCellAlignToStyle:t.tableCellAlignToStyle!==!1},s=h7(i,e,void 0);return s&&typeof s!="string"?s:i.create(e,i.Fragment,{children:s||void 0},void 0)}function h7(e,t,n){if(t.type==="element")return MR(e,t,n);if(t.type==="mdxFlowExpression"||t.type==="mdxTextExpression")return IR(e,t);if(t.type==="mdxJsxFlowElement"||t.type==="mdxJsxTextElement")return LR(e,t,n);if(t.type==="mdxjsEsm")return DR(e,t);if(t.type==="root")return PR(e,t,n);if(t.type==="text")return BR(e,t)}function MR(e,t,n){const r=e.schema;let i=r;t.tagName.toLowerCase()==="svg"&&r.space==="html"&&(i=ol,e.schema=i),e.ancestors.push(t);const s=m7(e,t.tagName,!1),o=FR(e,t);let c=m2(e,t);return NR.has(t.tagName)&&(c=c.filter(function(d){return typeof d=="string"?!dR(d):!0})),f7(e,o,s,t),f2(o,c),e.ancestors.pop(),e.schema=r,e.create(t,s,o,n)}function IR(e,t){if(t.data&&t.data.estree&&e.evaluater){const r=t.data.estree.body[0];return r.type,e.evaluater.evaluateExpression(r.expression)}u0(e,t.position)}function DR(e,t){if(t.data&&t.data.estree&&e.evaluater)return e.evaluater.evaluateProgram(t.data.estree);u0(e,t.position)}function LR(e,t,n){const r=e.schema;let i=r;t.name==="svg"&&r.space==="html"&&(i=ol,e.schema=i),e.ancestors.push(t);const s=t.name===null?e.Fragment:m7(e,t.name,!0),o=HR(e,t),c=m2(e,t);return f7(e,o,s,t),f2(o,c),e.ancestors.pop(),e.schema=r,e.create(t,s,o,n)}function PR(e,t,n){const r={};return f2(r,m2(e,t)),e.create(t,e.Fragment,r,n)}function BR(e,t){return t.value}function f7(e,t,n,r){typeof n!="string"&&n!==e.Fragment&&e.passNode&&(t.node=r)}function f2(e,t){if(t.length>0){const n=t.length>1?t:t[0];n&&(e.children=n)}}function UR(e,t,n){return r;function r(i,s,o,c){const f=Array.isArray(o.children)?n:t;return c?f(s,o,c):f(s,o)}}function zR(e,t){return n;function n(r,i,s,o){const c=Array.isArray(s.children),d=pa(r);return t(i,s,o,c,{columnNumber:d?d.column-1:void 0,fileName:e,lineNumber:d?d.line:void 0},void 0)}}function FR(e,t){const n={};let r,i;for(i in t.properties)if(i!=="children"&&h2.call(t.properties,i)){const s=jR(e,i,t.properties[i]);if(s){const[o,c]=s;e.tableCellAlignToStyle&&o==="align"&&typeof c=="string"&&OR.has(t.tagName)?r=c:n[o]=c}}if(r){const s=n.style||(n.style={});s[e.stylePropertyNameCase==="css"?"text-align":"textAlign"]=r}return n}function HR(e,t){const n={};for(const r of t.attributes)if(r.type==="mdxJsxExpressionAttribute")if(r.data&&r.data.estree&&e.evaluater){const s=r.data.estree.body[0];s.type;const o=s.expression;o.type;const c=o.properties[0];c.type,Object.assign(n,e.evaluater.evaluateExpression(c.argument))}else u0(e,t.position);else{const i=r.name;let s;if(r.value&&typeof r.value=="object")if(r.value.data&&r.value.data.estree&&e.evaluater){const c=r.value.data.estree.body[0];c.type,s=e.evaluater.evaluateExpression(c.expression)}else u0(e,t.position);else s=r.value===null?!0:r.value;n[i]=s}return n}function m2(e,t){const n=[];let r=-1;const i=e.passKeys?new Map:kR;for(;++r<t.children.length;){const s=t.children[r];let o;if(e.passKeys){const d=s.type==="element"?s.tagName:s.type==="mdxJsxFlowElement"||s.type==="mdxJsxTextElement"?s.name:void 0;if(d){const f=i.get(d)||0;o=d+"-"+f,i.set(d,f+1)}}const c=h7(e,s,o);c!==void 0&&n.push(c)}return n}function jR(e,t,n){const r=Hf(e.schema,t);if(!(n==null||typeof n=="number"&&Number.isNaN(n))){if(Array.isArray(n)&&(n=r.commaSeparated?t7(n):u7(n)),r.property==="style"){let i=typeof n=="object"?n:qR(e,String(n));return e.stylePropertyNameCase==="css"&&(i=$R(i)),["style",i]}return[e.elementAttributeNameCase==="react"&&r.space?pR[r.property]||r.property:r.attribute,n]}}function qR(e,t){try{return wR(t,{reactCompat:!0})}catch(n){if(e.ignoreInvalidStyle)return{};const r=n,i=new Or("Cannot parse `style` attribute",{ancestors:e.ancestors,cause:r,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw i.file=e.filePath||void 0,i.url=d7+"#cannot-parse-style-attribute",i}}function m7(e,t,n){let r;if(!n)r={type:"Literal",value:t};else if(t.includes(".")){const i=t.split(".");let s=-1,o;for(;++s<i.length;){const c=By(i[s])?{type:"Identifier",name:i[s]}:{type:"Literal",value:i[s]};o=o?{type:"MemberExpression",object:o,property:c,computed:!!(s&&c.type==="Literal"),optional:!1}:c}r=o}else r=By(t)&&!/^[a-z]/.test(t)?{type:"Identifier",name:t}:{type:"Literal",value:t};if(r.type==="Literal"){const i=r.value;return h2.call(e.components,i)?e.components[i]:i}if(e.evaluater)return e.evaluater.evaluateExpression(r);u0(e)}function u0(e,t){const n=new Or("Cannot handle MDX estrees without `createEvaluater`",{ancestors:e.ancestors,place:t,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw n.file=e.filePath||void 0,n.url=d7+"#cannot-handle-mdx-estrees-without-createevaluater",n}function $R(e){const t={};let n;for(n in e)h2.call(e,n)&&(t[GR(n)]=e[n]);return t}function GR(e){let t=e.replace(CR,YR);return t.slice(0,3)==="ms-"&&(t="-"+t),t}function YR(e){return"-"+e.toLowerCase()}const P1={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},VR={};function p2(e,t){const n=VR,r=typeof n.includeImageAlt=="boolean"?n.includeImageAlt:!0,i=typeof n.includeHtml=="boolean"?n.includeHtml:!0;return p7(e,r,i)}function p7(e,t,n){if(KR(e)){if("value"in e)return e.type==="html"&&!n?"":e.value;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return Ky(e.children,t,n)}return Array.isArray(e)?Ky(e,t,n):""}function Ky(e,t,n){const r=[];let i=-1;for(;++i<e.length;)r[i]=p7(e[i],t,n);return r.join("")}function KR(e){return!!(e&&typeof e=="object")}const Wy=document.createElement("i");function g2(e){const t="&"+e+";";Wy.innerHTML=t;const n=Wy.textContent;return n.charCodeAt(n.length-1)===59&&e!=="semi"||n===t?!1:n}function Ei(e,t,n,r){const i=e.length;let s=0,o;if(t<0?t=-t>i?0:i+t:t=t>i?i:t,n=n>0?n:0,r.length<1e4)o=Array.from(r),o.unshift(t,n),e.splice(...o);else for(n&&e.splice(t,n);s<r.length;)o=r.slice(s,s+1e4),o.unshift(t,0),e.splice(...o),s+=1e4,t+=1e4}function Li(e,t){return e.length>0?(Ei(e,e.length,0,t),e):t}const Xy={}.hasOwnProperty;function g7(e){const t={};let n=-1;for(;++n<e.length;)WR(t,e[n]);return t}function WR(e,t){let n;for(n in t){const i=(Xy.call(e,n)?e[n]:void 0)||(e[n]={}),s=t[n];let o;if(s)for(o in s){Xy.call(i,o)||(i[o]=[]);const c=s[o];XR(i[o],Array.isArray(c)?c:c?[c]:[])}}}function XR(e,t){let n=-1;const r=[];for(;++n<t.length;)(t[n].add==="after"?e:r).push(t[n]);Ei(e,0,0,r)}function b7(e,t){const n=Number.parseInt(e,t);return n<9||n===11||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||(n&65535)===65535||(n&65535)===65534||n>1114111?"�":String.fromCodePoint(n)}function Wi(e){return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const Fr=ul(/[A-Za-z]/),Nr=ul(/[\dA-Za-z]/),QR=ul(/[#-'*+\--9=?A-Z^-~]/);function Jh(e){return e!==null&&(e<32||e===127)}const nb=ul(/\d/),ZR=ul(/[\dA-Fa-f]/),JR=ul(/[!-/:-@[-`{-~]/);function tt(e){return e!==null&&e<-2}function fn(e){return e!==null&&(e<0||e===32)}function Lt(e){return e===-2||e===-1||e===32}const qf=ul(new RegExp("\\p{P}|\\p{S}","u")),ql=ul(/\s/);function ul(e){return t;function t(n){return n!==null&&n>-1&&e.test(String.fromCharCode(n))}}function gu(e){const t=[];let n=-1,r=0,i=0;for(;++n<e.length;){const s=e.charCodeAt(n);let o="";if(s===37&&Nr(e.charCodeAt(n+1))&&Nr(e.charCodeAt(n+2)))i=2;else if(s<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(s))||(o=String.fromCharCode(s));else if(s>55295&&s<57344){const c=e.charCodeAt(n+1);s<56320&&c>56319&&c<57344?(o=String.fromCharCode(s,c),i=1):o="�"}else o=String.fromCharCode(s);o&&(t.push(e.slice(r,n),encodeURIComponent(o)),r=n+i+1,o=""),i&&(n+=i,i=0)}return t.join("")+e.slice(r)}function Ot(e,t,n,r){const i=r?r-1:Number.POSITIVE_INFINITY;let s=0;return o;function o(d){return Lt(d)?(e.enter(n),c(d)):t(d)}function c(d){return Lt(d)&&s++<i?(e.consume(d),c):(e.exit(n),t(d))}}const eM={tokenize:tM};function tM(e){const t=e.attempt(this.parser.constructs.contentInitial,r,i);let n;return t;function r(c){if(c===null){e.consume(c);return}return e.enter("lineEnding"),e.consume(c),e.exit("lineEnding"),Ot(e,t,"linePrefix")}function i(c){return e.enter("paragraph"),s(c)}function s(c){const d=e.enter("chunkText",{contentType:"text",previous:n});return n&&(n.next=d),n=d,o(c)}function o(c){if(c===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(c);return}return tt(c)?(e.consume(c),e.exit("chunkText"),s):(e.consume(c),o)}}const nM={tokenize:rM},Qy={tokenize:iM};function rM(e){const t=this,n=[];let r=0,i,s,o;return c;function c(I){if(r<n.length){const $=n[r];return t.containerState=$[1],e.attempt($[0].continuation,d,f)(I)}return f(I)}function d(I){if(r++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,i&&O();const $=t.events.length;let V=$,B;for(;V--;)if(t.events[V][0]==="exit"&&t.events[V][1].type==="chunkFlow"){B=t.events[V][1].end;break}A(r);let Z=$;for(;Z<t.events.length;)t.events[Z][1].end={...B},Z++;return Ei(t.events,V+1,0,t.events.slice($)),t.events.length=Z,f(I)}return c(I)}function f(I){if(r===n.length){if(!i)return v(I);if(i.currentConstruct&&i.currentConstruct.concrete)return T(I);t.interrupt=!!(i.currentConstruct&&!i._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(Qy,m,p)(I)}function m(I){return i&&O(),A(r),v(I)}function p(I){return t.parser.lazy[t.now().line]=r!==n.length,o=t.now().offset,T(I)}function v(I){return t.containerState={},e.attempt(Qy,_,T)(I)}function _(I){return r++,n.push([t.currentConstruct,t.containerState]),v(I)}function T(I){if(I===null){i&&O(),A(0),e.consume(I);return}return i=i||t.parser.flow(t.now()),e.enter("chunkFlow",{_tokenizer:i,contentType:"flow",previous:s}),x(I)}function x(I){if(I===null){k(e.exit("chunkFlow"),!0),A(0),e.consume(I);return}return tt(I)?(e.consume(I),k(e.exit("chunkFlow")),r=0,t.interrupt=void 0,c):(e.consume(I),x)}function k(I,$){const V=t.sliceStream(I);if($&&V.push(null),I.previous=s,s&&(s.next=I),s=I,i.defineSkip(I.start),i.write(V),t.parser.lazy[I.start.line]){let B=i.events.length;for(;B--;)if(i.events[B][1].start.offset<o&&(!i.events[B][1].end||i.events[B][1].end.offset>o))return;const Z=t.events.length;let ee=Z,te,Y;for(;ee--;)if(t.events[ee][0]==="exit"&&t.events[ee][1].type==="chunkFlow"){if(te){Y=t.events[ee][1].end;break}te=!0}for(A(r),B=Z;B<t.events.length;)t.events[B][1].end={...Y},B++;Ei(t.events,ee+1,0,t.events.slice(Z)),t.events.length=B}}function A(I){let $=n.length;for(;$-- >I;){const V=n[$];t.containerState=V[1],V[0].exit.call(t,e)}n.length=I}function O(){i.write([null]),s=void 0,i=void 0,t.containerState._closeFlow=void 0}}function iM(e,t,n){return Ot(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function iu(e){if(e===null||fn(e)||ql(e))return 1;if(qf(e))return 2}function $f(e,t,n){const r=[];let i=-1;for(;++i<e.length;){const s=e[i].resolveAll;s&&!r.includes(s)&&(t=s(t,n),r.push(s))}return t}const rb={name:"attention",resolveAll:aM,tokenize:sM};function aM(e,t){let n=-1,r,i,s,o,c,d,f,m;for(;++n<e.length;)if(e[n][0]==="enter"&&e[n][1].type==="attentionSequence"&&e[n][1]._close){for(r=n;r--;)if(e[r][0]==="exit"&&e[r][1].type==="attentionSequence"&&e[r][1]._open&&t.sliceSerialize(e[r][1]).charCodeAt(0)===t.sliceSerialize(e[n][1]).charCodeAt(0)){if((e[r][1]._close||e[n][1]._open)&&(e[n][1].end.offset-e[n][1].start.offset)%3&&!((e[r][1].end.offset-e[r][1].start.offset+e[n][1].end.offset-e[n][1].start.offset)%3))continue;d=e[r][1].end.offset-e[r][1].start.offset>1&&e[n][1].end.offset-e[n][1].start.offset>1?2:1;const p={...e[r][1].end},v={...e[n][1].start};Zy(p,-d),Zy(v,d),o={type:d>1?"strongSequence":"emphasisSequence",start:p,end:{...e[r][1].end}},c={type:d>1?"strongSequence":"emphasisSequence",start:{...e[n][1].start},end:v},s={type:d>1?"strongText":"emphasisText",start:{...e[r][1].end},end:{...e[n][1].start}},i={type:d>1?"strong":"emphasis",start:{...o.start},end:{...c.end}},e[r][1].end={...o.start},e[n][1].start={...c.end},f=[],e[r][1].end.offset-e[r][1].start.offset&&(f=Li(f,[["enter",e[r][1],t],["exit",e[r][1],t]])),f=Li(f,[["enter",i,t],["enter",o,t],["exit",o,t],["enter",s,t]]),f=Li(f,$f(t.parser.constructs.insideSpan.null,e.slice(r+1,n),t)),f=Li(f,[["exit",s,t],["enter",c,t],["exit",c,t],["exit",i,t]]),e[n][1].end.offset-e[n][1].start.offset?(m=2,f=Li(f,[["enter",e[n][1],t],["exit",e[n][1],t]])):m=0,Ei(e,r-1,n-r+3,f),n=r+f.length-m-2;break}}for(n=-1;++n<e.length;)e[n][1].type==="attentionSequence"&&(e[n][1].type="data");return e}function sM(e,t){const n=this.parser.constructs.attentionMarkers.null,r=this.previous,i=iu(r);let s;return o;function o(d){return s=d,e.enter("attentionSequence"),c(d)}function c(d){if(d===s)return e.consume(d),c;const f=e.exit("attentionSequence"),m=iu(d),p=!m||m===2&&i||n.includes(d),v=!i||i===2&&m||n.includes(r);return f._open=!!(s===42?p:p&&(i||!v)),f._close=!!(s===42?v:v&&(m||!p)),t(d)}}function Zy(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}const lM={name:"autolink",tokenize:oM};function oM(e,t,n){let r=0;return i;function i(_){return e.enter("autolink"),e.enter("autolinkMarker"),e.consume(_),e.exit("autolinkMarker"),e.enter("autolinkProtocol"),s}function s(_){return Fr(_)?(e.consume(_),o):_===64?n(_):f(_)}function o(_){return _===43||_===45||_===46||Nr(_)?(r=1,c(_)):f(_)}function c(_){return _===58?(e.consume(_),r=0,d):(_===43||_===45||_===46||Nr(_))&&r++<32?(e.consume(_),c):(r=0,f(_))}function d(_){return _===62?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),e.consume(_),e.exit("autolinkMarker"),e.exit("autolink"),t):_===null||_===32||_===60||Jh(_)?n(_):(e.consume(_),d)}function f(_){return _===64?(e.consume(_),m):QR(_)?(e.consume(_),f):n(_)}function m(_){return Nr(_)?p(_):n(_)}function p(_){return _===46?(e.consume(_),r=0,m):_===62?(e.exit("autolinkProtocol").type="autolinkEmail",e.enter("autolinkMarker"),e.consume(_),e.exit("autolinkMarker"),e.exit("autolink"),t):v(_)}function v(_){if((_===45||Nr(_))&&r++<63){const T=_===45?v:p;return e.consume(_),T}return n(_)}}const C0={partial:!0,tokenize:uM};function uM(e,t,n){return r;function r(s){return Lt(s)?Ot(e,i,"linePrefix")(s):i(s)}function i(s){return s===null||tt(s)?t(s):n(s)}}const v7={continuation:{tokenize:dM},exit:hM,name:"blockQuote",tokenize:cM};function cM(e,t,n){const r=this;return i;function i(o){if(o===62){const c=r.containerState;return c.open||(e.enter("blockQuote",{_container:!0}),c.open=!0),e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(o),e.exit("blockQuoteMarker"),s}return n(o)}function s(o){return Lt(o)?(e.enter("blockQuotePrefixWhitespace"),e.consume(o),e.exit("blockQuotePrefixWhitespace"),e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(o))}}function dM(e,t,n){const r=this;return i;function i(o){return Lt(o)?Ot(e,s,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(o):s(o)}function s(o){return e.attempt(v7,t,n)(o)}}function hM(e){e.exit("blockQuote")}const _7={name:"characterEscape",tokenize:fM};function fM(e,t,n){return r;function r(s){return e.enter("characterEscape"),e.enter("escapeMarker"),e.consume(s),e.exit("escapeMarker"),i}function i(s){return JR(s)?(e.enter("characterEscapeValue"),e.consume(s),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):n(s)}}const y7={name:"characterReference",tokenize:mM};function mM(e,t,n){const r=this;let i=0,s,o;return c;function c(p){return e.enter("characterReference"),e.enter("characterReferenceMarker"),e.consume(p),e.exit("characterReferenceMarker"),d}function d(p){return p===35?(e.enter("characterReferenceMarkerNumeric"),e.consume(p),e.exit("characterReferenceMarkerNumeric"),f):(e.enter("characterReferenceValue"),s=31,o=Nr,m(p))}function f(p){return p===88||p===120?(e.enter("characterReferenceMarkerHexadecimal"),e.consume(p),e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),s=6,o=ZR,m):(e.enter("characterReferenceValue"),s=7,o=nb,m(p))}function m(p){if(p===59&&i){const v=e.exit("characterReferenceValue");return o===Nr&&!g2(r.sliceSerialize(v))?n(p):(e.enter("characterReferenceMarker"),e.consume(p),e.exit("characterReferenceMarker"),e.exit("characterReference"),t)}return o(p)&&i++<s?(e.consume(p),m):n(p)}}const Jy={partial:!0,tokenize:gM},eE={concrete:!0,name:"codeFenced",tokenize:pM};function pM(e,t,n){const r=this,i={partial:!0,tokenize:V};let s=0,o=0,c;return d;function d(B){return f(B)}function f(B){const Z=r.events[r.events.length-1];return s=Z&&Z[1].type==="linePrefix"?Z[2].sliceSerialize(Z[1],!0).length:0,c=B,e.enter("codeFenced"),e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),m(B)}function m(B){return B===c?(o++,e.consume(B),m):o<3?n(B):(e.exit("codeFencedFenceSequence"),Lt(B)?Ot(e,p,"whitespace")(B):p(B))}function p(B){return B===null||tt(B)?(e.exit("codeFencedFence"),r.interrupt?t(B):e.check(Jy,x,$)(B)):(e.enter("codeFencedFenceInfo"),e.enter("chunkString",{contentType:"string"}),v(B))}function v(B){return B===null||tt(B)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),p(B)):Lt(B)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),Ot(e,_,"whitespace")(B)):B===96&&B===c?n(B):(e.consume(B),v)}function _(B){return B===null||tt(B)?p(B):(e.enter("codeFencedFenceMeta"),e.enter("chunkString",{contentType:"string"}),T(B))}function T(B){return B===null||tt(B)?(e.exit("chunkString"),e.exit("codeFencedFenceMeta"),p(B)):B===96&&B===c?n(B):(e.consume(B),T)}function x(B){return e.attempt(i,$,k)(B)}function k(B){return e.enter("lineEnding"),e.consume(B),e.exit("lineEnding"),A}function A(B){return s>0&&Lt(B)?Ot(e,O,"linePrefix",s+1)(B):O(B)}function O(B){return B===null||tt(B)?e.check(Jy,x,$)(B):(e.enter("codeFlowValue"),I(B))}function I(B){return B===null||tt(B)?(e.exit("codeFlowValue"),O(B)):(e.consume(B),I)}function $(B){return e.exit("codeFenced"),t(B)}function V(B,Z,ee){let te=0;return Y;function Y(de){return B.enter("lineEnding"),B.consume(de),B.exit("lineEnding"),oe}function oe(de){return B.enter("codeFencedFence"),Lt(de)?Ot(B,he,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(de):he(de)}function he(de){return de===c?(B.enter("codeFencedFenceSequence"),Se(de)):ee(de)}function Se(de){return de===c?(te++,B.consume(de),Se):te>=o?(B.exit("codeFencedFenceSequence"),Lt(de)?Ot(B,fe,"whitespace")(de):fe(de)):ee(de)}function fe(de){return de===null||tt(de)?(B.exit("codeFencedFence"),Z(de)):ee(de)}}}function gM(e,t,n){const r=this;return i;function i(o){return o===null?n(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),s)}function s(o){return r.parser.lazy[r.now().line]?n(o):t(o)}}const B1={name:"codeIndented",tokenize:vM},bM={partial:!0,tokenize:_M};function vM(e,t,n){const r=this;return i;function i(f){return e.enter("codeIndented"),Ot(e,s,"linePrefix",5)(f)}function s(f){const m=r.events[r.events.length-1];return m&&m[1].type==="linePrefix"&&m[2].sliceSerialize(m[1],!0).length>=4?o(f):n(f)}function o(f){return f===null?d(f):tt(f)?e.attempt(bM,o,d)(f):(e.enter("codeFlowValue"),c(f))}function c(f){return f===null||tt(f)?(e.exit("codeFlowValue"),o(f)):(e.consume(f),c)}function d(f){return e.exit("codeIndented"),t(f)}}function _M(e,t,n){const r=this;return i;function i(o){return r.parser.lazy[r.now().line]?n(o):tt(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),i):Ot(e,s,"linePrefix",5)(o)}function s(o){const c=r.events[r.events.length-1];return c&&c[1].type==="linePrefix"&&c[2].sliceSerialize(c[1],!0).length>=4?t(o):tt(o)?i(o):n(o)}}const yM={name:"codeText",previous:TM,resolve:EM,tokenize:xM};function EM(e){let t=e.length-4,n=3,r,i;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="codeTextData"){e[n][1].type="codeTextPadding",e[t][1].type="codeTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)i===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(i=r):(r===t||e[r][1].type==="lineEnding")&&(e[i][1].type="codeTextData",r!==i+2&&(e[i][1].end=e[r-1][1].end,e.splice(i+2,r-i-2),t-=r-i-2,r=i+2),i=void 0);return e}function TM(e){return e!==96||this.events[this.events.length-1][1].type==="characterEscape"}function xM(e,t,n){let r=0,i,s;return o;function o(p){return e.enter("codeText"),e.enter("codeTextSequence"),c(p)}function c(p){return p===96?(e.consume(p),r++,c):(e.exit("codeTextSequence"),d(p))}function d(p){return p===null?n(p):p===32?(e.enter("space"),e.consume(p),e.exit("space"),d):p===96?(s=e.enter("codeTextSequence"),i=0,m(p)):tt(p)?(e.enter("lineEnding"),e.consume(p),e.exit("lineEnding"),d):(e.enter("codeTextData"),f(p))}function f(p){return p===null||p===32||p===96||tt(p)?(e.exit("codeTextData"),d(p)):(e.consume(p),f)}function m(p){return p===96?(e.consume(p),i++,m):i===r?(e.exit("codeTextSequence"),e.exit("codeText"),t(p)):(s.type="codeTextData",f(p))}}class SM{constructor(t){this.left=t?[...t]:[],this.right=[]}get(t){if(t<0||t>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+t+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return t<this.left.length?this.left[t]:this.right[this.right.length-t+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(t,n){const r=n??Number.POSITIVE_INFINITY;return r<this.left.length?this.left.slice(t,r):t>this.left.length?this.right.slice(this.right.length-r+this.left.length,this.right.length-t+this.left.length).reverse():this.left.slice(t).concat(this.right.slice(this.right.length-r+this.left.length).reverse())}splice(t,n,r){const i=n||0;this.setCursor(Math.trunc(t));const s=this.right.splice(this.right.length-i,Number.POSITIVE_INFINITY);return r&&Tc(this.left,r),s.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(t){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(t)}pushMany(t){this.setCursor(Number.POSITIVE_INFINITY),Tc(this.left,t)}unshift(t){this.setCursor(0),this.right.push(t)}unshiftMany(t){this.setCursor(0),Tc(this.right,t.reverse())}setCursor(t){if(!(t===this.left.length||t>this.left.length&&this.right.length===0||t<0&&this.left.length===0))if(t<this.left.length){const n=this.left.splice(t,Number.POSITIVE_INFINITY);Tc(this.right,n.reverse())}else{const n=this.right.splice(this.left.length+this.right.length-t,Number.POSITIVE_INFINITY);Tc(this.left,n.reverse())}}}function Tc(e,t){let n=0;if(t.length<1e4)e.push(...t);else for(;n<t.length;)e.push(...t.slice(n,n+1e4)),n+=1e4}function E7(e){const t={};let n=-1,r,i,s,o,c,d,f;const m=new SM(e);for(;++n<m.length;){for(;n in t;)n=t[n];if(r=m.get(n),n&&r[1].type==="chunkFlow"&&m.get(n-1)[1].type==="listItemPrefix"&&(d=r[1]._tokenizer.events,s=0,s<d.length&&d[s][1].type==="lineEndingBlank"&&(s+=2),s<d.length&&d[s][1].type==="content"))for(;++s<d.length&&d[s][1].type!=="content";)d[s][1].type==="chunkText"&&(d[s][1]._isInFirstContentOfListItem=!0,s++);if(r[0]==="enter")r[1].contentType&&(Object.assign(t,wM(m,n)),n=t[n],f=!0);else if(r[1]._container){for(s=n,i=void 0;s--;)if(o=m.get(s),o[1].type==="lineEnding"||o[1].type==="lineEndingBlank")o[0]==="enter"&&(i&&(m.get(i)[1].type="lineEndingBlank"),o[1].type="lineEnding",i=s);else if(!(o[1].type==="linePrefix"||o[1].type==="listItemIndent"))break;i&&(r[1].end={...m.get(i)[1].start},c=m.slice(i,n),c.unshift(r),m.splice(i,n-i+1,c))}}return Ei(e,0,Number.POSITIVE_INFINITY,m.slice(0)),!f}function wM(e,t){const n=e.get(t)[1],r=e.get(t)[2];let i=t-1;const s=[];let o=n._tokenizer;o||(o=r.parser[n.contentType](n.start),n._contentTypeTextTrailing&&(o._contentTypeTextTrailing=!0));const c=o.events,d=[],f={};let m,p,v=-1,_=n,T=0,x=0;const k=[x];for(;_;){for(;e.get(++i)[1]!==_;);s.push(i),_._tokenizer||(m=r.sliceStream(_),_.next||m.push(null),p&&o.defineSkip(_.start),_._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=!0),o.write(m),_._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=void 0)),p=_,_=_.next}for(_=n;++v<c.length;)c[v][0]==="exit"&&c[v-1][0]==="enter"&&c[v][1].type===c[v-1][1].type&&c[v][1].start.line!==c[v][1].end.line&&(x=v+1,k.push(x),_._tokenizer=void 0,_.previous=void 0,_=_.next);for(o.events=[],_?(_._tokenizer=void 0,_.previous=void 0):k.pop(),v=k.length;v--;){const A=c.slice(k[v],k[v+1]),O=s.pop();d.push([O,O+A.length-1]),e.splice(O,2,A)}for(d.reverse(),v=-1;++v<d.length;)f[T+d[v][0]]=T+d[v][1],T+=d[v][1]-d[v][0]-1;return f}const AM={resolve:CM,tokenize:NM},kM={partial:!0,tokenize:OM};function CM(e){return E7(e),e}function NM(e,t){let n;return r;function r(c){return e.enter("content"),n=e.enter("chunkContent",{contentType:"content"}),i(c)}function i(c){return c===null?s(c):tt(c)?e.check(kM,o,s)(c):(e.consume(c),i)}function s(c){return e.exit("chunkContent"),e.exit("content"),t(c)}function o(c){return e.consume(c),e.exit("chunkContent"),n.next=e.enter("chunkContent",{contentType:"content",previous:n}),n=n.next,i}}function OM(e,t,n){const r=this;return i;function i(o){return e.exit("chunkContent"),e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),Ot(e,s,"linePrefix")}function s(o){if(o===null||tt(o))return n(o);const c=r.events[r.events.length-1];return!r.parser.constructs.disable.null.includes("codeIndented")&&c&&c[1].type==="linePrefix"&&c[2].sliceSerialize(c[1],!0).length>=4?t(o):e.interrupt(r.parser.constructs.flow,n,t)(o)}}function T7(e,t,n,r,i,s,o,c,d){const f=d||Number.POSITIVE_INFINITY;let m=0;return p;function p(A){return A===60?(e.enter(r),e.enter(i),e.enter(s),e.consume(A),e.exit(s),v):A===null||A===32||A===41||Jh(A)?n(A):(e.enter(r),e.enter(o),e.enter(c),e.enter("chunkString",{contentType:"string"}),x(A))}function v(A){return A===62?(e.enter(s),e.consume(A),e.exit(s),e.exit(i),e.exit(r),t):(e.enter(c),e.enter("chunkString",{contentType:"string"}),_(A))}function _(A){return A===62?(e.exit("chunkString"),e.exit(c),v(A)):A===null||A===60||tt(A)?n(A):(e.consume(A),A===92?T:_)}function T(A){return A===60||A===62||A===92?(e.consume(A),_):_(A)}function x(A){return!m&&(A===null||A===41||fn(A))?(e.exit("chunkString"),e.exit(c),e.exit(o),e.exit(r),t(A)):m<f&&A===40?(e.consume(A),m++,x):A===41?(e.consume(A),m--,x):A===null||A===32||A===40||Jh(A)?n(A):(e.consume(A),A===92?k:x)}function k(A){return A===40||A===41||A===92?(e.consume(A),x):x(A)}}function x7(e,t,n,r,i,s){const o=this;let c=0,d;return f;function f(_){return e.enter(r),e.enter(i),e.consume(_),e.exit(i),e.enter(s),m}function m(_){return c>999||_===null||_===91||_===93&&!d||_===94&&!c&&"_hiddenFootnoteSupport"in o.parser.constructs?n(_):_===93?(e.exit(s),e.enter(i),e.consume(_),e.exit(i),e.exit(r),t):tt(_)?(e.enter("lineEnding"),e.consume(_),e.exit("lineEnding"),m):(e.enter("chunkString",{contentType:"string"}),p(_))}function p(_){return _===null||_===91||_===93||tt(_)||c++>999?(e.exit("chunkString"),m(_)):(e.consume(_),d||(d=!Lt(_)),_===92?v:p)}function v(_){return _===91||_===92||_===93?(e.consume(_),c++,p):p(_)}}function S7(e,t,n,r,i,s){let o;return c;function c(v){return v===34||v===39||v===40?(e.enter(r),e.enter(i),e.consume(v),e.exit(i),o=v===40?41:v,d):n(v)}function d(v){return v===o?(e.enter(i),e.consume(v),e.exit(i),e.exit(r),t):(e.enter(s),f(v))}function f(v){return v===o?(e.exit(s),d(o)):v===null?n(v):tt(v)?(e.enter("lineEnding"),e.consume(v),e.exit("lineEnding"),Ot(e,f,"linePrefix")):(e.enter("chunkString",{contentType:"string"}),m(v))}function m(v){return v===o||v===null||tt(v)?(e.exit("chunkString"),f(v)):(e.consume(v),v===92?p:m)}function p(v){return v===o||v===92?(e.consume(v),m):m(v)}}function Xc(e,t){let n;return r;function r(i){return tt(i)?(e.enter("lineEnding"),e.consume(i),e.exit("lineEnding"),n=!0,r):Lt(i)?Ot(e,r,n?"linePrefix":"lineSuffix")(i):t(i)}}const RM={name:"definition",tokenize:IM},MM={partial:!0,tokenize:DM};function IM(e,t,n){const r=this;let i;return s;function s(_){return e.enter("definition"),o(_)}function o(_){return x7.call(r,e,c,n,"definitionLabel","definitionLabelMarker","definitionLabelString")(_)}function c(_){return i=Wi(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)),_===58?(e.enter("definitionMarker"),e.consume(_),e.exit("definitionMarker"),d):n(_)}function d(_){return fn(_)?Xc(e,f)(_):f(_)}function f(_){return T7(e,m,n,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(_)}function m(_){return e.attempt(MM,p,p)(_)}function p(_){return Lt(_)?Ot(e,v,"whitespace")(_):v(_)}function v(_){return _===null||tt(_)?(e.exit("definition"),r.parser.defined.push(i),t(_)):n(_)}}function DM(e,t,n){return r;function r(c){return fn(c)?Xc(e,i)(c):n(c)}function i(c){return S7(e,s,n,"definitionTitle","definitionTitleMarker","definitionTitleString")(c)}function s(c){return Lt(c)?Ot(e,o,"whitespace")(c):o(c)}function o(c){return c===null||tt(c)?t(c):n(c)}}const LM={name:"hardBreakEscape",tokenize:PM};function PM(e,t,n){return r;function r(s){return e.enter("hardBreakEscape"),e.consume(s),i}function i(s){return tt(s)?(e.exit("hardBreakEscape"),t(s)):n(s)}}const BM={name:"headingAtx",resolve:UM,tokenize:zM};function UM(e,t){let n=e.length-2,r=3,i,s;return e[r][1].type==="whitespace"&&(r+=2),n-2>r&&e[n][1].type==="whitespace"&&(n-=2),e[n][1].type==="atxHeadingSequence"&&(r===n-1||n-4>r&&e[n-2][1].type==="whitespace")&&(n-=r+1===n?2:4),n>r&&(i={type:"atxHeadingText",start:e[r][1].start,end:e[n][1].end},s={type:"chunkText",start:e[r][1].start,end:e[n][1].end,contentType:"text"},Ei(e,r,n-r+1,[["enter",i,t],["enter",s,t],["exit",s,t],["exit",i,t]])),e}function zM(e,t,n){let r=0;return i;function i(m){return e.enter("atxHeading"),s(m)}function s(m){return e.enter("atxHeadingSequence"),o(m)}function o(m){return m===35&&r++<6?(e.consume(m),o):m===null||fn(m)?(e.exit("atxHeadingSequence"),c(m)):n(m)}function c(m){return m===35?(e.enter("atxHeadingSequence"),d(m)):m===null||tt(m)?(e.exit("atxHeading"),t(m)):Lt(m)?Ot(e,c,"whitespace")(m):(e.enter("atxHeadingText"),f(m))}function d(m){return m===35?(e.consume(m),d):(e.exit("atxHeadingSequence"),c(m))}function f(m){return m===null||m===35||fn(m)?(e.exit("atxHeadingText"),c(m)):(e.consume(m),f)}}const FM=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],tE=["pre","script","style","textarea"],HM={concrete:!0,name:"htmlFlow",resolveTo:$M,tokenize:GM},jM={partial:!0,tokenize:VM},qM={partial:!0,tokenize:YM};function $M(e){let t=e.length;for(;t--&&!(e[t][0]==="enter"&&e[t][1].type==="htmlFlow"););return t>1&&e[t-2][1].type==="linePrefix"&&(e[t][1].start=e[t-2][1].start,e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2)),e}function GM(e,t,n){const r=this;let i,s,o,c,d;return f;function f(D){return m(D)}function m(D){return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(D),p}function p(D){return D===33?(e.consume(D),v):D===47?(e.consume(D),s=!0,x):D===63?(e.consume(D),i=3,r.interrupt?t:P):Fr(D)?(e.consume(D),o=String.fromCharCode(D),k):n(D)}function v(D){return D===45?(e.consume(D),i=2,_):D===91?(e.consume(D),i=5,c=0,T):Fr(D)?(e.consume(D),i=4,r.interrupt?t:P):n(D)}function _(D){return D===45?(e.consume(D),r.interrupt?t:P):n(D)}function T(D){const Ae="CDATA[";return D===Ae.charCodeAt(c++)?(e.consume(D),c===Ae.length?r.interrupt?t:he:T):n(D)}function x(D){return Fr(D)?(e.consume(D),o=String.fromCharCode(D),k):n(D)}function k(D){if(D===null||D===47||D===62||fn(D)){const Ae=D===47,Le=o.toLowerCase();return!Ae&&!s&&tE.includes(Le)?(i=1,r.interrupt?t(D):he(D)):FM.includes(o.toLowerCase())?(i=6,Ae?(e.consume(D),A):r.interrupt?t(D):he(D)):(i=7,r.interrupt&&!r.parser.lazy[r.now().line]?n(D):s?O(D):I(D))}return D===45||Nr(D)?(e.consume(D),o+=String.fromCharCode(D),k):n(D)}function A(D){return D===62?(e.consume(D),r.interrupt?t:he):n(D)}function O(D){return Lt(D)?(e.consume(D),O):Y(D)}function I(D){return D===47?(e.consume(D),Y):D===58||D===95||Fr(D)?(e.consume(D),$):Lt(D)?(e.consume(D),I):Y(D)}function $(D){return D===45||D===46||D===58||D===95||Nr(D)?(e.consume(D),$):V(D)}function V(D){return D===61?(e.consume(D),B):Lt(D)?(e.consume(D),V):I(D)}function B(D){return D===null||D===60||D===61||D===62||D===96?n(D):D===34||D===39?(e.consume(D),d=D,Z):Lt(D)?(e.consume(D),B):ee(D)}function Z(D){return D===d?(e.consume(D),d=null,te):D===null||tt(D)?n(D):(e.consume(D),Z)}function ee(D){return D===null||D===34||D===39||D===47||D===60||D===61||D===62||D===96||fn(D)?V(D):(e.consume(D),ee)}function te(D){return D===47||D===62||Lt(D)?I(D):n(D)}function Y(D){return D===62?(e.consume(D),oe):n(D)}function oe(D){return D===null||tt(D)?he(D):Lt(D)?(e.consume(D),oe):n(D)}function he(D){return D===45&&i===2?(e.consume(D),H):D===60&&i===1?(e.consume(D),ie):D===62&&i===4?(e.consume(D),z):D===63&&i===3?(e.consume(D),P):D===93&&i===5?(e.consume(D),xe):tt(D)&&(i===6||i===7)?(e.exit("htmlFlowData"),e.check(jM,J,Se)(D)):D===null||tt(D)?(e.exit("htmlFlowData"),Se(D)):(e.consume(D),he)}function Se(D){return e.check(qM,fe,J)(D)}function fe(D){return e.enter("lineEnding"),e.consume(D),e.exit("lineEnding"),de}function de(D){return D===null||tt(D)?Se(D):(e.enter("htmlFlowData"),he(D))}function H(D){return D===45?(e.consume(D),P):he(D)}function ie(D){return D===47?(e.consume(D),o="",ve):he(D)}function ve(D){if(D===62){const Ae=o.toLowerCase();return tE.includes(Ae)?(e.consume(D),z):he(D)}return Fr(D)&&o.length<8?(e.consume(D),o+=String.fromCharCode(D),ve):he(D)}function xe(D){return D===93?(e.consume(D),P):he(D)}function P(D){return D===62?(e.consume(D),z):D===45&&i===2?(e.consume(D),P):he(D)}function z(D){return D===null||tt(D)?(e.exit("htmlFlowData"),J(D)):(e.consume(D),z)}function J(D){return e.exit("htmlFlow"),t(D)}}function YM(e,t,n){const r=this;return i;function i(o){return tt(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),s):n(o)}function s(o){return r.parser.lazy[r.now().line]?n(o):t(o)}}function VM(e,t,n){return r;function r(i){return e.enter("lineEnding"),e.consume(i),e.exit("lineEnding"),e.attempt(C0,t,n)}}const KM={name:"htmlText",tokenize:WM};function WM(e,t,n){const r=this;let i,s,o;return c;function c(P){return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(P),d}function d(P){return P===33?(e.consume(P),f):P===47?(e.consume(P),V):P===63?(e.consume(P),I):Fr(P)?(e.consume(P),ee):n(P)}function f(P){return P===45?(e.consume(P),m):P===91?(e.consume(P),s=0,T):Fr(P)?(e.consume(P),O):n(P)}function m(P){return P===45?(e.consume(P),_):n(P)}function p(P){return P===null?n(P):P===45?(e.consume(P),v):tt(P)?(o=p,ie(P)):(e.consume(P),p)}function v(P){return P===45?(e.consume(P),_):p(P)}function _(P){return P===62?H(P):P===45?v(P):p(P)}function T(P){const z="CDATA[";return P===z.charCodeAt(s++)?(e.consume(P),s===z.length?x:T):n(P)}function x(P){return P===null?n(P):P===93?(e.consume(P),k):tt(P)?(o=x,ie(P)):(e.consume(P),x)}function k(P){return P===93?(e.consume(P),A):x(P)}function A(P){return P===62?H(P):P===93?(e.consume(P),A):x(P)}function O(P){return P===null||P===62?H(P):tt(P)?(o=O,ie(P)):(e.consume(P),O)}function I(P){return P===null?n(P):P===63?(e.consume(P),$):tt(P)?(o=I,ie(P)):(e.consume(P),I)}function $(P){return P===62?H(P):I(P)}function V(P){return Fr(P)?(e.consume(P),B):n(P)}function B(P){return P===45||Nr(P)?(e.consume(P),B):Z(P)}function Z(P){return tt(P)?(o=Z,ie(P)):Lt(P)?(e.consume(P),Z):H(P)}function ee(P){return P===45||Nr(P)?(e.consume(P),ee):P===47||P===62||fn(P)?te(P):n(P)}function te(P){return P===47?(e.consume(P),H):P===58||P===95||Fr(P)?(e.consume(P),Y):tt(P)?(o=te,ie(P)):Lt(P)?(e.consume(P),te):H(P)}function Y(P){return P===45||P===46||P===58||P===95||Nr(P)?(e.consume(P),Y):oe(P)}function oe(P){return P===61?(e.consume(P),he):tt(P)?(o=oe,ie(P)):Lt(P)?(e.consume(P),oe):te(P)}function he(P){return P===null||P===60||P===61||P===62||P===96?n(P):P===34||P===39?(e.consume(P),i=P,Se):tt(P)?(o=he,ie(P)):Lt(P)?(e.consume(P),he):(e.consume(P),fe)}function Se(P){return P===i?(e.consume(P),i=void 0,de):P===null?n(P):tt(P)?(o=Se,ie(P)):(e.consume(P),Se)}function fe(P){return P===null||P===34||P===39||P===60||P===61||P===96?n(P):P===47||P===62||fn(P)?te(P):(e.consume(P),fe)}function de(P){return P===47||P===62||fn(P)?te(P):n(P)}function H(P){return P===62?(e.consume(P),e.exit("htmlTextData"),e.exit("htmlText"),t):n(P)}function ie(P){return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(P),e.exit("lineEnding"),ve}function ve(P){return Lt(P)?Ot(e,xe,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(P):xe(P)}function xe(P){return e.enter("htmlTextData"),o(P)}}const b2={name:"labelEnd",resolveAll:JM,resolveTo:eI,tokenize:tI},XM={tokenize:nI},QM={tokenize:rI},ZM={tokenize:iI};function JM(e){let t=-1;const n=[];for(;++t<e.length;){const r=e[t][1];if(n.push(e[t]),r.type==="labelImage"||r.type==="labelLink"||r.type==="labelEnd"){const i=r.type==="labelImage"?4:2;r.type="data",t+=i}}return e.length!==n.length&&Ei(e,0,e.length,n),e}function eI(e,t){let n=e.length,r=0,i,s,o,c;for(;n--;)if(i=e[n][1],s){if(i.type==="link"||i.type==="labelLink"&&i._inactive)break;e[n][0]==="enter"&&i.type==="labelLink"&&(i._inactive=!0)}else if(o){if(e[n][0]==="enter"&&(i.type==="labelImage"||i.type==="labelLink")&&!i._balanced&&(s=n,i.type!=="labelLink")){r=2;break}}else i.type==="labelEnd"&&(o=n);const d={type:e[s][1].type==="labelLink"?"link":"image",start:{...e[s][1].start},end:{...e[e.length-1][1].end}},f={type:"label",start:{...e[s][1].start},end:{...e[o][1].end}},m={type:"labelText",start:{...e[s+r+2][1].end},end:{...e[o-2][1].start}};return c=[["enter",d,t],["enter",f,t]],c=Li(c,e.slice(s+1,s+r+3)),c=Li(c,[["enter",m,t]]),c=Li(c,$f(t.parser.constructs.insideSpan.null,e.slice(s+r+4,o-3),t)),c=Li(c,[["exit",m,t],e[o-2],e[o-1],["exit",f,t]]),c=Li(c,e.slice(o+1)),c=Li(c,[["exit",d,t]]),Ei(e,s,e.length,c),e}function tI(e,t,n){const r=this;let i=r.events.length,s,o;for(;i--;)if((r.events[i][1].type==="labelImage"||r.events[i][1].type==="labelLink")&&!r.events[i][1]._balanced){s=r.events[i][1];break}return c;function c(v){return s?s._inactive?p(v):(o=r.parser.defined.includes(Wi(r.sliceSerialize({start:s.end,end:r.now()}))),e.enter("labelEnd"),e.enter("labelMarker"),e.consume(v),e.exit("labelMarker"),e.exit("labelEnd"),d):n(v)}function d(v){return v===40?e.attempt(XM,m,o?m:p)(v):v===91?e.attempt(QM,m,o?f:p)(v):o?m(v):p(v)}function f(v){return e.attempt(ZM,m,p)(v)}function m(v){return t(v)}function p(v){return s._balanced=!0,n(v)}}function nI(e,t,n){return r;function r(p){return e.enter("resource"),e.enter("resourceMarker"),e.consume(p),e.exit("resourceMarker"),i}function i(p){return fn(p)?Xc(e,s)(p):s(p)}function s(p){return p===41?m(p):T7(e,o,c,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(p)}function o(p){return fn(p)?Xc(e,d)(p):m(p)}function c(p){return n(p)}function d(p){return p===34||p===39||p===40?S7(e,f,n,"resourceTitle","resourceTitleMarker","resourceTitleString")(p):m(p)}function f(p){return fn(p)?Xc(e,m)(p):m(p)}function m(p){return p===41?(e.enter("resourceMarker"),e.consume(p),e.exit("resourceMarker"),e.exit("resource"),t):n(p)}}function rI(e,t,n){const r=this;return i;function i(c){return x7.call(r,e,s,o,"reference","referenceMarker","referenceString")(c)}function s(c){return r.parser.defined.includes(Wi(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)))?t(c):n(c)}function o(c){return n(c)}}function iI(e,t,n){return r;function r(s){return e.enter("reference"),e.enter("referenceMarker"),e.consume(s),e.exit("referenceMarker"),i}function i(s){return s===93?(e.enter("referenceMarker"),e.consume(s),e.exit("referenceMarker"),e.exit("reference"),t):n(s)}}const aI={name:"labelStartImage",resolveAll:b2.resolveAll,tokenize:sI};function sI(e,t,n){const r=this;return i;function i(c){return e.enter("labelImage"),e.enter("labelImageMarker"),e.consume(c),e.exit("labelImageMarker"),s}function s(c){return c===91?(e.enter("labelMarker"),e.consume(c),e.exit("labelMarker"),e.exit("labelImage"),o):n(c)}function o(c){return c===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(c):t(c)}}const lI={name:"labelStartLink",resolveAll:b2.resolveAll,tokenize:oI};function oI(e,t,n){const r=this;return i;function i(o){return e.enter("labelLink"),e.enter("labelMarker"),e.consume(o),e.exit("labelMarker"),e.exit("labelLink"),s}function s(o){return o===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(o):t(o)}}const U1={name:"lineEnding",tokenize:uI};function uI(e,t){return n;function n(r){return e.enter("lineEnding"),e.consume(r),e.exit("lineEnding"),Ot(e,t,"linePrefix")}}const Hh={name:"thematicBreak",tokenize:cI};function cI(e,t,n){let r=0,i;return s;function s(f){return e.enter("thematicBreak"),o(f)}function o(f){return i=f,c(f)}function c(f){return f===i?(e.enter("thematicBreakSequence"),d(f)):r>=3&&(f===null||tt(f))?(e.exit("thematicBreak"),t(f)):n(f)}function d(f){return f===i?(e.consume(f),r++,d):(e.exit("thematicBreakSequence"),Lt(f)?Ot(e,c,"whitespace")(f):c(f))}}const ei={continuation:{tokenize:mI},exit:gI,name:"list",tokenize:fI},dI={partial:!0,tokenize:bI},hI={partial:!0,tokenize:pI};function fI(e,t,n){const r=this,i=r.events[r.events.length-1];let s=i&&i[1].type==="linePrefix"?i[2].sliceSerialize(i[1],!0).length:0,o=0;return c;function c(_){const T=r.containerState.type||(_===42||_===43||_===45?"listUnordered":"listOrdered");if(T==="listUnordered"?!r.containerState.marker||_===r.containerState.marker:nb(_)){if(r.containerState.type||(r.containerState.type=T,e.enter(T,{_container:!0})),T==="listUnordered")return e.enter("listItemPrefix"),_===42||_===45?e.check(Hh,n,f)(_):f(_);if(!r.interrupt||_===49)return e.enter("listItemPrefix"),e.enter("listItemValue"),d(_)}return n(_)}function d(_){return nb(_)&&++o<10?(e.consume(_),d):(!r.interrupt||o<2)&&(r.containerState.marker?_===r.containerState.marker:_===41||_===46)?(e.exit("listItemValue"),f(_)):n(_)}function f(_){return e.enter("listItemMarker"),e.consume(_),e.exit("listItemMarker"),r.containerState.marker=r.containerState.marker||_,e.check(C0,r.interrupt?n:m,e.attempt(dI,v,p))}function m(_){return r.containerState.initialBlankLine=!0,s++,v(_)}function p(_){return Lt(_)?(e.enter("listItemPrefixWhitespace"),e.consume(_),e.exit("listItemPrefixWhitespace"),v):n(_)}function v(_){return r.containerState.size=s+r.sliceSerialize(e.exit("listItemPrefix"),!0).length,t(_)}}function mI(e,t,n){const r=this;return r.containerState._closeFlow=void 0,e.check(C0,i,s);function i(c){return r.containerState.furtherBlankLines=r.containerState.furtherBlankLines||r.containerState.initialBlankLine,Ot(e,t,"listItemIndent",r.containerState.size+1)(c)}function s(c){return r.containerState.furtherBlankLines||!Lt(c)?(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,o(c)):(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,e.attempt(hI,t,o)(c))}function o(c){return r.containerState._closeFlow=!0,r.interrupt=void 0,Ot(e,e.attempt(ei,t,n),"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(c)}}function pI(e,t,n){const r=this;return Ot(e,i,"listItemIndent",r.containerState.size+1);function i(s){const o=r.events[r.events.length-1];return o&&o[1].type==="listItemIndent"&&o[2].sliceSerialize(o[1],!0).length===r.containerState.size?t(s):n(s)}}function gI(e){e.exit(this.containerState.type)}function bI(e,t,n){const r=this;return Ot(e,i,"listItemPrefixWhitespace",r.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function i(s){const o=r.events[r.events.length-1];return!Lt(s)&&o&&o[1].type==="listItemPrefixWhitespace"?t(s):n(s)}}const nE={name:"setextUnderline",resolveTo:vI,tokenize:_I};function vI(e,t){let n=e.length,r,i,s;for(;n--;)if(e[n][0]==="enter"){if(e[n][1].type==="content"){r=n;break}e[n][1].type==="paragraph"&&(i=n)}else e[n][1].type==="content"&&e.splice(n,1),!s&&e[n][1].type==="definition"&&(s=n);const o={type:"setextHeading",start:{...e[r][1].start},end:{...e[e.length-1][1].end}};return e[i][1].type="setextHeadingText",s?(e.splice(i,0,["enter",o,t]),e.splice(s+1,0,["exit",e[r][1],t]),e[r][1].end={...e[s][1].end}):e[r][1]=o,e.push(["exit",o,t]),e}function _I(e,t,n){const r=this;let i;return s;function s(f){let m=r.events.length,p;for(;m--;)if(r.events[m][1].type!=="lineEnding"&&r.events[m][1].type!=="linePrefix"&&r.events[m][1].type!=="content"){p=r.events[m][1].type==="paragraph";break}return!r.parser.lazy[r.now().line]&&(r.interrupt||p)?(e.enter("setextHeadingLine"),i=f,o(f)):n(f)}function o(f){return e.enter("setextHeadingLineSequence"),c(f)}function c(f){return f===i?(e.consume(f),c):(e.exit("setextHeadingLineSequence"),Lt(f)?Ot(e,d,"lineSuffix")(f):d(f))}function d(f){return f===null||tt(f)?(e.exit("setextHeadingLine"),t(f)):n(f)}}const yI={tokenize:EI};function EI(e){const t=this,n=e.attempt(C0,r,e.attempt(this.parser.constructs.flowInitial,i,Ot(e,e.attempt(this.parser.constructs.flow,i,e.attempt(AM,i)),"linePrefix")));return n;function r(s){if(s===null){e.consume(s);return}return e.enter("lineEndingBlank"),e.consume(s),e.exit("lineEndingBlank"),t.currentConstruct=void 0,n}function i(s){if(s===null){e.consume(s);return}return e.enter("lineEnding"),e.consume(s),e.exit("lineEnding"),t.currentConstruct=void 0,n}}const TI={resolveAll:A7()},xI=w7("string"),SI=w7("text");function w7(e){return{resolveAll:A7(e==="text"?wI:void 0),tokenize:t};function t(n){const r=this,i=this.parser.constructs[e],s=n.attempt(i,o,c);return o;function o(m){return f(m)?s(m):c(m)}function c(m){if(m===null){n.consume(m);return}return n.enter("data"),n.consume(m),d}function d(m){return f(m)?(n.exit("data"),s(m)):(n.consume(m),d)}function f(m){if(m===null)return!0;const p=i[m];let v=-1;if(p)for(;++v<p.length;){const _=p[v];if(!_.previous||_.previous.call(r,r.previous))return!0}return!1}}}function A7(e){return t;function t(n,r){let i=-1,s;for(;++i<=n.length;)s===void 0?n[i]&&n[i][1].type==="data"&&(s=i,i++):(!n[i]||n[i][1].type!=="data")&&(i!==s+2&&(n[s][1].end=n[i-1][1].end,n.splice(s+2,i-s-2),i=s+2),s=void 0);return e?e(n,r):n}}function wI(e,t){let n=0;for(;++n<=e.length;)if((n===e.length||e[n][1].type==="lineEnding")&&e[n-1][1].type==="data"){const r=e[n-1][1],i=t.sliceStream(r);let s=i.length,o=-1,c=0,d;for(;s--;){const f=i[s];if(typeof f=="string"){for(o=f.length;f.charCodeAt(o-1)===32;)c++,o--;if(o)break;o=-1}else if(f===-2)d=!0,c++;else if(f!==-1){s++;break}}if(t._contentTypeTextTrailing&&n===e.length&&(c=0),c){const f={type:n===e.length||d||c<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:s?o:r.start._bufferIndex+o,_index:r.start._index+s,line:r.end.line,column:r.end.column-c,offset:r.end.offset-c},end:{...r.end}};r.end={...f.start},r.start.offset===r.end.offset?Object.assign(r,f):(e.splice(n,0,["enter",f,t],["exit",f,t]),n+=2)}n++}return e}const AI={42:ei,43:ei,45:ei,48:ei,49:ei,50:ei,51:ei,52:ei,53:ei,54:ei,55:ei,56:ei,57:ei,62:v7},kI={91:RM},CI={[-2]:B1,[-1]:B1,32:B1},NI={35:BM,42:Hh,45:[nE,Hh],60:HM,61:nE,95:Hh,96:eE,126:eE},OI={38:y7,92:_7},RI={[-5]:U1,[-4]:U1,[-3]:U1,33:aI,38:y7,42:rb,60:[lM,KM],91:lI,92:[LM,_7],93:b2,95:rb,96:yM},MI={null:[rb,TI]},II={null:[42,95]},DI={null:[]},LI=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:II,contentInitial:kI,disable:DI,document:AI,flow:NI,flowInitial:CI,insideSpan:MI,string:OI,text:RI},Symbol.toStringTag,{value:"Module"}));function PI(e,t,n){let r={_bufferIndex:-1,_index:0,line:n&&n.line||1,column:n&&n.column||1,offset:n&&n.offset||0};const i={},s=[];let o=[],c=[];const d={attempt:Z(V),check:Z(B),consume:O,enter:I,exit:$,interrupt:Z(B,{interrupt:!0})},f={code:null,containerState:{},defineSkip:x,events:[],now:T,parser:e,previous:null,sliceSerialize:v,sliceStream:_,write:p};let m=t.tokenize.call(f,d);return t.resolveAll&&s.push(t),f;function p(oe){return o=Li(o,oe),k(),o[o.length-1]!==null?[]:(ee(t,0),f.events=$f(s,f.events,f),f.events)}function v(oe,he){return UI(_(oe),he)}function _(oe){return BI(o,oe)}function T(){const{_bufferIndex:oe,_index:he,line:Se,column:fe,offset:de}=r;return{_bufferIndex:oe,_index:he,line:Se,column:fe,offset:de}}function x(oe){i[oe.line]=oe.column,Y()}function k(){let oe;for(;r._index<o.length;){const he=o[r._index];if(typeof he=="string")for(oe=r._index,r._bufferIndex<0&&(r._bufferIndex=0);r._index===oe&&r._bufferIndex<he.length;)A(he.charCodeAt(r._bufferIndex));else A(he)}}function A(oe){m=m(oe)}function O(oe){tt(oe)?(r.line++,r.column=1,r.offset+=oe===-3?2:1,Y()):oe!==-1&&(r.column++,r.offset++),r._bufferIndex<0?r._index++:(r._bufferIndex++,r._bufferIndex===o[r._index].length&&(r._bufferIndex=-1,r._index++)),f.previous=oe}function I(oe,he){const Se=he||{};return Se.type=oe,Se.start=T(),f.events.push(["enter",Se,f]),c.push(Se),Se}function $(oe){const he=c.pop();return he.end=T(),f.events.push(["exit",he,f]),he}function V(oe,he){ee(oe,he.from)}function B(oe,he){he.restore()}function Z(oe,he){return Se;function Se(fe,de,H){let ie,ve,xe,P;return Array.isArray(fe)?J(fe):"tokenize"in fe?J([fe]):z(fe);function z(ze){return at;function at(_t){const pt=_t!==null&&ze[_t],Tt=_t!==null&&ze.null,kn=[...Array.isArray(pt)?pt:pt?[pt]:[],...Array.isArray(Tt)?Tt:Tt?[Tt]:[]];return J(kn)(_t)}}function J(ze){return ie=ze,ve=0,ze.length===0?H:D(ze[ve])}function D(ze){return at;function at(_t){return P=te(),xe=ze,ze.partial||(f.currentConstruct=ze),ze.name&&f.parser.constructs.disable.null.includes(ze.name)?Le():ze.tokenize.call(he?Object.assign(Object.create(f),he):f,d,Ae,Le)(_t)}}function Ae(ze){return oe(xe,P),de}function Le(ze){return P.restore(),++ve<ie.length?D(ie[ve]):H}}}function ee(oe,he){oe.resolveAll&&!s.includes(oe)&&s.push(oe),oe.resolve&&Ei(f.events,he,f.events.length-he,oe.resolve(f.events.slice(he),f)),oe.resolveTo&&(f.events=oe.resolveTo(f.events,f))}function te(){const oe=T(),he=f.previous,Se=f.currentConstruct,fe=f.events.length,de=Array.from(c);return{from:fe,restore:H};function H(){r=oe,f.previous=he,f.currentConstruct=Se,f.events.length=fe,c=de,Y()}}function Y(){r.line in i&&r.column<2&&(r.column=i[r.line],r.offset+=i[r.line]-1)}}function BI(e,t){const n=t.start._index,r=t.start._bufferIndex,i=t.end._index,s=t.end._bufferIndex;let o;if(n===i)o=[e[n].slice(r,s)];else{if(o=e.slice(n,i),r>-1){const c=o[0];typeof c=="string"?o[0]=c.slice(r):o.shift()}s>0&&o.push(e[i].slice(0,s))}return o}function UI(e,t){let n=-1;const r=[];let i;for(;++n<e.length;){const s=e[n];let o;if(typeof s=="string")o=s;else switch(s){case-5:{o="\r";break}case-4:{o=`
`;break}case-3:{o=`\r
`;break}case-2:{o=t?" ":"	";break}case-1:{if(!t&&i)continue;o=" ";break}default:o=String.fromCharCode(s)}i=s===-2,r.push(o)}return r.join("")}function zI(e){const r={constructs:g7([LI,...(e||{}).extensions||[]]),content:i(eM),defined:[],document:i(nM),flow:i(yI),lazy:{},string:i(xI),text:i(SI)};return r;function i(s){return o;function o(c){return PI(r,s,c)}}}function FI(e){for(;!E7(e););return e}const rE=/[\0\t\n\r]/g;function HI(){let e=1,t="",n=!0,r;return i;function i(s,o,c){const d=[];let f,m,p,v,_;for(s=t+(typeof s=="string"?s.toString():new TextDecoder(o||void 0).decode(s)),p=0,t="",n&&(s.charCodeAt(0)===65279&&p++,n=void 0);p<s.length;){if(rE.lastIndex=p,f=rE.exec(s),v=f&&f.index!==void 0?f.index:s.length,_=s.charCodeAt(v),!f){t=s.slice(p);break}if(_===10&&p===v&&r)d.push(-3),r=void 0;else switch(r&&(d.push(-5),r=void 0),p<v&&(d.push(s.slice(p,v)),e+=v-p),_){case 0:{d.push(65533),e++;break}case 9:{for(m=Math.ceil(e/4)*4,d.push(-2);e++<m;)d.push(-1);break}case 10:{d.push(-4),e=1;break}default:r=!0,e=1}p=v+1}return c&&(r&&d.push(-5),t&&d.push(t),d.push(null)),d}}const jI=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function qI(e){return e.replace(jI,$I)}function $I(e,t,n){if(t)return t;if(n.charCodeAt(0)===35){const i=n.charCodeAt(1),s=i===120||i===88;return b7(n.slice(s?2:1),s?16:10)}return g2(n)||e}const k7={}.hasOwnProperty;function GI(e,t,n){return typeof t!="string"&&(n=t,t=void 0),YI(n)(FI(zI(n).document().write(HI()(e,t,!0))))}function YI(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:s(Pt),autolinkProtocol:te,autolinkEmail:te,atxHeading:s(Ft),blockQuote:s(Tt),characterEscape:te,characterReference:te,codeFenced:s(kn),codeFencedFenceInfo:o,codeFencedFenceMeta:o,codeIndented:s(kn,o),codeText:s(pr,o),codeTextData:te,data:te,codeFlowValue:te,definition:s(yt),definitionDestinationString:o,definitionLabelString:o,definitionTitleString:o,emphasis:s(ct),hardBreakEscape:s(Xe),hardBreakTrailing:s(Xe),htmlFlow:s(jt,o),htmlFlowData:te,htmlText:s(jt,o),htmlTextData:te,image:s(pn),label:o,link:s(Pt),listItem:s(Ge),listItemValue:v,listOrdered:s(un,p),listUnordered:s(un),paragraph:s(gn),reference:D,referenceString:o,resourceDestinationString:o,resourceTitleString:o,setextHeading:s(Ft),strong:s(In),thematicBreak:s(En)},exit:{atxHeading:d(),atxHeadingSequence:V,autolink:d(),autolinkEmail:pt,autolinkProtocol:_t,blockQuote:d(),characterEscapeValue:Y,characterReferenceMarkerHexadecimal:Le,characterReferenceMarkerNumeric:Le,characterReferenceValue:ze,characterReference:at,codeFenced:d(k),codeFencedFence:x,codeFencedFenceInfo:_,codeFencedFenceMeta:T,codeFlowValue:Y,codeIndented:d(A),codeText:d(de),codeTextData:Y,data:Y,definition:d(),definitionDestinationString:$,definitionLabelString:O,definitionTitleString:I,emphasis:d(),hardBreakEscape:d(he),hardBreakTrailing:d(he),htmlFlow:d(Se),htmlFlowData:Y,htmlText:d(fe),htmlTextData:Y,image:d(ie),label:xe,labelText:ve,lineEnding:oe,link:d(H),listItem:d(),listOrdered:d(),listUnordered:d(),paragraph:d(),referenceString:Ae,resourceDestinationString:P,resourceTitleString:z,resource:J,setextHeading:d(ee),setextHeadingLineSequence:Z,setextHeadingText:B,strong:d(),thematicBreak:d()}};C7(t,(e||{}).mdastExtensions||[]);const n={};return r;function r(me){let Ce={type:"root",children:[]};const Ye={stack:[Ce],tokenStack:[],config:t,enter:c,exit:f,buffer:o,resume:m,data:n},dt=[];let Ue=-1;for(;++Ue<me.length;)if(me[Ue][1].type==="listOrdered"||me[Ue][1].type==="listUnordered")if(me[Ue][0]==="enter")dt.push(Ue);else{const bt=dt.pop();Ue=i(me,bt,Ue)}for(Ue=-1;++Ue<me.length;){const bt=t[me[Ue][0]];k7.call(bt,me[Ue][1].type)&&bt[me[Ue][1].type].call(Object.assign({sliceSerialize:me[Ue][2].sliceSerialize},Ye),me[Ue][1])}if(Ye.tokenStack.length>0){const bt=Ye.tokenStack[Ye.tokenStack.length-1];(bt[1]||iE).call(Ye,void 0,bt[0])}for(Ce.position={start:Hs(me.length>0?me[0][1].start:{line:1,column:1,offset:0}),end:Hs(me.length>0?me[me.length-2][1].end:{line:1,column:1,offset:0})},Ue=-1;++Ue<t.transforms.length;)Ce=t.transforms[Ue](Ce)||Ce;return Ce}function i(me,Ce,Ye){let dt=Ce-1,Ue=-1,bt=!1,Re,Rt,At,kt;for(;++dt<=Ye;){const Zt=me[dt];switch(Zt[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{Zt[0]==="enter"?Ue++:Ue--,kt=void 0;break}case"lineEndingBlank":{Zt[0]==="enter"&&(Re&&!kt&&!Ue&&!At&&(At=dt),kt=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:kt=void 0}if(!Ue&&Zt[0]==="enter"&&Zt[1].type==="listItemPrefix"||Ue===-1&&Zt[0]==="exit"&&(Zt[1].type==="listUnordered"||Zt[1].type==="listOrdered")){if(Re){let Zi=dt;for(Rt=void 0;Zi--;){const Mr=me[Zi];if(Mr[1].type==="lineEnding"||Mr[1].type==="lineEndingBlank"){if(Mr[0]==="exit")continue;Rt&&(me[Rt][1].type="lineEndingBlank",bt=!0),Mr[1].type="lineEnding",Rt=Zi}else if(!(Mr[1].type==="linePrefix"||Mr[1].type==="blockQuotePrefix"||Mr[1].type==="blockQuotePrefixWhitespace"||Mr[1].type==="blockQuoteMarker"||Mr[1].type==="listItemIndent"))break}At&&(!Rt||At<Rt)&&(Re._spread=!0),Re.end=Object.assign({},Rt?me[Rt][1].start:Zt[1].end),me.splice(Rt||dt,0,["exit",Re,Zt[2]]),dt++,Ye++}if(Zt[1].type==="listItemPrefix"){const Zi={type:"listItem",_spread:!1,start:Object.assign({},Zt[1].start),end:void 0};Re=Zi,me.splice(dt,0,["enter",Zi,Zt[2]]),dt++,Ye++,At=void 0,kt=!0}}}return me[Ce][1]._spread=bt,Ye}function s(me,Ce){return Ye;function Ye(dt){c.call(this,me(dt),dt),Ce&&Ce.call(this,dt)}}function o(){this.stack.push({type:"fragment",children:[]})}function c(me,Ce,Ye){this.stack[this.stack.length-1].children.push(me),this.stack.push(me),this.tokenStack.push([Ce,Ye||void 0]),me.position={start:Hs(Ce.start),end:void 0}}function d(me){return Ce;function Ce(Ye){me&&me.call(this,Ye),f.call(this,Ye)}}function f(me,Ce){const Ye=this.stack.pop(),dt=this.tokenStack.pop();if(dt)dt[0].type!==me.type&&(Ce?Ce.call(this,me,dt[0]):(dt[1]||iE).call(this,me,dt[0]));else throw new Error("Cannot close `"+me.type+"` ("+Wc({start:me.start,end:me.end})+"): it’s not open");Ye.position.end=Hs(me.end)}function m(){return p2(this.stack.pop())}function p(){this.data.expectingFirstListItemValue=!0}function v(me){if(this.data.expectingFirstListItemValue){const Ce=this.stack[this.stack.length-2];Ce.start=Number.parseInt(this.sliceSerialize(me),10),this.data.expectingFirstListItemValue=void 0}}function _(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.lang=me}function T(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.meta=me}function x(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function k(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.value=me.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function A(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.value=me.replace(/(\r?\n|\r)$/g,"")}function O(me){const Ce=this.resume(),Ye=this.stack[this.stack.length-1];Ye.label=Ce,Ye.identifier=Wi(this.sliceSerialize(me)).toLowerCase()}function I(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.title=me}function $(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.url=me}function V(me){const Ce=this.stack[this.stack.length-1];if(!Ce.depth){const Ye=this.sliceSerialize(me).length;Ce.depth=Ye}}function B(){this.data.setextHeadingSlurpLineEnding=!0}function Z(me){const Ce=this.stack[this.stack.length-1];Ce.depth=this.sliceSerialize(me).codePointAt(0)===61?1:2}function ee(){this.data.setextHeadingSlurpLineEnding=void 0}function te(me){const Ye=this.stack[this.stack.length-1].children;let dt=Ye[Ye.length-1];(!dt||dt.type!=="text")&&(dt=Xt(),dt.position={start:Hs(me.start),end:void 0},Ye.push(dt)),this.stack.push(dt)}function Y(me){const Ce=this.stack.pop();Ce.value+=this.sliceSerialize(me),Ce.position.end=Hs(me.end)}function oe(me){const Ce=this.stack[this.stack.length-1];if(this.data.atHardBreak){const Ye=Ce.children[Ce.children.length-1];Ye.position.end=Hs(me.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(Ce.type)&&(te.call(this,me),Y.call(this,me))}function he(){this.data.atHardBreak=!0}function Se(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.value=me}function fe(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.value=me}function de(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.value=me}function H(){const me=this.stack[this.stack.length-1];if(this.data.inReference){const Ce=this.data.referenceType||"shortcut";me.type+="Reference",me.referenceType=Ce,delete me.url,delete me.title}else delete me.identifier,delete me.label;this.data.referenceType=void 0}function ie(){const me=this.stack[this.stack.length-1];if(this.data.inReference){const Ce=this.data.referenceType||"shortcut";me.type+="Reference",me.referenceType=Ce,delete me.url,delete me.title}else delete me.identifier,delete me.label;this.data.referenceType=void 0}function ve(me){const Ce=this.sliceSerialize(me),Ye=this.stack[this.stack.length-2];Ye.label=qI(Ce),Ye.identifier=Wi(Ce).toLowerCase()}function xe(){const me=this.stack[this.stack.length-1],Ce=this.resume(),Ye=this.stack[this.stack.length-1];if(this.data.inReference=!0,Ye.type==="link"){const dt=me.children;Ye.children=dt}else Ye.alt=Ce}function P(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.url=me}function z(){const me=this.resume(),Ce=this.stack[this.stack.length-1];Ce.title=me}function J(){this.data.inReference=void 0}function D(){this.data.referenceType="collapsed"}function Ae(me){const Ce=this.resume(),Ye=this.stack[this.stack.length-1];Ye.label=Ce,Ye.identifier=Wi(this.sliceSerialize(me)).toLowerCase(),this.data.referenceType="full"}function Le(me){this.data.characterReferenceType=me.type}function ze(me){const Ce=this.sliceSerialize(me),Ye=this.data.characterReferenceType;let dt;Ye?(dt=b7(Ce,Ye==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):dt=g2(Ce);const Ue=this.stack[this.stack.length-1];Ue.value+=dt}function at(me){const Ce=this.stack.pop();Ce.position.end=Hs(me.end)}function _t(me){Y.call(this,me);const Ce=this.stack[this.stack.length-1];Ce.url=this.sliceSerialize(me)}function pt(me){Y.call(this,me);const Ce=this.stack[this.stack.length-1];Ce.url="mailto:"+this.sliceSerialize(me)}function Tt(){return{type:"blockquote",children:[]}}function kn(){return{type:"code",lang:null,meta:null,value:""}}function pr(){return{type:"inlineCode",value:""}}function yt(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function ct(){return{type:"emphasis",children:[]}}function Ft(){return{type:"heading",depth:0,children:[]}}function Xe(){return{type:"break"}}function jt(){return{type:"html",value:""}}function pn(){return{type:"image",title:null,url:"",alt:null}}function Pt(){return{type:"link",title:null,url:"",children:[]}}function un(me){return{type:"list",ordered:me.type==="listOrdered",start:null,spread:me._spread,children:[]}}function Ge(me){return{type:"listItem",spread:me._spread,checked:null,children:[]}}function gn(){return{type:"paragraph",children:[]}}function In(){return{type:"strong",children:[]}}function Xt(){return{type:"text",value:""}}function En(){return{type:"thematicBreak"}}}function Hs(e){return{line:e.line,column:e.column,offset:e.offset}}function C7(e,t){let n=-1;for(;++n<t.length;){const r=t[n];Array.isArray(r)?C7(e,r):VI(e,r)}}function VI(e,t){let n;for(n in t)if(k7.call(t,n))switch(n){case"canContainEols":{const r=t[n];r&&e[n].push(...r);break}case"transforms":{const r=t[n];r&&e[n].push(...r);break}case"enter":case"exit":{const r=t[n];r&&Object.assign(e[n],r);break}}}function iE(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+Wc({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+Wc({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+Wc({start:t.start,end:t.end})+") is still open")}function KI(e){const t=this;t.parser=n;function n(r){return GI(r,{...t.data("settings"),...e,extensions:t.data("micromarkExtensions")||[],mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function WI(e,t){const n={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)}function XI(e,t){const n={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:`
`}]}function QI(e,t){const n=t.value?t.value+`
`:"",r={},i=t.lang?t.lang.split(/\s+/):[];i.length>0&&(r.className=["language-"+i[0]]);let s={type:"element",tagName:"code",properties:r,children:[{type:"text",value:n}]};return t.meta&&(s.data={meta:t.meta}),e.patch(t,s),s=e.applyData(t,s),s={type:"element",tagName:"pre",properties:{},children:[s]},e.patch(t,s),s}function ZI(e,t){const n={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function JI(e,t){const n={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function eD(e,t){const n=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",r=String(t.identifier).toUpperCase(),i=gu(r.toLowerCase()),s=e.footnoteOrder.indexOf(r);let o,c=e.footnoteCounts.get(r);c===void 0?(c=0,e.footnoteOrder.push(r),o=e.footnoteOrder.length):o=s+1,c+=1,e.footnoteCounts.set(r,c);const d={type:"element",tagName:"a",properties:{href:"#"+n+"fn-"+i,id:n+"fnref-"+i+(c>1?"-"+c:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(o)}]};e.patch(t,d);const f={type:"element",tagName:"sup",properties:{},children:[d]};return e.patch(t,f),e.applyData(t,f)}function tD(e,t){const n={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function nD(e,t){if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value};return e.patch(t,n),e.applyData(t,n)}}function N7(e,t){const n=t.referenceType;let r="]";if(n==="collapsed"?r+="[]":n==="full"&&(r+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return[{type:"text",value:"!["+t.alt+r}];const i=e.all(t),s=i[0];s&&s.type==="text"?s.value="["+s.value:i.unshift({type:"text",value:"["});const o=i[i.length-1];return o&&o.type==="text"?o.value+=r:i.push({type:"text",value:r}),i}function rD(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return N7(e,t);const i={src:gu(r.url||""),alt:t.alt};r.title!==null&&r.title!==void 0&&(i.title=r.title);const s={type:"element",tagName:"img",properties:i,children:[]};return e.patch(t,s),e.applyData(t,s)}function iD(e,t){const n={src:gu(t.url)};t.alt!==null&&t.alt!==void 0&&(n.alt=t.alt),t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,r),e.applyData(t,r)}function aD(e,t){const n={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const r={type:"element",tagName:"code",properties:{},children:[n]};return e.patch(t,r),e.applyData(t,r)}function sD(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return N7(e,t);const i={href:gu(r.url||"")};r.title!==null&&r.title!==void 0&&(i.title=r.title);const s={type:"element",tagName:"a",properties:i,children:e.all(t)};return e.patch(t,s),e.applyData(t,s)}function lD(e,t){const n={href:gu(t.url)};t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function oD(e,t,n){const r=e.all(t),i=n?uD(n):O7(t),s={},o=[];if(typeof t.checked=="boolean"){const m=r[0];let p;m&&m.type==="element"&&m.tagName==="p"?p=m:(p={type:"element",tagName:"p",properties:{},children:[]},r.unshift(p)),p.children.length>0&&p.children.unshift({type:"text",value:" "}),p.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),s.className=["task-list-item"]}let c=-1;for(;++c<r.length;){const m=r[c];(i||c!==0||m.type!=="element"||m.tagName!=="p")&&o.push({type:"text",value:`
`}),m.type==="element"&&m.tagName==="p"&&!i?o.push(...m.children):o.push(m)}const d=r[r.length-1];d&&(i||d.type!=="element"||d.tagName!=="p")&&o.push({type:"text",value:`
`});const f={type:"element",tagName:"li",properties:s,children:o};return e.patch(t,f),e.applyData(t,f)}function uD(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const n=e.children;let r=-1;for(;!t&&++r<n.length;)t=O7(n[r])}return t}function O7(e){const t=e.spread;return t??e.children.length>1}function cD(e,t){const n={},r=e.all(t);let i=-1;for(typeof t.start=="number"&&t.start!==1&&(n.start=t.start);++i<r.length;){const o=r[i];if(o.type==="element"&&o.tagName==="li"&&o.properties&&Array.isArray(o.properties.className)&&o.properties.className.includes("task-list-item")){n.className=["contains-task-list"];break}}const s={type:"element",tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(r,!0)};return e.patch(t,s),e.applyData(t,s)}function dD(e,t){const n={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function hD(e,t){const n={type:"root",children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)}function fD(e,t){const n={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function mD(e,t){const n=e.all(t),r=n.shift(),i=[];if(r){const o={type:"element",tagName:"thead",properties:{},children:e.wrap([r],!0)};e.patch(t.children[0],o),i.push(o)}if(n.length>0){const o={type:"element",tagName:"tbody",properties:{},children:e.wrap(n,!0)},c=pa(t.children[1]),d=jf(t.children[t.children.length-1]);c&&d&&(o.position={start:c,end:d}),i.push(o)}const s={type:"element",tagName:"table",properties:{},children:e.wrap(i,!0)};return e.patch(t,s),e.applyData(t,s)}function pD(e,t,n){const r=n?n.children:void 0,s=(r?r.indexOf(t):1)===0?"th":"td",o=n&&n.type==="table"?n.align:void 0,c=o?o.length:t.children.length;let d=-1;const f=[];for(;++d<c;){const p=t.children[d],v={},_=o?o[d]:void 0;_&&(v.align=_);let T={type:"element",tagName:s,properties:v,children:[]};p&&(T.children=e.all(p),e.patch(p,T),T=e.applyData(p,T)),f.push(T)}const m={type:"element",tagName:"tr",properties:{},children:e.wrap(f,!0)};return e.patch(t,m),e.applyData(t,m)}function gD(e,t){const n={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}const aE=9,sE=32;function bD(e){const t=String(e),n=/\r?\n|\r/g;let r=n.exec(t),i=0;const s=[];for(;r;)s.push(lE(t.slice(i,r.index),i>0,!0),r[0]),i=r.index+r[0].length,r=n.exec(t);return s.push(lE(t.slice(i),i>0,!1)),s.join("")}function lE(e,t,n){let r=0,i=e.length;if(t){let s=e.codePointAt(r);for(;s===aE||s===sE;)r++,s=e.codePointAt(r)}if(n){let s=e.codePointAt(i-1);for(;s===aE||s===sE;)i--,s=e.codePointAt(i-1)}return i>r?e.slice(r,i):""}function vD(e,t){const n={type:"text",value:bD(String(t.value))};return e.patch(t,n),e.applyData(t,n)}function _D(e,t){const n={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,n),e.applyData(t,n)}const yD={blockquote:WI,break:XI,code:QI,delete:ZI,emphasis:JI,footnoteReference:eD,heading:tD,html:nD,imageReference:rD,image:iD,inlineCode:aD,linkReference:sD,link:lD,listItem:oD,list:cD,paragraph:dD,root:hD,strong:fD,table:mD,tableCell:gD,tableRow:pD,text:vD,thematicBreak:_D,toml:uh,yaml:uh,definition:uh,footnoteDefinition:uh};function uh(){}const R7=-1,Gf=0,Qc=1,ef=2,v2=3,_2=4,y2=5,E2=6,M7=7,I7=8,oE=typeof self=="object"?self:globalThis,ED=(e,t)=>{const n=(i,s)=>(e.set(s,i),i),r=i=>{if(e.has(i))return e.get(i);const[s,o]=t[i];switch(s){case Gf:case R7:return n(o,i);case Qc:{const c=n([],i);for(const d of o)c.push(r(d));return c}case ef:{const c=n({},i);for(const[d,f]of o)c[r(d)]=r(f);return c}case v2:return n(new Date(o),i);case _2:{const{source:c,flags:d}=o;return n(new RegExp(c,d),i)}case y2:{const c=n(new Map,i);for(const[d,f]of o)c.set(r(d),r(f));return c}case E2:{const c=n(new Set,i);for(const d of o)c.add(r(d));return c}case M7:{const{name:c,message:d}=o;return n(new oE[c](d),i)}case I7:return n(BigInt(o),i);case"BigInt":return n(Object(BigInt(o)),i);case"ArrayBuffer":return n(new Uint8Array(o).buffer,o);case"DataView":{const{buffer:c}=new Uint8Array(o);return n(new DataView(c),o)}}return n(new oE[s](o),i)};return r},uE=e=>ED(new Map,e)(0),zo="",{toString:TD}={},{keys:xD}=Object,xc=e=>{const t=typeof e;if(t!=="object"||!e)return[Gf,t];const n=TD.call(e).slice(8,-1);switch(n){case"Array":return[Qc,zo];case"Object":return[ef,zo];case"Date":return[v2,zo];case"RegExp":return[_2,zo];case"Map":return[y2,zo];case"Set":return[E2,zo];case"DataView":return[Qc,n]}return n.includes("Array")?[Qc,n]:n.includes("Error")?[M7,n]:[ef,n]},ch=([e,t])=>e===Gf&&(t==="function"||t==="symbol"),SD=(e,t,n,r)=>{const i=(o,c)=>{const d=r.push(o)-1;return n.set(c,d),d},s=o=>{if(n.has(o))return n.get(o);let[c,d]=xc(o);switch(c){case Gf:{let m=o;switch(d){case"bigint":c=I7,m=o.toString();break;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+d);m=null;break;case"undefined":return i([R7],o)}return i([c,m],o)}case Qc:{if(d){let v=o;return d==="DataView"?v=new Uint8Array(o.buffer):d==="ArrayBuffer"&&(v=new Uint8Array(o)),i([d,[...v]],o)}const m=[],p=i([c,m],o);for(const v of o)m.push(s(v));return p}case ef:{if(d)switch(d){case"BigInt":return i([d,o.toString()],o);case"Boolean":case"Number":case"String":return i([d,o.valueOf()],o)}if(t&&"toJSON"in o)return s(o.toJSON());const m=[],p=i([c,m],o);for(const v of xD(o))(e||!ch(xc(o[v])))&&m.push([s(v),s(o[v])]);return p}case v2:return i([c,o.toISOString()],o);case _2:{const{source:m,flags:p}=o;return i([c,{source:m,flags:p}],o)}case y2:{const m=[],p=i([c,m],o);for(const[v,_]of o)(e||!(ch(xc(v))||ch(xc(_))))&&m.push([s(v),s(_)]);return p}case E2:{const m=[],p=i([c,m],o);for(const v of o)(e||!ch(xc(v)))&&m.push(s(v));return p}}const{message:f}=o;return i([c,{name:d,message:f}],o)};return s},cE=(e,{json:t,lossy:n}={})=>{const r=[];return SD(!(t||n),!!t,new Map,r)(e),r},au=typeof structuredClone=="function"?(e,t)=>t&&("json"in t||"lossy"in t)?uE(cE(e,t)):structuredClone(e):(e,t)=>uE(cE(e,t));function wD(e,t){const n=[{type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(t)}]}),n}function AD(e,t){return"Back to reference "+(e+1)+(t>1?"-"+t:"")}function kD(e){const t=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||wD,r=e.options.footnoteBackLabel||AD,i=e.options.footnoteLabel||"Footnotes",s=e.options.footnoteLabelTagName||"h2",o=e.options.footnoteLabelProperties||{className:["sr-only"]},c=[];let d=-1;for(;++d<e.footnoteOrder.length;){const f=e.footnoteById.get(e.footnoteOrder[d]);if(!f)continue;const m=e.all(f),p=String(f.identifier).toUpperCase(),v=gu(p.toLowerCase());let _=0;const T=[],x=e.footnoteCounts.get(p);for(;x!==void 0&&++_<=x;){T.length>0&&T.push({type:"text",value:" "});let O=typeof n=="string"?n:n(d,_);typeof O=="string"&&(O={type:"text",value:O}),T.push({type:"element",tagName:"a",properties:{href:"#"+t+"fnref-"+v+(_>1?"-"+_:""),dataFootnoteBackref:"",ariaLabel:typeof r=="string"?r:r(d,_),className:["data-footnote-backref"]},children:Array.isArray(O)?O:[O]})}const k=m[m.length-1];if(k&&k.type==="element"&&k.tagName==="p"){const O=k.children[k.children.length-1];O&&O.type==="text"?O.value+=" ":k.children.push({type:"text",value:" "}),k.children.push(...T)}else m.push(...T);const A={type:"element",tagName:"li",properties:{id:t+"fn-"+v},children:e.wrap(m,!0)};e.patch(f,A),c.push(A)}if(c.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:s,properties:{...au(o),id:"footnote-label"},children:[{type:"text",value:i}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(c,!0)},{type:"text",value:`
`}]}}const N0=(function(e){if(e==null)return RD;if(typeof e=="function")return Yf(e);if(typeof e=="object")return Array.isArray(e)?CD(e):ND(e);if(typeof e=="string")return OD(e);throw new Error("Expected function, string, or object as test")});function CD(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=N0(e[n]);return Yf(r);function r(...i){let s=-1;for(;++s<t.length;)if(t[s].apply(this,i))return!0;return!1}}function ND(e){const t=e;return Yf(n);function n(r){const i=r;let s;for(s in e)if(i[s]!==t[s])return!1;return!0}}function OD(e){return Yf(t);function t(n){return n&&n.type===e}}function Yf(e){return t;function t(n,r,i){return!!(MD(n)&&e.call(this,n,typeof r=="number"?r:void 0,i||void 0))}}function RD(){return!0}function MD(e){return e!==null&&typeof e=="object"&&"type"in e}const D7=[],ID=!0,ib=!1,L7="skip";function T2(e,t,n,r){let i;typeof t=="function"&&typeof n!="function"?(r=n,n=t):i=t;const s=N0(i),o=r?-1:1;c(e,void 0,[])();function c(d,f,m){const p=d&&typeof d=="object"?d:{};if(typeof p.type=="string"){const _=typeof p.tagName=="string"?p.tagName:typeof p.name=="string"?p.name:void 0;Object.defineProperty(v,"name",{value:"node ("+(d.type+(_?"<"+_+">":""))+")"})}return v;function v(){let _=D7,T,x,k;if((!t||s(d,f,m[m.length-1]||void 0))&&(_=DD(n(d,m)),_[0]===ib))return _;if("children"in d&&d.children){const A=d;if(A.children&&_[0]!==L7)for(x=(r?A.children.length:-1)+o,k=m.concat(A);x>-1&&x<A.children.length;){const O=A.children[x];if(T=c(O,x,k)(),T[0]===ib)return T;x=typeof T[1]=="number"?T[1]:x+o}}return _}}}function DD(e){return Array.isArray(e)?e:typeof e=="number"?[ID,e]:e==null?D7:[e]}function O0(e,t,n,r){let i,s,o;typeof t=="function"&&typeof n!="function"?(s=void 0,o=t,i=n):(s=t,o=n,i=r),T2(e,s,c,i);function c(d,f){const m=f[f.length-1],p=m?m.children.indexOf(d):void 0;return o(d,p,m)}}const ab={}.hasOwnProperty,LD={};function PD(e,t){const n=t||LD,r=new Map,i=new Map,s=new Map,o={...yD,...n.handlers},c={all:f,applyData:UD,definitionById:r,footnoteById:i,footnoteCounts:s,footnoteOrder:[],handlers:o,one:d,options:n,patch:BD,wrap:FD};return O0(e,function(m){if(m.type==="definition"||m.type==="footnoteDefinition"){const p=m.type==="definition"?r:i,v=String(m.identifier).toUpperCase();p.has(v)||p.set(v,m)}}),c;function d(m,p){const v=m.type,_=c.handlers[v];if(ab.call(c.handlers,v)&&_)return _(c,m,p);if(c.options.passThrough&&c.options.passThrough.includes(v)){if("children"in m){const{children:x,...k}=m,A=au(k);return A.children=c.all(m),A}return au(m)}return(c.options.unknownHandler||zD)(c,m,p)}function f(m){const p=[];if("children"in m){const v=m.children;let _=-1;for(;++_<v.length;){const T=c.one(v[_],m);if(T){if(_&&v[_-1].type==="break"&&(!Array.isArray(T)&&T.type==="text"&&(T.value=dE(T.value)),!Array.isArray(T)&&T.type==="element")){const x=T.children[0];x&&x.type==="text"&&(x.value=dE(x.value))}Array.isArray(T)?p.push(...T):p.push(T)}}}return p}}function BD(e,t){e.position&&(t.position=AR(e))}function UD(e,t){let n=t;if(e&&e.data){const r=e.data.hName,i=e.data.hChildren,s=e.data.hProperties;if(typeof r=="string")if(n.type==="element")n.tagName=r;else{const o="children"in n?n.children:[n];n={type:"element",tagName:r,properties:{},children:o}}n.type==="element"&&s&&Object.assign(n.properties,au(s)),"children"in n&&n.children&&i!==null&&i!==void 0&&(n.children=i)}return n}function zD(e,t){const n=t.data||{},r="value"in t&&!(ab.call(n,"hProperties")||ab.call(n,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function FD(e,t){const n=[];let r=-1;for(t&&n.push({type:"text",value:`
`});++r<e.length;)r&&n.push({type:"text",value:`
`}),n.push(e[r]);return t&&e.length>0&&n.push({type:"text",value:`
`}),n}function dE(e){let t=0,n=e.charCodeAt(t);for(;n===9||n===32;)t++,n=e.charCodeAt(t);return e.slice(t)}function hE(e,t){const n=PD(e,t),r=n.one(e,void 0),i=kD(n),s=Array.isArray(r)?{type:"root",children:r}:r||{type:"root",children:[]};return i&&s.children.push({type:"text",value:`
`},i),s}function HD(e,t){return e&&"run"in e?async function(n,r){const i=hE(n,{file:r,...t});await e.run(i,r)}:function(n,r){return hE(n,{file:r,...e||t})}}function fE(e){if(e)throw e}var z1,mE;function jD(){if(mE)return z1;mE=1;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,r=Object.getOwnPropertyDescriptor,i=function(f){return typeof Array.isArray=="function"?Array.isArray(f):t.call(f)==="[object Array]"},s=function(f){if(!f||t.call(f)!=="[object Object]")return!1;var m=e.call(f,"constructor"),p=f.constructor&&f.constructor.prototype&&e.call(f.constructor.prototype,"isPrototypeOf");if(f.constructor&&!m&&!p)return!1;var v;for(v in f);return typeof v>"u"||e.call(f,v)},o=function(f,m){n&&m.name==="__proto__"?n(f,m.name,{enumerable:!0,configurable:!0,value:m.newValue,writable:!0}):f[m.name]=m.newValue},c=function(f,m){if(m==="__proto__")if(e.call(f,m)){if(r)return r(f,m).value}else return;return f[m]};return z1=function d(){var f,m,p,v,_,T,x=arguments[0],k=1,A=arguments.length,O=!1;for(typeof x=="boolean"&&(O=x,x=arguments[1]||{},k=2),(x==null||typeof x!="object"&&typeof x!="function")&&(x={});k<A;++k)if(f=arguments[k],f!=null)for(m in f)p=c(x,m),v=c(f,m),x!==v&&(O&&v&&(s(v)||(_=i(v)))?(_?(_=!1,T=p&&i(p)?p:[]):T=p&&s(p)?p:{},o(x,{name:m,newValue:d(O,T,v)})):typeof v<"u"&&o(x,{name:m,newValue:v}));return x},z1}var qD=jD();const F1=Of(qD);function sb(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function $D(){const e=[],t={run:n,use:r};return t;function n(...i){let s=-1;const o=i.pop();if(typeof o!="function")throw new TypeError("Expected function as last argument, not "+o);c(null,...i);function c(d,...f){const m=e[++s];let p=-1;if(d){o(d);return}for(;++p<i.length;)(f[p]===null||f[p]===void 0)&&(f[p]=i[p]);i=f,m?GD(m,c)(...f):o(null,...f)}}function r(i){if(typeof i!="function")throw new TypeError("Expected `middelware` to be a function, not "+i);return e.push(i),t}}function GD(e,t){let n;return r;function r(...o){const c=e.length>o.length;let d;c&&o.push(i);try{d=e.apply(this,o)}catch(f){const m=f;if(c&&n)throw m;return i(m)}c||(d&&d.then&&typeof d.then=="function"?d.then(s,i):d instanceof Error?i(d):s(d))}function i(o,...c){n||(n=!0,t(o,...c))}function s(o){i(null,o)}}const sa={basename:YD,dirname:VD,extname:KD,join:WD,sep:"/"};function YD(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');R0(e);let n=0,r=-1,i=e.length,s;if(t===void 0||t.length===0||t.length>e.length){for(;i--;)if(e.codePointAt(i)===47){if(s){n=i+1;break}}else r<0&&(s=!0,r=i+1);return r<0?"":e.slice(n,r)}if(t===e)return"";let o=-1,c=t.length-1;for(;i--;)if(e.codePointAt(i)===47){if(s){n=i+1;break}}else o<0&&(s=!0,o=i+1),c>-1&&(e.codePointAt(i)===t.codePointAt(c--)?c<0&&(r=i):(c=-1,r=o));return n===r?r=o:r<0&&(r=e.length),e.slice(n,r)}function VD(e){if(R0(e),e.length===0)return".";let t=-1,n=e.length,r;for(;--n;)if(e.codePointAt(n)===47){if(r){t=n;break}}else r||(r=!0);return t<0?e.codePointAt(0)===47?"/":".":t===1&&e.codePointAt(0)===47?"//":e.slice(0,t)}function KD(e){R0(e);let t=e.length,n=-1,r=0,i=-1,s=0,o;for(;t--;){const c=e.codePointAt(t);if(c===47){if(o){r=t+1;break}continue}n<0&&(o=!0,n=t+1),c===46?i<0?i=t:s!==1&&(s=1):i>-1&&(s=-1)}return i<0||n<0||s===0||s===1&&i===n-1&&i===r+1?"":e.slice(i,n)}function WD(...e){let t=-1,n;for(;++t<e.length;)R0(e[t]),e[t]&&(n=n===void 0?e[t]:n+"/"+e[t]);return n===void 0?".":XD(n)}function XD(e){R0(e);const t=e.codePointAt(0)===47;let n=QD(e,!t);return n.length===0&&!t&&(n="."),n.length>0&&e.codePointAt(e.length-1)===47&&(n+="/"),t?"/"+n:n}function QD(e,t){let n="",r=0,i=-1,s=0,o=-1,c,d;for(;++o<=e.length;){if(o<e.length)c=e.codePointAt(o);else{if(c===47)break;c=47}if(c===47){if(!(i===o-1||s===1))if(i!==o-1&&s===2){if(n.length<2||r!==2||n.codePointAt(n.length-1)!==46||n.codePointAt(n.length-2)!==46){if(n.length>2){if(d=n.lastIndexOf("/"),d!==n.length-1){d<0?(n="",r=0):(n=n.slice(0,d),r=n.length-1-n.lastIndexOf("/")),i=o,s=0;continue}}else if(n.length>0){n="",r=0,i=o,s=0;continue}}t&&(n=n.length>0?n+"/..":"..",r=2)}else n.length>0?n+="/"+e.slice(i+1,o):n=e.slice(i+1,o),r=o-i-1;i=o,s=0}else c===46&&s>-1?s++:s=-1}return n}function R0(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const ZD={cwd:JD};function JD(){return"/"}function lb(e){return!!(e!==null&&typeof e=="object"&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&e.auth===void 0)}function eL(e){if(typeof e=="string")e=new URL(e);else if(!lb(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return tL(e)}function tL(e){if(e.hostname!==""){const r=new TypeError('File URL host must be "localhost" or empty on darwin');throw r.code="ERR_INVALID_FILE_URL_HOST",r}const t=e.pathname;let n=-1;for(;++n<t.length;)if(t.codePointAt(n)===37&&t.codePointAt(n+1)===50){const r=t.codePointAt(n+2);if(r===70||r===102){const i=new TypeError("File URL path must not include encoded / characters");throw i.code="ERR_INVALID_FILE_URL_PATH",i}}return decodeURIComponent(t)}const H1=["history","path","basename","stem","extname","dirname"];class P7{constructor(t){let n;t?lb(t)?n={path:t}:typeof t=="string"||nL(t)?n={value:t}:n=t:n={},this.cwd="cwd"in n?"":ZD.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let r=-1;for(;++r<H1.length;){const s=H1[r];s in n&&n[s]!==void 0&&n[s]!==null&&(this[s]=s==="history"?[...n[s]]:n[s])}let i;for(i in n)H1.includes(i)||(this[i]=n[i])}get basename(){return typeof this.path=="string"?sa.basename(this.path):void 0}set basename(t){q1(t,"basename"),j1(t,"basename"),this.path=sa.join(this.dirname||"",t)}get dirname(){return typeof this.path=="string"?sa.dirname(this.path):void 0}set dirname(t){pE(this.basename,"dirname"),this.path=sa.join(t||"",this.basename)}get extname(){return typeof this.path=="string"?sa.extname(this.path):void 0}set extname(t){if(j1(t,"extname"),pE(this.dirname,"extname"),t){if(t.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=sa.join(this.dirname,this.stem+(t||""))}get path(){return this.history[this.history.length-1]}set path(t){lb(t)&&(t=eL(t)),q1(t,"path"),this.path!==t&&this.history.push(t)}get stem(){return typeof this.path=="string"?sa.basename(this.path,this.extname):void 0}set stem(t){q1(t,"stem"),j1(t,"stem"),this.path=sa.join(this.dirname||"",t+(this.extname||""))}fail(t,n,r){const i=this.message(t,n,r);throw i.fatal=!0,i}info(t,n,r){const i=this.message(t,n,r);return i.fatal=void 0,i}message(t,n,r){const i=new Or(t,n,r);return this.path&&(i.name=this.path+":"+i.name,i.file=this.path),i.fatal=!1,this.messages.push(i),i}toString(t){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(t||void 0).decode(this.value)}}function j1(e,t){if(e&&e.includes(sa.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+sa.sep+"`")}function q1(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function pE(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function nL(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const rL=(function(e){const r=this.constructor.prototype,i=r[e],s=function(){return i.apply(s,arguments)};return Object.setPrototypeOf(s,r),s}),iL={}.hasOwnProperty;class x2 extends rL{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=$D()}copy(){const t=new x2;let n=-1;for(;++n<this.attachers.length;){const r=this.attachers[n];t.use(...r)}return t.data(F1(!0,{},this.namespace)),t}data(t,n){return typeof t=="string"?arguments.length===2?(Y1("data",this.frozen),this.namespace[t]=n,this):iL.call(this.namespace,t)&&this.namespace[t]||void 0:t?(Y1("data",this.frozen),this.namespace=t,this):this.namespace}freeze(){if(this.frozen)return this;const t=this;for(;++this.freezeIndex<this.attachers.length;){const[n,...r]=this.attachers[this.freezeIndex];if(r[0]===!1)continue;r[0]===!0&&(r[0]=void 0);const i=n.call(t,...r);typeof i=="function"&&this.transformers.use(i)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(t){this.freeze();const n=dh(t),r=this.parser||this.Parser;return $1("parse",r),r(String(n),n)}process(t,n){const r=this;return this.freeze(),$1("process",this.parser||this.Parser),G1("process",this.compiler||this.Compiler),n?i(void 0,n):new Promise(i);function i(s,o){const c=dh(t),d=r.parse(c);r.run(d,c,function(m,p,v){if(m||!p||!v)return f(m);const _=p,T=r.stringify(_,v);lL(T)?v.value=T:v.result=T,f(m,v)});function f(m,p){m||!p?o(m):s?s(p):n(void 0,p)}}}processSync(t){let n=!1,r;return this.freeze(),$1("processSync",this.parser||this.Parser),G1("processSync",this.compiler||this.Compiler),this.process(t,i),bE("processSync","process",n),r;function i(s,o){n=!0,fE(s),r=o}}run(t,n,r){gE(t),this.freeze();const i=this.transformers;return!r&&typeof n=="function"&&(r=n,n=void 0),r?s(void 0,r):new Promise(s);function s(o,c){const d=dh(n);i.run(t,d,f);function f(m,p,v){const _=p||t;m?c(m):o?o(_):r(void 0,_,v)}}}runSync(t,n){let r=!1,i;return this.run(t,n,s),bE("runSync","run",r),i;function s(o,c){fE(o),i=c,r=!0}}stringify(t,n){this.freeze();const r=dh(n),i=this.compiler||this.Compiler;return G1("stringify",i),gE(t),i(t,r)}use(t,...n){const r=this.attachers,i=this.namespace;if(Y1("use",this.frozen),t!=null)if(typeof t=="function")d(t,n);else if(typeof t=="object")Array.isArray(t)?c(t):o(t);else throw new TypeError("Expected usable value, not `"+t+"`");return this;function s(f){if(typeof f=="function")d(f,[]);else if(typeof f=="object")if(Array.isArray(f)){const[m,...p]=f;d(m,p)}else o(f);else throw new TypeError("Expected usable value, not `"+f+"`")}function o(f){if(!("plugins"in f)&&!("settings"in f))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");c(f.plugins),f.settings&&(i.settings=F1(!0,i.settings,f.settings))}function c(f){let m=-1;if(f!=null)if(Array.isArray(f))for(;++m<f.length;){const p=f[m];s(p)}else throw new TypeError("Expected a list of plugins, not `"+f+"`")}function d(f,m){let p=-1,v=-1;for(;++p<r.length;)if(r[p][0]===f){v=p;break}if(v===-1)r.push([f,...m]);else if(m.length>0){let[_,...T]=m;const x=r[v][1];sb(x)&&sb(_)&&(_=F1(!0,x,_)),r[v]=[f,_,...T]}}}}const aL=new x2().freeze();function $1(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `parser`")}function G1(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `compiler`")}function Y1(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function gE(e){if(!sb(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function bE(e,t,n){if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function dh(e){return sL(e)?e:new P7(e)}function sL(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function lL(e){return typeof e=="string"||oL(e)}function oL(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const uL="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",vE=[],_E={allowDangerousHtml:!0},cL=/^(https?|ircs?|mailto|xmpp)$/i,dL=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"className",id:"remove-classname"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function hL(e){const t=fL(e),n=mL(e);return pL(t.runSync(t.parse(n),n),e)}function fL(e){const t=e.rehypePlugins||vE,n=e.remarkPlugins||vE,r=e.remarkRehypeOptions?{...e.remarkRehypeOptions,..._E}:_E;return aL().use(KI).use(n).use(HD,r).use(t)}function mL(e){const t=e.children||"",n=new P7;return typeof t=="string"&&(n.value=t),n}function pL(e,t){const n=t.allowedElements,r=t.allowElement,i=t.components,s=t.disallowedElements,o=t.skipHtml,c=t.unwrapDisallowed,d=t.urlTransform||gL;for(const m of dL)Object.hasOwn(t,m.from)&&(""+m.from+(m.to?"use `"+m.to+"` instead":"remove it")+uL+m.id,void 0);return O0(e,f),RR(e,{Fragment:C.Fragment,components:i,ignoreInvalidStyle:!0,jsx:C.jsx,jsxs:C.jsxs,passKeys:!0,passNode:!0});function f(m,p,v){if(m.type==="raw"&&v&&typeof p=="number")return o?v.children.splice(p,1):v.children[p]={type:"text",value:m.value},p;if(m.type==="element"){let _;for(_ in P1)if(Object.hasOwn(P1,_)&&Object.hasOwn(m.properties,_)){const T=m.properties[_],x=P1[_];(x===null||x.includes(m.tagName))&&(m.properties[_]=d(String(T||""),_,m))}}if(m.type==="element"){let _=n?!n.includes(m.tagName):s?s.includes(m.tagName):!1;if(!_&&r&&typeof p=="number"&&(_=!r(m,p,v)),_&&v&&typeof p=="number")return c&&m.children?v.children.splice(p,1,...m.children):v.children.splice(p,1),p}}}function gL(e){const t=e.indexOf(":"),n=e.indexOf("?"),r=e.indexOf("#"),i=e.indexOf("/");return t===-1||i!==-1&&t>i||n!==-1&&t>n||r!==-1&&t>r||cL.test(e.slice(0,t))?e:""}function yE(e,t){const n=String(e);if(typeof t!="string")throw new TypeError("Expected character");let r=0,i=n.indexOf(t);for(;i!==-1;)r++,i=n.indexOf(t,i+t.length);return r}function bL(e){if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function vL(e,t,n){const i=N0((n||{}).ignore||[]),s=_L(t);let o=-1;for(;++o<s.length;)T2(e,"text",c);function c(f,m){let p=-1,v;for(;++p<m.length;){const _=m[p],T=v?v.children:void 0;if(i(_,T?T.indexOf(_):void 0,v))return;v=_}if(v)return d(f,m)}function d(f,m){const p=m[m.length-1],v=s[o][0],_=s[o][1];let T=0;const k=p.children.indexOf(f);let A=!1,O=[];v.lastIndex=0;let I=v.exec(f.value);for(;I;){const $=I.index,V={index:I.index,input:I.input,stack:[...m,f]};let B=_(...I,V);if(typeof B=="string"&&(B=B.length>0?{type:"text",value:B}:void 0),B===!1?v.lastIndex=$+1:(T!==$&&O.push({type:"text",value:f.value.slice(T,$)}),Array.isArray(B)?O.push(...B):B&&O.push(B),T=$+I[0].length,A=!0),!v.global)break;I=v.exec(f.value)}return A?(T<f.value.length&&O.push({type:"text",value:f.value.slice(T)}),p.children.splice(k,1,...O)):O=[f],k+O.length}}function _L(e){const t=[];if(!Array.isArray(e))throw new TypeError("Expected find and replace tuple or list of tuples");const n=!e[0]||Array.isArray(e[0])?e:[e];let r=-1;for(;++r<n.length;){const i=n[r];t.push([yL(i[0]),EL(i[1])])}return t}function yL(e){return typeof e=="string"?new RegExp(bL(e),"g"):e}function EL(e){return typeof e=="function"?e:function(){return e}}const V1="phrasing",K1=["autolink","link","image","label"];function TL(){return{transforms:[NL],enter:{literalAutolink:SL,literalAutolinkEmail:W1,literalAutolinkHttp:W1,literalAutolinkWww:W1},exit:{literalAutolink:CL,literalAutolinkEmail:kL,literalAutolinkHttp:wL,literalAutolinkWww:AL}}}function xL(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:V1,notInConstruct:K1},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:V1,notInConstruct:K1},{character:":",before:"[ps]",after:"\\/",inConstruct:V1,notInConstruct:K1}]}}function SL(e){this.enter({type:"link",title:null,url:"",children:[]},e)}function W1(e){this.config.enter.autolinkProtocol.call(this,e)}function wL(e){this.config.exit.autolinkProtocol.call(this,e)}function AL(e){this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1];t.type,t.url="http://"+this.sliceSerialize(e)}function kL(e){this.config.exit.autolinkEmail.call(this,e)}function CL(e){this.exit(e)}function NL(e){vL(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,OL],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),RL]],{ignore:["link","linkReference"]})}function OL(e,t,n,r,i){let s="";if(!B7(i)||(/^w/i.test(t)&&(n=t+n,t="",s="http://"),!ML(n)))return!1;const o=IL(n+r);if(!o[0])return!1;const c={type:"link",title:null,url:s+t+o[0],children:[{type:"text",value:t+o[0]}]};return o[1]?[c,{type:"text",value:o[1]}]:c}function RL(e,t,n,r){return!B7(r,!0)||/[-\d_]$/.test(n)?!1:{type:"link",title:null,url:"mailto:"+t+"@"+n,children:[{type:"text",value:t+"@"+n}]}}function ML(e){const t=e.split(".");return!(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))}function IL(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e);if(!t)return[e,void 0];e=e.slice(0,t.index);let n=t[0],r=n.indexOf(")");const i=yE(e,"(");let s=yE(e,")");for(;r!==-1&&i>s;)e+=n.slice(0,r+1),n=n.slice(r+1),r=n.indexOf(")"),s++;return[e,n]}function B7(e,t){const n=e.input.charCodeAt(e.index-1);return(e.index===0||ql(n)||qf(n))&&(!t||n!==47)}U7.peek=jL;function DL(){this.buffer()}function LL(e){this.enter({type:"footnoteReference",identifier:"",label:""},e)}function PL(){this.buffer()}function BL(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},e)}function UL(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=Wi(this.sliceSerialize(e)).toLowerCase(),n.label=t}function zL(e){this.exit(e)}function FL(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=Wi(this.sliceSerialize(e)).toLowerCase(),n.label=t}function HL(e){this.exit(e)}function jL(){return"["}function U7(e,t,n,r){const i=n.createTracker(r);let s=i.move("[^");const o=n.enter("footnoteReference"),c=n.enter("reference");return s+=i.move(n.safe(n.associationId(e),{after:"]",before:s})),c(),o(),s+=i.move("]"),s}function qL(){return{enter:{gfmFootnoteCallString:DL,gfmFootnoteCall:LL,gfmFootnoteDefinitionLabelString:PL,gfmFootnoteDefinition:BL},exit:{gfmFootnoteCallString:UL,gfmFootnoteCall:zL,gfmFootnoteDefinitionLabelString:FL,gfmFootnoteDefinition:HL}}}function $L(e){let t=!1;return e&&e.firstLineBlank&&(t=!0),{handlers:{footnoteDefinition:n,footnoteReference:U7},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function n(r,i,s,o){const c=s.createTracker(o);let d=c.move("[^");const f=s.enter("footnoteDefinition"),m=s.enter("label");return d+=c.move(s.safe(s.associationId(r),{before:d,after:"]"})),m(),d+=c.move("]:"),r.children&&r.children.length>0&&(c.shift(4),d+=c.move((t?`
`:" ")+s.indentLines(s.containerFlow(r,c.current()),t?z7:GL))),f(),d}}function GL(e,t,n){return t===0?e:z7(e,t,n)}function z7(e,t,n){return(n?"":"    ")+e}const YL=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];F7.peek=QL;function VL(){return{canContainEols:["delete"],enter:{strikethrough:WL},exit:{strikethrough:XL}}}function KL(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:YL}],handlers:{delete:F7}}}function WL(e){this.enter({type:"delete",children:[]},e)}function XL(e){this.exit(e)}function F7(e,t,n,r){const i=n.createTracker(r),s=n.enter("strikethrough");let o=i.move("~~");return o+=n.containerPhrasing(e,{...i.current(),before:o,after:"~"}),o+=i.move("~~"),s(),o}function QL(){return"~"}function ZL(e){return e.length}function JL(e,t){const n=t||{},r=(n.align||[]).concat(),i=n.stringLength||ZL,s=[],o=[],c=[],d=[];let f=0,m=-1;for(;++m<e.length;){const x=[],k=[];let A=-1;for(e[m].length>f&&(f=e[m].length);++A<e[m].length;){const O=eP(e[m][A]);if(n.alignDelimiters!==!1){const I=i(O);k[A]=I,(d[A]===void 0||I>d[A])&&(d[A]=I)}x.push(O)}o[m]=x,c[m]=k}let p=-1;if(typeof r=="object"&&"length"in r)for(;++p<f;)s[p]=EE(r[p]);else{const x=EE(r);for(;++p<f;)s[p]=x}p=-1;const v=[],_=[];for(;++p<f;){const x=s[p];let k="",A="";x===99?(k=":",A=":"):x===108?k=":":x===114&&(A=":");let O=n.alignDelimiters===!1?1:Math.max(1,d[p]-k.length-A.length);const I=k+"-".repeat(O)+A;n.alignDelimiters!==!1&&(O=k.length+O+A.length,O>d[p]&&(d[p]=O),_[p]=O),v[p]=I}o.splice(1,0,v),c.splice(1,0,_),m=-1;const T=[];for(;++m<o.length;){const x=o[m],k=c[m];p=-1;const A=[];for(;++p<f;){const O=x[p]||"";let I="",$="";if(n.alignDelimiters!==!1){const V=d[p]-(k[p]||0),B=s[p];B===114?I=" ".repeat(V):B===99?V%2?(I=" ".repeat(V/2+.5),$=" ".repeat(V/2-.5)):(I=" ".repeat(V/2),$=I):$=" ".repeat(V)}n.delimiterStart!==!1&&!p&&A.push("|"),n.padding!==!1&&!(n.alignDelimiters===!1&&O==="")&&(n.delimiterStart!==!1||p)&&A.push(" "),n.alignDelimiters!==!1&&A.push(I),A.push(O),n.alignDelimiters!==!1&&A.push($),n.padding!==!1&&A.push(" "),(n.delimiterEnd!==!1||p!==f-1)&&A.push("|")}T.push(n.delimiterEnd===!1?A.join("").replace(/ +$/,""):A.join(""))}return T.join(`
`)}function eP(e){return e==null?"":String(e)}function EE(e){const t=typeof e=="string"?e.codePointAt(0):0;return t===67||t===99?99:t===76||t===108?108:t===82||t===114?114:0}const TE={}.hasOwnProperty;function H7(e,t){const n=t||{};function r(i,...s){let o=r.invalid;const c=r.handlers;if(i&&TE.call(i,e)){const d=String(i[e]);o=TE.call(c,d)?c[d]:r.unknown}if(o)return o.call(this,i,...s)}return r.handlers=n.handlers||{},r.invalid=n.invalid,r.unknown=n.unknown,r}function tP(e,t,n,r){const i=n.enter("blockquote"),s=n.createTracker(r);s.move("> "),s.shift(2);const o=n.indentLines(n.containerFlow(e,s.current()),nP);return i(),o}function nP(e,t,n){return">"+(n?"":" ")+e}function rP(e,t){return xE(e,t.inConstruct,!0)&&!xE(e,t.notInConstruct,!1)}function xE(e,t,n){if(typeof t=="string"&&(t=[t]),!t||t.length===0)return n;let r=-1;for(;++r<t.length;)if(e.includes(t[r]))return!0;return!1}function SE(e,t,n,r){let i=-1;for(;++i<n.unsafe.length;)if(n.unsafe[i].character===`
`&&rP(n.stack,n.unsafe[i]))return/[ \t]/.test(r.before)?"":" ";return`\\
`}function j7(e,t){const n=String(e);let r=n.indexOf(t),i=r,s=0,o=0;if(typeof t!="string")throw new TypeError("Expected substring");for(;r!==-1;)r===i?++s>o&&(o=s):s=1,i=r+t.length,r=n.indexOf(t,i);return o}function iP(e,t){return!!(t.options.fences===!1&&e.value&&!e.lang&&/[^ \r\n]/.test(e.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(e.value))}function aP(e){const t=e.options.fence||"`";if(t!=="`"&&t!=="~")throw new Error("Cannot serialize code with `"+t+"` for `options.fence`, expected `` ` `` or `~`");return t}function sP(e,t,n,r){const i=aP(n),s=e.value||"",o=i==="`"?"GraveAccent":"Tilde";if(iP(e,n)){const p=n.enter("codeIndented"),v=n.indentLines(s,lP);return p(),v}const c=n.createTracker(r),d=i.repeat(Math.max(j7(s,i)+1,3)),f=n.enter("codeFenced");let m=c.move(d);if(e.lang){const p=n.enter(`codeFencedLang${o}`);m+=c.move(n.safe(e.lang,{before:m,after:" ",encode:["`"],...c.current()})),p()}if(e.lang&&e.meta){const p=n.enter(`codeFencedMeta${o}`);m+=c.move(" "),m+=c.move(n.safe(e.meta,{before:m,after:`
`,encode:["`"],...c.current()})),p()}return m+=c.move(`
`),s&&(m+=c.move(s+`
`)),m+=c.move(d),f(),m}function lP(e,t,n){return(n?"":"    ")+e}function S2(e){const t=e.options.quote||'"';if(t!=='"'&&t!=="'")throw new Error("Cannot serialize title with `"+t+"` for `options.quote`, expected `\"`, or `'`");return t}function oP(e,t,n,r){const i=S2(n),s=i==='"'?"Quote":"Apostrophe",o=n.enter("definition");let c=n.enter("label");const d=n.createTracker(r);let f=d.move("[");return f+=d.move(n.safe(n.associationId(e),{before:f,after:"]",...d.current()})),f+=d.move("]: "),c(),!e.url||/[\0- \u007F]/.test(e.url)?(c=n.enter("destinationLiteral"),f+=d.move("<"),f+=d.move(n.safe(e.url,{before:f,after:">",...d.current()})),f+=d.move(">")):(c=n.enter("destinationRaw"),f+=d.move(n.safe(e.url,{before:f,after:e.title?" ":`
`,...d.current()}))),c(),e.title&&(c=n.enter(`title${s}`),f+=d.move(" "+i),f+=d.move(n.safe(e.title,{before:f,after:i,...d.current()})),f+=d.move(i),c()),o(),f}function uP(e){const t=e.options.emphasis||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize emphasis with `"+t+"` for `options.emphasis`, expected `*`, or `_`");return t}function c0(e){return"&#x"+e.toString(16).toUpperCase()+";"}function tf(e,t,n){const r=iu(e),i=iu(t);return r===void 0?i===void 0?n==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:i===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:r===1?i===void 0?{inside:!1,outside:!1}:i===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:i===void 0?{inside:!1,outside:!1}:i===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}q7.peek=cP;function q7(e,t,n,r){const i=uP(n),s=n.enter("emphasis"),o=n.createTracker(r),c=o.move(i);let d=o.move(n.containerPhrasing(e,{after:i,before:c,...o.current()}));const f=d.charCodeAt(0),m=tf(r.before.charCodeAt(r.before.length-1),f,i);m.inside&&(d=c0(f)+d.slice(1));const p=d.charCodeAt(d.length-1),v=tf(r.after.charCodeAt(0),p,i);v.inside&&(d=d.slice(0,-1)+c0(p));const _=o.move(i);return s(),n.attentionEncodeSurroundingInfo={after:v.outside,before:m.outside},c+d+_}function cP(e,t,n){return n.options.emphasis||"*"}function dP(e,t){let n=!1;return O0(e,function(r){if("value"in r&&/\r?\n|\r/.test(r.value)||r.type==="break")return n=!0,ib}),!!((!e.depth||e.depth<3)&&p2(e)&&(t.options.setext||n))}function hP(e,t,n,r){const i=Math.max(Math.min(6,e.depth||1),1),s=n.createTracker(r);if(dP(e,n)){const m=n.enter("headingSetext"),p=n.enter("phrasing"),v=n.containerPhrasing(e,{...s.current(),before:`
`,after:`
`});return p(),m(),v+`
`+(i===1?"=":"-").repeat(v.length-(Math.max(v.lastIndexOf("\r"),v.lastIndexOf(`
`))+1))}const o="#".repeat(i),c=n.enter("headingAtx"),d=n.enter("phrasing");s.move(o+" ");let f=n.containerPhrasing(e,{before:"# ",after:`
`,...s.current()});return/^[\t ]/.test(f)&&(f=c0(f.charCodeAt(0))+f.slice(1)),f=f?o+" "+f:o,n.options.closeAtx&&(f+=" "+o),d(),c(),f}$7.peek=fP;function $7(e){return e.value||""}function fP(){return"<"}G7.peek=mP;function G7(e,t,n,r){const i=S2(n),s=i==='"'?"Quote":"Apostrophe",o=n.enter("image");let c=n.enter("label");const d=n.createTracker(r);let f=d.move("![");return f+=d.move(n.safe(e.alt,{before:f,after:"]",...d.current()})),f+=d.move("]("),c(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(c=n.enter("destinationLiteral"),f+=d.move("<"),f+=d.move(n.safe(e.url,{before:f,after:">",...d.current()})),f+=d.move(">")):(c=n.enter("destinationRaw"),f+=d.move(n.safe(e.url,{before:f,after:e.title?" ":")",...d.current()}))),c(),e.title&&(c=n.enter(`title${s}`),f+=d.move(" "+i),f+=d.move(n.safe(e.title,{before:f,after:i,...d.current()})),f+=d.move(i),c()),f+=d.move(")"),o(),f}function mP(){return"!"}Y7.peek=pP;function Y7(e,t,n,r){const i=e.referenceType,s=n.enter("imageReference");let o=n.enter("label");const c=n.createTracker(r);let d=c.move("![");const f=n.safe(e.alt,{before:d,after:"]",...c.current()});d+=c.move(f+"]["),o();const m=n.stack;n.stack=[],o=n.enter("reference");const p=n.safe(n.associationId(e),{before:d,after:"]",...c.current()});return o(),n.stack=m,s(),i==="full"||!f||f!==p?d+=c.move(p+"]"):i==="shortcut"?d=d.slice(0,-1):d+=c.move("]"),d}function pP(){return"!"}V7.peek=gP;function V7(e,t,n){let r=e.value||"",i="`",s=-1;for(;new RegExp("(^|[^`])"+i+"([^`]|$)").test(r);)i+="`";for(/[^ \r\n]/.test(r)&&(/^[ \r\n]/.test(r)&&/[ \r\n]$/.test(r)||/^`|`$/.test(r))&&(r=" "+r+" ");++s<n.unsafe.length;){const o=n.unsafe[s],c=n.compilePattern(o);let d;if(o.atBreak)for(;d=c.exec(r);){let f=d.index;r.charCodeAt(f)===10&&r.charCodeAt(f-1)===13&&f--,r=r.slice(0,f)+" "+r.slice(d.index+1)}}return i+r+i}function gP(){return"`"}function K7(e,t){const n=p2(e);return!!(!t.options.resourceLink&&e.url&&!e.title&&e.children&&e.children.length===1&&e.children[0].type==="text"&&(n===e.url||"mailto:"+n===e.url)&&/^[a-z][a-z+.-]+:/i.test(e.url)&&!/[\0- <>\u007F]/.test(e.url))}W7.peek=bP;function W7(e,t,n,r){const i=S2(n),s=i==='"'?"Quote":"Apostrophe",o=n.createTracker(r);let c,d;if(K7(e,n)){const m=n.stack;n.stack=[],c=n.enter("autolink");let p=o.move("<");return p+=o.move(n.containerPhrasing(e,{before:p,after:">",...o.current()})),p+=o.move(">"),c(),n.stack=m,p}c=n.enter("link"),d=n.enter("label");let f=o.move("[");return f+=o.move(n.containerPhrasing(e,{before:f,after:"](",...o.current()})),f+=o.move("]("),d(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(d=n.enter("destinationLiteral"),f+=o.move("<"),f+=o.move(n.safe(e.url,{before:f,after:">",...o.current()})),f+=o.move(">")):(d=n.enter("destinationRaw"),f+=o.move(n.safe(e.url,{before:f,after:e.title?" ":")",...o.current()}))),d(),e.title&&(d=n.enter(`title${s}`),f+=o.move(" "+i),f+=o.move(n.safe(e.title,{before:f,after:i,...o.current()})),f+=o.move(i),d()),f+=o.move(")"),c(),f}function bP(e,t,n){return K7(e,n)?"<":"["}X7.peek=vP;function X7(e,t,n,r){const i=e.referenceType,s=n.enter("linkReference");let o=n.enter("label");const c=n.createTracker(r);let d=c.move("[");const f=n.containerPhrasing(e,{before:d,after:"]",...c.current()});d+=c.move(f+"]["),o();const m=n.stack;n.stack=[],o=n.enter("reference");const p=n.safe(n.associationId(e),{before:d,after:"]",...c.current()});return o(),n.stack=m,s(),i==="full"||!f||f!==p?d+=c.move(p+"]"):i==="shortcut"?d=d.slice(0,-1):d+=c.move("]"),d}function vP(){return"["}function w2(e){const t=e.options.bullet||"*";if(t!=="*"&&t!=="+"&&t!=="-")throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`");return t}function _P(e){const t=w2(e),n=e.options.bulletOther;if(!n)return t==="*"?"-":"*";if(n!=="*"&&n!=="+"&&n!=="-")throw new Error("Cannot serialize items with `"+n+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(n===t)throw new Error("Expected `bullet` (`"+t+"`) and `bulletOther` (`"+n+"`) to be different");return n}function yP(e){const t=e.options.bulletOrdered||".";if(t!=="."&&t!==")")throw new Error("Cannot serialize items with `"+t+"` for `options.bulletOrdered`, expected `.` or `)`");return t}function Q7(e){const t=e.options.rule||"*";if(t!=="*"&&t!=="-"&&t!=="_")throw new Error("Cannot serialize rules with `"+t+"` for `options.rule`, expected `*`, `-`, or `_`");return t}function EP(e,t,n,r){const i=n.enter("list"),s=n.bulletCurrent;let o=e.ordered?yP(n):w2(n);const c=e.ordered?o==="."?")":".":_P(n);let d=t&&n.bulletLastUsed?o===n.bulletLastUsed:!1;if(!e.ordered){const m=e.children?e.children[0]:void 0;if((o==="*"||o==="-")&&m&&(!m.children||!m.children[0])&&n.stack[n.stack.length-1]==="list"&&n.stack[n.stack.length-2]==="listItem"&&n.stack[n.stack.length-3]==="list"&&n.stack[n.stack.length-4]==="listItem"&&n.indexStack[n.indexStack.length-1]===0&&n.indexStack[n.indexStack.length-2]===0&&n.indexStack[n.indexStack.length-3]===0&&(d=!0),Q7(n)===o&&m){let p=-1;for(;++p<e.children.length;){const v=e.children[p];if(v&&v.type==="listItem"&&v.children&&v.children[0]&&v.children[0].type==="thematicBreak"){d=!0;break}}}}d&&(o=c),n.bulletCurrent=o;const f=n.containerFlow(e,r);return n.bulletLastUsed=o,n.bulletCurrent=s,i(),f}function TP(e){const t=e.options.listItemIndent||"one";if(t!=="tab"&&t!=="one"&&t!=="mixed")throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return t}function xP(e,t,n,r){const i=TP(n);let s=n.bulletCurrent||w2(n);t&&t.type==="list"&&t.ordered&&(s=(typeof t.start=="number"&&t.start>-1?t.start:1)+(n.options.incrementListMarker===!1?0:t.children.indexOf(e))+s);let o=s.length+1;(i==="tab"||i==="mixed"&&(t&&t.type==="list"&&t.spread||e.spread))&&(o=Math.ceil(o/4)*4);const c=n.createTracker(r);c.move(s+" ".repeat(o-s.length)),c.shift(o);const d=n.enter("listItem"),f=n.indentLines(n.containerFlow(e,c.current()),m);return d(),f;function m(p,v,_){return v?(_?"":" ".repeat(o))+p:(_?s:s+" ".repeat(o-s.length))+p}}function SP(e,t,n,r){const i=n.enter("paragraph"),s=n.enter("phrasing"),o=n.containerPhrasing(e,r);return s(),i(),o}const wP=N0(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function AP(e,t,n,r){return(e.children.some(function(o){return wP(o)})?n.containerPhrasing:n.containerFlow).call(n,e,r)}function kP(e){const t=e.options.strong||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize strong with `"+t+"` for `options.strong`, expected `*`, or `_`");return t}Z7.peek=CP;function Z7(e,t,n,r){const i=kP(n),s=n.enter("strong"),o=n.createTracker(r),c=o.move(i+i);let d=o.move(n.containerPhrasing(e,{after:i,before:c,...o.current()}));const f=d.charCodeAt(0),m=tf(r.before.charCodeAt(r.before.length-1),f,i);m.inside&&(d=c0(f)+d.slice(1));const p=d.charCodeAt(d.length-1),v=tf(r.after.charCodeAt(0),p,i);v.inside&&(d=d.slice(0,-1)+c0(p));const _=o.move(i+i);return s(),n.attentionEncodeSurroundingInfo={after:v.outside,before:m.outside},c+d+_}function CP(e,t,n){return n.options.strong||"*"}function NP(e,t,n,r){return n.safe(e.value,r)}function OP(e){const t=e.options.ruleRepetition||3;if(t<3)throw new Error("Cannot serialize rules with repetition `"+t+"` for `options.ruleRepetition`, expected `3` or more");return t}function RP(e,t,n){const r=(Q7(n)+(n.options.ruleSpaces?" ":"")).repeat(OP(n));return n.options.ruleSpaces?r.slice(0,-1):r}const J7={blockquote:tP,break:SE,code:sP,definition:oP,emphasis:q7,hardBreak:SE,heading:hP,html:$7,image:G7,imageReference:Y7,inlineCode:V7,link:W7,linkReference:X7,list:EP,listItem:xP,paragraph:SP,root:AP,strong:Z7,text:NP,thematicBreak:RP};function MP(){return{enter:{table:IP,tableData:wE,tableHeader:wE,tableRow:LP},exit:{codeText:PP,table:DP,tableData:X1,tableHeader:X1,tableRow:X1}}}function IP(e){const t=e._align;this.enter({type:"table",align:t.map(function(n){return n==="none"?null:n}),children:[]},e),this.data.inTable=!0}function DP(e){this.exit(e),this.data.inTable=void 0}function LP(e){this.enter({type:"tableRow",children:[]},e)}function X1(e){this.exit(e)}function wE(e){this.enter({type:"tableCell",children:[]},e)}function PP(e){let t=this.resume();this.data.inTable&&(t=t.replace(/\\([\\|])/g,BP));const n=this.stack[this.stack.length-1];n.type,n.value=t,this.exit(e)}function BP(e,t){return t==="|"?t:e}function UP(e){const t=e||{},n=t.tableCellPadding,r=t.tablePipeAlign,i=t.stringLength,s=n?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:v,table:o,tableCell:d,tableRow:c}};function o(_,T,x,k){return f(m(_,x,k),_.align)}function c(_,T,x,k){const A=p(_,x,k),O=f([A]);return O.slice(0,O.indexOf(`
`))}function d(_,T,x,k){const A=x.enter("tableCell"),O=x.enter("phrasing"),I=x.containerPhrasing(_,{...k,before:s,after:s});return O(),A(),I}function f(_,T){return JL(_,{align:T,alignDelimiters:r,padding:n,stringLength:i})}function m(_,T,x){const k=_.children;let A=-1;const O=[],I=T.enter("table");for(;++A<k.length;)O[A]=p(k[A],T,x);return I(),O}function p(_,T,x){const k=_.children;let A=-1;const O=[],I=T.enter("tableRow");for(;++A<k.length;)O[A]=d(k[A],_,T,x);return I(),O}function v(_,T,x){let k=J7.inlineCode(_,T,x);return x.stack.includes("tableCell")&&(k=k.replace(/\|/g,"\\$&")),k}}function zP(){return{exit:{taskListCheckValueChecked:AE,taskListCheckValueUnchecked:AE,paragraph:HP}}}function FP(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:jP}}}function AE(e){const t=this.stack[this.stack.length-2];t.type,t.checked=e.type==="taskListCheckValueChecked"}function HP(e){const t=this.stack[this.stack.length-2];if(t&&t.type==="listItem"&&typeof t.checked=="boolean"){const n=this.stack[this.stack.length-1];n.type;const r=n.children[0];if(r&&r.type==="text"){const i=t.children;let s=-1,o;for(;++s<i.length;){const c=i[s];if(c.type==="paragraph"){o=c;break}}o===n&&(r.value=r.value.slice(1),r.value.length===0?n.children.shift():n.position&&r.position&&typeof r.position.start.offset=="number"&&(r.position.start.column++,r.position.start.offset++,n.position.start=Object.assign({},r.position.start)))}}this.exit(e)}function jP(e,t,n,r){const i=e.children[0],s=typeof e.checked=="boolean"&&i&&i.type==="paragraph",o="["+(e.checked?"x":" ")+"] ",c=n.createTracker(r);s&&c.move(o);let d=J7.listItem(e,t,n,{...r,...c.current()});return s&&(d=d.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,f)),d;function f(m){return m+o}}function qP(){return[TL(),qL(),VL(),MP(),zP()]}function $P(e){return{extensions:[xL(),$L(e),KL(),UP(e),FP()]}}const GP={tokenize:QP,partial:!0},eT={tokenize:ZP,partial:!0},tT={tokenize:JP,partial:!0},nT={tokenize:eB,partial:!0},YP={tokenize:tB,partial:!0},rT={name:"wwwAutolink",tokenize:WP,previous:aT},iT={name:"protocolAutolink",tokenize:XP,previous:sT},ds={name:"emailAutolink",tokenize:KP,previous:lT},ga={};function VP(){return{text:ga}}let Il=48;for(;Il<123;)ga[Il]=ds,Il++,Il===58?Il=65:Il===91&&(Il=97);ga[43]=ds;ga[45]=ds;ga[46]=ds;ga[95]=ds;ga[72]=[ds,iT];ga[104]=[ds,iT];ga[87]=[ds,rT];ga[119]=[ds,rT];function KP(e,t,n){const r=this;let i,s;return o;function o(p){return!ob(p)||!lT.call(r,r.previous)||A2(r.events)?n(p):(e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),c(p))}function c(p){return ob(p)?(e.consume(p),c):p===64?(e.consume(p),d):n(p)}function d(p){return p===46?e.check(YP,m,f)(p):p===45||p===95||Nr(p)?(s=!0,e.consume(p),d):m(p)}function f(p){return e.consume(p),i=!0,d}function m(p){return s&&i&&Fr(r.previous)?(e.exit("literalAutolinkEmail"),e.exit("literalAutolink"),t(p)):n(p)}}function WP(e,t,n){const r=this;return i;function i(o){return o!==87&&o!==119||!aT.call(r,r.previous)||A2(r.events)?n(o):(e.enter("literalAutolink"),e.enter("literalAutolinkWww"),e.check(GP,e.attempt(eT,e.attempt(tT,s),n),n)(o))}function s(o){return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(o)}}function XP(e,t,n){const r=this;let i="",s=!1;return o;function o(p){return(p===72||p===104)&&sT.call(r,r.previous)&&!A2(r.events)?(e.enter("literalAutolink"),e.enter("literalAutolinkHttp"),i+=String.fromCodePoint(p),e.consume(p),c):n(p)}function c(p){if(Fr(p)&&i.length<5)return i+=String.fromCodePoint(p),e.consume(p),c;if(p===58){const v=i.toLowerCase();if(v==="http"||v==="https")return e.consume(p),d}return n(p)}function d(p){return p===47?(e.consume(p),s?f:(s=!0,d)):n(p)}function f(p){return p===null||Jh(p)||fn(p)||ql(p)||qf(p)?n(p):e.attempt(eT,e.attempt(tT,m),n)(p)}function m(p){return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(p)}}function QP(e,t,n){let r=0;return i;function i(o){return(o===87||o===119)&&r<3?(r++,e.consume(o),i):o===46&&r===3?(e.consume(o),s):n(o)}function s(o){return o===null?n(o):t(o)}}function ZP(e,t,n){let r,i,s;return o;function o(f){return f===46||f===95?e.check(nT,d,c)(f):f===null||fn(f)||ql(f)||f!==45&&qf(f)?d(f):(s=!0,e.consume(f),o)}function c(f){return f===95?r=!0:(i=r,r=void 0),e.consume(f),o}function d(f){return i||r||!s?n(f):t(f)}}function JP(e,t){let n=0,r=0;return i;function i(o){return o===40?(n++,e.consume(o),i):o===41&&r<n?s(o):o===33||o===34||o===38||o===39||o===41||o===42||o===44||o===46||o===58||o===59||o===60||o===63||o===93||o===95||o===126?e.check(nT,t,s)(o):o===null||fn(o)||ql(o)?t(o):(e.consume(o),i)}function s(o){return o===41&&r++,e.consume(o),i}}function eB(e,t,n){return r;function r(c){return c===33||c===34||c===39||c===41||c===42||c===44||c===46||c===58||c===59||c===63||c===95||c===126?(e.consume(c),r):c===38?(e.consume(c),s):c===93?(e.consume(c),i):c===60||c===null||fn(c)||ql(c)?t(c):n(c)}function i(c){return c===null||c===40||c===91||fn(c)||ql(c)?t(c):r(c)}function s(c){return Fr(c)?o(c):n(c)}function o(c){return c===59?(e.consume(c),r):Fr(c)?(e.consume(c),o):n(c)}}function tB(e,t,n){return r;function r(s){return e.consume(s),i}function i(s){return Nr(s)?n(s):t(s)}}function aT(e){return e===null||e===40||e===42||e===95||e===91||e===93||e===126||fn(e)}function sT(e){return!Fr(e)}function lT(e){return!(e===47||ob(e))}function ob(e){return e===43||e===45||e===46||e===95||Nr(e)}function A2(e){let t=e.length,n=!1;for(;t--;){const r=e[t][1];if((r.type==="labelLink"||r.type==="labelImage")&&!r._balanced){n=!0;break}if(r._gfmAutolinkLiteralWalkedInto){n=!1;break}}return e.length>0&&!n&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),n}const nB={tokenize:cB,partial:!0};function rB(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:lB,continuation:{tokenize:oB},exit:uB}},text:{91:{name:"gfmFootnoteCall",tokenize:sB},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:iB,resolveTo:aB}}}}function iB(e,t,n){const r=this;let i=r.events.length;const s=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let o;for(;i--;){const d=r.events[i][1];if(d.type==="labelImage"){o=d;break}if(d.type==="gfmFootnoteCall"||d.type==="labelLink"||d.type==="label"||d.type==="image"||d.type==="link")break}return c;function c(d){if(!o||!o._balanced)return n(d);const f=Wi(r.sliceSerialize({start:o.end,end:r.now()}));return f.codePointAt(0)!==94||!s.includes(f.slice(1))?n(d):(e.enter("gfmFootnoteCallLabelMarker"),e.consume(d),e.exit("gfmFootnoteCallLabelMarker"),t(d))}}function aB(e,t){let n=e.length;for(;n--;)if(e[n][1].type==="labelImage"&&e[n][0]==="enter"){e[n][1];break}e[n+1][1].type="data",e[n+3][1].type="gfmFootnoteCallLabelMarker";const r={type:"gfmFootnoteCall",start:Object.assign({},e[n+3][1].start),end:Object.assign({},e[e.length-1][1].end)},i={type:"gfmFootnoteCallMarker",start:Object.assign({},e[n+3][1].end),end:Object.assign({},e[n+3][1].end)};i.end.column++,i.end.offset++,i.end._bufferIndex++;const s={type:"gfmFootnoteCallString",start:Object.assign({},i.end),end:Object.assign({},e[e.length-1][1].start)},o={type:"chunkString",contentType:"string",start:Object.assign({},s.start),end:Object.assign({},s.end)},c=[e[n+1],e[n+2],["enter",r,t],e[n+3],e[n+4],["enter",i,t],["exit",i,t],["enter",s,t],["enter",o,t],["exit",o,t],["exit",s,t],e[e.length-2],e[e.length-1],["exit",r,t]];return e.splice(n,e.length-n+1,...c),e}function sB(e,t,n){const r=this,i=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let s=0,o;return c;function c(p){return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),e.consume(p),e.exit("gfmFootnoteCallLabelMarker"),d}function d(p){return p!==94?n(p):(e.enter("gfmFootnoteCallMarker"),e.consume(p),e.exit("gfmFootnoteCallMarker"),e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",f)}function f(p){if(s>999||p===93&&!o||p===null||p===91||fn(p))return n(p);if(p===93){e.exit("chunkString");const v=e.exit("gfmFootnoteCallString");return i.includes(Wi(r.sliceSerialize(v)))?(e.enter("gfmFootnoteCallLabelMarker"),e.consume(p),e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):n(p)}return fn(p)||(o=!0),s++,e.consume(p),p===92?m:f}function m(p){return p===91||p===92||p===93?(e.consume(p),s++,f):f(p)}}function lB(e,t,n){const r=this,i=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let s,o=0,c;return d;function d(T){return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(T),e.exit("gfmFootnoteDefinitionLabelMarker"),f}function f(T){return T===94?(e.enter("gfmFootnoteDefinitionMarker"),e.consume(T),e.exit("gfmFootnoteDefinitionMarker"),e.enter("gfmFootnoteDefinitionLabelString"),e.enter("chunkString").contentType="string",m):n(T)}function m(T){if(o>999||T===93&&!c||T===null||T===91||fn(T))return n(T);if(T===93){e.exit("chunkString");const x=e.exit("gfmFootnoteDefinitionLabelString");return s=Wi(r.sliceSerialize(x)),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(T),e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),v}return fn(T)||(c=!0),o++,e.consume(T),T===92?p:m}function p(T){return T===91||T===92||T===93?(e.consume(T),o++,m):m(T)}function v(T){return T===58?(e.enter("definitionMarker"),e.consume(T),e.exit("definitionMarker"),i.includes(s)||i.push(s),Ot(e,_,"gfmFootnoteDefinitionWhitespace")):n(T)}function _(T){return t(T)}}function oB(e,t,n){return e.check(C0,t,e.attempt(nB,t,n))}function uB(e){e.exit("gfmFootnoteDefinition")}function cB(e,t,n){const r=this;return Ot(e,i,"gfmFootnoteDefinitionIndent",5);function i(s){const o=r.events[r.events.length-1];return o&&o[1].type==="gfmFootnoteDefinitionIndent"&&o[2].sliceSerialize(o[1],!0).length===4?t(s):n(s)}}function dB(e){let n=(e||{}).singleTilde;const r={name:"strikethrough",tokenize:s,resolveAll:i};return n==null&&(n=!0),{text:{126:r},insideSpan:{null:[r]},attentionMarkers:{null:[126]}};function i(o,c){let d=-1;for(;++d<o.length;)if(o[d][0]==="enter"&&o[d][1].type==="strikethroughSequenceTemporary"&&o[d][1]._close){let f=d;for(;f--;)if(o[f][0]==="exit"&&o[f][1].type==="strikethroughSequenceTemporary"&&o[f][1]._open&&o[d][1].end.offset-o[d][1].start.offset===o[f][1].end.offset-o[f][1].start.offset){o[d][1].type="strikethroughSequence",o[f][1].type="strikethroughSequence";const m={type:"strikethrough",start:Object.assign({},o[f][1].start),end:Object.assign({},o[d][1].end)},p={type:"strikethroughText",start:Object.assign({},o[f][1].end),end:Object.assign({},o[d][1].start)},v=[["enter",m,c],["enter",o[f][1],c],["exit",o[f][1],c],["enter",p,c]],_=c.parser.constructs.insideSpan.null;_&&Ei(v,v.length,0,$f(_,o.slice(f+1,d),c)),Ei(v,v.length,0,[["exit",p,c],["enter",o[d][1],c],["exit",o[d][1],c],["exit",m,c]]),Ei(o,f-1,d-f+3,v),d=f+v.length-2;break}}for(d=-1;++d<o.length;)o[d][1].type==="strikethroughSequenceTemporary"&&(o[d][1].type="data");return o}function s(o,c,d){const f=this.previous,m=this.events;let p=0;return v;function v(T){return f===126&&m[m.length-1][1].type!=="characterEscape"?d(T):(o.enter("strikethroughSequenceTemporary"),_(T))}function _(T){const x=iu(f);if(T===126)return p>1?d(T):(o.consume(T),p++,_);if(p<2&&!n)return d(T);const k=o.exit("strikethroughSequenceTemporary"),A=iu(T);return k._open=!A||A===2&&!!x,k._close=!x||x===2&&!!A,c(T)}}}class hB{constructor(){this.map=[]}add(t,n,r){fB(this,t,n,r)}consume(t){if(this.map.sort(function(s,o){return s[0]-o[0]}),this.map.length===0)return;let n=this.map.length;const r=[];for(;n>0;)n-=1,r.push(t.slice(this.map[n][0]+this.map[n][1]),this.map[n][2]),t.length=this.map[n][0];r.push(t.slice()),t.length=0;let i=r.pop();for(;i;){for(const s of i)t.push(s);i=r.pop()}this.map.length=0}}function fB(e,t,n,r){let i=0;if(!(n===0&&r.length===0)){for(;i<e.map.length;){if(e.map[i][0]===t){e.map[i][1]+=n,e.map[i][2].push(...r);return}i+=1}e.map.push([t,n,r])}}function mB(e,t){let n=!1;const r=[];for(;t<e.length;){const i=e[t];if(n){if(i[0]==="enter")i[1].type==="tableContent"&&r.push(e[t+1][1].type==="tableDelimiterMarker"?"left":"none");else if(i[1].type==="tableContent"){if(e[t-1][1].type==="tableDelimiterMarker"){const s=r.length-1;r[s]=r[s]==="left"?"center":"right"}}else if(i[1].type==="tableDelimiterRow")break}else i[0]==="enter"&&i[1].type==="tableDelimiterRow"&&(n=!0);t+=1}return r}function pB(){return{flow:{null:{name:"table",tokenize:gB,resolveAll:bB}}}}function gB(e,t,n){const r=this;let i=0,s=0,o;return c;function c(Y){let oe=r.events.length-1;for(;oe>-1;){const fe=r.events[oe][1].type;if(fe==="lineEnding"||fe==="linePrefix")oe--;else break}const he=oe>-1?r.events[oe][1].type:null,Se=he==="tableHead"||he==="tableRow"?B:d;return Se===B&&r.parser.lazy[r.now().line]?n(Y):Se(Y)}function d(Y){return e.enter("tableHead"),e.enter("tableRow"),f(Y)}function f(Y){return Y===124||(o=!0,s+=1),m(Y)}function m(Y){return Y===null?n(Y):tt(Y)?s>1?(s=0,r.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),e.consume(Y),e.exit("lineEnding"),_):n(Y):Lt(Y)?Ot(e,m,"whitespace")(Y):(s+=1,o&&(o=!1,i+=1),Y===124?(e.enter("tableCellDivider"),e.consume(Y),e.exit("tableCellDivider"),o=!0,m):(e.enter("data"),p(Y)))}function p(Y){return Y===null||Y===124||fn(Y)?(e.exit("data"),m(Y)):(e.consume(Y),Y===92?v:p)}function v(Y){return Y===92||Y===124?(e.consume(Y),p):p(Y)}function _(Y){return r.interrupt=!1,r.parser.lazy[r.now().line]?n(Y):(e.enter("tableDelimiterRow"),o=!1,Lt(Y)?Ot(e,T,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(Y):T(Y))}function T(Y){return Y===45||Y===58?k(Y):Y===124?(o=!0,e.enter("tableCellDivider"),e.consume(Y),e.exit("tableCellDivider"),x):V(Y)}function x(Y){return Lt(Y)?Ot(e,k,"whitespace")(Y):k(Y)}function k(Y){return Y===58?(s+=1,o=!0,e.enter("tableDelimiterMarker"),e.consume(Y),e.exit("tableDelimiterMarker"),A):Y===45?(s+=1,A(Y)):Y===null||tt(Y)?$(Y):V(Y)}function A(Y){return Y===45?(e.enter("tableDelimiterFiller"),O(Y)):V(Y)}function O(Y){return Y===45?(e.consume(Y),O):Y===58?(o=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),e.consume(Y),e.exit("tableDelimiterMarker"),I):(e.exit("tableDelimiterFiller"),I(Y))}function I(Y){return Lt(Y)?Ot(e,$,"whitespace")(Y):$(Y)}function $(Y){return Y===124?T(Y):Y===null||tt(Y)?!o||i!==s?V(Y):(e.exit("tableDelimiterRow"),e.exit("tableHead"),t(Y)):V(Y)}function V(Y){return n(Y)}function B(Y){return e.enter("tableRow"),Z(Y)}function Z(Y){return Y===124?(e.enter("tableCellDivider"),e.consume(Y),e.exit("tableCellDivider"),Z):Y===null||tt(Y)?(e.exit("tableRow"),t(Y)):Lt(Y)?Ot(e,Z,"whitespace")(Y):(e.enter("data"),ee(Y))}function ee(Y){return Y===null||Y===124||fn(Y)?(e.exit("data"),Z(Y)):(e.consume(Y),Y===92?te:ee)}function te(Y){return Y===92||Y===124?(e.consume(Y),ee):ee(Y)}}function bB(e,t){let n=-1,r=!0,i=0,s=[0,0,0,0],o=[0,0,0,0],c=!1,d=0,f,m,p;const v=new hB;for(;++n<e.length;){const _=e[n],T=_[1];_[0]==="enter"?T.type==="tableHead"?(c=!1,d!==0&&(kE(v,t,d,f,m),m=void 0,d=0),f={type:"table",start:Object.assign({},T.start),end:Object.assign({},T.end)},v.add(n,0,[["enter",f,t]])):T.type==="tableRow"||T.type==="tableDelimiterRow"?(r=!0,p=void 0,s=[0,0,0,0],o=[0,n+1,0,0],c&&(c=!1,m={type:"tableBody",start:Object.assign({},T.start),end:Object.assign({},T.end)},v.add(n,0,[["enter",m,t]])),i=T.type==="tableDelimiterRow"?2:m?3:1):i&&(T.type==="data"||T.type==="tableDelimiterMarker"||T.type==="tableDelimiterFiller")?(r=!1,o[2]===0&&(s[1]!==0&&(o[0]=o[1],p=hh(v,t,s,i,void 0,p),s=[0,0,0,0]),o[2]=n)):T.type==="tableCellDivider"&&(r?r=!1:(s[1]!==0&&(o[0]=o[1],p=hh(v,t,s,i,void 0,p)),s=o,o=[s[1],n,0,0])):T.type==="tableHead"?(c=!0,d=n):T.type==="tableRow"||T.type==="tableDelimiterRow"?(d=n,s[1]!==0?(o[0]=o[1],p=hh(v,t,s,i,n,p)):o[1]!==0&&(p=hh(v,t,o,i,n,p)),i=0):i&&(T.type==="data"||T.type==="tableDelimiterMarker"||T.type==="tableDelimiterFiller")&&(o[3]=n)}for(d!==0&&kE(v,t,d,f,m),v.consume(t.events),n=-1;++n<t.events.length;){const _=t.events[n];_[0]==="enter"&&_[1].type==="table"&&(_[1]._align=mB(t.events,n))}return e}function hh(e,t,n,r,i,s){const o=r===1?"tableHeader":r===2?"tableDelimiter":"tableData",c="tableContent";n[0]!==0&&(s.end=Object.assign({},Go(t.events,n[0])),e.add(n[0],0,[["exit",s,t]]));const d=Go(t.events,n[1]);if(s={type:o,start:Object.assign({},d),end:Object.assign({},d)},e.add(n[1],0,[["enter",s,t]]),n[2]!==0){const f=Go(t.events,n[2]),m=Go(t.events,n[3]),p={type:c,start:Object.assign({},f),end:Object.assign({},m)};if(e.add(n[2],0,[["enter",p,t]]),r!==2){const v=t.events[n[2]],_=t.events[n[3]];if(v[1].end=Object.assign({},_[1].end),v[1].type="chunkText",v[1].contentType="text",n[3]>n[2]+1){const T=n[2]+1,x=n[3]-n[2]-1;e.add(T,x,[])}}e.add(n[3]+1,0,[["exit",p,t]])}return i!==void 0&&(s.end=Object.assign({},Go(t.events,i)),e.add(i,0,[["exit",s,t]]),s=void 0),s}function kE(e,t,n,r,i){const s=[],o=Go(t.events,n);i&&(i.end=Object.assign({},o),s.push(["exit",i,t])),r.end=Object.assign({},o),s.push(["exit",r,t]),e.add(n+1,0,s)}function Go(e,t){const n=e[t],r=n[0]==="enter"?"start":"end";return n[1][r]}const vB={name:"tasklistCheck",tokenize:yB};function _B(){return{text:{91:vB}}}function yB(e,t,n){const r=this;return i;function i(d){return r.previous!==null||!r._gfmTasklistFirstContentOfListItem?n(d):(e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(d),e.exit("taskListCheckMarker"),s)}function s(d){return fn(d)?(e.enter("taskListCheckValueUnchecked"),e.consume(d),e.exit("taskListCheckValueUnchecked"),o):d===88||d===120?(e.enter("taskListCheckValueChecked"),e.consume(d),e.exit("taskListCheckValueChecked"),o):n(d)}function o(d){return d===93?(e.enter("taskListCheckMarker"),e.consume(d),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),c):n(d)}function c(d){return tt(d)?t(d):Lt(d)?e.check({tokenize:EB},t,n)(d):n(d)}}function EB(e,t,n){return Ot(e,r,"whitespace");function r(i){return i===null?n(i):t(i)}}function TB(e){return g7([VP(),rB(),dB(e),pB(),_B()])}const xB={};function SB(e){const t=this,n=e||xB,r=t.data(),i=r.micromarkExtensions||(r.micromarkExtensions=[]),s=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),o=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);i.push(TB(n)),s.push(qP()),o.push($P(n))}const CE=/[#.]/g;function wB(e,t){const n=e||"",r={};let i=0,s,o;for(;i<n.length;){CE.lastIndex=i;const c=CE.exec(n),d=n.slice(i,c?c.index:n.length);d&&(s?s==="#"?r.id=d:Array.isArray(r.className)?r.className.push(d):r.className=[d]:o=d,i+=d.length),c&&(s=c[0],i++)}return{type:"element",tagName:o||t||"div",properties:r,children:[]}}function oT(e,t,n){const r=n?NB(n):void 0;function i(s,o,...c){let d;if(s==null){d={type:"root",children:[]};const f=o;c.unshift(f)}else{d=wB(s,t);const f=d.tagName.toLowerCase(),m=r?r.get(f):void 0;if(d.tagName=m||f,AB(o))c.unshift(o);else for(const[p,v]of Object.entries(o))kB(e,d.properties,p,v)}for(const f of c)ub(d.children,f);return d.type==="element"&&d.tagName==="template"&&(d.content={type:"root",children:d.children},d.children=[]),d}return i}function AB(e){if(e===null||typeof e!="object"||Array.isArray(e))return!0;if(typeof e.type!="string")return!1;const t=e,n=Object.keys(e);for(const r of n){const i=t[r];if(i&&typeof i=="object"){if(!Array.isArray(i))return!0;const s=i;for(const o of s)if(typeof o!="number"&&typeof o!="string")return!0}}return!!("children"in e&&Array.isArray(e.children))}function kB(e,t,n,r){const i=Hf(e,n);let s;if(r!=null){if(typeof r=="number"){if(Number.isNaN(r))return;s=r}else typeof r=="boolean"?s=r:typeof r=="string"?i.spaceSeparated?s=Hy(r):i.commaSeparated?s=Py(r):i.commaOrSpaceSeparated?s=Hy(Py(r).join(" ")):s=NE(i,i.property,r):Array.isArray(r)?s=[...r]:s=i.property==="style"?CB(r):String(r);if(Array.isArray(s)){const o=[];for(const c of s)o.push(NE(i,i.property,c));s=o}i.property==="className"&&Array.isArray(t.className)&&(s=t.className.concat(s)),t[i.property]=s}}function ub(e,t){if(t!=null)if(typeof t=="number"||typeof t=="string")e.push({type:"text",value:String(t)});else if(Array.isArray(t))for(const n of t)ub(e,n);else if(typeof t=="object"&&"type"in t)t.type==="root"?ub(e,t.children):e.push(t);else throw new Error("Expected node, nodes, or string, got `"+t+"`")}function NE(e,t,n){if(typeof n=="string"){if(e.number&&n&&!Number.isNaN(Number(n)))return Number(n);if((e.boolean||e.overloadedBoolean)&&(n===""||o0(n)===o0(t)))return!0}return n}function CB(e){const t=[];for(const[n,r]of Object.entries(e))t.push([n,r].join(": "));return t.join("; ")}function NB(e){const t=new Map;for(const n of e)t.set(n.toLowerCase(),n);return t}const OB=["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","solidColor","textArea","textPath"],uT=oT(k0,"div"),cT=oT(ol,"g",OB);function RB(e){const t=String(e),n=[];return{toOffset:i,toPoint:r};function r(s){if(typeof s=="number"&&s>-1&&s<=t.length){let o=0;for(;;){let c=n[o];if(c===void 0){const d=OE(t,n[o-1]);c=d===-1?t.length+1:d+1,n[o]=c}if(c>s)return{line:o+1,column:s-(o>0?n[o-1]:0)+1,offset:s};o++}}}function i(s){if(s&&typeof s.line=="number"&&typeof s.column=="number"&&!Number.isNaN(s.line)&&!Number.isNaN(s.column)){for(;n.length<s.line;){const c=n[n.length-1],d=OE(t,c),f=d===-1?t.length+1:d+1;if(c===f)break;n.push(f)}const o=(s.line>1?n[s.line-2]:0)+s.column-1;if(o<n[s.line-1])return o}}}function OE(e,t){const n=e.indexOf("\r",t),r=e.indexOf(`
`,t);return r===-1?n:n===-1||n+1===r?r:n<r?n:r}const ca={html:"http://www.w3.org/1999/xhtml",mathml:"http://www.w3.org/1998/Math/MathML",svg:"http://www.w3.org/2000/svg",xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"},dT={}.hasOwnProperty,MB=Object.prototype;function IB(e,t){const n=t||{};return k2({file:n.file||void 0,location:!1,schema:n.space==="svg"?ol:k0,verbose:n.verbose||!1},e)}function k2(e,t){let n;switch(t.nodeName){case"#comment":{const r=t;return n={type:"comment",value:r.data},jh(e,r,n),n}case"#document":case"#document-fragment":{const r=t,i="mode"in r?r.mode==="quirks"||r.mode==="limited-quirks":!1;if(n={type:"root",children:hT(e,t.childNodes),data:{quirksMode:i}},e.file&&e.location){const s=String(e.file),o=RB(s),c=o.toPoint(0),d=o.toPoint(s.length);n.position={start:c,end:d}}return n}case"#documentType":{const r=t;return n={type:"doctype"},jh(e,r,n),n}case"#text":{const r=t;return n={type:"text",value:r.value},jh(e,r,n),n}default:return n=DB(e,t),n}}function hT(e,t){let n=-1;const r=[];for(;++n<t.length;){const i=k2(e,t[n]);r.push(i)}return r}function DB(e,t){const n=e.schema;e.schema=t.namespaceURI===ca.svg?ol:k0;let r=-1;const i={};for(;++r<t.attrs.length;){const c=t.attrs[r],d=(c.prefix?c.prefix+":":"")+c.name;dT.call(MB,d)||(i[d]=c.value)}const o=(e.schema.space==="svg"?cT:uT)(t.tagName,i,hT(e,t.childNodes));if(jh(e,t,o),o.tagName==="template"){const c=t,d=c.sourceCodeLocation,f=d&&d.startTag&&Xo(d.startTag),m=d&&d.endTag&&Xo(d.endTag),p=k2(e,c.content);f&&m&&e.file&&(p.position={start:f.end,end:m.start}),o.content=p}return e.schema=n,o}function jh(e,t,n){if("sourceCodeLocation"in t&&t.sourceCodeLocation&&e.file){const r=LB(e,n,t.sourceCodeLocation);r&&(e.location=!0,n.position=r)}}function LB(e,t,n){const r=Xo(n);if(t.type==="element"){const i=t.children[t.children.length-1];if(r&&!n.endTag&&i&&i.position&&i.position.end&&(r.end=Object.assign({},i.position.end)),e.verbose){const s={};let o;if(n.attrs)for(o in n.attrs)dT.call(n.attrs,o)&&(s[Hf(e.schema,o).property]=Xo(n.attrs[o]));n.startTag;const c=Xo(n.startTag),d=n.endTag?Xo(n.endTag):void 0,f={opening:c};d&&(f.closing=d),f.properties=s,t.data={position:f}}}return r}function Xo(e){const t=RE({line:e.startLine,column:e.startCol,offset:e.startOffset}),n=RE({line:e.endLine,column:e.endCol,offset:e.endOffset});return t||n?{start:t,end:n}:void 0}function RE(e){return e.line&&e.column?e:void 0}const PB={},BB={}.hasOwnProperty,fT=H7("type",{handlers:{root:zB,element:$B,text:jB,comment:qB,doctype:HB}});function UB(e,t){const r=(t||PB).space;return fT(e,r==="svg"?ol:k0)}function zB(e,t){const n={nodeName:"#document",mode:(e.data||{}).quirksMode?"quirks":"no-quirks",childNodes:[]};return n.childNodes=C2(e.children,n,t),bu(e,n),n}function FB(e,t){const n={nodeName:"#document-fragment",childNodes:[]};return n.childNodes=C2(e.children,n,t),bu(e,n),n}function HB(e){const t={nodeName:"#documentType",name:"html",publicId:"",systemId:"",parentNode:null};return bu(e,t),t}function jB(e){const t={nodeName:"#text",value:e.value,parentNode:null};return bu(e,t),t}function qB(e){const t={nodeName:"#comment",data:e.value,parentNode:null};return bu(e,t),t}function $B(e,t){const n=t;let r=n;e.type==="element"&&e.tagName.toLowerCase()==="svg"&&n.space==="html"&&(r=ol);const i=[];let s;if(e.properties){for(s in e.properties)if(s!=="children"&&BB.call(e.properties,s)){const d=GB(r,s,e.properties[s]);d&&i.push(d)}}const o=r.space,c={nodeName:e.tagName,tagName:e.tagName,attrs:i,namespaceURI:ca[o],childNodes:[],parentNode:null};return c.childNodes=C2(e.children,c,r),bu(e,c),e.tagName==="template"&&e.content&&(c.content=FB(e.content,r)),c}function GB(e,t,n){const r=Hf(e,t);if(n===!1||n===null||n===void 0||typeof n=="number"&&Number.isNaN(n)||!n&&r.boolean)return;Array.isArray(n)&&(n=r.commaSeparated?t7(n):u7(n));const i={name:r.attribute,value:n===!0?"":String(n)};if(r.space&&r.space!=="html"&&r.space!=="svg"){const s=i.name.indexOf(":");s<0?i.prefix="":(i.name=i.name.slice(s+1),i.prefix=r.attribute.slice(0,s)),i.namespace=ca[r.space]}return i}function C2(e,t,n){let r=-1;const i=[];if(e)for(;++r<e.length;){const s=fT(e[r],n);s.parentNode=t,i.push(s)}return i}function bu(e,t){const n=e.position;n&&n.start&&n.end&&(n.start.offset,n.end.offset,t.sourceCodeLocation={startLine:n.start.line,startCol:n.start.column,startOffset:n.start.offset,endLine:n.end.line,endCol:n.end.column,endOffset:n.end.offset})}const YB=["area","base","basefont","bgsound","br","col","command","embed","frame","hr","image","img","input","keygen","link","meta","param","source","track","wbr"],VB=new Set([65534,65535,131070,131071,196606,196607,262142,262143,327678,327679,393214,393215,458750,458751,524286,524287,589822,589823,655358,655359,720894,720895,786430,786431,851966,851967,917502,917503,983038,983039,1048574,1048575,1114110,1114111]),On="�";var L;(function(e){e[e.EOF=-1]="EOF",e[e.NULL=0]="NULL",e[e.TABULATION=9]="TABULATION",e[e.CARRIAGE_RETURN=13]="CARRIAGE_RETURN",e[e.LINE_FEED=10]="LINE_FEED",e[e.FORM_FEED=12]="FORM_FEED",e[e.SPACE=32]="SPACE",e[e.EXCLAMATION_MARK=33]="EXCLAMATION_MARK",e[e.QUOTATION_MARK=34]="QUOTATION_MARK",e[e.AMPERSAND=38]="AMPERSAND",e[e.APOSTROPHE=39]="APOSTROPHE",e[e.HYPHEN_MINUS=45]="HYPHEN_MINUS",e[e.SOLIDUS=47]="SOLIDUS",e[e.DIGIT_0=48]="DIGIT_0",e[e.DIGIT_9=57]="DIGIT_9",e[e.SEMICOLON=59]="SEMICOLON",e[e.LESS_THAN_SIGN=60]="LESS_THAN_SIGN",e[e.EQUALS_SIGN=61]="EQUALS_SIGN",e[e.GREATER_THAN_SIGN=62]="GREATER_THAN_SIGN",e[e.QUESTION_MARK=63]="QUESTION_MARK",e[e.LATIN_CAPITAL_A=65]="LATIN_CAPITAL_A",e[e.LATIN_CAPITAL_Z=90]="LATIN_CAPITAL_Z",e[e.RIGHT_SQUARE_BRACKET=93]="RIGHT_SQUARE_BRACKET",e[e.GRAVE_ACCENT=96]="GRAVE_ACCENT",e[e.LATIN_SMALL_A=97]="LATIN_SMALL_A",e[e.LATIN_SMALL_Z=122]="LATIN_SMALL_Z"})(L||(L={}));const Jr={DASH_DASH:"--",CDATA_START:"[CDATA[",DOCTYPE:"doctype",SCRIPT:"script",PUBLIC:"public",SYSTEM:"system"};function mT(e){return e>=55296&&e<=57343}function KB(e){return e>=56320&&e<=57343}function WB(e,t){return(e-55296)*1024+9216+t}function pT(e){return e!==32&&e!==10&&e!==13&&e!==9&&e!==12&&e>=1&&e<=31||e>=127&&e<=159}function gT(e){return e>=64976&&e<=65007||VB.has(e)}var be;(function(e){e.controlCharacterInInputStream="control-character-in-input-stream",e.noncharacterInInputStream="noncharacter-in-input-stream",e.surrogateInInputStream="surrogate-in-input-stream",e.nonVoidHtmlElementStartTagWithTrailingSolidus="non-void-html-element-start-tag-with-trailing-solidus",e.endTagWithAttributes="end-tag-with-attributes",e.endTagWithTrailingSolidus="end-tag-with-trailing-solidus",e.unexpectedSolidusInTag="unexpected-solidus-in-tag",e.unexpectedNullCharacter="unexpected-null-character",e.unexpectedQuestionMarkInsteadOfTagName="unexpected-question-mark-instead-of-tag-name",e.invalidFirstCharacterOfTagName="invalid-first-character-of-tag-name",e.unexpectedEqualsSignBeforeAttributeName="unexpected-equals-sign-before-attribute-name",e.missingEndTagName="missing-end-tag-name",e.unexpectedCharacterInAttributeName="unexpected-character-in-attribute-name",e.unknownNamedCharacterReference="unknown-named-character-reference",e.missingSemicolonAfterCharacterReference="missing-semicolon-after-character-reference",e.unexpectedCharacterAfterDoctypeSystemIdentifier="unexpected-character-after-doctype-system-identifier",e.unexpectedCharacterInUnquotedAttributeValue="unexpected-character-in-unquoted-attribute-value",e.eofBeforeTagName="eof-before-tag-name",e.eofInTag="eof-in-tag",e.missingAttributeValue="missing-attribute-value",e.missingWhitespaceBetweenAttributes="missing-whitespace-between-attributes",e.missingWhitespaceAfterDoctypePublicKeyword="missing-whitespace-after-doctype-public-keyword",e.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers="missing-whitespace-between-doctype-public-and-system-identifiers",e.missingWhitespaceAfterDoctypeSystemKeyword="missing-whitespace-after-doctype-system-keyword",e.missingQuoteBeforeDoctypePublicIdentifier="missing-quote-before-doctype-public-identifier",e.missingQuoteBeforeDoctypeSystemIdentifier="missing-quote-before-doctype-system-identifier",e.missingDoctypePublicIdentifier="missing-doctype-public-identifier",e.missingDoctypeSystemIdentifier="missing-doctype-system-identifier",e.abruptDoctypePublicIdentifier="abrupt-doctype-public-identifier",e.abruptDoctypeSystemIdentifier="abrupt-doctype-system-identifier",e.cdataInHtmlContent="cdata-in-html-content",e.incorrectlyOpenedComment="incorrectly-opened-comment",e.eofInScriptHtmlCommentLikeText="eof-in-script-html-comment-like-text",e.eofInDoctype="eof-in-doctype",e.nestedComment="nested-comment",e.abruptClosingOfEmptyComment="abrupt-closing-of-empty-comment",e.eofInComment="eof-in-comment",e.incorrectlyClosedComment="incorrectly-closed-comment",e.eofInCdata="eof-in-cdata",e.absenceOfDigitsInNumericCharacterReference="absence-of-digits-in-numeric-character-reference",e.nullCharacterReference="null-character-reference",e.surrogateCharacterReference="surrogate-character-reference",e.characterReferenceOutsideUnicodeRange="character-reference-outside-unicode-range",e.controlCharacterReference="control-character-reference",e.noncharacterCharacterReference="noncharacter-character-reference",e.missingWhitespaceBeforeDoctypeName="missing-whitespace-before-doctype-name",e.missingDoctypeName="missing-doctype-name",e.invalidCharacterSequenceAfterDoctypeName="invalid-character-sequence-after-doctype-name",e.duplicateAttribute="duplicate-attribute",e.nonConformingDoctype="non-conforming-doctype",e.missingDoctype="missing-doctype",e.misplacedDoctype="misplaced-doctype",e.endTagWithoutMatchingOpenElement="end-tag-without-matching-open-element",e.closingOfElementWithOpenChildElements="closing-of-element-with-open-child-elements",e.disallowedContentInNoscriptInHead="disallowed-content-in-noscript-in-head",e.openElementsLeftAfterEof="open-elements-left-after-eof",e.abandonedHeadElementChild="abandoned-head-element-child",e.misplacedStartTagForHeadElement="misplaced-start-tag-for-head-element",e.nestedNoscriptInHead="nested-noscript-in-head",e.eofInElementThatCanContainOnlyText="eof-in-element-that-can-contain-only-text"})(be||(be={}));const XB=65536;class QB{constructor(t){this.handler=t,this.html="",this.pos=-1,this.lastGapPos=-2,this.gapStack=[],this.skipNextNewLine=!1,this.lastChunkWritten=!1,this.endOfChunkHit=!1,this.bufferWaterline=XB,this.isEol=!1,this.lineStartPos=0,this.droppedBufferSize=0,this.line=1,this.lastErrOffset=-1}get col(){return this.pos-this.lineStartPos+ +(this.lastGapPos!==this.pos)}get offset(){return this.droppedBufferSize+this.pos}getError(t,n){const{line:r,col:i,offset:s}=this,o=i+n,c=s+n;return{code:t,startLine:r,endLine:r,startCol:o,endCol:o,startOffset:c,endOffset:c}}_err(t){this.handler.onParseError&&this.lastErrOffset!==this.offset&&(this.lastErrOffset=this.offset,this.handler.onParseError(this.getError(t,0)))}_addGap(){this.gapStack.push(this.lastGapPos),this.lastGapPos=this.pos}_processSurrogate(t){if(this.pos!==this.html.length-1){const n=this.html.charCodeAt(this.pos+1);if(KB(n))return this.pos++,this._addGap(),WB(t,n)}else if(!this.lastChunkWritten)return this.endOfChunkHit=!0,L.EOF;return this._err(be.surrogateInInputStream),t}willDropParsedChunk(){return this.pos>this.bufferWaterline}dropParsedChunk(){this.willDropParsedChunk()&&(this.html=this.html.substring(this.pos),this.lineStartPos-=this.pos,this.droppedBufferSize+=this.pos,this.pos=0,this.lastGapPos=-2,this.gapStack.length=0)}write(t,n){this.html.length>0?this.html+=t:this.html=t,this.endOfChunkHit=!1,this.lastChunkWritten=n}insertHtmlAtCurrentPos(t){this.html=this.html.substring(0,this.pos+1)+t+this.html.substring(this.pos+1),this.endOfChunkHit=!1}startsWith(t,n){if(this.pos+t.length>this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,!1;if(n)return this.html.startsWith(t,this.pos);for(let r=0;r<t.length;r++)if((this.html.charCodeAt(this.pos+r)|32)!==t.charCodeAt(r))return!1;return!0}peek(t){const n=this.pos+t;if(n>=this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,L.EOF;const r=this.html.charCodeAt(n);return r===L.CARRIAGE_RETURN?L.LINE_FEED:r}advance(){if(this.pos++,this.isEol&&(this.isEol=!1,this.line++,this.lineStartPos=this.pos),this.pos>=this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,L.EOF;let t=this.html.charCodeAt(this.pos);return t===L.CARRIAGE_RETURN?(this.isEol=!0,this.skipNextNewLine=!0,L.LINE_FEED):t===L.LINE_FEED&&(this.isEol=!0,this.skipNextNewLine)?(this.line--,this.skipNextNewLine=!1,this._addGap(),this.advance()):(this.skipNextNewLine=!1,mT(t)&&(t=this._processSurrogate(t)),this.handler.onParseError===null||t>31&&t<127||t===L.LINE_FEED||t===L.CARRIAGE_RETURN||t>159&&t<64976||this._checkForProblematicCharacters(t),t)}_checkForProblematicCharacters(t){pT(t)?this._err(be.controlCharacterInInputStream):gT(t)&&this._err(be.noncharacterInInputStream)}retreat(t){for(this.pos-=t;this.pos<this.lastGapPos;)this.lastGapPos=this.gapStack.pop(),this.pos--;this.isEol=!1}}var Nt;(function(e){e[e.CHARACTER=0]="CHARACTER",e[e.NULL_CHARACTER=1]="NULL_CHARACTER",e[e.WHITESPACE_CHARACTER=2]="WHITESPACE_CHARACTER",e[e.START_TAG=3]="START_TAG",e[e.END_TAG=4]="END_TAG",e[e.COMMENT=5]="COMMENT",e[e.DOCTYPE=6]="DOCTYPE",e[e.EOF=7]="EOF",e[e.HIBERNATION=8]="HIBERNATION"})(Nt||(Nt={}));function bT(e,t){for(let n=e.attrs.length-1;n>=0;n--)if(e.attrs[n].name===t)return e.attrs[n].value;return null}const ZB=new Uint16Array('ᵁ<Õıʊҝջאٵ۞ޢߖࠏ੊ઑඡ๭༉༦჊ረዡᐕᒝᓃᓟᔥ\0\0\0\0\0\0ᕫᛍᦍᰒᷝ὾⁠↰⊍⏀⏻⑂⠤⤒ⴈ⹈⿎〖㊺㘹㞬㣾㨨㩱㫠㬮ࠀEMabcfglmnoprstu\\bfms¦³¹ÈÏlig耻Æ䃆P耻&䀦cute耻Á䃁reve;䄂Āiyx}rc耻Â䃂;䐐r;쀀𝔄rave耻À䃀pha;䎑acr;䄀d;橓Āgp¡on;䄄f;쀀𝔸plyFunction;恡ing耻Å䃅Ācs¾Ãr;쀀𝒜ign;扔ilde耻Ã䃃ml耻Ä䃄ЀaceforsuåûþėĜĢħĪĀcrêòkslash;或Ŷöø;櫧ed;挆y;䐑ƀcrtąċĔause;戵noullis;愬a;䎒r;쀀𝔅pf;쀀𝔹eve;䋘còēmpeq;扎܀HOacdefhilorsuōőŖƀƞƢƵƷƺǜȕɳɸɾcy;䐧PY耻©䂩ƀcpyŝŢźute;䄆Ā;iŧŨ拒talDifferentialD;慅leys;愭ȀaeioƉƎƔƘron;䄌dil耻Ç䃇rc;䄈nint;戰ot;䄊ĀdnƧƭilla;䂸terDot;䂷òſi;䎧rcleȀDMPTǇǋǑǖot;抙inus;抖lus;投imes;抗oĀcsǢǸkwiseContourIntegral;戲eCurlyĀDQȃȏoubleQuote;思uote;怙ȀlnpuȞȨɇɕonĀ;eȥȦ户;橴ƀgitȯȶȺruent;扡nt;戯ourIntegral;戮ĀfrɌɎ;愂oduct;成nterClockwiseContourIntegral;戳oss;樯cr;쀀𝒞pĀ;Cʄʅ拓ap;才րDJSZacefiosʠʬʰʴʸˋ˗ˡ˦̳ҍĀ;oŹʥtrahd;椑cy;䐂cy;䐅cy;䐏ƀgrsʿ˄ˇger;怡r;憡hv;櫤Āayː˕ron;䄎;䐔lĀ;t˝˞戇a;䎔r;쀀𝔇Āaf˫̧Ācm˰̢riticalȀADGT̖̜̀̆cute;䂴oŴ̋̍;䋙bleAcute;䋝rave;䁠ilde;䋜ond;拄ferentialD;慆Ѱ̽\0\0\0͔͂\0Ѕf;쀀𝔻ƀ;DE͈͉͍䂨ot;惜qual;扐blèCDLRUVͣͲ΂ϏϢϸontourIntegraìȹoɴ͹\0\0ͻ»͉nArrow;懓Āeo·ΤftƀARTΐΖΡrrow;懐ightArrow;懔eåˊngĀLRΫτeftĀARγιrrow;柸ightArrow;柺ightArrow;柹ightĀATϘϞrrow;懒ee;抨pɁϩ\0\0ϯrrow;懑ownArrow;懕erticalBar;戥ǹABLRTaВЪаўѿͼrrowƀ;BUНОТ憓ar;椓pArrow;懵reve;䌑eft˒к\0ц\0ѐightVector;楐eeVector;楞ectorĀ;Bљњ憽ar;楖ightǔѧ\0ѱeeVector;楟ectorĀ;BѺѻ懁ar;楗eeĀ;A҆҇护rrow;憧ĀctҒҗr;쀀𝒟rok;䄐ࠀNTacdfglmopqstuxҽӀӄӋӞӢӧӮӵԡԯԶՒ՝ՠեG;䅊H耻Ð䃐cute耻É䃉ƀaiyӒӗӜron;䄚rc耻Ê䃊;䐭ot;䄖r;쀀𝔈rave耻È䃈ement;戈ĀapӺӾcr;䄒tyɓԆ\0\0ԒmallSquare;旻erySmallSquare;斫ĀgpԦԪon;䄘f;쀀𝔼silon;䎕uĀaiԼՉlĀ;TՂՃ橵ilde;扂librium;懌Āci՗՚r;愰m;橳a;䎗ml耻Ë䃋Āipժկsts;戃onentialE;慇ʀcfiosօֈ֍ֲ׌y;䐤r;쀀𝔉lledɓ֗\0\0֣mallSquare;旼erySmallSquare;斪Ͱֺ\0ֿ\0\0ׄf;쀀𝔽All;戀riertrf;愱cò׋؀JTabcdfgorstר׬ׯ׺؀ؒؖ؛؝أ٬ٲcy;䐃耻>䀾mmaĀ;d׷׸䎓;䏜reve;䄞ƀeiy؇،ؐdil;䄢rc;䄜;䐓ot;䄠r;쀀𝔊;拙pf;쀀𝔾eater̀EFGLSTصلَٖٛ٦qualĀ;Lؾؿ扥ess;招ullEqual;执reater;檢ess;扷lantEqual;橾ilde;扳cr;쀀𝒢;扫ЀAacfiosuڅڋږڛڞڪھۊRDcy;䐪Āctڐڔek;䋇;䁞irc;䄤r;愌lbertSpace;愋ǰگ\0ڲf;愍izontalLine;攀Āctۃۅòکrok;䄦mpńېۘownHumðįqual;扏܀EJOacdfgmnostuۺ۾܃܇܎ܚܞܡܨ݄ݸދޏޕcy;䐕lig;䄲cy;䐁cute耻Í䃍Āiyܓܘrc耻Î䃎;䐘ot;䄰r;愑rave耻Ì䃌ƀ;apܠܯܿĀcgܴܷr;䄪inaryI;慈lieóϝǴ݉\0ݢĀ;eݍݎ戬Āgrݓݘral;戫section;拂isibleĀCTݬݲomma;恣imes;恢ƀgptݿރވon;䄮f;쀀𝕀a;䎙cr;愐ilde;䄨ǫޚ\0ޞcy;䐆l耻Ï䃏ʀcfosuެ޷޼߂ߐĀiyޱ޵rc;䄴;䐙r;쀀𝔍pf;쀀𝕁ǣ߇\0ߌr;쀀𝒥rcy;䐈kcy;䐄΀HJacfosߤߨ߽߬߱ࠂࠈcy;䐥cy;䐌ppa;䎚Āey߶߻dil;䄶;䐚r;쀀𝔎pf;쀀𝕂cr;쀀𝒦րJTaceflmostࠥࠩࠬࡐࡣ঳সে্਷ੇcy;䐉耻<䀼ʀcmnpr࠷࠼ࡁࡄࡍute;䄹bda;䎛g;柪lacetrf;愒r;憞ƀaeyࡗ࡜ࡡron;䄽dil;䄻;䐛Āfsࡨ॰tԀACDFRTUVarࡾࢩࢱࣦ࣠ࣼयज़ΐ४Ānrࢃ࢏gleBracket;柨rowƀ;BR࢙࢚࢞憐ar;懤ightArrow;懆eiling;挈oǵࢷ\0ࣃbleBracket;柦nǔࣈ\0࣒eeVector;楡ectorĀ;Bࣛࣜ懃ar;楙loor;挊ightĀAV࣯ࣵrrow;憔ector;楎Āerँगeƀ;AVउऊऐ抣rrow;憤ector;楚iangleƀ;BEतथऩ抲ar;槏qual;抴pƀDTVषूौownVector;楑eeVector;楠ectorĀ;Bॖॗ憿ar;楘ectorĀ;B॥०憼ar;楒ightáΜs̀EFGLSTॾঋকঝঢভqualGreater;拚ullEqual;扦reater;扶ess;檡lantEqual;橽ilde;扲r;쀀𝔏Ā;eঽা拘ftarrow;懚idot;䄿ƀnpw৔ਖਛgȀLRlr৞৷ਂਐeftĀAR০৬rrow;柵ightArrow;柷ightArrow;柶eftĀarγਊightáοightáϊf;쀀𝕃erĀLRਢਬeftArrow;憙ightArrow;憘ƀchtਾੀੂòࡌ;憰rok;䅁;扪Ѐacefiosuਗ਼੝੠੷੼અઋ઎p;椅y;䐜Ādl੥੯iumSpace;恟lintrf;愳r;쀀𝔐nusPlus;戓pf;쀀𝕄cò੶;䎜ҀJacefostuણધભીଔଙඑ඗ඞcy;䐊cute;䅃ƀaey઴હાron;䅇dil;䅅;䐝ƀgswે૰଎ativeƀMTV૓૟૨ediumSpace;怋hiĀcn૦૘ë૙eryThiî૙tedĀGL૸ଆreaterGreateòٳessLesóੈLine;䀊r;쀀𝔑ȀBnptଢନଷ଺reak;恠BreakingSpace;䂠f;愕ڀ;CDEGHLNPRSTV୕ୖ୪୼஡௫ఄ౞಄ದ೘ൡඅ櫬Āou୛୤ngruent;扢pCap;扭oubleVerticalBar;戦ƀlqxஃஊ஛ement;戉ualĀ;Tஒஓ扠ilde;쀀≂̸ists;戄reater΀;EFGLSTஶஷ஽௉௓௘௥扯qual;扱ullEqual;쀀≧̸reater;쀀≫̸ess;批lantEqual;쀀⩾̸ilde;扵umpń௲௽ownHump;쀀≎̸qual;쀀≏̸eĀfsఊధtTriangleƀ;BEచఛడ拪ar;쀀⧏̸qual;括s̀;EGLSTవశ఼ౄోౘ扮qual;扰reater;扸ess;쀀≪̸lantEqual;쀀⩽̸ilde;扴estedĀGL౨౹reaterGreater;쀀⪢̸essLess;쀀⪡̸recedesƀ;ESಒಓಛ技qual;쀀⪯̸lantEqual;拠ĀeiಫಹverseElement;戌ghtTriangleƀ;BEೋೌ೒拫ar;쀀⧐̸qual;拭ĀquೝഌuareSuĀbp೨೹setĀ;E೰ೳ쀀⊏̸qual;拢ersetĀ;Eഃആ쀀⊐̸qual;拣ƀbcpഓതൎsetĀ;Eഛഞ쀀⊂⃒qual;抈ceedsȀ;ESTലള഻െ抁qual;쀀⪰̸lantEqual;拡ilde;쀀≿̸ersetĀ;E൘൛쀀⊃⃒qual;抉ildeȀ;EFT൮൯൵ൿ扁qual;扄ullEqual;扇ilde;扉erticalBar;戤cr;쀀𝒩ilde耻Ñ䃑;䎝܀Eacdfgmoprstuvලෂ෉෕ෛ෠෧෼ขภยา฿ไlig;䅒cute耻Ó䃓Āiy෎ීrc耻Ô䃔;䐞blac;䅐r;쀀𝔒rave耻Ò䃒ƀaei෮ෲ෶cr;䅌ga;䎩cron;䎟pf;쀀𝕆enCurlyĀDQฎบoubleQuote;怜uote;怘;橔Āclวฬr;쀀𝒪ash耻Ø䃘iŬื฼de耻Õ䃕es;樷ml耻Ö䃖erĀBP๋๠Āar๐๓r;怾acĀek๚๜;揞et;掴arenthesis;揜Ҁacfhilors๿ງຊຏຒດຝະ໼rtialD;戂y;䐟r;쀀𝔓i;䎦;䎠usMinus;䂱Āipຢອncareplanåڝf;愙Ȁ;eio຺ູ໠໤檻cedesȀ;EST່້໏໚扺qual;檯lantEqual;扼ilde;找me;怳Ādp໩໮uct;戏ortionĀ;aȥ໹l;戝Āci༁༆r;쀀𝒫;䎨ȀUfos༑༖༛༟OT耻"䀢r;쀀𝔔pf;愚cr;쀀𝒬؀BEacefhiorsu༾གྷཇའཱིྦྷྪྭ႖ႩႴႾarr;椐G耻®䂮ƀcnrཎནབute;䅔g;柫rĀ;tཛྷཝ憠l;椖ƀaeyཧཬཱron;䅘dil;䅖;䐠Ā;vླྀཹ愜erseĀEUྂྙĀlq྇ྎement;戋uilibrium;懋pEquilibrium;楯r»ཹo;䎡ghtЀACDFTUVa࿁࿫࿳ဢဨၛႇϘĀnr࿆࿒gleBracket;柩rowƀ;BL࿜࿝࿡憒ar;懥eftArrow;懄eiling;按oǵ࿹\0စbleBracket;柧nǔည\0နeeVector;楝ectorĀ;Bဝသ懂ar;楕loor;挋Āerိ၃eƀ;AVဵံြ抢rrow;憦ector;楛iangleƀ;BEၐၑၕ抳ar;槐qual;抵pƀDTVၣၮၸownVector;楏eeVector;楜ectorĀ;Bႂႃ憾ar;楔ectorĀ;B႑႒懀ar;楓Āpuႛ႞f;愝ndImplies;楰ightarrow;懛ĀchႹႼr;愛;憱leDelayed;槴ڀHOacfhimoqstuფჱჷჽᄙᄞᅑᅖᅡᅧᆵᆻᆿĀCcჩხHcy;䐩y;䐨FTcy;䐬cute;䅚ʀ;aeiyᄈᄉᄎᄓᄗ檼ron;䅠dil;䅞rc;䅜;䐡r;쀀𝔖ortȀDLRUᄪᄴᄾᅉownArrow»ОeftArrow»࢚ightArrow»࿝pArrow;憑gma;䎣allCircle;战pf;쀀𝕊ɲᅭ\0\0ᅰt;戚areȀ;ISUᅻᅼᆉᆯ斡ntersection;抓uĀbpᆏᆞsetĀ;Eᆗᆘ抏qual;抑ersetĀ;Eᆨᆩ抐qual;抒nion;抔cr;쀀𝒮ar;拆ȀbcmpᇈᇛሉላĀ;sᇍᇎ拐etĀ;Eᇍᇕqual;抆ĀchᇠህeedsȀ;ESTᇭᇮᇴᇿ扻qual;檰lantEqual;扽ilde;承Tháྌ;我ƀ;esሒሓሣ拑rsetĀ;Eሜም抃qual;抇et»ሓրHRSacfhiorsሾቄ቉ቕ቞ቱቶኟዂወዑORN耻Þ䃞ADE;愢ĀHc቎ቒcy;䐋y;䐦Ābuቚቜ;䀉;䎤ƀaeyብቪቯron;䅤dil;䅢;䐢r;쀀𝔗Āeiቻ኉ǲኀ\0ኇefore;戴a;䎘Ācn኎ኘkSpace;쀀  Space;怉ldeȀ;EFTካኬኲኼ戼qual;扃ullEqual;扅ilde;扈pf;쀀𝕋ipleDot;惛Āctዖዛr;쀀𝒯rok;䅦ૡዷጎጚጦ\0ጬጱ\0\0\0\0\0ጸጽ፷ᎅ\0᏿ᐄᐊᐐĀcrዻጁute耻Ú䃚rĀ;oጇገ憟cir;楉rǣጓ\0጖y;䐎ve;䅬Āiyጞጣrc耻Û䃛;䐣blac;䅰r;쀀𝔘rave耻Ù䃙acr;䅪Ādiፁ፩erĀBPፈ፝Āarፍፐr;䁟acĀekፗፙ;揟et;掵arenthesis;揝onĀ;P፰፱拃lus;抎Āgp፻፿on;䅲f;쀀𝕌ЀADETadps᎕ᎮᎸᏄϨᏒᏗᏳrrowƀ;BDᅐᎠᎤar;椒ownArrow;懅ownArrow;憕quilibrium;楮eeĀ;AᏋᏌ报rrow;憥ownáϳerĀLRᏞᏨeftArrow;憖ightArrow;憗iĀ;lᏹᏺ䏒on;䎥ing;䅮cr;쀀𝒰ilde;䅨ml耻Ü䃜ҀDbcdefosvᐧᐬᐰᐳᐾᒅᒊᒐᒖash;披ar;櫫y;䐒ashĀ;lᐻᐼ抩;櫦Āerᑃᑅ;拁ƀbtyᑌᑐᑺar;怖Ā;iᑏᑕcalȀBLSTᑡᑥᑪᑴar;戣ine;䁼eparator;杘ilde;所ThinSpace;怊r;쀀𝔙pf;쀀𝕍cr;쀀𝒱dash;抪ʀcefosᒧᒬᒱᒶᒼirc;䅴dge;拀r;쀀𝔚pf;쀀𝕎cr;쀀𝒲Ȁfiosᓋᓐᓒᓘr;쀀𝔛;䎞pf;쀀𝕏cr;쀀𝒳ҀAIUacfosuᓱᓵᓹᓽᔄᔏᔔᔚᔠcy;䐯cy;䐇cy;䐮cute耻Ý䃝Āiyᔉᔍrc;䅶;䐫r;쀀𝔜pf;쀀𝕐cr;쀀𝒴ml;䅸ЀHacdefosᔵᔹᔿᕋᕏᕝᕠᕤcy;䐖cute;䅹Āayᕄᕉron;䅽;䐗ot;䅻ǲᕔ\0ᕛoWidtè૙a;䎖r;愨pf;愤cr;쀀𝒵௡ᖃᖊᖐ\0ᖰᖶᖿ\0\0\0\0ᗆᗛᗫᙟ᙭\0ᚕ᚛ᚲᚹ\0ᚾcute耻á䃡reve;䄃̀;Ediuyᖜᖝᖡᖣᖨᖭ戾;쀀∾̳;房rc耻â䃢te肻´̆;䐰lig耻æ䃦Ā;r²ᖺ;쀀𝔞rave耻à䃠ĀepᗊᗖĀfpᗏᗔsym;愵èᗓha;䎱ĀapᗟcĀclᗤᗧr;䄁g;樿ɤᗰ\0\0ᘊʀ;adsvᗺᗻᗿᘁᘇ戧nd;橕;橜lope;橘;橚΀;elmrszᘘᘙᘛᘞᘿᙏᙙ戠;榤e»ᘙsdĀ;aᘥᘦ戡ѡᘰᘲᘴᘶᘸᘺᘼᘾ;榨;榩;榪;榫;榬;榭;榮;榯tĀ;vᙅᙆ戟bĀ;dᙌᙍ抾;榝Āptᙔᙗh;戢»¹arr;捼Āgpᙣᙧon;䄅f;쀀𝕒΀;Eaeiop዁ᙻᙽᚂᚄᚇᚊ;橰cir;橯;扊d;手s;䀧roxĀ;e዁ᚒñᚃing耻å䃥ƀctyᚡᚦᚨr;쀀𝒶;䀪mpĀ;e዁ᚯñʈilde耻ã䃣ml耻ä䃤Āciᛂᛈoninôɲnt;樑ࠀNabcdefiklnoprsu᛭ᛱᜰ᜼ᝃᝈ᝸᝽០៦ᠹᡐᜍ᤽᥈ᥰot;櫭Ācrᛶ᜞kȀcepsᜀᜅᜍᜓong;扌psilon;䏶rime;怵imĀ;e᜚᜛戽q;拍Ŷᜢᜦee;抽edĀ;gᜬᜭ挅e»ᜭrkĀ;t፜᜷brk;掶Āoyᜁᝁ;䐱quo;怞ʀcmprtᝓ᝛ᝡᝤᝨausĀ;eĊĉptyv;榰séᜌnoõēƀahwᝯ᝱ᝳ;䎲;愶een;扬r;쀀𝔟g΀costuvwឍឝឳេ៕៛៞ƀaiuបពរðݠrc;旯p»፱ƀdptឤឨឭot;樀lus;樁imes;樂ɱឹ\0\0ើcup;樆ar;昅riangleĀdu៍្own;施p;斳plus;樄eåᑄåᒭarow;植ƀako៭ᠦᠵĀcn៲ᠣkƀlst៺֫᠂ozenge;槫riangleȀ;dlr᠒᠓᠘᠝斴own;斾eft;旂ight;斸k;搣Ʊᠫ\0ᠳƲᠯ\0ᠱ;斒;斑4;斓ck;斈ĀeoᠾᡍĀ;qᡃᡆ쀀=⃥uiv;쀀≡⃥t;挐Ȁptwxᡙᡞᡧᡬf;쀀𝕓Ā;tᏋᡣom»Ꮜtie;拈؀DHUVbdhmptuvᢅᢖᢪᢻᣗᣛᣬ᣿ᤅᤊᤐᤡȀLRlrᢎᢐᢒᢔ;敗;敔;敖;敓ʀ;DUduᢡᢢᢤᢦᢨ敐;敦;敩;敤;敧ȀLRlrᢳᢵᢷᢹ;敝;敚;敜;教΀;HLRhlrᣊᣋᣍᣏᣑᣓᣕ救;敬;散;敠;敫;敢;敟ox;槉ȀLRlrᣤᣦᣨᣪ;敕;敒;攐;攌ʀ;DUduڽ᣷᣹᣻᣽;敥;敨;攬;攴inus;抟lus;択imes;抠ȀLRlrᤙᤛᤝ᤟;敛;敘;攘;攔΀;HLRhlrᤰᤱᤳᤵᤷ᤻᤹攂;敪;敡;敞;攼;攤;攜Āevģ᥂bar耻¦䂦Ȁceioᥑᥖᥚᥠr;쀀𝒷mi;恏mĀ;e᜚᜜lƀ;bhᥨᥩᥫ䁜;槅sub;柈Ŭᥴ᥾lĀ;e᥹᥺怢t»᥺pƀ;Eeįᦅᦇ;檮Ā;qۜۛೡᦧ\0᧨ᨑᨕᨲ\0ᨷᩐ\0\0᪴\0\0᫁\0\0ᬡᬮ᭍᭒\0᯽\0ᰌƀcpr᦭ᦲ᧝ute;䄇̀;abcdsᦿᧀᧄ᧊᧕᧙戩nd;橄rcup;橉Āau᧏᧒p;橋p;橇ot;橀;쀀∩︀Āeo᧢᧥t;恁îړȀaeiu᧰᧻ᨁᨅǰ᧵\0᧸s;橍on;䄍dil耻ç䃧rc;䄉psĀ;sᨌᨍ橌m;橐ot;䄋ƀdmnᨛᨠᨦil肻¸ƭptyv;榲t脀¢;eᨭᨮ䂢räƲr;쀀𝔠ƀceiᨽᩀᩍy;䑇ckĀ;mᩇᩈ朓ark»ᩈ;䏇r΀;Ecefms᩟᩠ᩢᩫ᪤᪪᪮旋;槃ƀ;elᩩᩪᩭ䋆q;扗eɡᩴ\0\0᪈rrowĀlr᩼᪁eft;憺ight;憻ʀRSacd᪒᪔᪖᪚᪟»ཇ;擈st;抛irc;抚ash;抝nint;樐id;櫯cir;槂ubsĀ;u᪻᪼晣it»᪼ˬ᫇᫔᫺\0ᬊonĀ;eᫍᫎ䀺Ā;qÇÆɭ᫙\0\0᫢aĀ;t᫞᫟䀬;䁀ƀ;fl᫨᫩᫫戁îᅠeĀmx᫱᫶ent»᫩eóɍǧ᫾\0ᬇĀ;dኻᬂot;橭nôɆƀfryᬐᬔᬗ;쀀𝕔oäɔ脀©;sŕᬝr;愗Āaoᬥᬩrr;憵ss;朗Ācuᬲᬷr;쀀𝒸Ābpᬼ᭄Ā;eᭁᭂ櫏;櫑Ā;eᭉᭊ櫐;櫒dot;拯΀delprvw᭠᭬᭷ᮂᮬᯔ᯹arrĀlr᭨᭪;椸;椵ɰ᭲\0\0᭵r;拞c;拟arrĀ;p᭿ᮀ憶;椽̀;bcdosᮏᮐᮖᮡᮥᮨ截rcap;橈Āauᮛᮞp;橆p;橊ot;抍r;橅;쀀∪︀Ȁalrv᮵ᮿᯞᯣrrĀ;mᮼᮽ憷;椼yƀevwᯇᯔᯘqɰᯎ\0\0ᯒreã᭳uã᭵ee;拎edge;拏en耻¤䂤earrowĀlrᯮ᯳eft»ᮀight»ᮽeäᯝĀciᰁᰇoninôǷnt;戱lcty;挭ঀAHabcdefhijlorstuwz᰸᰻᰿ᱝᱩᱵᲊᲞᲬᲷ᳻᳿ᴍᵻᶑᶫᶻ᷆᷍rò΁ar;楥Ȁglrs᱈ᱍ᱒᱔ger;怠eth;愸òᄳhĀ;vᱚᱛ怐»ऊūᱡᱧarow;椏aã̕Āayᱮᱳron;䄏;䐴ƀ;ao̲ᱼᲄĀgrʿᲁr;懊tseq;橷ƀglmᲑᲔᲘ耻°䂰ta;䎴ptyv;榱ĀirᲣᲨsht;楿;쀀𝔡arĀlrᲳᲵ»ࣜ»သʀaegsv᳂͸᳖᳜᳠mƀ;oș᳊᳔ndĀ;ș᳑uit;晦amma;䏝in;拲ƀ;io᳧᳨᳸䃷de脀÷;o᳧ᳰntimes;拇nø᳷cy;䑒cɯᴆ\0\0ᴊrn;挞op;挍ʀlptuwᴘᴝᴢᵉᵕlar;䀤f;쀀𝕕ʀ;emps̋ᴭᴷᴽᵂqĀ;d͒ᴳot;扑inus;戸lus;戔quare;抡blebarwedgåúnƀadhᄮᵝᵧownarrowóᲃarpoonĀlrᵲᵶefôᲴighôᲶŢᵿᶅkaro÷གɯᶊ\0\0ᶎrn;挟op;挌ƀcotᶘᶣᶦĀryᶝᶡ;쀀𝒹;䑕l;槶rok;䄑Ādrᶰᶴot;拱iĀ;fᶺ᠖斿Āah᷀᷃ròЩaòྦangle;榦Āci᷒ᷕy;䑟grarr;柿ऀDacdefglmnopqrstuxḁḉḙḸոḼṉṡṾấắẽỡἪἷὄ὎὚ĀDoḆᴴoôᲉĀcsḎḔute耻é䃩ter;橮ȀaioyḢḧḱḶron;䄛rĀ;cḭḮ扖耻ê䃪lon;払;䑍ot;䄗ĀDrṁṅot;扒;쀀𝔢ƀ;rsṐṑṗ檚ave耻è䃨Ā;dṜṝ檖ot;檘Ȁ;ilsṪṫṲṴ檙nters;揧;愓Ā;dṹṺ檕ot;檗ƀapsẅẉẗcr;䄓tyƀ;svẒẓẕ戅et»ẓpĀ1;ẝẤĳạả;怄;怅怃ĀgsẪẬ;䅋p;怂ĀgpẴẸon;䄙f;쀀𝕖ƀalsỄỎỒrĀ;sỊị拕l;槣us;橱iƀ;lvỚớở䎵on»ớ;䏵ȀcsuvỪỳἋἣĀioữḱrc»Ḯɩỹ\0\0ỻíՈantĀglἂἆtr»ṝess»Ṻƀaeiἒ἖Ἒls;䀽st;扟vĀ;DȵἠD;橸parsl;槥ĀDaἯἳot;打rr;楱ƀcdiἾὁỸr;愯oô͒ĀahὉὋ;䎷耻ð䃰Āmrὓὗl耻ë䃫o;悬ƀcipὡὤὧl;䀡sôծĀeoὬὴctatioîՙnentialåչৡᾒ\0ᾞ\0ᾡᾧ\0\0ῆῌ\0ΐ\0ῦῪ \0 ⁚llingdotseñṄy;䑄male;晀ƀilrᾭᾳ῁lig;耀ﬃɩᾹ\0\0᾽g;耀ﬀig;耀ﬄ;쀀𝔣lig;耀ﬁlig;쀀fjƀaltῙ῜ῡt;晭ig;耀ﬂns;斱of;䆒ǰ΅\0ῳf;쀀𝕗ĀakֿῷĀ;vῼ´拔;櫙artint;樍Āao‌⁕Ācs‑⁒α‚‰‸⁅⁈\0⁐β•‥‧‪‬\0‮耻½䂽;慓耻¼䂼;慕;慙;慛Ƴ‴\0‶;慔;慖ʴ‾⁁\0\0⁃耻¾䂾;慗;慜5;慘ƶ⁌\0⁎;慚;慝8;慞l;恄wn;挢cr;쀀𝒻ࢀEabcdefgijlnorstv₂₉₟₥₰₴⃰⃵⃺⃿℃ℒℸ̗ℾ⅒↞Ā;lٍ₇;檌ƀcmpₐₕ₝ute;䇵maĀ;dₜ᳚䎳;檆reve;䄟Āiy₪₮rc;䄝;䐳ot;䄡Ȁ;lqsؾق₽⃉ƀ;qsؾٌ⃄lanô٥Ȁ;cdl٥⃒⃥⃕c;檩otĀ;o⃜⃝檀Ā;l⃢⃣檂;檄Ā;e⃪⃭쀀⋛︀s;檔r;쀀𝔤Ā;gٳ؛mel;愷cy;䑓Ȁ;Eajٚℌℎℐ;檒;檥;檤ȀEaesℛℝ℩ℴ;扩pĀ;p℣ℤ檊rox»ℤĀ;q℮ℯ檈Ā;q℮ℛim;拧pf;쀀𝕘Āci⅃ⅆr;愊mƀ;el٫ⅎ⅐;檎;檐茀>;cdlqr׮ⅠⅪⅮⅳⅹĀciⅥⅧ;檧r;橺ot;拗Par;榕uest;橼ʀadelsↄⅪ←ٖ↛ǰ↉\0↎proø₞r;楸qĀlqؿ↖lesó₈ií٫Āen↣↭rtneqq;쀀≩︀Å↪ԀAabcefkosy⇄⇇⇱⇵⇺∘∝∯≨≽ròΠȀilmr⇐⇔⇗⇛rsðᒄf»․ilôکĀdr⇠⇤cy;䑊ƀ;cwࣴ⇫⇯ir;楈;憭ar;意irc;䄥ƀalr∁∎∓rtsĀ;u∉∊晥it»∊lip;怦con;抹r;쀀𝔥sĀew∣∩arow;椥arow;椦ʀamopr∺∾≃≞≣rr;懿tht;戻kĀlr≉≓eftarrow;憩ightarrow;憪f;쀀𝕙bar;怕ƀclt≯≴≸r;쀀𝒽asè⇴rok;䄧Ābp⊂⊇ull;恃hen»ᱛૡ⊣\0⊪\0⊸⋅⋎\0⋕⋳\0\0⋸⌢⍧⍢⍿\0⎆⎪⎴cute耻í䃭ƀ;iyݱ⊰⊵rc耻î䃮;䐸Ācx⊼⊿y;䐵cl耻¡䂡ĀfrΟ⋉;쀀𝔦rave耻ì䃬Ȁ;inoܾ⋝⋩⋮Āin⋢⋦nt;樌t;戭fin;槜ta;愩lig;䄳ƀaop⋾⌚⌝ƀcgt⌅⌈⌗r;䄫ƀelpܟ⌏⌓inåގarôܠh;䄱f;抷ed;䆵ʀ;cfotӴ⌬⌱⌽⍁are;愅inĀ;t⌸⌹戞ie;槝doô⌙ʀ;celpݗ⍌⍐⍛⍡al;抺Āgr⍕⍙eróᕣã⍍arhk;樗rod;樼Ȁcgpt⍯⍲⍶⍻y;䑑on;䄯f;쀀𝕚a;䎹uest耻¿䂿Āci⎊⎏r;쀀𝒾nʀ;EdsvӴ⎛⎝⎡ӳ;拹ot;拵Ā;v⎦⎧拴;拳Ā;iݷ⎮lde;䄩ǫ⎸\0⎼cy;䑖l耻ï䃯̀cfmosu⏌⏗⏜⏡⏧⏵Āiy⏑⏕rc;䄵;䐹r;쀀𝔧ath;䈷pf;쀀𝕛ǣ⏬\0⏱r;쀀𝒿rcy;䑘kcy;䑔Ѐacfghjos␋␖␢␧␭␱␵␻ppaĀ;v␓␔䎺;䏰Āey␛␠dil;䄷;䐺r;쀀𝔨reen;䄸cy;䑅cy;䑜pf;쀀𝕜cr;쀀𝓀஀ABEHabcdefghjlmnoprstuv⑰⒁⒆⒍⒑┎┽╚▀♎♞♥♹♽⚚⚲⛘❝❨➋⟀⠁⠒ƀart⑷⑺⑼rò৆òΕail;椛arr;椎Ā;gঔ⒋;檋ar;楢ॣ⒥\0⒪\0⒱\0\0\0\0\0⒵Ⓔ\0ⓆⓈⓍ\0⓹ute;䄺mptyv;榴raîࡌbda;䎻gƀ;dlࢎⓁⓃ;榑åࢎ;檅uo耻«䂫rЀ;bfhlpst࢙ⓞⓦⓩ⓫⓮⓱⓵Ā;f࢝ⓣs;椟s;椝ë≒p;憫l;椹im;楳l;憢ƀ;ae⓿─┄檫il;椙Ā;s┉┊檭;쀀⪭︀ƀabr┕┙┝rr;椌rk;杲Āak┢┬cĀek┨┪;䁻;䁛Āes┱┳;榋lĀdu┹┻;榏;榍Ȁaeuy╆╋╖╘ron;䄾Ādi═╔il;䄼ìࢰâ┩;䐻Ȁcqrs╣╦╭╽a;椶uoĀ;rนᝆĀdu╲╷har;楧shar;楋h;憲ʀ;fgqs▋▌উ◳◿扤tʀahlrt▘▤▷◂◨rrowĀ;t࢙□aé⓶arpoonĀdu▯▴own»њp»०eftarrows;懇ightƀahs◍◖◞rrowĀ;sࣴࢧarpoonó྘quigarro÷⇰hreetimes;拋ƀ;qs▋ও◺lanôবʀ;cdgsব☊☍☝☨c;檨otĀ;o☔☕橿Ā;r☚☛檁;檃Ā;e☢☥쀀⋚︀s;檓ʀadegs☳☹☽♉♋pproøⓆot;拖qĀgq♃♅ôউgtò⒌ôছiíলƀilr♕࣡♚sht;楼;쀀𝔩Ā;Eজ♣;檑š♩♶rĀdu▲♮Ā;l॥♳;楪lk;斄cy;䑙ʀ;achtੈ⚈⚋⚑⚖rò◁orneòᴈard;楫ri;旺Āio⚟⚤dot;䅀ustĀ;a⚬⚭掰che»⚭ȀEaes⚻⚽⛉⛔;扨pĀ;p⛃⛄檉rox»⛄Ā;q⛎⛏檇Ā;q⛎⚻im;拦Ѐabnoptwz⛩⛴⛷✚✯❁❇❐Ānr⛮⛱g;柬r;懽rëࣁgƀlmr⛿✍✔eftĀar০✇ightá৲apsto;柼ightá৽parrowĀlr✥✩efô⓭ight;憬ƀafl✶✹✽r;榅;쀀𝕝us;樭imes;樴š❋❏st;戗áፎƀ;ef❗❘᠀旊nge»❘arĀ;l❤❥䀨t;榓ʀachmt❳❶❼➅➇ròࢨorneòᶌarĀ;d྘➃;業;怎ri;抿̀achiqt➘➝ੀ➢➮➻quo;怹r;쀀𝓁mƀ;egল➪➬;檍;檏Ābu┪➳oĀ;rฟ➹;怚rok;䅂萀<;cdhilqrࠫ⟒☹⟜⟠⟥⟪⟰Āci⟗⟙;檦r;橹reå◲mes;拉arr;楶uest;橻ĀPi⟵⟹ar;榖ƀ;ef⠀भ᠛旃rĀdu⠇⠍shar;楊har;楦Āen⠗⠡rtneqq;쀀≨︀Å⠞܀Dacdefhilnopsu⡀⡅⢂⢎⢓⢠⢥⢨⣚⣢⣤ઃ⣳⤂Dot;戺Ȁclpr⡎⡒⡣⡽r耻¯䂯Āet⡗⡙;時Ā;e⡞⡟朠se»⡟Ā;sျ⡨toȀ;dluျ⡳⡷⡻owîҌefôएðᏑker;斮Āoy⢇⢌mma;権;䐼ash;怔asuredangle»ᘦr;쀀𝔪o;愧ƀcdn⢯⢴⣉ro耻µ䂵Ȁ;acdᑤ⢽⣀⣄sôᚧir;櫰ot肻·Ƶusƀ;bd⣒ᤃ⣓戒Ā;uᴼ⣘;横ţ⣞⣡p;櫛ò−ðઁĀdp⣩⣮els;抧f;쀀𝕞Āct⣸⣽r;쀀𝓂pos»ᖝƀ;lm⤉⤊⤍䎼timap;抸ఀGLRVabcdefghijlmoprstuvw⥂⥓⥾⦉⦘⧚⧩⨕⨚⩘⩝⪃⪕⪤⪨⬄⬇⭄⭿⮮ⰴⱧⱼ⳩Āgt⥇⥋;쀀⋙̸Ā;v⥐௏쀀≫⃒ƀelt⥚⥲⥶ftĀar⥡⥧rrow;懍ightarrow;懎;쀀⋘̸Ā;v⥻ే쀀≪⃒ightarrow;懏ĀDd⦎⦓ash;抯ash;抮ʀbcnpt⦣⦧⦬⦱⧌la»˞ute;䅄g;쀀∠⃒ʀ;Eiop඄⦼⧀⧅⧈;쀀⩰̸d;쀀≋̸s;䅉roø඄urĀ;a⧓⧔普lĀ;s⧓ସǳ⧟\0⧣p肻 ଷmpĀ;e௹ఀʀaeouy⧴⧾⨃⨐⨓ǰ⧹\0⧻;橃on;䅈dil;䅆ngĀ;dൾ⨊ot;쀀⩭̸p;橂;䐽ash;怓΀;Aadqsxஒ⨩⨭⨻⩁⩅⩐rr;懗rĀhr⨳⨶k;椤Ā;oᏲᏰot;쀀≐̸uiöୣĀei⩊⩎ar;椨í஘istĀ;s஠டr;쀀𝔫ȀEest௅⩦⩹⩼ƀ;qs஼⩭௡ƀ;qs஼௅⩴lanô௢ií௪Ā;rஶ⪁»ஷƀAap⪊⪍⪑rò⥱rr;憮ar;櫲ƀ;svྍ⪜ྌĀ;d⪡⪢拼;拺cy;䑚΀AEadest⪷⪺⪾⫂⫅⫶⫹rò⥦;쀀≦̸rr;憚r;急Ȁ;fqs఻⫎⫣⫯tĀar⫔⫙rro÷⫁ightarro÷⪐ƀ;qs఻⪺⫪lanôౕĀ;sౕ⫴»శiíౝĀ;rవ⫾iĀ;eచథiäඐĀpt⬌⬑f;쀀𝕟膀¬;in⬙⬚⬶䂬nȀ;Edvஉ⬤⬨⬮;쀀⋹̸ot;쀀⋵̸ǡஉ⬳⬵;拷;拶iĀ;vಸ⬼ǡಸ⭁⭃;拾;拽ƀaor⭋⭣⭩rȀ;ast୻⭕⭚⭟lleì୻l;쀀⫽⃥;쀀∂̸lint;樔ƀ;ceಒ⭰⭳uåಥĀ;cಘ⭸Ā;eಒ⭽ñಘȀAait⮈⮋⮝⮧rò⦈rrƀ;cw⮔⮕⮙憛;쀀⤳̸;쀀↝̸ghtarrow»⮕riĀ;eೋೖ΀chimpqu⮽⯍⯙⬄୸⯤⯯Ȁ;cerല⯆ഷ⯉uå൅;쀀𝓃ortɭ⬅\0\0⯖ará⭖mĀ;e൮⯟Ā;q൴൳suĀbp⯫⯭å೸åഋƀbcp⯶ⰑⰙȀ;Ees⯿ⰀഢⰄ抄;쀀⫅̸etĀ;eഛⰋqĀ;qണⰀcĀ;eലⰗñസȀ;EesⰢⰣൟⰧ抅;쀀⫆̸etĀ;e൘ⰮqĀ;qൠⰣȀgilrⰽⰿⱅⱇìௗlde耻ñ䃱çృiangleĀlrⱒⱜeftĀ;eచⱚñదightĀ;eೋⱥñ೗Ā;mⱬⱭ䎽ƀ;esⱴⱵⱹ䀣ro;愖p;怇ҀDHadgilrsⲏⲔⲙⲞⲣⲰⲶⳓⳣash;抭arr;椄p;쀀≍⃒ash;抬ĀetⲨⲬ;쀀≥⃒;쀀>⃒nfin;槞ƀAetⲽⳁⳅrr;椂;쀀≤⃒Ā;rⳊⳍ쀀<⃒ie;쀀⊴⃒ĀAtⳘⳜrr;椃rie;쀀⊵⃒im;쀀∼⃒ƀAan⳰⳴ⴂrr;懖rĀhr⳺⳽k;椣Ā;oᏧᏥear;椧ቓ᪕\0\0\0\0\0\0\0\0\0\0\0\0\0ⴭ\0ⴸⵈⵠⵥ⵲ⶄᬇ\0\0ⶍⶫ\0ⷈⷎ\0ⷜ⸙⸫⸾⹃Ācsⴱ᪗ute耻ó䃳ĀiyⴼⵅrĀ;c᪞ⵂ耻ô䃴;䐾ʀabios᪠ⵒⵗǈⵚlac;䅑v;樸old;榼lig;䅓Ācr⵩⵭ir;榿;쀀𝔬ͯ⵹\0\0⵼\0ⶂn;䋛ave耻ò䃲;槁Ābmⶈ෴ar;榵Ȁacitⶕ⶘ⶥⶨrò᪀Āir⶝ⶠr;榾oss;榻nå๒;槀ƀaeiⶱⶵⶹcr;䅍ga;䏉ƀcdnⷀⷅǍron;䎿;榶pf;쀀𝕠ƀaelⷔ⷗ǒr;榷rp;榹΀;adiosvⷪⷫⷮ⸈⸍⸐⸖戨rò᪆Ȁ;efmⷷⷸ⸂⸅橝rĀ;oⷾⷿ愴f»ⷿ耻ª䂪耻º䂺gof;抶r;橖lope;橗;橛ƀclo⸟⸡⸧ò⸁ash耻ø䃸l;折iŬⸯ⸴de耻õ䃵esĀ;aǛ⸺s;樶ml耻ö䃶bar;挽ૡ⹞\0⹽\0⺀⺝\0⺢⺹\0\0⻋ຜ\0⼓\0\0⼫⾼\0⿈rȀ;astЃ⹧⹲຅脀¶;l⹭⹮䂶leìЃɩ⹸\0\0⹻m;櫳;櫽y;䐿rʀcimpt⺋⺏⺓ᡥ⺗nt;䀥od;䀮il;怰enk;怱r;쀀𝔭ƀimo⺨⺰⺴Ā;v⺭⺮䏆;䏕maô੶ne;明ƀ;tv⺿⻀⻈䏀chfork»´;䏖Āau⻏⻟nĀck⻕⻝kĀ;h⇴⻛;愎ö⇴sҀ;abcdemst⻳⻴ᤈ⻹⻽⼄⼆⼊⼎䀫cir;樣ir;樢Āouᵀ⼂;樥;橲n肻±ຝim;樦wo;樧ƀipu⼙⼠⼥ntint;樕f;쀀𝕡nd耻£䂣Ԁ;Eaceinosu່⼿⽁⽄⽇⾁⾉⾒⽾⾶;檳p;檷uå໙Ā;c໎⽌̀;acens່⽙⽟⽦⽨⽾pproø⽃urlyeñ໙ñ໎ƀaes⽯⽶⽺pprox;檹qq;檵im;拨iíໟmeĀ;s⾈ຮ怲ƀEas⽸⾐⽺ð⽵ƀdfp໬⾙⾯ƀals⾠⾥⾪lar;挮ine;挒urf;挓Ā;t໻⾴ï໻rel;抰Āci⿀⿅r;쀀𝓅;䏈ncsp;怈̀fiopsu⿚⋢⿟⿥⿫⿱r;쀀𝔮pf;쀀𝕢rime;恗cr;쀀𝓆ƀaeo⿸〉〓tĀei⿾々rnionóڰnt;樖stĀ;e【】䀿ñἙô༔઀ABHabcdefhilmnoprstux぀けさすムㄎㄫㅇㅢㅲㆎ㈆㈕㈤㈩㉘㉮㉲㊐㊰㊷ƀartぇおがròႳòϝail;検aròᱥar;楤΀cdenqrtとふへみわゔヌĀeuねぱ;쀀∽̱te;䅕iãᅮmptyv;榳gȀ;del࿑らるろ;榒;榥å࿑uo耻»䂻rր;abcfhlpstw࿜ガクシスゼゾダッデナp;極Ā;f࿠ゴs;椠;椳s;椞ë≝ð✮l;楅im;楴l;憣;憝Āaiパフil;椚oĀ;nホボ戶aló༞ƀabrョリヮrò៥rk;杳ĀakンヽcĀekヹ・;䁽;䁝Āes㄂㄄;榌lĀduㄊㄌ;榎;榐Ȁaeuyㄗㄜㄧㄩron;䅙Ādiㄡㄥil;䅗ì࿲âヺ;䑀Ȁclqsㄴㄷㄽㅄa;椷dhar;楩uoĀ;rȎȍh;憳ƀacgㅎㅟངlȀ;ipsླྀㅘㅛႜnåႻarôྩt;断ƀilrㅩဣㅮsht;楽;쀀𝔯ĀaoㅷㆆrĀduㅽㅿ»ѻĀ;l႑ㆄ;楬Ā;vㆋㆌ䏁;䏱ƀgns㆕ㇹㇼht̀ahlrstㆤㆰ㇂㇘㇤㇮rrowĀ;t࿜ㆭaéトarpoonĀduㆻㆿowîㅾp»႒eftĀah㇊㇐rrowó࿪arpoonóՑightarrows;應quigarro÷ニhreetimes;拌g;䋚ingdotseñἲƀahm㈍㈐㈓rò࿪aòՑ;怏oustĀ;a㈞㈟掱che»㈟mid;櫮Ȁabpt㈲㈽㉀㉒Ānr㈷㈺g;柭r;懾rëဃƀafl㉇㉊㉎r;榆;쀀𝕣us;樮imes;樵Āap㉝㉧rĀ;g㉣㉤䀩t;榔olint;樒arò㇣Ȁachq㉻㊀Ⴜ㊅quo;怺r;쀀𝓇Ābu・㊊oĀ;rȔȓƀhir㊗㊛㊠reåㇸmes;拊iȀ;efl㊪ၙᠡ㊫方tri;槎luhar;楨;愞ൡ㋕㋛㋟㌬㌸㍱\0㍺㎤\0\0㏬㏰\0㐨㑈㑚㒭㒱㓊㓱\0㘖\0\0㘳cute;䅛quï➺Ԁ;Eaceinpsyᇭ㋳㋵㋿㌂㌋㌏㌟㌦㌩;檴ǰ㋺\0㋼;檸on;䅡uåᇾĀ;dᇳ㌇il;䅟rc;䅝ƀEas㌖㌘㌛;檶p;檺im;择olint;樓iíሄ;䑁otƀ;be㌴ᵇ㌵担;橦΀Aacmstx㍆㍊㍗㍛㍞㍣㍭rr;懘rĀhr㍐㍒ë∨Ā;oਸ਼਴t耻§䂧i;䀻war;椩mĀin㍩ðnuóñt;朶rĀ;o㍶⁕쀀𝔰Ȁacoy㎂㎆㎑㎠rp;景Āhy㎋㎏cy;䑉;䑈rtɭ㎙\0\0㎜iäᑤaraì⹯耻­䂭Āgm㎨㎴maƀ;fv㎱㎲㎲䏃;䏂Ѐ;deglnprካ㏅㏉㏎㏖㏞㏡㏦ot;橪Ā;q኱ኰĀ;E㏓㏔檞;檠Ā;E㏛㏜檝;檟e;扆lus;樤arr;楲aròᄽȀaeit㏸㐈㐏㐗Āls㏽㐄lsetmé㍪hp;樳parsl;槤Ādlᑣ㐔e;挣Ā;e㐜㐝檪Ā;s㐢㐣檬;쀀⪬︀ƀflp㐮㐳㑂tcy;䑌Ā;b㐸㐹䀯Ā;a㐾㐿槄r;挿f;쀀𝕤aĀdr㑍ЂesĀ;u㑔㑕晠it»㑕ƀcsu㑠㑹㒟Āau㑥㑯pĀ;sᆈ㑫;쀀⊓︀pĀ;sᆴ㑵;쀀⊔︀uĀbp㑿㒏ƀ;esᆗᆜ㒆etĀ;eᆗ㒍ñᆝƀ;esᆨᆭ㒖etĀ;eᆨ㒝ñᆮƀ;afᅻ㒦ְrť㒫ֱ»ᅼaròᅈȀcemt㒹㒾㓂㓅r;쀀𝓈tmîñiì㐕aræᆾĀar㓎㓕rĀ;f㓔ឿ昆Āan㓚㓭ightĀep㓣㓪psiloîỠhé⺯s»⡒ʀbcmnp㓻㕞ሉ㖋㖎Ҁ;Edemnprs㔎㔏㔑㔕㔞㔣㔬㔱㔶抂;櫅ot;檽Ā;dᇚ㔚ot;櫃ult;櫁ĀEe㔨㔪;櫋;把lus;檿arr;楹ƀeiu㔽㕒㕕tƀ;en㔎㕅㕋qĀ;qᇚ㔏eqĀ;q㔫㔨m;櫇Ābp㕚㕜;櫕;櫓c̀;acensᇭ㕬㕲㕹㕻㌦pproø㋺urlyeñᇾñᇳƀaes㖂㖈㌛pproø㌚qñ㌗g;晪ڀ123;Edehlmnps㖩㖬㖯ሜ㖲㖴㗀㗉㗕㗚㗟㗨㗭耻¹䂹耻²䂲耻³䂳;櫆Āos㖹㖼t;檾ub;櫘Ā;dሢ㗅ot;櫄sĀou㗏㗒l;柉b;櫗arr;楻ult;櫂ĀEe㗤㗦;櫌;抋lus;櫀ƀeiu㗴㘉㘌tƀ;enሜ㗼㘂qĀ;qሢ㖲eqĀ;q㗧㗤m;櫈Ābp㘑㘓;櫔;櫖ƀAan㘜㘠㘭rr;懙rĀhr㘦㘨ë∮Ā;oਫ਩war;椪lig耻ß䃟௡㙑㙝㙠ዎ㙳㙹\0㙾㛂\0\0\0\0\0㛛㜃\0㜉㝬\0\0\0㞇ɲ㙖\0\0㙛get;挖;䏄rë๟ƀaey㙦㙫㙰ron;䅥dil;䅣;䑂lrec;挕r;쀀𝔱Ȁeiko㚆㚝㚵㚼ǲ㚋\0㚑eĀ4fኄኁaƀ;sv㚘㚙㚛䎸ym;䏑Ācn㚢㚲kĀas㚨㚮pproø዁im»ኬsðኞĀas㚺㚮ð዁rn耻þ䃾Ǭ̟㛆⋧es膀×;bd㛏㛐㛘䃗Ā;aᤏ㛕r;樱;樰ƀeps㛡㛣㜀á⩍Ȁ;bcf҆㛬㛰㛴ot;挶ir;櫱Ā;o㛹㛼쀀𝕥rk;櫚á㍢rime;怴ƀaip㜏㜒㝤dåቈ΀adempst㜡㝍㝀㝑㝗㝜㝟ngleʀ;dlqr㜰㜱㜶㝀㝂斵own»ᶻeftĀ;e⠀㜾ñम;扜ightĀ;e㊪㝋ñၚot;旬inus;樺lus;樹b;槍ime;樻ezium;揢ƀcht㝲㝽㞁Āry㝷㝻;쀀𝓉;䑆cy;䑛rok;䅧Āio㞋㞎xô᝷headĀlr㞗㞠eftarro÷ࡏightarrow»ཝऀAHabcdfghlmoprstuw㟐㟓㟗㟤㟰㟼㠎㠜㠣㠴㡑㡝㡫㢩㣌㣒㣪㣶ròϭar;楣Ācr㟜㟢ute耻ú䃺òᅐrǣ㟪\0㟭y;䑞ve;䅭Āiy㟵㟺rc耻û䃻;䑃ƀabh㠃㠆㠋ròᎭlac;䅱aòᏃĀir㠓㠘sht;楾;쀀𝔲rave耻ù䃹š㠧㠱rĀlr㠬㠮»ॗ»ႃlk;斀Āct㠹㡍ɯ㠿\0\0㡊rnĀ;e㡅㡆挜r»㡆op;挏ri;旸Āal㡖㡚cr;䅫肻¨͉Āgp㡢㡦on;䅳f;쀀𝕦̀adhlsuᅋ㡸㡽፲㢑㢠ownáᎳarpoonĀlr㢈㢌efô㠭ighô㠯iƀ;hl㢙㢚㢜䏅»ᏺon»㢚parrows;懈ƀcit㢰㣄㣈ɯ㢶\0\0㣁rnĀ;e㢼㢽挝r»㢽op;挎ng;䅯ri;旹cr;쀀𝓊ƀdir㣙㣝㣢ot;拰lde;䅩iĀ;f㜰㣨»᠓Āam㣯㣲rò㢨l耻ü䃼angle;榧ހABDacdeflnoprsz㤜㤟㤩㤭㦵㦸㦽㧟㧤㧨㧳㧹㧽㨁㨠ròϷarĀ;v㤦㤧櫨;櫩asèϡĀnr㤲㤷grt;榜΀eknprst㓣㥆㥋㥒㥝㥤㦖appá␕othinçẖƀhir㓫⻈㥙opô⾵Ā;hᎷ㥢ïㆍĀiu㥩㥭gmá㎳Ābp㥲㦄setneqĀ;q㥽㦀쀀⊊︀;쀀⫋︀setneqĀ;q㦏㦒쀀⊋︀;쀀⫌︀Āhr㦛㦟etá㚜iangleĀlr㦪㦯eft»थight»ၑy;䐲ash»ံƀelr㧄㧒㧗ƀ;beⷪ㧋㧏ar;抻q;扚lip;拮Ābt㧜ᑨaòᑩr;쀀𝔳tré㦮suĀbp㧯㧱»ജ»൙pf;쀀𝕧roð໻tré㦴Ācu㨆㨋r;쀀𝓋Ābp㨐㨘nĀEe㦀㨖»㥾nĀEe㦒㨞»㦐igzag;榚΀cefoprs㨶㨻㩖㩛㩔㩡㩪irc;䅵Ādi㩀㩑Ābg㩅㩉ar;機eĀ;qᗺ㩏;扙erp;愘r;쀀𝔴pf;쀀𝕨Ā;eᑹ㩦atèᑹcr;쀀𝓌ૣណ㪇\0㪋\0㪐㪛\0\0㪝㪨㪫㪯\0\0㫃㫎\0㫘ៜ៟tré៑r;쀀𝔵ĀAa㪔㪗ròσrò৶;䎾ĀAa㪡㪤ròθrò৫að✓is;拻ƀdptឤ㪵㪾Āfl㪺ឩ;쀀𝕩imåឲĀAa㫇㫊ròώròਁĀcq㫒ីr;쀀𝓍Āpt៖㫜ré។Ѐacefiosu㫰㫽㬈㬌㬑㬕㬛㬡cĀuy㫶㫻te耻ý䃽;䑏Āiy㬂㬆rc;䅷;䑋n耻¥䂥r;쀀𝔶cy;䑗pf;쀀𝕪cr;쀀𝓎Ācm㬦㬩y;䑎l耻ÿ䃿Ԁacdefhiosw㭂㭈㭔㭘㭤㭩㭭㭴㭺㮀cute;䅺Āay㭍㭒ron;䅾;䐷ot;䅼Āet㭝㭡træᕟa;䎶r;쀀𝔷cy;䐶grarr;懝pf;쀀𝕫cr;쀀𝓏Ājn㮅㮇;怍j;怌'.split("").map(e=>e.charCodeAt(0))),JB=new Map([[0,65533],[128,8364],[130,8218],[131,402],[132,8222],[133,8230],[134,8224],[135,8225],[136,710],[137,8240],[138,352],[139,8249],[140,338],[142,381],[145,8216],[146,8217],[147,8220],[148,8221],[149,8226],[150,8211],[151,8212],[152,732],[153,8482],[154,353],[155,8250],[156,339],[158,382],[159,376]]);function eU(e){var t;return e>=55296&&e<=57343||e>1114111?65533:(t=JB.get(e))!==null&&t!==void 0?t:e}var mr;(function(e){e[e.NUM=35]="NUM",e[e.SEMI=59]="SEMI",e[e.EQUALS=61]="EQUALS",e[e.ZERO=48]="ZERO",e[e.NINE=57]="NINE",e[e.LOWER_A=97]="LOWER_A",e[e.LOWER_F=102]="LOWER_F",e[e.LOWER_X=120]="LOWER_X",e[e.LOWER_Z=122]="LOWER_Z",e[e.UPPER_A=65]="UPPER_A",e[e.UPPER_F=70]="UPPER_F",e[e.UPPER_Z=90]="UPPER_Z"})(mr||(mr={}));const tU=32;var Js;(function(e){e[e.VALUE_LENGTH=49152]="VALUE_LENGTH",e[e.BRANCH_LENGTH=16256]="BRANCH_LENGTH",e[e.JUMP_TABLE=127]="JUMP_TABLE"})(Js||(Js={}));function cb(e){return e>=mr.ZERO&&e<=mr.NINE}function nU(e){return e>=mr.UPPER_A&&e<=mr.UPPER_F||e>=mr.LOWER_A&&e<=mr.LOWER_F}function rU(e){return e>=mr.UPPER_A&&e<=mr.UPPER_Z||e>=mr.LOWER_A&&e<=mr.LOWER_Z||cb(e)}function iU(e){return e===mr.EQUALS||rU(e)}var dr;(function(e){e[e.EntityStart=0]="EntityStart",e[e.NumericStart=1]="NumericStart",e[e.NumericDecimal=2]="NumericDecimal",e[e.NumericHex=3]="NumericHex",e[e.NamedEntity=4]="NamedEntity"})(dr||(dr={}));var Wa;(function(e){e[e.Legacy=0]="Legacy",e[e.Strict=1]="Strict",e[e.Attribute=2]="Attribute"})(Wa||(Wa={}));class aU{constructor(t,n,r){this.decodeTree=t,this.emitCodePoint=n,this.errors=r,this.state=dr.EntityStart,this.consumed=1,this.result=0,this.treeIndex=0,this.excess=1,this.decodeMode=Wa.Strict}startEntity(t){this.decodeMode=t,this.state=dr.EntityStart,this.result=0,this.treeIndex=0,this.excess=1,this.consumed=1}write(t,n){switch(this.state){case dr.EntityStart:return t.charCodeAt(n)===mr.NUM?(this.state=dr.NumericStart,this.consumed+=1,this.stateNumericStart(t,n+1)):(this.state=dr.NamedEntity,this.stateNamedEntity(t,n));case dr.NumericStart:return this.stateNumericStart(t,n);case dr.NumericDecimal:return this.stateNumericDecimal(t,n);case dr.NumericHex:return this.stateNumericHex(t,n);case dr.NamedEntity:return this.stateNamedEntity(t,n)}}stateNumericStart(t,n){return n>=t.length?-1:(t.charCodeAt(n)|tU)===mr.LOWER_X?(this.state=dr.NumericHex,this.consumed+=1,this.stateNumericHex(t,n+1)):(this.state=dr.NumericDecimal,this.stateNumericDecimal(t,n))}addToNumericResult(t,n,r,i){if(n!==r){const s=r-n;this.result=this.result*Math.pow(i,s)+Number.parseInt(t.substr(n,s),i),this.consumed+=s}}stateNumericHex(t,n){const r=n;for(;n<t.length;){const i=t.charCodeAt(n);if(cb(i)||nU(i))n+=1;else return this.addToNumericResult(t,r,n,16),this.emitNumericEntity(i,3)}return this.addToNumericResult(t,r,n,16),-1}stateNumericDecimal(t,n){const r=n;for(;n<t.length;){const i=t.charCodeAt(n);if(cb(i))n+=1;else return this.addToNumericResult(t,r,n,10),this.emitNumericEntity(i,2)}return this.addToNumericResult(t,r,n,10),-1}emitNumericEntity(t,n){var r;if(this.consumed<=n)return(r=this.errors)===null||r===void 0||r.absenceOfDigitsInNumericCharacterReference(this.consumed),0;if(t===mr.SEMI)this.consumed+=1;else if(this.decodeMode===Wa.Strict)return 0;return this.emitCodePoint(eU(this.result),this.consumed),this.errors&&(t!==mr.SEMI&&this.errors.missingSemicolonAfterCharacterReference(),this.errors.validateNumericCharacterReference(this.result)),this.consumed}stateNamedEntity(t,n){const{decodeTree:r}=this;let i=r[this.treeIndex],s=(i&Js.VALUE_LENGTH)>>14;for(;n<t.length;n++,this.excess++){const o=t.charCodeAt(n);if(this.treeIndex=sU(r,i,this.treeIndex+Math.max(1,s),o),this.treeIndex<0)return this.result===0||this.decodeMode===Wa.Attribute&&(s===0||iU(o))?0:this.emitNotTerminatedNamedEntity();if(i=r[this.treeIndex],s=(i&Js.VALUE_LENGTH)>>14,s!==0){if(o===mr.SEMI)return this.emitNamedEntityData(this.treeIndex,s,this.consumed+this.excess);this.decodeMode!==Wa.Strict&&(this.result=this.treeIndex,this.consumed+=this.excess,this.excess=0)}}return-1}emitNotTerminatedNamedEntity(){var t;const{result:n,decodeTree:r}=this,i=(r[n]&Js.VALUE_LENGTH)>>14;return this.emitNamedEntityData(n,i,this.consumed),(t=this.errors)===null||t===void 0||t.missingSemicolonAfterCharacterReference(),this.consumed}emitNamedEntityData(t,n,r){const{decodeTree:i}=this;return this.emitCodePoint(n===1?i[t]&~Js.VALUE_LENGTH:i[t+1],r),n===3&&this.emitCodePoint(i[t+2],r),r}end(){var t;switch(this.state){case dr.NamedEntity:return this.result!==0&&(this.decodeMode!==Wa.Attribute||this.result===this.treeIndex)?this.emitNotTerminatedNamedEntity():0;case dr.NumericDecimal:return this.emitNumericEntity(0,2);case dr.NumericHex:return this.emitNumericEntity(0,3);case dr.NumericStart:return(t=this.errors)===null||t===void 0||t.absenceOfDigitsInNumericCharacterReference(this.consumed),0;case dr.EntityStart:return 0}}}function sU(e,t,n,r){const i=(t&Js.BRANCH_LENGTH)>>7,s=t&Js.JUMP_TABLE;if(i===0)return s!==0&&r===s?n:-1;if(s){const d=r-s;return d<0||d>=i?-1:e[n+d]-1}let o=n,c=o+i-1;for(;o<=c;){const d=o+c>>>1,f=e[d];if(f<r)o=d+1;else if(f>r)c=d-1;else return e[d+i]}return-1}var ke;(function(e){e.HTML="http://www.w3.org/1999/xhtml",e.MATHML="http://www.w3.org/1998/Math/MathML",e.SVG="http://www.w3.org/2000/svg",e.XLINK="http://www.w3.org/1999/xlink",e.XML="http://www.w3.org/XML/1998/namespace",e.XMLNS="http://www.w3.org/2000/xmlns/"})(ke||(ke={}));var jl;(function(e){e.TYPE="type",e.ACTION="action",e.ENCODING="encoding",e.PROMPT="prompt",e.NAME="name",e.COLOR="color",e.FACE="face",e.SIZE="size"})(jl||(jl={}));var Pi;(function(e){e.NO_QUIRKS="no-quirks",e.QUIRKS="quirks",e.LIMITED_QUIRKS="limited-quirks"})(Pi||(Pi={}));var re;(function(e){e.A="a",e.ADDRESS="address",e.ANNOTATION_XML="annotation-xml",e.APPLET="applet",e.AREA="area",e.ARTICLE="article",e.ASIDE="aside",e.B="b",e.BASE="base",e.BASEFONT="basefont",e.BGSOUND="bgsound",e.BIG="big",e.BLOCKQUOTE="blockquote",e.BODY="body",e.BR="br",e.BUTTON="button",e.CAPTION="caption",e.CENTER="center",e.CODE="code",e.COL="col",e.COLGROUP="colgroup",e.DD="dd",e.DESC="desc",e.DETAILS="details",e.DIALOG="dialog",e.DIR="dir",e.DIV="div",e.DL="dl",e.DT="dt",e.EM="em",e.EMBED="embed",e.FIELDSET="fieldset",e.FIGCAPTION="figcaption",e.FIGURE="figure",e.FONT="font",e.FOOTER="footer",e.FOREIGN_OBJECT="foreignObject",e.FORM="form",e.FRAME="frame",e.FRAMESET="frameset",e.H1="h1",e.H2="h2",e.H3="h3",e.H4="h4",e.H5="h5",e.H6="h6",e.HEAD="head",e.HEADER="header",e.HGROUP="hgroup",e.HR="hr",e.HTML="html",e.I="i",e.IMG="img",e.IMAGE="image",e.INPUT="input",e.IFRAME="iframe",e.KEYGEN="keygen",e.LABEL="label",e.LI="li",e.LINK="link",e.LISTING="listing",e.MAIN="main",e.MALIGNMARK="malignmark",e.MARQUEE="marquee",e.MATH="math",e.MENU="menu",e.META="meta",e.MGLYPH="mglyph",e.MI="mi",e.MO="mo",e.MN="mn",e.MS="ms",e.MTEXT="mtext",e.NAV="nav",e.NOBR="nobr",e.NOFRAMES="noframes",e.NOEMBED="noembed",e.NOSCRIPT="noscript",e.OBJECT="object",e.OL="ol",e.OPTGROUP="optgroup",e.OPTION="option",e.P="p",e.PARAM="param",e.PLAINTEXT="plaintext",e.PRE="pre",e.RB="rb",e.RP="rp",e.RT="rt",e.RTC="rtc",e.RUBY="ruby",e.S="s",e.SCRIPT="script",e.SEARCH="search",e.SECTION="section",e.SELECT="select",e.SOURCE="source",e.SMALL="small",e.SPAN="span",e.STRIKE="strike",e.STRONG="strong",e.STYLE="style",e.SUB="sub",e.SUMMARY="summary",e.SUP="sup",e.TABLE="table",e.TBODY="tbody",e.TEMPLATE="template",e.TEXTAREA="textarea",e.TFOOT="tfoot",e.TD="td",e.TH="th",e.THEAD="thead",e.TITLE="title",e.TR="tr",e.TRACK="track",e.TT="tt",e.U="u",e.UL="ul",e.SVG="svg",e.VAR="var",e.WBR="wbr",e.XMP="xmp"})(re||(re={}));var y;(function(e){e[e.UNKNOWN=0]="UNKNOWN",e[e.A=1]="A",e[e.ADDRESS=2]="ADDRESS",e[e.ANNOTATION_XML=3]="ANNOTATION_XML",e[e.APPLET=4]="APPLET",e[e.AREA=5]="AREA",e[e.ARTICLE=6]="ARTICLE",e[e.ASIDE=7]="ASIDE",e[e.B=8]="B",e[e.BASE=9]="BASE",e[e.BASEFONT=10]="BASEFONT",e[e.BGSOUND=11]="BGSOUND",e[e.BIG=12]="BIG",e[e.BLOCKQUOTE=13]="BLOCKQUOTE",e[e.BODY=14]="BODY",e[e.BR=15]="BR",e[e.BUTTON=16]="BUTTON",e[e.CAPTION=17]="CAPTION",e[e.CENTER=18]="CENTER",e[e.CODE=19]="CODE",e[e.COL=20]="COL",e[e.COLGROUP=21]="COLGROUP",e[e.DD=22]="DD",e[e.DESC=23]="DESC",e[e.DETAILS=24]="DETAILS",e[e.DIALOG=25]="DIALOG",e[e.DIR=26]="DIR",e[e.DIV=27]="DIV",e[e.DL=28]="DL",e[e.DT=29]="DT",e[e.EM=30]="EM",e[e.EMBED=31]="EMBED",e[e.FIELDSET=32]="FIELDSET",e[e.FIGCAPTION=33]="FIGCAPTION",e[e.FIGURE=34]="FIGURE",e[e.FONT=35]="FONT",e[e.FOOTER=36]="FOOTER",e[e.FOREIGN_OBJECT=37]="FOREIGN_OBJECT",e[e.FORM=38]="FORM",e[e.FRAME=39]="FRAME",e[e.FRAMESET=40]="FRAMESET",e[e.H1=41]="H1",e[e.H2=42]="H2",e[e.H3=43]="H3",e[e.H4=44]="H4",e[e.H5=45]="H5",e[e.H6=46]="H6",e[e.HEAD=47]="HEAD",e[e.HEADER=48]="HEADER",e[e.HGROUP=49]="HGROUP",e[e.HR=50]="HR",e[e.HTML=51]="HTML",e[e.I=52]="I",e[e.IMG=53]="IMG",e[e.IMAGE=54]="IMAGE",e[e.INPUT=55]="INPUT",e[e.IFRAME=56]="IFRAME",e[e.KEYGEN=57]="KEYGEN",e[e.LABEL=58]="LABEL",e[e.LI=59]="LI",e[e.LINK=60]="LINK",e[e.LISTING=61]="LISTING",e[e.MAIN=62]="MAIN",e[e.MALIGNMARK=63]="MALIGNMARK",e[e.MARQUEE=64]="MARQUEE",e[e.MATH=65]="MATH",e[e.MENU=66]="MENU",e[e.META=67]="META",e[e.MGLYPH=68]="MGLYPH",e[e.MI=69]="MI",e[e.MO=70]="MO",e[e.MN=71]="MN",e[e.MS=72]="MS",e[e.MTEXT=73]="MTEXT",e[e.NAV=74]="NAV",e[e.NOBR=75]="NOBR",e[e.NOFRAMES=76]="NOFRAMES",e[e.NOEMBED=77]="NOEMBED",e[e.NOSCRIPT=78]="NOSCRIPT",e[e.OBJECT=79]="OBJECT",e[e.OL=80]="OL",e[e.OPTGROUP=81]="OPTGROUP",e[e.OPTION=82]="OPTION",e[e.P=83]="P",e[e.PARAM=84]="PARAM",e[e.PLAINTEXT=85]="PLAINTEXT",e[e.PRE=86]="PRE",e[e.RB=87]="RB",e[e.RP=88]="RP",e[e.RT=89]="RT",e[e.RTC=90]="RTC",e[e.RUBY=91]="RUBY",e[e.S=92]="S",e[e.SCRIPT=93]="SCRIPT",e[e.SEARCH=94]="SEARCH",e[e.SECTION=95]="SECTION",e[e.SELECT=96]="SELECT",e[e.SOURCE=97]="SOURCE",e[e.SMALL=98]="SMALL",e[e.SPAN=99]="SPAN",e[e.STRIKE=100]="STRIKE",e[e.STRONG=101]="STRONG",e[e.STYLE=102]="STYLE",e[e.SUB=103]="SUB",e[e.SUMMARY=104]="SUMMARY",e[e.SUP=105]="SUP",e[e.TABLE=106]="TABLE",e[e.TBODY=107]="TBODY",e[e.TEMPLATE=108]="TEMPLATE",e[e.TEXTAREA=109]="TEXTAREA",e[e.TFOOT=110]="TFOOT",e[e.TD=111]="TD",e[e.TH=112]="TH",e[e.THEAD=113]="THEAD",e[e.TITLE=114]="TITLE",e[e.TR=115]="TR",e[e.TRACK=116]="TRACK",e[e.TT=117]="TT",e[e.U=118]="U",e[e.UL=119]="UL",e[e.SVG=120]="SVG",e[e.VAR=121]="VAR",e[e.WBR=122]="WBR",e[e.XMP=123]="XMP"})(y||(y={}));const lU=new Map([[re.A,y.A],[re.ADDRESS,y.ADDRESS],[re.ANNOTATION_XML,y.ANNOTATION_XML],[re.APPLET,y.APPLET],[re.AREA,y.AREA],[re.ARTICLE,y.ARTICLE],[re.ASIDE,y.ASIDE],[re.B,y.B],[re.BASE,y.BASE],[re.BASEFONT,y.BASEFONT],[re.BGSOUND,y.BGSOUND],[re.BIG,y.BIG],[re.BLOCKQUOTE,y.BLOCKQUOTE],[re.BODY,y.BODY],[re.BR,y.BR],[re.BUTTON,y.BUTTON],[re.CAPTION,y.CAPTION],[re.CENTER,y.CENTER],[re.CODE,y.CODE],[re.COL,y.COL],[re.COLGROUP,y.COLGROUP],[re.DD,y.DD],[re.DESC,y.DESC],[re.DETAILS,y.DETAILS],[re.DIALOG,y.DIALOG],[re.DIR,y.DIR],[re.DIV,y.DIV],[re.DL,y.DL],[re.DT,y.DT],[re.EM,y.EM],[re.EMBED,y.EMBED],[re.FIELDSET,y.FIELDSET],[re.FIGCAPTION,y.FIGCAPTION],[re.FIGURE,y.FIGURE],[re.FONT,y.FONT],[re.FOOTER,y.FOOTER],[re.FOREIGN_OBJECT,y.FOREIGN_OBJECT],[re.FORM,y.FORM],[re.FRAME,y.FRAME],[re.FRAMESET,y.FRAMESET],[re.H1,y.H1],[re.H2,y.H2],[re.H3,y.H3],[re.H4,y.H4],[re.H5,y.H5],[re.H6,y.H6],[re.HEAD,y.HEAD],[re.HEADER,y.HEADER],[re.HGROUP,y.HGROUP],[re.HR,y.HR],[re.HTML,y.HTML],[re.I,y.I],[re.IMG,y.IMG],[re.IMAGE,y.IMAGE],[re.INPUT,y.INPUT],[re.IFRAME,y.IFRAME],[re.KEYGEN,y.KEYGEN],[re.LABEL,y.LABEL],[re.LI,y.LI],[re.LINK,y.LINK],[re.LISTING,y.LISTING],[re.MAIN,y.MAIN],[re.MALIGNMARK,y.MALIGNMARK],[re.MARQUEE,y.MARQUEE],[re.MATH,y.MATH],[re.MENU,y.MENU],[re.META,y.META],[re.MGLYPH,y.MGLYPH],[re.MI,y.MI],[re.MO,y.MO],[re.MN,y.MN],[re.MS,y.MS],[re.MTEXT,y.MTEXT],[re.NAV,y.NAV],[re.NOBR,y.NOBR],[re.NOFRAMES,y.NOFRAMES],[re.NOEMBED,y.NOEMBED],[re.NOSCRIPT,y.NOSCRIPT],[re.OBJECT,y.OBJECT],[re.OL,y.OL],[re.OPTGROUP,y.OPTGROUP],[re.OPTION,y.OPTION],[re.P,y.P],[re.PARAM,y.PARAM],[re.PLAINTEXT,y.PLAINTEXT],[re.PRE,y.PRE],[re.RB,y.RB],[re.RP,y.RP],[re.RT,y.RT],[re.RTC,y.RTC],[re.RUBY,y.RUBY],[re.S,y.S],[re.SCRIPT,y.SCRIPT],[re.SEARCH,y.SEARCH],[re.SECTION,y.SECTION],[re.SELECT,y.SELECT],[re.SOURCE,y.SOURCE],[re.SMALL,y.SMALL],[re.SPAN,y.SPAN],[re.STRIKE,y.STRIKE],[re.STRONG,y.STRONG],[re.STYLE,y.STYLE],[re.SUB,y.SUB],[re.SUMMARY,y.SUMMARY],[re.SUP,y.SUP],[re.TABLE,y.TABLE],[re.TBODY,y.TBODY],[re.TEMPLATE,y.TEMPLATE],[re.TEXTAREA,y.TEXTAREA],[re.TFOOT,y.TFOOT],[re.TD,y.TD],[re.TH,y.TH],[re.THEAD,y.THEAD],[re.TITLE,y.TITLE],[re.TR,y.TR],[re.TRACK,y.TRACK],[re.TT,y.TT],[re.U,y.U],[re.UL,y.UL],[re.SVG,y.SVG],[re.VAR,y.VAR],[re.WBR,y.WBR],[re.XMP,y.XMP]]);function vu(e){var t;return(t=lU.get(e))!==null&&t!==void 0?t:y.UNKNOWN}const Ne=y,oU={[ke.HTML]:new Set([Ne.ADDRESS,Ne.APPLET,Ne.AREA,Ne.ARTICLE,Ne.ASIDE,Ne.BASE,Ne.BASEFONT,Ne.BGSOUND,Ne.BLOCKQUOTE,Ne.BODY,Ne.BR,Ne.BUTTON,Ne.CAPTION,Ne.CENTER,Ne.COL,Ne.COLGROUP,Ne.DD,Ne.DETAILS,Ne.DIR,Ne.DIV,Ne.DL,Ne.DT,Ne.EMBED,Ne.FIELDSET,Ne.FIGCAPTION,Ne.FIGURE,Ne.FOOTER,Ne.FORM,Ne.FRAME,Ne.FRAMESET,Ne.H1,Ne.H2,Ne.H3,Ne.H4,Ne.H5,Ne.H6,Ne.HEAD,Ne.HEADER,Ne.HGROUP,Ne.HR,Ne.HTML,Ne.IFRAME,Ne.IMG,Ne.INPUT,Ne.LI,Ne.LINK,Ne.LISTING,Ne.MAIN,Ne.MARQUEE,Ne.MENU,Ne.META,Ne.NAV,Ne.NOEMBED,Ne.NOFRAMES,Ne.NOSCRIPT,Ne.OBJECT,Ne.OL,Ne.P,Ne.PARAM,Ne.PLAINTEXT,Ne.PRE,Ne.SCRIPT,Ne.SECTION,Ne.SELECT,Ne.SOURCE,Ne.STYLE,Ne.SUMMARY,Ne.TABLE,Ne.TBODY,Ne.TD,Ne.TEMPLATE,Ne.TEXTAREA,Ne.TFOOT,Ne.TH,Ne.THEAD,Ne.TITLE,Ne.TR,Ne.TRACK,Ne.UL,Ne.WBR,Ne.XMP]),[ke.MATHML]:new Set([Ne.MI,Ne.MO,Ne.MN,Ne.MS,Ne.MTEXT,Ne.ANNOTATION_XML]),[ke.SVG]:new Set([Ne.TITLE,Ne.FOREIGN_OBJECT,Ne.DESC]),[ke.XLINK]:new Set,[ke.XML]:new Set,[ke.XMLNS]:new Set},db=new Set([Ne.H1,Ne.H2,Ne.H3,Ne.H4,Ne.H5,Ne.H6]);re.STYLE,re.SCRIPT,re.XMP,re.IFRAME,re.NOEMBED,re.NOFRAMES,re.PLAINTEXT;var U;(function(e){e[e.DATA=0]="DATA",e[e.RCDATA=1]="RCDATA",e[e.RAWTEXT=2]="RAWTEXT",e[e.SCRIPT_DATA=3]="SCRIPT_DATA",e[e.PLAINTEXT=4]="PLAINTEXT",e[e.TAG_OPEN=5]="TAG_OPEN",e[e.END_TAG_OPEN=6]="END_TAG_OPEN",e[e.TAG_NAME=7]="TAG_NAME",e[e.RCDATA_LESS_THAN_SIGN=8]="RCDATA_LESS_THAN_SIGN",e[e.RCDATA_END_TAG_OPEN=9]="RCDATA_END_TAG_OPEN",e[e.RCDATA_END_TAG_NAME=10]="RCDATA_END_TAG_NAME",e[e.RAWTEXT_LESS_THAN_SIGN=11]="RAWTEXT_LESS_THAN_SIGN",e[e.RAWTEXT_END_TAG_OPEN=12]="RAWTEXT_END_TAG_OPEN",e[e.RAWTEXT_END_TAG_NAME=13]="RAWTEXT_END_TAG_NAME",e[e.SCRIPT_DATA_LESS_THAN_SIGN=14]="SCRIPT_DATA_LESS_THAN_SIGN",e[e.SCRIPT_DATA_END_TAG_OPEN=15]="SCRIPT_DATA_END_TAG_OPEN",e[e.SCRIPT_DATA_END_TAG_NAME=16]="SCRIPT_DATA_END_TAG_NAME",e[e.SCRIPT_DATA_ESCAPE_START=17]="SCRIPT_DATA_ESCAPE_START",e[e.SCRIPT_DATA_ESCAPE_START_DASH=18]="SCRIPT_DATA_ESCAPE_START_DASH",e[e.SCRIPT_DATA_ESCAPED=19]="SCRIPT_DATA_ESCAPED",e[e.SCRIPT_DATA_ESCAPED_DASH=20]="SCRIPT_DATA_ESCAPED_DASH",e[e.SCRIPT_DATA_ESCAPED_DASH_DASH=21]="SCRIPT_DATA_ESCAPED_DASH_DASH",e[e.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN=22]="SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN",e[e.SCRIPT_DATA_ESCAPED_END_TAG_OPEN=23]="SCRIPT_DATA_ESCAPED_END_TAG_OPEN",e[e.SCRIPT_DATA_ESCAPED_END_TAG_NAME=24]="SCRIPT_DATA_ESCAPED_END_TAG_NAME",e[e.SCRIPT_DATA_DOUBLE_ESCAPE_START=25]="SCRIPT_DATA_DOUBLE_ESCAPE_START",e[e.SCRIPT_DATA_DOUBLE_ESCAPED=26]="SCRIPT_DATA_DOUBLE_ESCAPED",e[e.SCRIPT_DATA_DOUBLE_ESCAPED_DASH=27]="SCRIPT_DATA_DOUBLE_ESCAPED_DASH",e[e.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH=28]="SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH",e[e.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN=29]="SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN",e[e.SCRIPT_DATA_DOUBLE_ESCAPE_END=30]="SCRIPT_DATA_DOUBLE_ESCAPE_END",e[e.BEFORE_ATTRIBUTE_NAME=31]="BEFORE_ATTRIBUTE_NAME",e[e.ATTRIBUTE_NAME=32]="ATTRIBUTE_NAME",e[e.AFTER_ATTRIBUTE_NAME=33]="AFTER_ATTRIBUTE_NAME",e[e.BEFORE_ATTRIBUTE_VALUE=34]="BEFORE_ATTRIBUTE_VALUE",e[e.ATTRIBUTE_VALUE_DOUBLE_QUOTED=35]="ATTRIBUTE_VALUE_DOUBLE_QUOTED",e[e.ATTRIBUTE_VALUE_SINGLE_QUOTED=36]="ATTRIBUTE_VALUE_SINGLE_QUOTED",e[e.ATTRIBUTE_VALUE_UNQUOTED=37]="ATTRIBUTE_VALUE_UNQUOTED",e[e.AFTER_ATTRIBUTE_VALUE_QUOTED=38]="AFTER_ATTRIBUTE_VALUE_QUOTED",e[e.SELF_CLOSING_START_TAG=39]="SELF_CLOSING_START_TAG",e[e.BOGUS_COMMENT=40]="BOGUS_COMMENT",e[e.MARKUP_DECLARATION_OPEN=41]="MARKUP_DECLARATION_OPEN",e[e.COMMENT_START=42]="COMMENT_START",e[e.COMMENT_START_DASH=43]="COMMENT_START_DASH",e[e.COMMENT=44]="COMMENT",e[e.COMMENT_LESS_THAN_SIGN=45]="COMMENT_LESS_THAN_SIGN",e[e.COMMENT_LESS_THAN_SIGN_BANG=46]="COMMENT_LESS_THAN_SIGN_BANG",e[e.COMMENT_LESS_THAN_SIGN_BANG_DASH=47]="COMMENT_LESS_THAN_SIGN_BANG_DASH",e[e.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH=48]="COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH",e[e.COMMENT_END_DASH=49]="COMMENT_END_DASH",e[e.COMMENT_END=50]="COMMENT_END",e[e.COMMENT_END_BANG=51]="COMMENT_END_BANG",e[e.DOCTYPE=52]="DOCTYPE",e[e.BEFORE_DOCTYPE_NAME=53]="BEFORE_DOCTYPE_NAME",e[e.DOCTYPE_NAME=54]="DOCTYPE_NAME",e[e.AFTER_DOCTYPE_NAME=55]="AFTER_DOCTYPE_NAME",e[e.AFTER_DOCTYPE_PUBLIC_KEYWORD=56]="AFTER_DOCTYPE_PUBLIC_KEYWORD",e[e.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER=57]="BEFORE_DOCTYPE_PUBLIC_IDENTIFIER",e[e.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED=58]="DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED",e[e.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED=59]="DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED",e[e.AFTER_DOCTYPE_PUBLIC_IDENTIFIER=60]="AFTER_DOCTYPE_PUBLIC_IDENTIFIER",e[e.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS=61]="BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS",e[e.AFTER_DOCTYPE_SYSTEM_KEYWORD=62]="AFTER_DOCTYPE_SYSTEM_KEYWORD",e[e.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER=63]="BEFORE_DOCTYPE_SYSTEM_IDENTIFIER",e[e.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED=64]="DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED",e[e.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED=65]="DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED",e[e.AFTER_DOCTYPE_SYSTEM_IDENTIFIER=66]="AFTER_DOCTYPE_SYSTEM_IDENTIFIER",e[e.BOGUS_DOCTYPE=67]="BOGUS_DOCTYPE",e[e.CDATA_SECTION=68]="CDATA_SECTION",e[e.CDATA_SECTION_BRACKET=69]="CDATA_SECTION_BRACKET",e[e.CDATA_SECTION_END=70]="CDATA_SECTION_END",e[e.CHARACTER_REFERENCE=71]="CHARACTER_REFERENCE",e[e.AMBIGUOUS_AMPERSAND=72]="AMBIGUOUS_AMPERSAND"})(U||(U={}));const Kn={DATA:U.DATA,RCDATA:U.RCDATA,RAWTEXT:U.RAWTEXT,SCRIPT_DATA:U.SCRIPT_DATA,PLAINTEXT:U.PLAINTEXT,CDATA_SECTION:U.CDATA_SECTION};function uU(e){return e>=L.DIGIT_0&&e<=L.DIGIT_9}function Bc(e){return e>=L.LATIN_CAPITAL_A&&e<=L.LATIN_CAPITAL_Z}function cU(e){return e>=L.LATIN_SMALL_A&&e<=L.LATIN_SMALL_Z}function Ks(e){return cU(e)||Bc(e)}function ME(e){return Ks(e)||uU(e)}function fh(e){return e+32}function vT(e){return e===L.SPACE||e===L.LINE_FEED||e===L.TABULATION||e===L.FORM_FEED}function IE(e){return vT(e)||e===L.SOLIDUS||e===L.GREATER_THAN_SIGN}function dU(e){return e===L.NULL?be.nullCharacterReference:e>1114111?be.characterReferenceOutsideUnicodeRange:mT(e)?be.surrogateCharacterReference:gT(e)?be.noncharacterCharacterReference:pT(e)||e===L.CARRIAGE_RETURN?be.controlCharacterReference:null}class hU{constructor(t,n){this.options=t,this.handler=n,this.paused=!1,this.inLoop=!1,this.inForeignNode=!1,this.lastStartTagName="",this.active=!1,this.state=U.DATA,this.returnState=U.DATA,this.entityStartPos=0,this.consumedAfterSnapshot=-1,this.currentCharacterToken=null,this.currentToken=null,this.currentAttr={name:"",value:""},this.preprocessor=new QB(n),this.currentLocation=this.getCurrentLocation(-1),this.entityDecoder=new aU(ZB,(r,i)=>{this.preprocessor.pos=this.entityStartPos+i-1,this._flushCodePointConsumedAsCharacterReference(r)},n.onParseError?{missingSemicolonAfterCharacterReference:()=>{this._err(be.missingSemicolonAfterCharacterReference,1)},absenceOfDigitsInNumericCharacterReference:r=>{this._err(be.absenceOfDigitsInNumericCharacterReference,this.entityStartPos-this.preprocessor.pos+r)},validateNumericCharacterReference:r=>{const i=dU(r);i&&this._err(i,1)}}:void 0)}_err(t,n=0){var r,i;(i=(r=this.handler).onParseError)===null||i===void 0||i.call(r,this.preprocessor.getError(t,n))}getCurrentLocation(t){return this.options.sourceCodeLocationInfo?{startLine:this.preprocessor.line,startCol:this.preprocessor.col-t,startOffset:this.preprocessor.offset-t,endLine:-1,endCol:-1,endOffset:-1}:null}_runParsingLoop(){if(!this.inLoop){for(this.inLoop=!0;this.active&&!this.paused;){this.consumedAfterSnapshot=0;const t=this._consume();this._ensureHibernation()||this._callState(t)}this.inLoop=!1}}pause(){this.paused=!0}resume(t){if(!this.paused)throw new Error("Parser was already resumed");this.paused=!1,!this.inLoop&&(this._runParsingLoop(),this.paused||t==null||t())}write(t,n,r){this.active=!0,this.preprocessor.write(t,n),this._runParsingLoop(),this.paused||r==null||r()}insertHtmlAtCurrentPos(t){this.active=!0,this.preprocessor.insertHtmlAtCurrentPos(t),this._runParsingLoop()}_ensureHibernation(){return this.preprocessor.endOfChunkHit?(this.preprocessor.retreat(this.consumedAfterSnapshot),this.consumedAfterSnapshot=0,this.active=!1,!0):!1}_consume(){return this.consumedAfterSnapshot++,this.preprocessor.advance()}_advanceBy(t){this.consumedAfterSnapshot+=t;for(let n=0;n<t;n++)this.preprocessor.advance()}_consumeSequenceIfMatch(t,n){return this.preprocessor.startsWith(t,n)?(this._advanceBy(t.length-1),!0):!1}_createStartTagToken(){this.currentToken={type:Nt.START_TAG,tagName:"",tagID:y.UNKNOWN,selfClosing:!1,ackSelfClosing:!1,attrs:[],location:this.getCurrentLocation(1)}}_createEndTagToken(){this.currentToken={type:Nt.END_TAG,tagName:"",tagID:y.UNKNOWN,selfClosing:!1,ackSelfClosing:!1,attrs:[],location:this.getCurrentLocation(2)}}_createCommentToken(t){this.currentToken={type:Nt.COMMENT,data:"",location:this.getCurrentLocation(t)}}_createDoctypeToken(t){this.currentToken={type:Nt.DOCTYPE,name:t,forceQuirks:!1,publicId:null,systemId:null,location:this.currentLocation}}_createCharacterToken(t,n){this.currentCharacterToken={type:t,chars:n,location:this.currentLocation}}_createAttr(t){this.currentAttr={name:t,value:""},this.currentLocation=this.getCurrentLocation(0)}_leaveAttrName(){var t,n;const r=this.currentToken;if(bT(r,this.currentAttr.name)===null){if(r.attrs.push(this.currentAttr),r.location&&this.currentLocation){const i=(t=(n=r.location).attrs)!==null&&t!==void 0?t:n.attrs=Object.create(null);i[this.currentAttr.name]=this.currentLocation,this._leaveAttrValue()}}else this._err(be.duplicateAttribute)}_leaveAttrValue(){this.currentLocation&&(this.currentLocation.endLine=this.preprocessor.line,this.currentLocation.endCol=this.preprocessor.col,this.currentLocation.endOffset=this.preprocessor.offset)}prepareToken(t){this._emitCurrentCharacterToken(t.location),this.currentToken=null,t.location&&(t.location.endLine=this.preprocessor.line,t.location.endCol=this.preprocessor.col+1,t.location.endOffset=this.preprocessor.offset+1),this.currentLocation=this.getCurrentLocation(-1)}emitCurrentTagToken(){const t=this.currentToken;this.prepareToken(t),t.tagID=vu(t.tagName),t.type===Nt.START_TAG?(this.lastStartTagName=t.tagName,this.handler.onStartTag(t)):(t.attrs.length>0&&this._err(be.endTagWithAttributes),t.selfClosing&&this._err(be.endTagWithTrailingSolidus),this.handler.onEndTag(t)),this.preprocessor.dropParsedChunk()}emitCurrentComment(t){this.prepareToken(t),this.handler.onComment(t),this.preprocessor.dropParsedChunk()}emitCurrentDoctype(t){this.prepareToken(t),this.handler.onDoctype(t),this.preprocessor.dropParsedChunk()}_emitCurrentCharacterToken(t){if(this.currentCharacterToken){switch(t&&this.currentCharacterToken.location&&(this.currentCharacterToken.location.endLine=t.startLine,this.currentCharacterToken.location.endCol=t.startCol,this.currentCharacterToken.location.endOffset=t.startOffset),this.currentCharacterToken.type){case Nt.CHARACTER:{this.handler.onCharacter(this.currentCharacterToken);break}case Nt.NULL_CHARACTER:{this.handler.onNullCharacter(this.currentCharacterToken);break}case Nt.WHITESPACE_CHARACTER:{this.handler.onWhitespaceCharacter(this.currentCharacterToken);break}}this.currentCharacterToken=null}}_emitEOFToken(){const t=this.getCurrentLocation(0);t&&(t.endLine=t.startLine,t.endCol=t.startCol,t.endOffset=t.startOffset),this._emitCurrentCharacterToken(t),this.handler.onEof({type:Nt.EOF,location:t}),this.active=!1}_appendCharToCurrentCharacterToken(t,n){if(this.currentCharacterToken)if(this.currentCharacterToken.type===t){this.currentCharacterToken.chars+=n;return}else this.currentLocation=this.getCurrentLocation(0),this._emitCurrentCharacterToken(this.currentLocation),this.preprocessor.dropParsedChunk();this._createCharacterToken(t,n)}_emitCodePoint(t){const n=vT(t)?Nt.WHITESPACE_CHARACTER:t===L.NULL?Nt.NULL_CHARACTER:Nt.CHARACTER;this._appendCharToCurrentCharacterToken(n,String.fromCodePoint(t))}_emitChars(t){this._appendCharToCurrentCharacterToken(Nt.CHARACTER,t)}_startCharacterReference(){this.returnState=this.state,this.state=U.CHARACTER_REFERENCE,this.entityStartPos=this.preprocessor.pos,this.entityDecoder.startEntity(this._isCharacterReferenceInAttribute()?Wa.Attribute:Wa.Legacy)}_isCharacterReferenceInAttribute(){return this.returnState===U.ATTRIBUTE_VALUE_DOUBLE_QUOTED||this.returnState===U.ATTRIBUTE_VALUE_SINGLE_QUOTED||this.returnState===U.ATTRIBUTE_VALUE_UNQUOTED}_flushCodePointConsumedAsCharacterReference(t){this._isCharacterReferenceInAttribute()?this.currentAttr.value+=String.fromCodePoint(t):this._emitCodePoint(t)}_callState(t){switch(this.state){case U.DATA:{this._stateData(t);break}case U.RCDATA:{this._stateRcdata(t);break}case U.RAWTEXT:{this._stateRawtext(t);break}case U.SCRIPT_DATA:{this._stateScriptData(t);break}case U.PLAINTEXT:{this._statePlaintext(t);break}case U.TAG_OPEN:{this._stateTagOpen(t);break}case U.END_TAG_OPEN:{this._stateEndTagOpen(t);break}case U.TAG_NAME:{this._stateTagName(t);break}case U.RCDATA_LESS_THAN_SIGN:{this._stateRcdataLessThanSign(t);break}case U.RCDATA_END_TAG_OPEN:{this._stateRcdataEndTagOpen(t);break}case U.RCDATA_END_TAG_NAME:{this._stateRcdataEndTagName(t);break}case U.RAWTEXT_LESS_THAN_SIGN:{this._stateRawtextLessThanSign(t);break}case U.RAWTEXT_END_TAG_OPEN:{this._stateRawtextEndTagOpen(t);break}case U.RAWTEXT_END_TAG_NAME:{this._stateRawtextEndTagName(t);break}case U.SCRIPT_DATA_LESS_THAN_SIGN:{this._stateScriptDataLessThanSign(t);break}case U.SCRIPT_DATA_END_TAG_OPEN:{this._stateScriptDataEndTagOpen(t);break}case U.SCRIPT_DATA_END_TAG_NAME:{this._stateScriptDataEndTagName(t);break}case U.SCRIPT_DATA_ESCAPE_START:{this._stateScriptDataEscapeStart(t);break}case U.SCRIPT_DATA_ESCAPE_START_DASH:{this._stateScriptDataEscapeStartDash(t);break}case U.SCRIPT_DATA_ESCAPED:{this._stateScriptDataEscaped(t);break}case U.SCRIPT_DATA_ESCAPED_DASH:{this._stateScriptDataEscapedDash(t);break}case U.SCRIPT_DATA_ESCAPED_DASH_DASH:{this._stateScriptDataEscapedDashDash(t);break}case U.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN:{this._stateScriptDataEscapedLessThanSign(t);break}case U.SCRIPT_DATA_ESCAPED_END_TAG_OPEN:{this._stateScriptDataEscapedEndTagOpen(t);break}case U.SCRIPT_DATA_ESCAPED_END_TAG_NAME:{this._stateScriptDataEscapedEndTagName(t);break}case U.SCRIPT_DATA_DOUBLE_ESCAPE_START:{this._stateScriptDataDoubleEscapeStart(t);break}case U.SCRIPT_DATA_DOUBLE_ESCAPED:{this._stateScriptDataDoubleEscaped(t);break}case U.SCRIPT_DATA_DOUBLE_ESCAPED_DASH:{this._stateScriptDataDoubleEscapedDash(t);break}case U.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH:{this._stateScriptDataDoubleEscapedDashDash(t);break}case U.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN:{this._stateScriptDataDoubleEscapedLessThanSign(t);break}case U.SCRIPT_DATA_DOUBLE_ESCAPE_END:{this._stateScriptDataDoubleEscapeEnd(t);break}case U.BEFORE_ATTRIBUTE_NAME:{this._stateBeforeAttributeName(t);break}case U.ATTRIBUTE_NAME:{this._stateAttributeName(t);break}case U.AFTER_ATTRIBUTE_NAME:{this._stateAfterAttributeName(t);break}case U.BEFORE_ATTRIBUTE_VALUE:{this._stateBeforeAttributeValue(t);break}case U.ATTRIBUTE_VALUE_DOUBLE_QUOTED:{this._stateAttributeValueDoubleQuoted(t);break}case U.ATTRIBUTE_VALUE_SINGLE_QUOTED:{this._stateAttributeValueSingleQuoted(t);break}case U.ATTRIBUTE_VALUE_UNQUOTED:{this._stateAttributeValueUnquoted(t);break}case U.AFTER_ATTRIBUTE_VALUE_QUOTED:{this._stateAfterAttributeValueQuoted(t);break}case U.SELF_CLOSING_START_TAG:{this._stateSelfClosingStartTag(t);break}case U.BOGUS_COMMENT:{this._stateBogusComment(t);break}case U.MARKUP_DECLARATION_OPEN:{this._stateMarkupDeclarationOpen(t);break}case U.COMMENT_START:{this._stateCommentStart(t);break}case U.COMMENT_START_DASH:{this._stateCommentStartDash(t);break}case U.COMMENT:{this._stateComment(t);break}case U.COMMENT_LESS_THAN_SIGN:{this._stateCommentLessThanSign(t);break}case U.COMMENT_LESS_THAN_SIGN_BANG:{this._stateCommentLessThanSignBang(t);break}case U.COMMENT_LESS_THAN_SIGN_BANG_DASH:{this._stateCommentLessThanSignBangDash(t);break}case U.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH:{this._stateCommentLessThanSignBangDashDash(t);break}case U.COMMENT_END_DASH:{this._stateCommentEndDash(t);break}case U.COMMENT_END:{this._stateCommentEnd(t);break}case U.COMMENT_END_BANG:{this._stateCommentEndBang(t);break}case U.DOCTYPE:{this._stateDoctype(t);break}case U.BEFORE_DOCTYPE_NAME:{this._stateBeforeDoctypeName(t);break}case U.DOCTYPE_NAME:{this._stateDoctypeName(t);break}case U.AFTER_DOCTYPE_NAME:{this._stateAfterDoctypeName(t);break}case U.AFTER_DOCTYPE_PUBLIC_KEYWORD:{this._stateAfterDoctypePublicKeyword(t);break}case U.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER:{this._stateBeforeDoctypePublicIdentifier(t);break}case U.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED:{this._stateDoctypePublicIdentifierDoubleQuoted(t);break}case U.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED:{this._stateDoctypePublicIdentifierSingleQuoted(t);break}case U.AFTER_DOCTYPE_PUBLIC_IDENTIFIER:{this._stateAfterDoctypePublicIdentifier(t);break}case U.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS:{this._stateBetweenDoctypePublicAndSystemIdentifiers(t);break}case U.AFTER_DOCTYPE_SYSTEM_KEYWORD:{this._stateAfterDoctypeSystemKeyword(t);break}case U.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER:{this._stateBeforeDoctypeSystemIdentifier(t);break}case U.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED:{this._stateDoctypeSystemIdentifierDoubleQuoted(t);break}case U.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED:{this._stateDoctypeSystemIdentifierSingleQuoted(t);break}case U.AFTER_DOCTYPE_SYSTEM_IDENTIFIER:{this._stateAfterDoctypeSystemIdentifier(t);break}case U.BOGUS_DOCTYPE:{this._stateBogusDoctype(t);break}case U.CDATA_SECTION:{this._stateCdataSection(t);break}case U.CDATA_SECTION_BRACKET:{this._stateCdataSectionBracket(t);break}case U.CDATA_SECTION_END:{this._stateCdataSectionEnd(t);break}case U.CHARACTER_REFERENCE:{this._stateCharacterReference();break}case U.AMBIGUOUS_AMPERSAND:{this._stateAmbiguousAmpersand(t);break}default:throw new Error("Unknown state")}}_stateData(t){switch(t){case L.LESS_THAN_SIGN:{this.state=U.TAG_OPEN;break}case L.AMPERSAND:{this._startCharacterReference();break}case L.NULL:{this._err(be.unexpectedNullCharacter),this._emitCodePoint(t);break}case L.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateRcdata(t){switch(t){case L.AMPERSAND:{this._startCharacterReference();break}case L.LESS_THAN_SIGN:{this.state=U.RCDATA_LESS_THAN_SIGN;break}case L.NULL:{this._err(be.unexpectedNullCharacter),this._emitChars(On);break}case L.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateRawtext(t){switch(t){case L.LESS_THAN_SIGN:{this.state=U.RAWTEXT_LESS_THAN_SIGN;break}case L.NULL:{this._err(be.unexpectedNullCharacter),this._emitChars(On);break}case L.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateScriptData(t){switch(t){case L.LESS_THAN_SIGN:{this.state=U.SCRIPT_DATA_LESS_THAN_SIGN;break}case L.NULL:{this._err(be.unexpectedNullCharacter),this._emitChars(On);break}case L.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_statePlaintext(t){switch(t){case L.NULL:{this._err(be.unexpectedNullCharacter),this._emitChars(On);break}case L.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateTagOpen(t){if(Ks(t))this._createStartTagToken(),this.state=U.TAG_NAME,this._stateTagName(t);else switch(t){case L.EXCLAMATION_MARK:{this.state=U.MARKUP_DECLARATION_OPEN;break}case L.SOLIDUS:{this.state=U.END_TAG_OPEN;break}case L.QUESTION_MARK:{this._err(be.unexpectedQuestionMarkInsteadOfTagName),this._createCommentToken(1),this.state=U.BOGUS_COMMENT,this._stateBogusComment(t);break}case L.EOF:{this._err(be.eofBeforeTagName),this._emitChars("<"),this._emitEOFToken();break}default:this._err(be.invalidFirstCharacterOfTagName),this._emitChars("<"),this.state=U.DATA,this._stateData(t)}}_stateEndTagOpen(t){if(Ks(t))this._createEndTagToken(),this.state=U.TAG_NAME,this._stateTagName(t);else switch(t){case L.GREATER_THAN_SIGN:{this._err(be.missingEndTagName),this.state=U.DATA;break}case L.EOF:{this._err(be.eofBeforeTagName),this._emitChars("</"),this._emitEOFToken();break}default:this._err(be.invalidFirstCharacterOfTagName),this._createCommentToken(2),this.state=U.BOGUS_COMMENT,this._stateBogusComment(t)}}_stateTagName(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:{this.state=U.BEFORE_ATTRIBUTE_NAME;break}case L.SOLIDUS:{this.state=U.SELF_CLOSING_START_TAG;break}case L.GREATER_THAN_SIGN:{this.state=U.DATA,this.emitCurrentTagToken();break}case L.NULL:{this._err(be.unexpectedNullCharacter),n.tagName+=On;break}case L.EOF:{this._err(be.eofInTag),this._emitEOFToken();break}default:n.tagName+=String.fromCodePoint(Bc(t)?fh(t):t)}}_stateRcdataLessThanSign(t){t===L.SOLIDUS?this.state=U.RCDATA_END_TAG_OPEN:(this._emitChars("<"),this.state=U.RCDATA,this._stateRcdata(t))}_stateRcdataEndTagOpen(t){Ks(t)?(this.state=U.RCDATA_END_TAG_NAME,this._stateRcdataEndTagName(t)):(this._emitChars("</"),this.state=U.RCDATA,this._stateRcdata(t))}handleSpecialEndTag(t){if(!this.preprocessor.startsWith(this.lastStartTagName,!1))return!this._ensureHibernation();this._createEndTagToken();const n=this.currentToken;switch(n.tagName=this.lastStartTagName,this.preprocessor.peek(this.lastStartTagName.length)){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:return this._advanceBy(this.lastStartTagName.length),this.state=U.BEFORE_ATTRIBUTE_NAME,!1;case L.SOLIDUS:return this._advanceBy(this.lastStartTagName.length),this.state=U.SELF_CLOSING_START_TAG,!1;case L.GREATER_THAN_SIGN:return this._advanceBy(this.lastStartTagName.length),this.emitCurrentTagToken(),this.state=U.DATA,!1;default:return!this._ensureHibernation()}}_stateRcdataEndTagName(t){this.handleSpecialEndTag(t)&&(this._emitChars("</"),this.state=U.RCDATA,this._stateRcdata(t))}_stateRawtextLessThanSign(t){t===L.SOLIDUS?this.state=U.RAWTEXT_END_TAG_OPEN:(this._emitChars("<"),this.state=U.RAWTEXT,this._stateRawtext(t))}_stateRawtextEndTagOpen(t){Ks(t)?(this.state=U.RAWTEXT_END_TAG_NAME,this._stateRawtextEndTagName(t)):(this._emitChars("</"),this.state=U.RAWTEXT,this._stateRawtext(t))}_stateRawtextEndTagName(t){this.handleSpecialEndTag(t)&&(this._emitChars("</"),this.state=U.RAWTEXT,this._stateRawtext(t))}_stateScriptDataLessThanSign(t){switch(t){case L.SOLIDUS:{this.state=U.SCRIPT_DATA_END_TAG_OPEN;break}case L.EXCLAMATION_MARK:{this.state=U.SCRIPT_DATA_ESCAPE_START,this._emitChars("<!");break}default:this._emitChars("<"),this.state=U.SCRIPT_DATA,this._stateScriptData(t)}}_stateScriptDataEndTagOpen(t){Ks(t)?(this.state=U.SCRIPT_DATA_END_TAG_NAME,this._stateScriptDataEndTagName(t)):(this._emitChars("</"),this.state=U.SCRIPT_DATA,this._stateScriptData(t))}_stateScriptDataEndTagName(t){this.handleSpecialEndTag(t)&&(this._emitChars("</"),this.state=U.SCRIPT_DATA,this._stateScriptData(t))}_stateScriptDataEscapeStart(t){t===L.HYPHEN_MINUS?(this.state=U.SCRIPT_DATA_ESCAPE_START_DASH,this._emitChars("-")):(this.state=U.SCRIPT_DATA,this._stateScriptData(t))}_stateScriptDataEscapeStartDash(t){t===L.HYPHEN_MINUS?(this.state=U.SCRIPT_DATA_ESCAPED_DASH_DASH,this._emitChars("-")):(this.state=U.SCRIPT_DATA,this._stateScriptData(t))}_stateScriptDataEscaped(t){switch(t){case L.HYPHEN_MINUS:{this.state=U.SCRIPT_DATA_ESCAPED_DASH,this._emitChars("-");break}case L.LESS_THAN_SIGN:{this.state=U.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break}case L.NULL:{this._err(be.unexpectedNullCharacter),this._emitChars(On);break}case L.EOF:{this._err(be.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateScriptDataEscapedDash(t){switch(t){case L.HYPHEN_MINUS:{this.state=U.SCRIPT_DATA_ESCAPED_DASH_DASH,this._emitChars("-");break}case L.LESS_THAN_SIGN:{this.state=U.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break}case L.NULL:{this._err(be.unexpectedNullCharacter),this.state=U.SCRIPT_DATA_ESCAPED,this._emitChars(On);break}case L.EOF:{this._err(be.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this.state=U.SCRIPT_DATA_ESCAPED,this._emitCodePoint(t)}}_stateScriptDataEscapedDashDash(t){switch(t){case L.HYPHEN_MINUS:{this._emitChars("-");break}case L.LESS_THAN_SIGN:{this.state=U.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break}case L.GREATER_THAN_SIGN:{this.state=U.SCRIPT_DATA,this._emitChars(">");break}case L.NULL:{this._err(be.unexpectedNullCharacter),this.state=U.SCRIPT_DATA_ESCAPED,this._emitChars(On);break}case L.EOF:{this._err(be.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this.state=U.SCRIPT_DATA_ESCAPED,this._emitCodePoint(t)}}_stateScriptDataEscapedLessThanSign(t){t===L.SOLIDUS?this.state=U.SCRIPT_DATA_ESCAPED_END_TAG_OPEN:Ks(t)?(this._emitChars("<"),this.state=U.SCRIPT_DATA_DOUBLE_ESCAPE_START,this._stateScriptDataDoubleEscapeStart(t)):(this._emitChars("<"),this.state=U.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(t))}_stateScriptDataEscapedEndTagOpen(t){Ks(t)?(this.state=U.SCRIPT_DATA_ESCAPED_END_TAG_NAME,this._stateScriptDataEscapedEndTagName(t)):(this._emitChars("</"),this.state=U.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(t))}_stateScriptDataEscapedEndTagName(t){this.handleSpecialEndTag(t)&&(this._emitChars("</"),this.state=U.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(t))}_stateScriptDataDoubleEscapeStart(t){if(this.preprocessor.startsWith(Jr.SCRIPT,!1)&&IE(this.preprocessor.peek(Jr.SCRIPT.length))){this._emitCodePoint(t);for(let n=0;n<Jr.SCRIPT.length;n++)this._emitCodePoint(this._consume());this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED}else this._ensureHibernation()||(this.state=U.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(t))}_stateScriptDataDoubleEscaped(t){switch(t){case L.HYPHEN_MINUS:{this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED_DASH,this._emitChars("-");break}case L.LESS_THAN_SIGN:{this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,this._emitChars("<");break}case L.NULL:{this._err(be.unexpectedNullCharacter),this._emitChars(On);break}case L.EOF:{this._err(be.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateScriptDataDoubleEscapedDash(t){switch(t){case L.HYPHEN_MINUS:{this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH,this._emitChars("-");break}case L.LESS_THAN_SIGN:{this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,this._emitChars("<");break}case L.NULL:{this._err(be.unexpectedNullCharacter),this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitChars(On);break}case L.EOF:{this._err(be.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitCodePoint(t)}}_stateScriptDataDoubleEscapedDashDash(t){switch(t){case L.HYPHEN_MINUS:{this._emitChars("-");break}case L.LESS_THAN_SIGN:{this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,this._emitChars("<");break}case L.GREATER_THAN_SIGN:{this.state=U.SCRIPT_DATA,this._emitChars(">");break}case L.NULL:{this._err(be.unexpectedNullCharacter),this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitChars(On);break}case L.EOF:{this._err(be.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitCodePoint(t)}}_stateScriptDataDoubleEscapedLessThanSign(t){t===L.SOLIDUS?(this.state=U.SCRIPT_DATA_DOUBLE_ESCAPE_END,this._emitChars("/")):(this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED,this._stateScriptDataDoubleEscaped(t))}_stateScriptDataDoubleEscapeEnd(t){if(this.preprocessor.startsWith(Jr.SCRIPT,!1)&&IE(this.preprocessor.peek(Jr.SCRIPT.length))){this._emitCodePoint(t);for(let n=0;n<Jr.SCRIPT.length;n++)this._emitCodePoint(this._consume());this.state=U.SCRIPT_DATA_ESCAPED}else this._ensureHibernation()||(this.state=U.SCRIPT_DATA_DOUBLE_ESCAPED,this._stateScriptDataDoubleEscaped(t))}_stateBeforeAttributeName(t){switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.SOLIDUS:case L.GREATER_THAN_SIGN:case L.EOF:{this.state=U.AFTER_ATTRIBUTE_NAME,this._stateAfterAttributeName(t);break}case L.EQUALS_SIGN:{this._err(be.unexpectedEqualsSignBeforeAttributeName),this._createAttr("="),this.state=U.ATTRIBUTE_NAME;break}default:this._createAttr(""),this.state=U.ATTRIBUTE_NAME,this._stateAttributeName(t)}}_stateAttributeName(t){switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:case L.SOLIDUS:case L.GREATER_THAN_SIGN:case L.EOF:{this._leaveAttrName(),this.state=U.AFTER_ATTRIBUTE_NAME,this._stateAfterAttributeName(t);break}case L.EQUALS_SIGN:{this._leaveAttrName(),this.state=U.BEFORE_ATTRIBUTE_VALUE;break}case L.QUOTATION_MARK:case L.APOSTROPHE:case L.LESS_THAN_SIGN:{this._err(be.unexpectedCharacterInAttributeName),this.currentAttr.name+=String.fromCodePoint(t);break}case L.NULL:{this._err(be.unexpectedNullCharacter),this.currentAttr.name+=On;break}default:this.currentAttr.name+=String.fromCodePoint(Bc(t)?fh(t):t)}}_stateAfterAttributeName(t){switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.SOLIDUS:{this.state=U.SELF_CLOSING_START_TAG;break}case L.EQUALS_SIGN:{this.state=U.BEFORE_ATTRIBUTE_VALUE;break}case L.GREATER_THAN_SIGN:{this.state=U.DATA,this.emitCurrentTagToken();break}case L.EOF:{this._err(be.eofInTag),this._emitEOFToken();break}default:this._createAttr(""),this.state=U.ATTRIBUTE_NAME,this._stateAttributeName(t)}}_stateBeforeAttributeValue(t){switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.QUOTATION_MARK:{this.state=U.ATTRIBUTE_VALUE_DOUBLE_QUOTED;break}case L.APOSTROPHE:{this.state=U.ATTRIBUTE_VALUE_SINGLE_QUOTED;break}case L.GREATER_THAN_SIGN:{this._err(be.missingAttributeValue),this.state=U.DATA,this.emitCurrentTagToken();break}default:this.state=U.ATTRIBUTE_VALUE_UNQUOTED,this._stateAttributeValueUnquoted(t)}}_stateAttributeValueDoubleQuoted(t){switch(t){case L.QUOTATION_MARK:{this.state=U.AFTER_ATTRIBUTE_VALUE_QUOTED;break}case L.AMPERSAND:{this._startCharacterReference();break}case L.NULL:{this._err(be.unexpectedNullCharacter),this.currentAttr.value+=On;break}case L.EOF:{this._err(be.eofInTag),this._emitEOFToken();break}default:this.currentAttr.value+=String.fromCodePoint(t)}}_stateAttributeValueSingleQuoted(t){switch(t){case L.APOSTROPHE:{this.state=U.AFTER_ATTRIBUTE_VALUE_QUOTED;break}case L.AMPERSAND:{this._startCharacterReference();break}case L.NULL:{this._err(be.unexpectedNullCharacter),this.currentAttr.value+=On;break}case L.EOF:{this._err(be.eofInTag),this._emitEOFToken();break}default:this.currentAttr.value+=String.fromCodePoint(t)}}_stateAttributeValueUnquoted(t){switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:{this._leaveAttrValue(),this.state=U.BEFORE_ATTRIBUTE_NAME;break}case L.AMPERSAND:{this._startCharacterReference();break}case L.GREATER_THAN_SIGN:{this._leaveAttrValue(),this.state=U.DATA,this.emitCurrentTagToken();break}case L.NULL:{this._err(be.unexpectedNullCharacter),this.currentAttr.value+=On;break}case L.QUOTATION_MARK:case L.APOSTROPHE:case L.LESS_THAN_SIGN:case L.EQUALS_SIGN:case L.GRAVE_ACCENT:{this._err(be.unexpectedCharacterInUnquotedAttributeValue),this.currentAttr.value+=String.fromCodePoint(t);break}case L.EOF:{this._err(be.eofInTag),this._emitEOFToken();break}default:this.currentAttr.value+=String.fromCodePoint(t)}}_stateAfterAttributeValueQuoted(t){switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:{this._leaveAttrValue(),this.state=U.BEFORE_ATTRIBUTE_NAME;break}case L.SOLIDUS:{this._leaveAttrValue(),this.state=U.SELF_CLOSING_START_TAG;break}case L.GREATER_THAN_SIGN:{this._leaveAttrValue(),this.state=U.DATA,this.emitCurrentTagToken();break}case L.EOF:{this._err(be.eofInTag),this._emitEOFToken();break}default:this._err(be.missingWhitespaceBetweenAttributes),this.state=U.BEFORE_ATTRIBUTE_NAME,this._stateBeforeAttributeName(t)}}_stateSelfClosingStartTag(t){switch(t){case L.GREATER_THAN_SIGN:{const n=this.currentToken;n.selfClosing=!0,this.state=U.DATA,this.emitCurrentTagToken();break}case L.EOF:{this._err(be.eofInTag),this._emitEOFToken();break}default:this._err(be.unexpectedSolidusInTag),this.state=U.BEFORE_ATTRIBUTE_NAME,this._stateBeforeAttributeName(t)}}_stateBogusComment(t){const n=this.currentToken;switch(t){case L.GREATER_THAN_SIGN:{this.state=U.DATA,this.emitCurrentComment(n);break}case L.EOF:{this.emitCurrentComment(n),this._emitEOFToken();break}case L.NULL:{this._err(be.unexpectedNullCharacter),n.data+=On;break}default:n.data+=String.fromCodePoint(t)}}_stateMarkupDeclarationOpen(t){this._consumeSequenceIfMatch(Jr.DASH_DASH,!0)?(this._createCommentToken(Jr.DASH_DASH.length+1),this.state=U.COMMENT_START):this._consumeSequenceIfMatch(Jr.DOCTYPE,!1)?(this.currentLocation=this.getCurrentLocation(Jr.DOCTYPE.length+1),this.state=U.DOCTYPE):this._consumeSequenceIfMatch(Jr.CDATA_START,!0)?this.inForeignNode?this.state=U.CDATA_SECTION:(this._err(be.cdataInHtmlContent),this._createCommentToken(Jr.CDATA_START.length+1),this.currentToken.data="[CDATA[",this.state=U.BOGUS_COMMENT):this._ensureHibernation()||(this._err(be.incorrectlyOpenedComment),this._createCommentToken(2),this.state=U.BOGUS_COMMENT,this._stateBogusComment(t))}_stateCommentStart(t){switch(t){case L.HYPHEN_MINUS:{this.state=U.COMMENT_START_DASH;break}case L.GREATER_THAN_SIGN:{this._err(be.abruptClosingOfEmptyComment),this.state=U.DATA;const n=this.currentToken;this.emitCurrentComment(n);break}default:this.state=U.COMMENT,this._stateComment(t)}}_stateCommentStartDash(t){const n=this.currentToken;switch(t){case L.HYPHEN_MINUS:{this.state=U.COMMENT_END;break}case L.GREATER_THAN_SIGN:{this._err(be.abruptClosingOfEmptyComment),this.state=U.DATA,this.emitCurrentComment(n);break}case L.EOF:{this._err(be.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+="-",this.state=U.COMMENT,this._stateComment(t)}}_stateComment(t){const n=this.currentToken;switch(t){case L.HYPHEN_MINUS:{this.state=U.COMMENT_END_DASH;break}case L.LESS_THAN_SIGN:{n.data+="<",this.state=U.COMMENT_LESS_THAN_SIGN;break}case L.NULL:{this._err(be.unexpectedNullCharacter),n.data+=On;break}case L.EOF:{this._err(be.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+=String.fromCodePoint(t)}}_stateCommentLessThanSign(t){const n=this.currentToken;switch(t){case L.EXCLAMATION_MARK:{n.data+="!",this.state=U.COMMENT_LESS_THAN_SIGN_BANG;break}case L.LESS_THAN_SIGN:{n.data+="<";break}default:this.state=U.COMMENT,this._stateComment(t)}}_stateCommentLessThanSignBang(t){t===L.HYPHEN_MINUS?this.state=U.COMMENT_LESS_THAN_SIGN_BANG_DASH:(this.state=U.COMMENT,this._stateComment(t))}_stateCommentLessThanSignBangDash(t){t===L.HYPHEN_MINUS?this.state=U.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH:(this.state=U.COMMENT_END_DASH,this._stateCommentEndDash(t))}_stateCommentLessThanSignBangDashDash(t){t!==L.GREATER_THAN_SIGN&&t!==L.EOF&&this._err(be.nestedComment),this.state=U.COMMENT_END,this._stateCommentEnd(t)}_stateCommentEndDash(t){const n=this.currentToken;switch(t){case L.HYPHEN_MINUS:{this.state=U.COMMENT_END;break}case L.EOF:{this._err(be.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+="-",this.state=U.COMMENT,this._stateComment(t)}}_stateCommentEnd(t){const n=this.currentToken;switch(t){case L.GREATER_THAN_SIGN:{this.state=U.DATA,this.emitCurrentComment(n);break}case L.EXCLAMATION_MARK:{this.state=U.COMMENT_END_BANG;break}case L.HYPHEN_MINUS:{n.data+="-";break}case L.EOF:{this._err(be.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+="--",this.state=U.COMMENT,this._stateComment(t)}}_stateCommentEndBang(t){const n=this.currentToken;switch(t){case L.HYPHEN_MINUS:{n.data+="--!",this.state=U.COMMENT_END_DASH;break}case L.GREATER_THAN_SIGN:{this._err(be.incorrectlyClosedComment),this.state=U.DATA,this.emitCurrentComment(n);break}case L.EOF:{this._err(be.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+="--!",this.state=U.COMMENT,this._stateComment(t)}}_stateDoctype(t){switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:{this.state=U.BEFORE_DOCTYPE_NAME;break}case L.GREATER_THAN_SIGN:{this.state=U.BEFORE_DOCTYPE_NAME,this._stateBeforeDoctypeName(t);break}case L.EOF:{this._err(be.eofInDoctype),this._createDoctypeToken(null);const n=this.currentToken;n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(be.missingWhitespaceBeforeDoctypeName),this.state=U.BEFORE_DOCTYPE_NAME,this._stateBeforeDoctypeName(t)}}_stateBeforeDoctypeName(t){if(Bc(t))this._createDoctypeToken(String.fromCharCode(fh(t))),this.state=U.DOCTYPE_NAME;else switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.NULL:{this._err(be.unexpectedNullCharacter),this._createDoctypeToken(On),this.state=U.DOCTYPE_NAME;break}case L.GREATER_THAN_SIGN:{this._err(be.missingDoctypeName),this._createDoctypeToken(null);const n=this.currentToken;n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=U.DATA;break}case L.EOF:{this._err(be.eofInDoctype),this._createDoctypeToken(null);const n=this.currentToken;n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._createDoctypeToken(String.fromCodePoint(t)),this.state=U.DOCTYPE_NAME}}_stateDoctypeName(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:{this.state=U.AFTER_DOCTYPE_NAME;break}case L.GREATER_THAN_SIGN:{this.state=U.DATA,this.emitCurrentDoctype(n);break}case L.NULL:{this._err(be.unexpectedNullCharacter),n.name+=On;break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.name+=String.fromCodePoint(Bc(t)?fh(t):t)}}_stateAfterDoctypeName(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.GREATER_THAN_SIGN:{this.state=U.DATA,this.emitCurrentDoctype(n);break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._consumeSequenceIfMatch(Jr.PUBLIC,!1)?this.state=U.AFTER_DOCTYPE_PUBLIC_KEYWORD:this._consumeSequenceIfMatch(Jr.SYSTEM,!1)?this.state=U.AFTER_DOCTYPE_SYSTEM_KEYWORD:this._ensureHibernation()||(this._err(be.invalidCharacterSequenceAfterDoctypeName),n.forceQuirks=!0,this.state=U.BOGUS_DOCTYPE,this._stateBogusDoctype(t))}}_stateAfterDoctypePublicKeyword(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:{this.state=U.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER;break}case L.QUOTATION_MARK:{this._err(be.missingWhitespaceAfterDoctypePublicKeyword),n.publicId="",this.state=U.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED;break}case L.APOSTROPHE:{this._err(be.missingWhitespaceAfterDoctypePublicKeyword),n.publicId="",this.state=U.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED;break}case L.GREATER_THAN_SIGN:{this._err(be.missingDoctypePublicIdentifier),n.forceQuirks=!0,this.state=U.DATA,this.emitCurrentDoctype(n);break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(be.missingQuoteBeforeDoctypePublicIdentifier),n.forceQuirks=!0,this.state=U.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateBeforeDoctypePublicIdentifier(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.QUOTATION_MARK:{n.publicId="",this.state=U.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED;break}case L.APOSTROPHE:{n.publicId="",this.state=U.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED;break}case L.GREATER_THAN_SIGN:{this._err(be.missingDoctypePublicIdentifier),n.forceQuirks=!0,this.state=U.DATA,this.emitCurrentDoctype(n);break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(be.missingQuoteBeforeDoctypePublicIdentifier),n.forceQuirks=!0,this.state=U.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateDoctypePublicIdentifierDoubleQuoted(t){const n=this.currentToken;switch(t){case L.QUOTATION_MARK:{this.state=U.AFTER_DOCTYPE_PUBLIC_IDENTIFIER;break}case L.NULL:{this._err(be.unexpectedNullCharacter),n.publicId+=On;break}case L.GREATER_THAN_SIGN:{this._err(be.abruptDoctypePublicIdentifier),n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=U.DATA;break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.publicId+=String.fromCodePoint(t)}}_stateDoctypePublicIdentifierSingleQuoted(t){const n=this.currentToken;switch(t){case L.APOSTROPHE:{this.state=U.AFTER_DOCTYPE_PUBLIC_IDENTIFIER;break}case L.NULL:{this._err(be.unexpectedNullCharacter),n.publicId+=On;break}case L.GREATER_THAN_SIGN:{this._err(be.abruptDoctypePublicIdentifier),n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=U.DATA;break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.publicId+=String.fromCodePoint(t)}}_stateAfterDoctypePublicIdentifier(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:{this.state=U.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS;break}case L.GREATER_THAN_SIGN:{this.state=U.DATA,this.emitCurrentDoctype(n);break}case L.QUOTATION_MARK:{this._err(be.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers),n.systemId="",this.state=U.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break}case L.APOSTROPHE:{this._err(be.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers),n.systemId="",this.state=U.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(be.missingQuoteBeforeDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=U.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateBetweenDoctypePublicAndSystemIdentifiers(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.GREATER_THAN_SIGN:{this.emitCurrentDoctype(n),this.state=U.DATA;break}case L.QUOTATION_MARK:{n.systemId="",this.state=U.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break}case L.APOSTROPHE:{n.systemId="",this.state=U.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(be.missingQuoteBeforeDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=U.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateAfterDoctypeSystemKeyword(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:{this.state=U.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER;break}case L.QUOTATION_MARK:{this._err(be.missingWhitespaceAfterDoctypeSystemKeyword),n.systemId="",this.state=U.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break}case L.APOSTROPHE:{this._err(be.missingWhitespaceAfterDoctypeSystemKeyword),n.systemId="",this.state=U.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break}case L.GREATER_THAN_SIGN:{this._err(be.missingDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=U.DATA,this.emitCurrentDoctype(n);break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(be.missingQuoteBeforeDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=U.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateBeforeDoctypeSystemIdentifier(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.QUOTATION_MARK:{n.systemId="",this.state=U.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break}case L.APOSTROPHE:{n.systemId="",this.state=U.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break}case L.GREATER_THAN_SIGN:{this._err(be.missingDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=U.DATA,this.emitCurrentDoctype(n);break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(be.missingQuoteBeforeDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=U.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateDoctypeSystemIdentifierDoubleQuoted(t){const n=this.currentToken;switch(t){case L.QUOTATION_MARK:{this.state=U.AFTER_DOCTYPE_SYSTEM_IDENTIFIER;break}case L.NULL:{this._err(be.unexpectedNullCharacter),n.systemId+=On;break}case L.GREATER_THAN_SIGN:{this._err(be.abruptDoctypeSystemIdentifier),n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=U.DATA;break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.systemId+=String.fromCodePoint(t)}}_stateDoctypeSystemIdentifierSingleQuoted(t){const n=this.currentToken;switch(t){case L.APOSTROPHE:{this.state=U.AFTER_DOCTYPE_SYSTEM_IDENTIFIER;break}case L.NULL:{this._err(be.unexpectedNullCharacter),n.systemId+=On;break}case L.GREATER_THAN_SIGN:{this._err(be.abruptDoctypeSystemIdentifier),n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=U.DATA;break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.systemId+=String.fromCodePoint(t)}}_stateAfterDoctypeSystemIdentifier(t){const n=this.currentToken;switch(t){case L.SPACE:case L.LINE_FEED:case L.TABULATION:case L.FORM_FEED:break;case L.GREATER_THAN_SIGN:{this.emitCurrentDoctype(n),this.state=U.DATA;break}case L.EOF:{this._err(be.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(be.unexpectedCharacterAfterDoctypeSystemIdentifier),this.state=U.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateBogusDoctype(t){const n=this.currentToken;switch(t){case L.GREATER_THAN_SIGN:{this.emitCurrentDoctype(n),this.state=U.DATA;break}case L.NULL:{this._err(be.unexpectedNullCharacter);break}case L.EOF:{this.emitCurrentDoctype(n),this._emitEOFToken();break}}}_stateCdataSection(t){switch(t){case L.RIGHT_SQUARE_BRACKET:{this.state=U.CDATA_SECTION_BRACKET;break}case L.EOF:{this._err(be.eofInCdata),this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateCdataSectionBracket(t){t===L.RIGHT_SQUARE_BRACKET?this.state=U.CDATA_SECTION_END:(this._emitChars("]"),this.state=U.CDATA_SECTION,this._stateCdataSection(t))}_stateCdataSectionEnd(t){switch(t){case L.GREATER_THAN_SIGN:{this.state=U.DATA;break}case L.RIGHT_SQUARE_BRACKET:{this._emitChars("]");break}default:this._emitChars("]]"),this.state=U.CDATA_SECTION,this._stateCdataSection(t)}}_stateCharacterReference(){let t=this.entityDecoder.write(this.preprocessor.html,this.preprocessor.pos);if(t<0)if(this.preprocessor.lastChunkWritten)t=this.entityDecoder.end();else{this.active=!1,this.preprocessor.pos=this.preprocessor.html.length-1,this.consumedAfterSnapshot=0,this.preprocessor.endOfChunkHit=!0;return}t===0?(this.preprocessor.pos=this.entityStartPos,this._flushCodePointConsumedAsCharacterReference(L.AMPERSAND),this.state=!this._isCharacterReferenceInAttribute()&&ME(this.preprocessor.peek(1))?U.AMBIGUOUS_AMPERSAND:this.returnState):this.state=this.returnState}_stateAmbiguousAmpersand(t){ME(t)?this._flushCodePointConsumedAsCharacterReference(t):(t===L.SEMICOLON&&this._err(be.unknownNamedCharacterReference),this.state=this.returnState,this._callState(t))}}const _T=new Set([y.DD,y.DT,y.LI,y.OPTGROUP,y.OPTION,y.P,y.RB,y.RP,y.RT,y.RTC]),DE=new Set([..._T,y.CAPTION,y.COLGROUP,y.TBODY,y.TD,y.TFOOT,y.TH,y.THEAD,y.TR]),nf=new Set([y.APPLET,y.CAPTION,y.HTML,y.MARQUEE,y.OBJECT,y.TABLE,y.TD,y.TEMPLATE,y.TH]),fU=new Set([...nf,y.OL,y.UL]),mU=new Set([...nf,y.BUTTON]),LE=new Set([y.ANNOTATION_XML,y.MI,y.MN,y.MO,y.MS,y.MTEXT]),PE=new Set([y.DESC,y.FOREIGN_OBJECT,y.TITLE]),pU=new Set([y.TR,y.TEMPLATE,y.HTML]),gU=new Set([y.TBODY,y.TFOOT,y.THEAD,y.TEMPLATE,y.HTML]),bU=new Set([y.TABLE,y.TEMPLATE,y.HTML]),vU=new Set([y.TD,y.TH]);class _U{get currentTmplContentOrNode(){return this._isInTemplate()?this.treeAdapter.getTemplateContent(this.current):this.current}constructor(t,n,r){this.treeAdapter=n,this.handler=r,this.items=[],this.tagIDs=[],this.stackTop=-1,this.tmplCount=0,this.currentTagId=y.UNKNOWN,this.current=t}_indexOf(t){return this.items.lastIndexOf(t,this.stackTop)}_isInTemplate(){return this.currentTagId===y.TEMPLATE&&this.treeAdapter.getNamespaceURI(this.current)===ke.HTML}_updateCurrentElement(){this.current=this.items[this.stackTop],this.currentTagId=this.tagIDs[this.stackTop]}push(t,n){this.stackTop++,this.items[this.stackTop]=t,this.current=t,this.tagIDs[this.stackTop]=n,this.currentTagId=n,this._isInTemplate()&&this.tmplCount++,this.handler.onItemPush(t,n,!0)}pop(){const t=this.current;this.tmplCount>0&&this._isInTemplate()&&this.tmplCount--,this.stackTop--,this._updateCurrentElement(),this.handler.onItemPop(t,!0)}replace(t,n){const r=this._indexOf(t);this.items[r]=n,r===this.stackTop&&(this.current=n)}insertAfter(t,n,r){const i=this._indexOf(t)+1;this.items.splice(i,0,n),this.tagIDs.splice(i,0,r),this.stackTop++,i===this.stackTop&&this._updateCurrentElement(),this.current&&this.currentTagId!==void 0&&this.handler.onItemPush(this.current,this.currentTagId,i===this.stackTop)}popUntilTagNamePopped(t){let n=this.stackTop+1;do n=this.tagIDs.lastIndexOf(t,n-1);while(n>0&&this.treeAdapter.getNamespaceURI(this.items[n])!==ke.HTML);this.shortenToLength(Math.max(n,0))}shortenToLength(t){for(;this.stackTop>=t;){const n=this.current;this.tmplCount>0&&this._isInTemplate()&&(this.tmplCount-=1),this.stackTop--,this._updateCurrentElement(),this.handler.onItemPop(n,this.stackTop<t)}}popUntilElementPopped(t){const n=this._indexOf(t);this.shortenToLength(Math.max(n,0))}popUntilPopped(t,n){const r=this._indexOfTagNames(t,n);this.shortenToLength(Math.max(r,0))}popUntilNumberedHeaderPopped(){this.popUntilPopped(db,ke.HTML)}popUntilTableCellPopped(){this.popUntilPopped(vU,ke.HTML)}popAllUpToHtmlElement(){this.tmplCount=0,this.shortenToLength(1)}_indexOfTagNames(t,n){for(let r=this.stackTop;r>=0;r--)if(t.has(this.tagIDs[r])&&this.treeAdapter.getNamespaceURI(this.items[r])===n)return r;return-1}clearBackTo(t,n){const r=this._indexOfTagNames(t,n);this.shortenToLength(r+1)}clearBackToTableContext(){this.clearBackTo(bU,ke.HTML)}clearBackToTableBodyContext(){this.clearBackTo(gU,ke.HTML)}clearBackToTableRowContext(){this.clearBackTo(pU,ke.HTML)}remove(t){const n=this._indexOf(t);n>=0&&(n===this.stackTop?this.pop():(this.items.splice(n,1),this.tagIDs.splice(n,1),this.stackTop--,this._updateCurrentElement(),this.handler.onItemPop(t,!1)))}tryPeekProperlyNestedBodyElement(){return this.stackTop>=1&&this.tagIDs[1]===y.BODY?this.items[1]:null}contains(t){return this._indexOf(t)>-1}getCommonAncestor(t){const n=this._indexOf(t)-1;return n>=0?this.items[n]:null}isRootHtmlElementCurrent(){return this.stackTop===0&&this.tagIDs[0]===y.HTML}hasInDynamicScope(t,n){for(let r=this.stackTop;r>=0;r--){const i=this.tagIDs[r];switch(this.treeAdapter.getNamespaceURI(this.items[r])){case ke.HTML:{if(i===t)return!0;if(n.has(i))return!1;break}case ke.SVG:{if(PE.has(i))return!1;break}case ke.MATHML:{if(LE.has(i))return!1;break}}}return!0}hasInScope(t){return this.hasInDynamicScope(t,nf)}hasInListItemScope(t){return this.hasInDynamicScope(t,fU)}hasInButtonScope(t){return this.hasInDynamicScope(t,mU)}hasNumberedHeaderInScope(){for(let t=this.stackTop;t>=0;t--){const n=this.tagIDs[t];switch(this.treeAdapter.getNamespaceURI(this.items[t])){case ke.HTML:{if(db.has(n))return!0;if(nf.has(n))return!1;break}case ke.SVG:{if(PE.has(n))return!1;break}case ke.MATHML:{if(LE.has(n))return!1;break}}}return!0}hasInTableScope(t){for(let n=this.stackTop;n>=0;n--)if(this.treeAdapter.getNamespaceURI(this.items[n])===ke.HTML)switch(this.tagIDs[n]){case t:return!0;case y.TABLE:case y.HTML:return!1}return!0}hasTableBodyContextInTableScope(){for(let t=this.stackTop;t>=0;t--)if(this.treeAdapter.getNamespaceURI(this.items[t])===ke.HTML)switch(this.tagIDs[t]){case y.TBODY:case y.THEAD:case y.TFOOT:return!0;case y.TABLE:case y.HTML:return!1}return!0}hasInSelectScope(t){for(let n=this.stackTop;n>=0;n--)if(this.treeAdapter.getNamespaceURI(this.items[n])===ke.HTML)switch(this.tagIDs[n]){case t:return!0;case y.OPTION:case y.OPTGROUP:break;default:return!1}return!0}generateImpliedEndTags(){for(;this.currentTagId!==void 0&&_T.has(this.currentTagId);)this.pop()}generateImpliedEndTagsThoroughly(){for(;this.currentTagId!==void 0&&DE.has(this.currentTagId);)this.pop()}generateImpliedEndTagsWithExclusion(t){for(;this.currentTagId!==void 0&&this.currentTagId!==t&&DE.has(this.currentTagId);)this.pop()}}const Q1=3;var la;(function(e){e[e.Marker=0]="Marker",e[e.Element=1]="Element"})(la||(la={}));const BE={type:la.Marker};class yU{constructor(t){this.treeAdapter=t,this.entries=[],this.bookmark=null}_getNoahArkConditionCandidates(t,n){const r=[],i=n.length,s=this.treeAdapter.getTagName(t),o=this.treeAdapter.getNamespaceURI(t);for(let c=0;c<this.entries.length;c++){const d=this.entries[c];if(d.type===la.Marker)break;const{element:f}=d;if(this.treeAdapter.getTagName(f)===s&&this.treeAdapter.getNamespaceURI(f)===o){const m=this.treeAdapter.getAttrList(f);m.length===i&&r.push({idx:c,attrs:m})}}return r}_ensureNoahArkCondition(t){if(this.entries.length<Q1)return;const n=this.treeAdapter.getAttrList(t),r=this._getNoahArkConditionCandidates(t,n);if(r.length<Q1)return;const i=new Map(n.map(o=>[o.name,o.value]));let s=0;for(let o=0;o<r.length;o++){const c=r[o];c.attrs.every(d=>i.get(d.name)===d.value)&&(s+=1,s>=Q1&&this.entries.splice(c.idx,1))}}insertMarker(){this.entries.unshift(BE)}pushElement(t,n){this._ensureNoahArkCondition(t),this.entries.unshift({type:la.Element,element:t,token:n})}insertElementAfterBookmark(t,n){const r=this.entries.indexOf(this.bookmark);this.entries.splice(r,0,{type:la.Element,element:t,token:n})}removeEntry(t){const n=this.entries.indexOf(t);n!==-1&&this.entries.splice(n,1)}clearToLastMarker(){const t=this.entries.indexOf(BE);t===-1?this.entries.length=0:this.entries.splice(0,t+1)}getElementEntryInScopeWithTagName(t){const n=this.entries.find(r=>r.type===la.Marker||this.treeAdapter.getTagName(r.element)===t);return n&&n.type===la.Element?n:null}getElementEntry(t){return this.entries.find(n=>n.type===la.Element&&n.element===t)}}const Ws={createDocument(){return{nodeName:"#document",mode:Pi.NO_QUIRKS,childNodes:[]}},createDocumentFragment(){return{nodeName:"#document-fragment",childNodes:[]}},createElement(e,t,n){return{nodeName:e,tagName:e,attrs:n,namespaceURI:t,childNodes:[],parentNode:null}},createCommentNode(e){return{nodeName:"#comment",data:e,parentNode:null}},createTextNode(e){return{nodeName:"#text",value:e,parentNode:null}},appendChild(e,t){e.childNodes.push(t),t.parentNode=e},insertBefore(e,t,n){const r=e.childNodes.indexOf(n);e.childNodes.splice(r,0,t),t.parentNode=e},setTemplateContent(e,t){e.content=t},getTemplateContent(e){return e.content},setDocumentType(e,t,n,r){const i=e.childNodes.find(s=>s.nodeName==="#documentType");if(i)i.name=t,i.publicId=n,i.systemId=r;else{const s={nodeName:"#documentType",name:t,publicId:n,systemId:r,parentNode:null};Ws.appendChild(e,s)}},setDocumentMode(e,t){e.mode=t},getDocumentMode(e){return e.mode},detachNode(e){if(e.parentNode){const t=e.parentNode.childNodes.indexOf(e);e.parentNode.childNodes.splice(t,1),e.parentNode=null}},insertText(e,t){if(e.childNodes.length>0){const n=e.childNodes[e.childNodes.length-1];if(Ws.isTextNode(n)){n.value+=t;return}}Ws.appendChild(e,Ws.createTextNode(t))},insertTextBefore(e,t,n){const r=e.childNodes[e.childNodes.indexOf(n)-1];r&&Ws.isTextNode(r)?r.value+=t:Ws.insertBefore(e,Ws.createTextNode(t),n)},adoptAttributes(e,t){const n=new Set(e.attrs.map(r=>r.name));for(let r=0;r<t.length;r++)n.has(t[r].name)||e.attrs.push(t[r])},getFirstChild(e){return e.childNodes[0]},getChildNodes(e){return e.childNodes},getParentNode(e){return e.parentNode},getAttrList(e){return e.attrs},getTagName(e){return e.tagName},getNamespaceURI(e){return e.namespaceURI},getTextNodeContent(e){return e.value},getCommentNodeContent(e){return e.data},getDocumentTypeNodeName(e){return e.name},getDocumentTypeNodePublicId(e){return e.publicId},getDocumentTypeNodeSystemId(e){return e.systemId},isTextNode(e){return e.nodeName==="#text"},isCommentNode(e){return e.nodeName==="#comment"},isDocumentTypeNode(e){return e.nodeName==="#documentType"},isElementNode(e){return Object.prototype.hasOwnProperty.call(e,"tagName")},setNodeSourceCodeLocation(e,t){e.sourceCodeLocation=t},getNodeSourceCodeLocation(e){return e.sourceCodeLocation},updateNodeSourceCodeLocation(e,t){e.sourceCodeLocation={...e.sourceCodeLocation,...t}}},yT="html",EU="about:legacy-compat",TU="http://www.ibm.com/data/dtd/v11/ibmxhtml1-transitional.dtd",ET=["+//silmaril//dtd html pro v0r11 19970101//","-//as//dtd html 3.0 aswedit + extensions//","-//advasoft ltd//dtd html 3.0 aswedit + extensions//","-//ietf//dtd html 2.0 level 1//","-//ietf//dtd html 2.0 level 2//","-//ietf//dtd html 2.0 strict level 1//","-//ietf//dtd html 2.0 strict level 2//","-//ietf//dtd html 2.0 strict//","-//ietf//dtd html 2.0//","-//ietf//dtd html 2.1e//","-//ietf//dtd html 3.0//","-//ietf//dtd html 3.2 final//","-//ietf//dtd html 3.2//","-//ietf//dtd html 3//","-//ietf//dtd html level 0//","-//ietf//dtd html level 1//","-//ietf//dtd html level 2//","-//ietf//dtd html level 3//","-//ietf//dtd html strict level 0//","-//ietf//dtd html strict level 1//","-//ietf//dtd html strict level 2//","-//ietf//dtd html strict level 3//","-//ietf//dtd html strict//","-//ietf//dtd html//","-//metrius//dtd metrius presentational//","-//microsoft//dtd internet explorer 2.0 html strict//","-//microsoft//dtd internet explorer 2.0 html//","-//microsoft//dtd internet explorer 2.0 tables//","-//microsoft//dtd internet explorer 3.0 html strict//","-//microsoft//dtd internet explorer 3.0 html//","-//microsoft//dtd internet explorer 3.0 tables//","-//netscape comm. corp.//dtd html//","-//netscape comm. corp.//dtd strict html//","-//o'reilly and associates//dtd html 2.0//","-//o'reilly and associates//dtd html extended 1.0//","-//o'reilly and associates//dtd html extended relaxed 1.0//","-//sq//dtd html 2.0 hotmetal + extensions//","-//softquad software//dtd hotmetal pro 6.0::19990601::extensions to html 4.0//","-//softquad//dtd hotmetal pro 4.0::19971010::extensions to html 4.0//","-//spyglass//dtd html 2.0 extended//","-//sun microsystems corp.//dtd hotjava html//","-//sun microsystems corp.//dtd hotjava strict html//","-//w3c//dtd html 3 1995-03-24//","-//w3c//dtd html 3.2 draft//","-//w3c//dtd html 3.2 final//","-//w3c//dtd html 3.2//","-//w3c//dtd html 3.2s draft//","-//w3c//dtd html 4.0 frameset//","-//w3c//dtd html 4.0 transitional//","-//w3c//dtd html experimental 19960712//","-//w3c//dtd html experimental 970421//","-//w3c//dtd w3 html//","-//w3o//dtd w3 html 3.0//","-//webtechs//dtd mozilla html 2.0//","-//webtechs//dtd mozilla html//"],xU=[...ET,"-//w3c//dtd html 4.01 frameset//","-//w3c//dtd html 4.01 transitional//"],SU=new Set(["-//w3o//dtd w3 html strict 3.0//en//","-/w3c/dtd html 4.0 transitional/en","html"]),TT=["-//w3c//dtd xhtml 1.0 frameset//","-//w3c//dtd xhtml 1.0 transitional//"],wU=[...TT,"-//w3c//dtd html 4.01 frameset//","-//w3c//dtd html 4.01 transitional//"];function UE(e,t){return t.some(n=>e.startsWith(n))}function AU(e){return e.name===yT&&e.publicId===null&&(e.systemId===null||e.systemId===EU)}function kU(e){if(e.name!==yT)return Pi.QUIRKS;const{systemId:t}=e;if(t&&t.toLowerCase()===TU)return Pi.QUIRKS;let{publicId:n}=e;if(n!==null){if(n=n.toLowerCase(),SU.has(n))return Pi.QUIRKS;let r=t===null?xU:ET;if(UE(n,r))return Pi.QUIRKS;if(r=t===null?TT:wU,UE(n,r))return Pi.LIMITED_QUIRKS}return Pi.NO_QUIRKS}const zE={TEXT_HTML:"text/html",APPLICATION_XML:"application/xhtml+xml"},CU="definitionurl",NU="definitionURL",OU=new Map(["attributeName","attributeType","baseFrequency","baseProfile","calcMode","clipPathUnits","diffuseConstant","edgeMode","filterUnits","glyphRef","gradientTransform","gradientUnits","kernelMatrix","kernelUnitLength","keyPoints","keySplines","keyTimes","lengthAdjust","limitingConeAngle","markerHeight","markerUnits","markerWidth","maskContentUnits","maskUnits","numOctaves","pathLength","patternContentUnits","patternTransform","patternUnits","pointsAtX","pointsAtY","pointsAtZ","preserveAlpha","preserveAspectRatio","primitiveUnits","refX","refY","repeatCount","repeatDur","requiredExtensions","requiredFeatures","specularConstant","specularExponent","spreadMethod","startOffset","stdDeviation","stitchTiles","surfaceScale","systemLanguage","tableValues","targetX","targetY","textLength","viewBox","viewTarget","xChannelSelector","yChannelSelector","zoomAndPan"].map(e=>[e.toLowerCase(),e])),RU=new Map([["xlink:actuate",{prefix:"xlink",name:"actuate",namespace:ke.XLINK}],["xlink:arcrole",{prefix:"xlink",name:"arcrole",namespace:ke.XLINK}],["xlink:href",{prefix:"xlink",name:"href",namespace:ke.XLINK}],["xlink:role",{prefix:"xlink",name:"role",namespace:ke.XLINK}],["xlink:show",{prefix:"xlink",name:"show",namespace:ke.XLINK}],["xlink:title",{prefix:"xlink",name:"title",namespace:ke.XLINK}],["xlink:type",{prefix:"xlink",name:"type",namespace:ke.XLINK}],["xml:lang",{prefix:"xml",name:"lang",namespace:ke.XML}],["xml:space",{prefix:"xml",name:"space",namespace:ke.XML}],["xmlns",{prefix:"",name:"xmlns",namespace:ke.XMLNS}],["xmlns:xlink",{prefix:"xmlns",name:"xlink",namespace:ke.XMLNS}]]),MU=new Map(["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","textPath"].map(e=>[e.toLowerCase(),e])),IU=new Set([y.B,y.BIG,y.BLOCKQUOTE,y.BODY,y.BR,y.CENTER,y.CODE,y.DD,y.DIV,y.DL,y.DT,y.EM,y.EMBED,y.H1,y.H2,y.H3,y.H4,y.H5,y.H6,y.HEAD,y.HR,y.I,y.IMG,y.LI,y.LISTING,y.MENU,y.META,y.NOBR,y.OL,y.P,y.PRE,y.RUBY,y.S,y.SMALL,y.SPAN,y.STRONG,y.STRIKE,y.SUB,y.SUP,y.TABLE,y.TT,y.U,y.UL,y.VAR]);function DU(e){const t=e.tagID;return t===y.FONT&&e.attrs.some(({name:r})=>r===jl.COLOR||r===jl.SIZE||r===jl.FACE)||IU.has(t)}function xT(e){for(let t=0;t<e.attrs.length;t++)if(e.attrs[t].name===CU){e.attrs[t].name=NU;break}}function ST(e){for(let t=0;t<e.attrs.length;t++){const n=OU.get(e.attrs[t].name);n!=null&&(e.attrs[t].name=n)}}function N2(e){for(let t=0;t<e.attrs.length;t++){const n=RU.get(e.attrs[t].name);n&&(e.attrs[t].prefix=n.prefix,e.attrs[t].name=n.name,e.attrs[t].namespace=n.namespace)}}function LU(e){const t=MU.get(e.tagName);t!=null&&(e.tagName=t,e.tagID=vu(e.tagName))}function PU(e,t){return t===ke.MATHML&&(e===y.MI||e===y.MO||e===y.MN||e===y.MS||e===y.MTEXT)}function BU(e,t,n){if(t===ke.MATHML&&e===y.ANNOTATION_XML){for(let r=0;r<n.length;r++)if(n[r].name===jl.ENCODING){const i=n[r].value.toLowerCase();return i===zE.TEXT_HTML||i===zE.APPLICATION_XML}}return t===ke.SVG&&(e===y.FOREIGN_OBJECT||e===y.DESC||e===y.TITLE)}function UU(e,t,n,r){return(!r||r===ke.HTML)&&BU(e,t,n)||(!r||r===ke.MATHML)&&PU(e,t)}const zU="hidden",FU=8,HU=3;var G;(function(e){e[e.INITIAL=0]="INITIAL",e[e.BEFORE_HTML=1]="BEFORE_HTML",e[e.BEFORE_HEAD=2]="BEFORE_HEAD",e[e.IN_HEAD=3]="IN_HEAD",e[e.IN_HEAD_NO_SCRIPT=4]="IN_HEAD_NO_SCRIPT",e[e.AFTER_HEAD=5]="AFTER_HEAD",e[e.IN_BODY=6]="IN_BODY",e[e.TEXT=7]="TEXT",e[e.IN_TABLE=8]="IN_TABLE",e[e.IN_TABLE_TEXT=9]="IN_TABLE_TEXT",e[e.IN_CAPTION=10]="IN_CAPTION",e[e.IN_COLUMN_GROUP=11]="IN_COLUMN_GROUP",e[e.IN_TABLE_BODY=12]="IN_TABLE_BODY",e[e.IN_ROW=13]="IN_ROW",e[e.IN_CELL=14]="IN_CELL",e[e.IN_SELECT=15]="IN_SELECT",e[e.IN_SELECT_IN_TABLE=16]="IN_SELECT_IN_TABLE",e[e.IN_TEMPLATE=17]="IN_TEMPLATE",e[e.AFTER_BODY=18]="AFTER_BODY",e[e.IN_FRAMESET=19]="IN_FRAMESET",e[e.AFTER_FRAMESET=20]="AFTER_FRAMESET",e[e.AFTER_AFTER_BODY=21]="AFTER_AFTER_BODY",e[e.AFTER_AFTER_FRAMESET=22]="AFTER_AFTER_FRAMESET"})(G||(G={}));const jU={startLine:-1,startCol:-1,startOffset:-1,endLine:-1,endCol:-1,endOffset:-1},wT=new Set([y.TABLE,y.TBODY,y.TFOOT,y.THEAD,y.TR]),FE={scriptingEnabled:!0,sourceCodeLocationInfo:!1,treeAdapter:Ws,onParseError:null};let HE=class{constructor(t,n,r=null,i=null){this.fragmentContext=r,this.scriptHandler=i,this.currentToken=null,this.stopped=!1,this.insertionMode=G.INITIAL,this.originalInsertionMode=G.INITIAL,this.headElement=null,this.formElement=null,this.currentNotInHTML=!1,this.tmplInsertionModeStack=[],this.pendingCharacterTokens=[],this.hasNonWhitespacePendingCharacterToken=!1,this.framesetOk=!0,this.skipNextNewLine=!1,this.fosterParentingEnabled=!1,this.options={...FE,...t},this.treeAdapter=this.options.treeAdapter,this.onParseError=this.options.onParseError,this.onParseError&&(this.options.sourceCodeLocationInfo=!0),this.document=n??this.treeAdapter.createDocument(),this.tokenizer=new hU(this.options,this),this.activeFormattingElements=new yU(this.treeAdapter),this.fragmentContextID=r?vu(this.treeAdapter.getTagName(r)):y.UNKNOWN,this._setContextModes(r??this.document,this.fragmentContextID),this.openElements=new _U(this.document,this.treeAdapter,this)}static parse(t,n){const r=new this(n);return r.tokenizer.write(t,!0),r.document}static getFragmentParser(t,n){const r={...FE,...n};t??(t=r.treeAdapter.createElement(re.TEMPLATE,ke.HTML,[]));const i=r.treeAdapter.createElement("documentmock",ke.HTML,[]),s=new this(r,i,t);return s.fragmentContextID===y.TEMPLATE&&s.tmplInsertionModeStack.unshift(G.IN_TEMPLATE),s._initTokenizerForFragmentParsing(),s._insertFakeRootElement(),s._resetInsertionMode(),s._findFormInFragmentContext(),s}getFragment(){const t=this.treeAdapter.getFirstChild(this.document),n=this.treeAdapter.createDocumentFragment();return this._adoptNodes(t,n),n}_err(t,n,r){var i;if(!this.onParseError)return;const s=(i=t.location)!==null&&i!==void 0?i:jU,o={code:n,startLine:s.startLine,startCol:s.startCol,startOffset:s.startOffset,endLine:r?s.startLine:s.endLine,endCol:r?s.startCol:s.endCol,endOffset:r?s.startOffset:s.endOffset};this.onParseError(o)}onItemPush(t,n,r){var i,s;(s=(i=this.treeAdapter).onItemPush)===null||s===void 0||s.call(i,t),r&&this.openElements.stackTop>0&&this._setContextModes(t,n)}onItemPop(t,n){var r,i;if(this.options.sourceCodeLocationInfo&&this._setEndLocation(t,this.currentToken),(i=(r=this.treeAdapter).onItemPop)===null||i===void 0||i.call(r,t,this.openElements.current),n){let s,o;this.openElements.stackTop===0&&this.fragmentContext?(s=this.fragmentContext,o=this.fragmentContextID):{current:s,currentTagId:o}=this.openElements,this._setContextModes(s,o)}}_setContextModes(t,n){const r=t===this.document||t&&this.treeAdapter.getNamespaceURI(t)===ke.HTML;this.currentNotInHTML=!r,this.tokenizer.inForeignNode=!r&&t!==void 0&&n!==void 0&&!this._isIntegrationPoint(n,t)}_switchToTextParsing(t,n){this._insertElement(t,ke.HTML),this.tokenizer.state=n,this.originalInsertionMode=this.insertionMode,this.insertionMode=G.TEXT}switchToPlaintextParsing(){this.insertionMode=G.TEXT,this.originalInsertionMode=G.IN_BODY,this.tokenizer.state=Kn.PLAINTEXT}_getAdjustedCurrentElement(){return this.openElements.stackTop===0&&this.fragmentContext?this.fragmentContext:this.openElements.current}_findFormInFragmentContext(){let t=this.fragmentContext;for(;t;){if(this.treeAdapter.getTagName(t)===re.FORM){this.formElement=t;break}t=this.treeAdapter.getParentNode(t)}}_initTokenizerForFragmentParsing(){if(!(!this.fragmentContext||this.treeAdapter.getNamespaceURI(this.fragmentContext)!==ke.HTML))switch(this.fragmentContextID){case y.TITLE:case y.TEXTAREA:{this.tokenizer.state=Kn.RCDATA;break}case y.STYLE:case y.XMP:case y.IFRAME:case y.NOEMBED:case y.NOFRAMES:case y.NOSCRIPT:{this.tokenizer.state=Kn.RAWTEXT;break}case y.SCRIPT:{this.tokenizer.state=Kn.SCRIPT_DATA;break}case y.PLAINTEXT:{this.tokenizer.state=Kn.PLAINTEXT;break}}}_setDocumentType(t){const n=t.name||"",r=t.publicId||"",i=t.systemId||"";if(this.treeAdapter.setDocumentType(this.document,n,r,i),t.location){const o=this.treeAdapter.getChildNodes(this.document).find(c=>this.treeAdapter.isDocumentTypeNode(c));o&&this.treeAdapter.setNodeSourceCodeLocation(o,t.location)}}_attachElementToTree(t,n){if(this.options.sourceCodeLocationInfo){const r=n&&{...n,startTag:n};this.treeAdapter.setNodeSourceCodeLocation(t,r)}if(this._shouldFosterParentOnInsertion())this._fosterParentElement(t);else{const r=this.openElements.currentTmplContentOrNode;this.treeAdapter.appendChild(r??this.document,t)}}_appendElement(t,n){const r=this.treeAdapter.createElement(t.tagName,n,t.attrs);this._attachElementToTree(r,t.location)}_insertElement(t,n){const r=this.treeAdapter.createElement(t.tagName,n,t.attrs);this._attachElementToTree(r,t.location),this.openElements.push(r,t.tagID)}_insertFakeElement(t,n){const r=this.treeAdapter.createElement(t,ke.HTML,[]);this._attachElementToTree(r,null),this.openElements.push(r,n)}_insertTemplate(t){const n=this.treeAdapter.createElement(t.tagName,ke.HTML,t.attrs),r=this.treeAdapter.createDocumentFragment();this.treeAdapter.setTemplateContent(n,r),this._attachElementToTree(n,t.location),this.openElements.push(n,t.tagID),this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(r,null)}_insertFakeRootElement(){const t=this.treeAdapter.createElement(re.HTML,ke.HTML,[]);this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(t,null),this.treeAdapter.appendChild(this.openElements.current,t),this.openElements.push(t,y.HTML)}_appendCommentNode(t,n){const r=this.treeAdapter.createCommentNode(t.data);this.treeAdapter.appendChild(n,r),this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(r,t.location)}_insertCharacters(t){let n,r;if(this._shouldFosterParentOnInsertion()?({parent:n,beforeElement:r}=this._findFosterParentingLocation(),r?this.treeAdapter.insertTextBefore(n,t.chars,r):this.treeAdapter.insertText(n,t.chars)):(n=this.openElements.currentTmplContentOrNode,this.treeAdapter.insertText(n,t.chars)),!t.location)return;const i=this.treeAdapter.getChildNodes(n),s=r?i.lastIndexOf(r):i.length,o=i[s-1];if(this.treeAdapter.getNodeSourceCodeLocation(o)){const{endLine:d,endCol:f,endOffset:m}=t.location;this.treeAdapter.updateNodeSourceCodeLocation(o,{endLine:d,endCol:f,endOffset:m})}else this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(o,t.location)}_adoptNodes(t,n){for(let r=this.treeAdapter.getFirstChild(t);r;r=this.treeAdapter.getFirstChild(t))this.treeAdapter.detachNode(r),this.treeAdapter.appendChild(n,r)}_setEndLocation(t,n){if(this.treeAdapter.getNodeSourceCodeLocation(t)&&n.location){const r=n.location,i=this.treeAdapter.getTagName(t),s=n.type===Nt.END_TAG&&i===n.tagName?{endTag:{...r},endLine:r.endLine,endCol:r.endCol,endOffset:r.endOffset}:{endLine:r.startLine,endCol:r.startCol,endOffset:r.startOffset};this.treeAdapter.updateNodeSourceCodeLocation(t,s)}}shouldProcessStartTagTokenInForeignContent(t){if(!this.currentNotInHTML)return!1;let n,r;return this.openElements.stackTop===0&&this.fragmentContext?(n=this.fragmentContext,r=this.fragmentContextID):{current:n,currentTagId:r}=this.openElements,t.tagID===y.SVG&&this.treeAdapter.getTagName(n)===re.ANNOTATION_XML&&this.treeAdapter.getNamespaceURI(n)===ke.MATHML?!1:this.tokenizer.inForeignNode||(t.tagID===y.MGLYPH||t.tagID===y.MALIGNMARK)&&r!==void 0&&!this._isIntegrationPoint(r,n,ke.HTML)}_processToken(t){switch(t.type){case Nt.CHARACTER:{this.onCharacter(t);break}case Nt.NULL_CHARACTER:{this.onNullCharacter(t);break}case Nt.COMMENT:{this.onComment(t);break}case Nt.DOCTYPE:{this.onDoctype(t);break}case Nt.START_TAG:{this._processStartTag(t);break}case Nt.END_TAG:{this.onEndTag(t);break}case Nt.EOF:{this.onEof(t);break}case Nt.WHITESPACE_CHARACTER:{this.onWhitespaceCharacter(t);break}}}_isIntegrationPoint(t,n,r){const i=this.treeAdapter.getNamespaceURI(n),s=this.treeAdapter.getAttrList(n);return UU(t,i,s,r)}_reconstructActiveFormattingElements(){const t=this.activeFormattingElements.entries.length;if(t){const n=this.activeFormattingElements.entries.findIndex(i=>i.type===la.Marker||this.openElements.contains(i.element)),r=n===-1?t-1:n-1;for(let i=r;i>=0;i--){const s=this.activeFormattingElements.entries[i];this._insertElement(s.token,this.treeAdapter.getNamespaceURI(s.element)),s.element=this.openElements.current}}}_closeTableCell(){this.openElements.generateImpliedEndTags(),this.openElements.popUntilTableCellPopped(),this.activeFormattingElements.clearToLastMarker(),this.insertionMode=G.IN_ROW}_closePElement(){this.openElements.generateImpliedEndTagsWithExclusion(y.P),this.openElements.popUntilTagNamePopped(y.P)}_resetInsertionMode(){for(let t=this.openElements.stackTop;t>=0;t--)switch(t===0&&this.fragmentContext?this.fragmentContextID:this.openElements.tagIDs[t]){case y.TR:{this.insertionMode=G.IN_ROW;return}case y.TBODY:case y.THEAD:case y.TFOOT:{this.insertionMode=G.IN_TABLE_BODY;return}case y.CAPTION:{this.insertionMode=G.IN_CAPTION;return}case y.COLGROUP:{this.insertionMode=G.IN_COLUMN_GROUP;return}case y.TABLE:{this.insertionMode=G.IN_TABLE;return}case y.BODY:{this.insertionMode=G.IN_BODY;return}case y.FRAMESET:{this.insertionMode=G.IN_FRAMESET;return}case y.SELECT:{this._resetInsertionModeForSelect(t);return}case y.TEMPLATE:{this.insertionMode=this.tmplInsertionModeStack[0];return}case y.HTML:{this.insertionMode=this.headElement?G.AFTER_HEAD:G.BEFORE_HEAD;return}case y.TD:case y.TH:{if(t>0){this.insertionMode=G.IN_CELL;return}break}case y.HEAD:{if(t>0){this.insertionMode=G.IN_HEAD;return}break}}this.insertionMode=G.IN_BODY}_resetInsertionModeForSelect(t){if(t>0)for(let n=t-1;n>0;n--){const r=this.openElements.tagIDs[n];if(r===y.TEMPLATE)break;if(r===y.TABLE){this.insertionMode=G.IN_SELECT_IN_TABLE;return}}this.insertionMode=G.IN_SELECT}_isElementCausesFosterParenting(t){return wT.has(t)}_shouldFosterParentOnInsertion(){return this.fosterParentingEnabled&&this.openElements.currentTagId!==void 0&&this._isElementCausesFosterParenting(this.openElements.currentTagId)}_findFosterParentingLocation(){for(let t=this.openElements.stackTop;t>=0;t--){const n=this.openElements.items[t];switch(this.openElements.tagIDs[t]){case y.TEMPLATE:{if(this.treeAdapter.getNamespaceURI(n)===ke.HTML)return{parent:this.treeAdapter.getTemplateContent(n),beforeElement:null};break}case y.TABLE:{const r=this.treeAdapter.getParentNode(n);return r?{parent:r,beforeElement:n}:{parent:this.openElements.items[t-1],beforeElement:null}}}}return{parent:this.openElements.items[0],beforeElement:null}}_fosterParentElement(t){const n=this._findFosterParentingLocation();n.beforeElement?this.treeAdapter.insertBefore(n.parent,t,n.beforeElement):this.treeAdapter.appendChild(n.parent,t)}_isSpecialElement(t,n){const r=this.treeAdapter.getNamespaceURI(t);return oU[r].has(n)}onCharacter(t){if(this.skipNextNewLine=!1,this.tokenizer.inForeignNode){vF(this,t);return}switch(this.insertionMode){case G.INITIAL:{Sc(this,t);break}case G.BEFORE_HTML:{Zc(this,t);break}case G.BEFORE_HEAD:{Jc(this,t);break}case G.IN_HEAD:{e0(this,t);break}case G.IN_HEAD_NO_SCRIPT:{t0(this,t);break}case G.AFTER_HEAD:{n0(this,t);break}case G.IN_BODY:case G.IN_CAPTION:case G.IN_CELL:case G.IN_TEMPLATE:{kT(this,t);break}case G.TEXT:case G.IN_SELECT:case G.IN_SELECT_IN_TABLE:{this._insertCharacters(t);break}case G.IN_TABLE:case G.IN_TABLE_BODY:case G.IN_ROW:{Z1(this,t);break}case G.IN_TABLE_TEXT:{IT(this,t);break}case G.IN_COLUMN_GROUP:{rf(this,t);break}case G.AFTER_BODY:{af(this,t);break}case G.AFTER_AFTER_BODY:{qh(this,t);break}}}onNullCharacter(t){if(this.skipNextNewLine=!1,this.tokenizer.inForeignNode){bF(this,t);return}switch(this.insertionMode){case G.INITIAL:{Sc(this,t);break}case G.BEFORE_HTML:{Zc(this,t);break}case G.BEFORE_HEAD:{Jc(this,t);break}case G.IN_HEAD:{e0(this,t);break}case G.IN_HEAD_NO_SCRIPT:{t0(this,t);break}case G.AFTER_HEAD:{n0(this,t);break}case G.TEXT:{this._insertCharacters(t);break}case G.IN_TABLE:case G.IN_TABLE_BODY:case G.IN_ROW:{Z1(this,t);break}case G.IN_COLUMN_GROUP:{rf(this,t);break}case G.AFTER_BODY:{af(this,t);break}case G.AFTER_AFTER_BODY:{qh(this,t);break}}}onComment(t){if(this.skipNextNewLine=!1,this.currentNotInHTML){hb(this,t);return}switch(this.insertionMode){case G.INITIAL:case G.BEFORE_HTML:case G.BEFORE_HEAD:case G.IN_HEAD:case G.IN_HEAD_NO_SCRIPT:case G.AFTER_HEAD:case G.IN_BODY:case G.IN_TABLE:case G.IN_CAPTION:case G.IN_COLUMN_GROUP:case G.IN_TABLE_BODY:case G.IN_ROW:case G.IN_CELL:case G.IN_SELECT:case G.IN_SELECT_IN_TABLE:case G.IN_TEMPLATE:case G.IN_FRAMESET:case G.AFTER_FRAMESET:{hb(this,t);break}case G.IN_TABLE_TEXT:{wc(this,t);break}case G.AFTER_BODY:{WU(this,t);break}case G.AFTER_AFTER_BODY:case G.AFTER_AFTER_FRAMESET:{XU(this,t);break}}}onDoctype(t){switch(this.skipNextNewLine=!1,this.insertionMode){case G.INITIAL:{QU(this,t);break}case G.BEFORE_HEAD:case G.IN_HEAD:case G.IN_HEAD_NO_SCRIPT:case G.AFTER_HEAD:{this._err(t,be.misplacedDoctype);break}case G.IN_TABLE_TEXT:{wc(this,t);break}}}onStartTag(t){this.skipNextNewLine=!1,this.currentToken=t,this._processStartTag(t),t.selfClosing&&!t.ackSelfClosing&&this._err(t,be.nonVoidHtmlElementStartTagWithTrailingSolidus)}_processStartTag(t){this.shouldProcessStartTagTokenInForeignContent(t)?_F(this,t):this._startTagOutsideForeignContent(t)}_startTagOutsideForeignContent(t){switch(this.insertionMode){case G.INITIAL:{Sc(this,t);break}case G.BEFORE_HTML:{ZU(this,t);break}case G.BEFORE_HEAD:{ez(this,t);break}case G.IN_HEAD:{Xi(this,t);break}case G.IN_HEAD_NO_SCRIPT:{rz(this,t);break}case G.AFTER_HEAD:{az(this,t);break}case G.IN_BODY:{Rr(this,t);break}case G.IN_TABLE:{su(this,t);break}case G.IN_TABLE_TEXT:{wc(this,t);break}case G.IN_CAPTION:{tF(this,t);break}case G.IN_COLUMN_GROUP:{M2(this,t);break}case G.IN_TABLE_BODY:{Wf(this,t);break}case G.IN_ROW:{Xf(this,t);break}case G.IN_CELL:{iF(this,t);break}case G.IN_SELECT:{PT(this,t);break}case G.IN_SELECT_IN_TABLE:{sF(this,t);break}case G.IN_TEMPLATE:{oF(this,t);break}case G.AFTER_BODY:{cF(this,t);break}case G.IN_FRAMESET:{dF(this,t);break}case G.AFTER_FRAMESET:{fF(this,t);break}case G.AFTER_AFTER_BODY:{pF(this,t);break}case G.AFTER_AFTER_FRAMESET:{gF(this,t);break}}}onEndTag(t){this.skipNextNewLine=!1,this.currentToken=t,this.currentNotInHTML?yF(this,t):this._endTagOutsideForeignContent(t)}_endTagOutsideForeignContent(t){switch(this.insertionMode){case G.INITIAL:{Sc(this,t);break}case G.BEFORE_HTML:{JU(this,t);break}case G.BEFORE_HEAD:{tz(this,t);break}case G.IN_HEAD:{nz(this,t);break}case G.IN_HEAD_NO_SCRIPT:{iz(this,t);break}case G.AFTER_HEAD:{sz(this,t);break}case G.IN_BODY:{Kf(this,t);break}case G.TEXT:{Gz(this,t);break}case G.IN_TABLE:{d0(this,t);break}case G.IN_TABLE_TEXT:{wc(this,t);break}case G.IN_CAPTION:{nF(this,t);break}case G.IN_COLUMN_GROUP:{rF(this,t);break}case G.IN_TABLE_BODY:{fb(this,t);break}case G.IN_ROW:{LT(this,t);break}case G.IN_CELL:{aF(this,t);break}case G.IN_SELECT:{BT(this,t);break}case G.IN_SELECT_IN_TABLE:{lF(this,t);break}case G.IN_TEMPLATE:{uF(this,t);break}case G.AFTER_BODY:{zT(this,t);break}case G.IN_FRAMESET:{hF(this,t);break}case G.AFTER_FRAMESET:{mF(this,t);break}case G.AFTER_AFTER_BODY:{qh(this,t);break}}}onEof(t){switch(this.insertionMode){case G.INITIAL:{Sc(this,t);break}case G.BEFORE_HTML:{Zc(this,t);break}case G.BEFORE_HEAD:{Jc(this,t);break}case G.IN_HEAD:{e0(this,t);break}case G.IN_HEAD_NO_SCRIPT:{t0(this,t);break}case G.AFTER_HEAD:{n0(this,t);break}case G.IN_BODY:case G.IN_TABLE:case G.IN_CAPTION:case G.IN_COLUMN_GROUP:case G.IN_TABLE_BODY:case G.IN_ROW:case G.IN_CELL:case G.IN_SELECT:case G.IN_SELECT_IN_TABLE:{RT(this,t);break}case G.TEXT:{Yz(this,t);break}case G.IN_TABLE_TEXT:{wc(this,t);break}case G.IN_TEMPLATE:{UT(this,t);break}case G.AFTER_BODY:case G.IN_FRAMESET:case G.AFTER_FRAMESET:case G.AFTER_AFTER_BODY:case G.AFTER_AFTER_FRAMESET:{R2(this,t);break}}}onWhitespaceCharacter(t){if(this.skipNextNewLine&&(this.skipNextNewLine=!1,t.chars.charCodeAt(0)===L.LINE_FEED)){if(t.chars.length===1)return;t.chars=t.chars.substr(1)}if(this.tokenizer.inForeignNode){this._insertCharacters(t);return}switch(this.insertionMode){case G.IN_HEAD:case G.IN_HEAD_NO_SCRIPT:case G.AFTER_HEAD:case G.TEXT:case G.IN_COLUMN_GROUP:case G.IN_SELECT:case G.IN_SELECT_IN_TABLE:case G.IN_FRAMESET:case G.AFTER_FRAMESET:{this._insertCharacters(t);break}case G.IN_BODY:case G.IN_CAPTION:case G.IN_CELL:case G.IN_TEMPLATE:case G.AFTER_BODY:case G.AFTER_AFTER_BODY:case G.AFTER_AFTER_FRAMESET:{AT(this,t);break}case G.IN_TABLE:case G.IN_TABLE_BODY:case G.IN_ROW:{Z1(this,t);break}case G.IN_TABLE_TEXT:{MT(this,t);break}}}};function qU(e,t){let n=e.activeFormattingElements.getElementEntryInScopeWithTagName(t.tagName);return n?e.openElements.contains(n.element)?e.openElements.hasInScope(t.tagID)||(n=null):(e.activeFormattingElements.removeEntry(n),n=null):OT(e,t),n}function $U(e,t){let n=null,r=e.openElements.stackTop;for(;r>=0;r--){const i=e.openElements.items[r];if(i===t.element)break;e._isSpecialElement(i,e.openElements.tagIDs[r])&&(n=i)}return n||(e.openElements.shortenToLength(Math.max(r,0)),e.activeFormattingElements.removeEntry(t)),n}function GU(e,t,n){let r=t,i=e.openElements.getCommonAncestor(t);for(let s=0,o=i;o!==n;s++,o=i){i=e.openElements.getCommonAncestor(o);const c=e.activeFormattingElements.getElementEntry(o),d=c&&s>=HU;!c||d?(d&&e.activeFormattingElements.removeEntry(c),e.openElements.remove(o)):(o=YU(e,c),r===t&&(e.activeFormattingElements.bookmark=c),e.treeAdapter.detachNode(r),e.treeAdapter.appendChild(o,r),r=o)}return r}function YU(e,t){const n=e.treeAdapter.getNamespaceURI(t.element),r=e.treeAdapter.createElement(t.token.tagName,n,t.token.attrs);return e.openElements.replace(t.element,r),t.element=r,r}function VU(e,t,n){const r=e.treeAdapter.getTagName(t),i=vu(r);if(e._isElementCausesFosterParenting(i))e._fosterParentElement(n);else{const s=e.treeAdapter.getNamespaceURI(t);i===y.TEMPLATE&&s===ke.HTML&&(t=e.treeAdapter.getTemplateContent(t)),e.treeAdapter.appendChild(t,n)}}function KU(e,t,n){const r=e.treeAdapter.getNamespaceURI(n.element),{token:i}=n,s=e.treeAdapter.createElement(i.tagName,r,i.attrs);e._adoptNodes(t,s),e.treeAdapter.appendChild(t,s),e.activeFormattingElements.insertElementAfterBookmark(s,i),e.activeFormattingElements.removeEntry(n),e.openElements.remove(n.element),e.openElements.insertAfter(t,s,i.tagID)}function O2(e,t){for(let n=0;n<FU;n++){const r=qU(e,t);if(!r)break;const i=$U(e,r);if(!i)break;e.activeFormattingElements.bookmark=r;const s=GU(e,i,r.element),o=e.openElements.getCommonAncestor(r.element);e.treeAdapter.detachNode(s),o&&VU(e,o,s),KU(e,i,r)}}function hb(e,t){e._appendCommentNode(t,e.openElements.currentTmplContentOrNode)}function WU(e,t){e._appendCommentNode(t,e.openElements.items[0])}function XU(e,t){e._appendCommentNode(t,e.document)}function R2(e,t){if(e.stopped=!0,t.location){const n=e.fragmentContext?0:2;for(let r=e.openElements.stackTop;r>=n;r--)e._setEndLocation(e.openElements.items[r],t);if(!e.fragmentContext&&e.openElements.stackTop>=0){const r=e.openElements.items[0],i=e.treeAdapter.getNodeSourceCodeLocation(r);if(i&&!i.endTag&&(e._setEndLocation(r,t),e.openElements.stackTop>=1)){const s=e.openElements.items[1],o=e.treeAdapter.getNodeSourceCodeLocation(s);o&&!o.endTag&&e._setEndLocation(s,t)}}}}function QU(e,t){e._setDocumentType(t);const n=t.forceQuirks?Pi.QUIRKS:kU(t);AU(t)||e._err(t,be.nonConformingDoctype),e.treeAdapter.setDocumentMode(e.document,n),e.insertionMode=G.BEFORE_HTML}function Sc(e,t){e._err(t,be.missingDoctype,!0),e.treeAdapter.setDocumentMode(e.document,Pi.QUIRKS),e.insertionMode=G.BEFORE_HTML,e._processToken(t)}function ZU(e,t){t.tagID===y.HTML?(e._insertElement(t,ke.HTML),e.insertionMode=G.BEFORE_HEAD):Zc(e,t)}function JU(e,t){const n=t.tagID;(n===y.HTML||n===y.HEAD||n===y.BODY||n===y.BR)&&Zc(e,t)}function Zc(e,t){e._insertFakeRootElement(),e.insertionMode=G.BEFORE_HEAD,e._processToken(t)}function ez(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.HEAD:{e._insertElement(t,ke.HTML),e.headElement=e.openElements.current,e.insertionMode=G.IN_HEAD;break}default:Jc(e,t)}}function tz(e,t){const n=t.tagID;n===y.HEAD||n===y.BODY||n===y.HTML||n===y.BR?Jc(e,t):e._err(t,be.endTagWithoutMatchingOpenElement)}function Jc(e,t){e._insertFakeElement(re.HEAD,y.HEAD),e.headElement=e.openElements.current,e.insertionMode=G.IN_HEAD,e._processToken(t)}function Xi(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.BASE:case y.BASEFONT:case y.BGSOUND:case y.LINK:case y.META:{e._appendElement(t,ke.HTML),t.ackSelfClosing=!0;break}case y.TITLE:{e._switchToTextParsing(t,Kn.RCDATA);break}case y.NOSCRIPT:{e.options.scriptingEnabled?e._switchToTextParsing(t,Kn.RAWTEXT):(e._insertElement(t,ke.HTML),e.insertionMode=G.IN_HEAD_NO_SCRIPT);break}case y.NOFRAMES:case y.STYLE:{e._switchToTextParsing(t,Kn.RAWTEXT);break}case y.SCRIPT:{e._switchToTextParsing(t,Kn.SCRIPT_DATA);break}case y.TEMPLATE:{e._insertTemplate(t),e.activeFormattingElements.insertMarker(),e.framesetOk=!1,e.insertionMode=G.IN_TEMPLATE,e.tmplInsertionModeStack.unshift(G.IN_TEMPLATE);break}case y.HEAD:{e._err(t,be.misplacedStartTagForHeadElement);break}default:e0(e,t)}}function nz(e,t){switch(t.tagID){case y.HEAD:{e.openElements.pop(),e.insertionMode=G.AFTER_HEAD;break}case y.BODY:case y.BR:case y.HTML:{e0(e,t);break}case y.TEMPLATE:{Ql(e,t);break}default:e._err(t,be.endTagWithoutMatchingOpenElement)}}function Ql(e,t){e.openElements.tmplCount>0?(e.openElements.generateImpliedEndTagsThoroughly(),e.openElements.currentTagId!==y.TEMPLATE&&e._err(t,be.closingOfElementWithOpenChildElements),e.openElements.popUntilTagNamePopped(y.TEMPLATE),e.activeFormattingElements.clearToLastMarker(),e.tmplInsertionModeStack.shift(),e._resetInsertionMode()):e._err(t,be.endTagWithoutMatchingOpenElement)}function e0(e,t){e.openElements.pop(),e.insertionMode=G.AFTER_HEAD,e._processToken(t)}function rz(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.BASEFONT:case y.BGSOUND:case y.HEAD:case y.LINK:case y.META:case y.NOFRAMES:case y.STYLE:{Xi(e,t);break}case y.NOSCRIPT:{e._err(t,be.nestedNoscriptInHead);break}default:t0(e,t)}}function iz(e,t){switch(t.tagID){case y.NOSCRIPT:{e.openElements.pop(),e.insertionMode=G.IN_HEAD;break}case y.BR:{t0(e,t);break}default:e._err(t,be.endTagWithoutMatchingOpenElement)}}function t0(e,t){const n=t.type===Nt.EOF?be.openElementsLeftAfterEof:be.disallowedContentInNoscriptInHead;e._err(t,n),e.openElements.pop(),e.insertionMode=G.IN_HEAD,e._processToken(t)}function az(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.BODY:{e._insertElement(t,ke.HTML),e.framesetOk=!1,e.insertionMode=G.IN_BODY;break}case y.FRAMESET:{e._insertElement(t,ke.HTML),e.insertionMode=G.IN_FRAMESET;break}case y.BASE:case y.BASEFONT:case y.BGSOUND:case y.LINK:case y.META:case y.NOFRAMES:case y.SCRIPT:case y.STYLE:case y.TEMPLATE:case y.TITLE:{e._err(t,be.abandonedHeadElementChild),e.openElements.push(e.headElement,y.HEAD),Xi(e,t),e.openElements.remove(e.headElement);break}case y.HEAD:{e._err(t,be.misplacedStartTagForHeadElement);break}default:n0(e,t)}}function sz(e,t){switch(t.tagID){case y.BODY:case y.HTML:case y.BR:{n0(e,t);break}case y.TEMPLATE:{Ql(e,t);break}default:e._err(t,be.endTagWithoutMatchingOpenElement)}}function n0(e,t){e._insertFakeElement(re.BODY,y.BODY),e.insertionMode=G.IN_BODY,Vf(e,t)}function Vf(e,t){switch(t.type){case Nt.CHARACTER:{kT(e,t);break}case Nt.WHITESPACE_CHARACTER:{AT(e,t);break}case Nt.COMMENT:{hb(e,t);break}case Nt.START_TAG:{Rr(e,t);break}case Nt.END_TAG:{Kf(e,t);break}case Nt.EOF:{RT(e,t);break}}}function AT(e,t){e._reconstructActiveFormattingElements(),e._insertCharacters(t)}function kT(e,t){e._reconstructActiveFormattingElements(),e._insertCharacters(t),e.framesetOk=!1}function lz(e,t){e.openElements.tmplCount===0&&e.treeAdapter.adoptAttributes(e.openElements.items[0],t.attrs)}function oz(e,t){const n=e.openElements.tryPeekProperlyNestedBodyElement();n&&e.openElements.tmplCount===0&&(e.framesetOk=!1,e.treeAdapter.adoptAttributes(n,t.attrs))}function uz(e,t){const n=e.openElements.tryPeekProperlyNestedBodyElement();e.framesetOk&&n&&(e.treeAdapter.detachNode(n),e.openElements.popAllUpToHtmlElement(),e._insertElement(t,ke.HTML),e.insertionMode=G.IN_FRAMESET)}function cz(e,t){e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e._insertElement(t,ke.HTML)}function dz(e,t){e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e.openElements.currentTagId!==void 0&&db.has(e.openElements.currentTagId)&&e.openElements.pop(),e._insertElement(t,ke.HTML)}function hz(e,t){e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e._insertElement(t,ke.HTML),e.skipNextNewLine=!0,e.framesetOk=!1}function fz(e,t){const n=e.openElements.tmplCount>0;(!e.formElement||n)&&(e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e._insertElement(t,ke.HTML),n||(e.formElement=e.openElements.current))}function mz(e,t){e.framesetOk=!1;const n=t.tagID;for(let r=e.openElements.stackTop;r>=0;r--){const i=e.openElements.tagIDs[r];if(n===y.LI&&i===y.LI||(n===y.DD||n===y.DT)&&(i===y.DD||i===y.DT)){e.openElements.generateImpliedEndTagsWithExclusion(i),e.openElements.popUntilTagNamePopped(i);break}if(i!==y.ADDRESS&&i!==y.DIV&&i!==y.P&&e._isSpecialElement(e.openElements.items[r],i))break}e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e._insertElement(t,ke.HTML)}function pz(e,t){e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e._insertElement(t,ke.HTML),e.tokenizer.state=Kn.PLAINTEXT}function gz(e,t){e.openElements.hasInScope(y.BUTTON)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(y.BUTTON)),e._reconstructActiveFormattingElements(),e._insertElement(t,ke.HTML),e.framesetOk=!1}function bz(e,t){const n=e.activeFormattingElements.getElementEntryInScopeWithTagName(re.A);n&&(O2(e,t),e.openElements.remove(n.element),e.activeFormattingElements.removeEntry(n)),e._reconstructActiveFormattingElements(),e._insertElement(t,ke.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)}function vz(e,t){e._reconstructActiveFormattingElements(),e._insertElement(t,ke.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)}function _z(e,t){e._reconstructActiveFormattingElements(),e.openElements.hasInScope(y.NOBR)&&(O2(e,t),e._reconstructActiveFormattingElements()),e._insertElement(t,ke.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)}function yz(e,t){e._reconstructActiveFormattingElements(),e._insertElement(t,ke.HTML),e.activeFormattingElements.insertMarker(),e.framesetOk=!1}function Ez(e,t){e.treeAdapter.getDocumentMode(e.document)!==Pi.QUIRKS&&e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e._insertElement(t,ke.HTML),e.framesetOk=!1,e.insertionMode=G.IN_TABLE}function CT(e,t){e._reconstructActiveFormattingElements(),e._appendElement(t,ke.HTML),e.framesetOk=!1,t.ackSelfClosing=!0}function NT(e){const t=bT(e,jl.TYPE);return t!=null&&t.toLowerCase()===zU}function Tz(e,t){e._reconstructActiveFormattingElements(),e._appendElement(t,ke.HTML),NT(t)||(e.framesetOk=!1),t.ackSelfClosing=!0}function xz(e,t){e._appendElement(t,ke.HTML),t.ackSelfClosing=!0}function Sz(e,t){e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e._appendElement(t,ke.HTML),e.framesetOk=!1,t.ackSelfClosing=!0}function wz(e,t){t.tagName=re.IMG,t.tagID=y.IMG,CT(e,t)}function Az(e,t){e._insertElement(t,ke.HTML),e.skipNextNewLine=!0,e.tokenizer.state=Kn.RCDATA,e.originalInsertionMode=e.insertionMode,e.framesetOk=!1,e.insertionMode=G.TEXT}function kz(e,t){e.openElements.hasInButtonScope(y.P)&&e._closePElement(),e._reconstructActiveFormattingElements(),e.framesetOk=!1,e._switchToTextParsing(t,Kn.RAWTEXT)}function Cz(e,t){e.framesetOk=!1,e._switchToTextParsing(t,Kn.RAWTEXT)}function jE(e,t){e._switchToTextParsing(t,Kn.RAWTEXT)}function Nz(e,t){e._reconstructActiveFormattingElements(),e._insertElement(t,ke.HTML),e.framesetOk=!1,e.insertionMode=e.insertionMode===G.IN_TABLE||e.insertionMode===G.IN_CAPTION||e.insertionMode===G.IN_TABLE_BODY||e.insertionMode===G.IN_ROW||e.insertionMode===G.IN_CELL?G.IN_SELECT_IN_TABLE:G.IN_SELECT}function Oz(e,t){e.openElements.currentTagId===y.OPTION&&e.openElements.pop(),e._reconstructActiveFormattingElements(),e._insertElement(t,ke.HTML)}function Rz(e,t){e.openElements.hasInScope(y.RUBY)&&e.openElements.generateImpliedEndTags(),e._insertElement(t,ke.HTML)}function Mz(e,t){e.openElements.hasInScope(y.RUBY)&&e.openElements.generateImpliedEndTagsWithExclusion(y.RTC),e._insertElement(t,ke.HTML)}function Iz(e,t){e._reconstructActiveFormattingElements(),xT(t),N2(t),t.selfClosing?e._appendElement(t,ke.MATHML):e._insertElement(t,ke.MATHML),t.ackSelfClosing=!0}function Dz(e,t){e._reconstructActiveFormattingElements(),ST(t),N2(t),t.selfClosing?e._appendElement(t,ke.SVG):e._insertElement(t,ke.SVG),t.ackSelfClosing=!0}function qE(e,t){e._reconstructActiveFormattingElements(),e._insertElement(t,ke.HTML)}function Rr(e,t){switch(t.tagID){case y.I:case y.S:case y.B:case y.U:case y.EM:case y.TT:case y.BIG:case y.CODE:case y.FONT:case y.SMALL:case y.STRIKE:case y.STRONG:{vz(e,t);break}case y.A:{bz(e,t);break}case y.H1:case y.H2:case y.H3:case y.H4:case y.H5:case y.H6:{dz(e,t);break}case y.P:case y.DL:case y.OL:case y.UL:case y.DIV:case y.DIR:case y.NAV:case y.MAIN:case y.MENU:case y.ASIDE:case y.CENTER:case y.FIGURE:case y.FOOTER:case y.HEADER:case y.HGROUP:case y.DIALOG:case y.DETAILS:case y.ADDRESS:case y.ARTICLE:case y.SEARCH:case y.SECTION:case y.SUMMARY:case y.FIELDSET:case y.BLOCKQUOTE:case y.FIGCAPTION:{cz(e,t);break}case y.LI:case y.DD:case y.DT:{mz(e,t);break}case y.BR:case y.IMG:case y.WBR:case y.AREA:case y.EMBED:case y.KEYGEN:{CT(e,t);break}case y.HR:{Sz(e,t);break}case y.RB:case y.RTC:{Rz(e,t);break}case y.RT:case y.RP:{Mz(e,t);break}case y.PRE:case y.LISTING:{hz(e,t);break}case y.XMP:{kz(e,t);break}case y.SVG:{Dz(e,t);break}case y.HTML:{lz(e,t);break}case y.BASE:case y.LINK:case y.META:case y.STYLE:case y.TITLE:case y.SCRIPT:case y.BGSOUND:case y.BASEFONT:case y.TEMPLATE:{Xi(e,t);break}case y.BODY:{oz(e,t);break}case y.FORM:{fz(e,t);break}case y.NOBR:{_z(e,t);break}case y.MATH:{Iz(e,t);break}case y.TABLE:{Ez(e,t);break}case y.INPUT:{Tz(e,t);break}case y.PARAM:case y.TRACK:case y.SOURCE:{xz(e,t);break}case y.IMAGE:{wz(e,t);break}case y.BUTTON:{gz(e,t);break}case y.APPLET:case y.OBJECT:case y.MARQUEE:{yz(e,t);break}case y.IFRAME:{Cz(e,t);break}case y.SELECT:{Nz(e,t);break}case y.OPTION:case y.OPTGROUP:{Oz(e,t);break}case y.NOEMBED:case y.NOFRAMES:{jE(e,t);break}case y.FRAMESET:{uz(e,t);break}case y.TEXTAREA:{Az(e,t);break}case y.NOSCRIPT:{e.options.scriptingEnabled?jE(e,t):qE(e,t);break}case y.PLAINTEXT:{pz(e,t);break}case y.COL:case y.TH:case y.TD:case y.TR:case y.HEAD:case y.FRAME:case y.TBODY:case y.TFOOT:case y.THEAD:case y.CAPTION:case y.COLGROUP:break;default:qE(e,t)}}function Lz(e,t){if(e.openElements.hasInScope(y.BODY)&&(e.insertionMode=G.AFTER_BODY,e.options.sourceCodeLocationInfo)){const n=e.openElements.tryPeekProperlyNestedBodyElement();n&&e._setEndLocation(n,t)}}function Pz(e,t){e.openElements.hasInScope(y.BODY)&&(e.insertionMode=G.AFTER_BODY,zT(e,t))}function Bz(e,t){const n=t.tagID;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(n))}function Uz(e){const t=e.openElements.tmplCount>0,{formElement:n}=e;t||(e.formElement=null),(n||t)&&e.openElements.hasInScope(y.FORM)&&(e.openElements.generateImpliedEndTags(),t?e.openElements.popUntilTagNamePopped(y.FORM):n&&e.openElements.remove(n))}function zz(e){e.openElements.hasInButtonScope(y.P)||e._insertFakeElement(re.P,y.P),e._closePElement()}function Fz(e){e.openElements.hasInListItemScope(y.LI)&&(e.openElements.generateImpliedEndTagsWithExclusion(y.LI),e.openElements.popUntilTagNamePopped(y.LI))}function Hz(e,t){const n=t.tagID;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTagsWithExclusion(n),e.openElements.popUntilTagNamePopped(n))}function jz(e){e.openElements.hasNumberedHeaderInScope()&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilNumberedHeaderPopped())}function qz(e,t){const n=t.tagID;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(n),e.activeFormattingElements.clearToLastMarker())}function $z(e){e._reconstructActiveFormattingElements(),e._insertFakeElement(re.BR,y.BR),e.openElements.pop(),e.framesetOk=!1}function OT(e,t){const n=t.tagName,r=t.tagID;for(let i=e.openElements.stackTop;i>0;i--){const s=e.openElements.items[i],o=e.openElements.tagIDs[i];if(r===o&&(r!==y.UNKNOWN||e.treeAdapter.getTagName(s)===n)){e.openElements.generateImpliedEndTagsWithExclusion(r),e.openElements.stackTop>=i&&e.openElements.shortenToLength(i);break}if(e._isSpecialElement(s,o))break}}function Kf(e,t){switch(t.tagID){case y.A:case y.B:case y.I:case y.S:case y.U:case y.EM:case y.TT:case y.BIG:case y.CODE:case y.FONT:case y.NOBR:case y.SMALL:case y.STRIKE:case y.STRONG:{O2(e,t);break}case y.P:{zz(e);break}case y.DL:case y.UL:case y.OL:case y.DIR:case y.DIV:case y.NAV:case y.PRE:case y.MAIN:case y.MENU:case y.ASIDE:case y.BUTTON:case y.CENTER:case y.FIGURE:case y.FOOTER:case y.HEADER:case y.HGROUP:case y.DIALOG:case y.ADDRESS:case y.ARTICLE:case y.DETAILS:case y.SEARCH:case y.SECTION:case y.SUMMARY:case y.LISTING:case y.FIELDSET:case y.BLOCKQUOTE:case y.FIGCAPTION:{Bz(e,t);break}case y.LI:{Fz(e);break}case y.DD:case y.DT:{Hz(e,t);break}case y.H1:case y.H2:case y.H3:case y.H4:case y.H5:case y.H6:{jz(e);break}case y.BR:{$z(e);break}case y.BODY:{Lz(e,t);break}case y.HTML:{Pz(e,t);break}case y.FORM:{Uz(e);break}case y.APPLET:case y.OBJECT:case y.MARQUEE:{qz(e,t);break}case y.TEMPLATE:{Ql(e,t);break}default:OT(e,t)}}function RT(e,t){e.tmplInsertionModeStack.length>0?UT(e,t):R2(e,t)}function Gz(e,t){var n;t.tagID===y.SCRIPT&&((n=e.scriptHandler)===null||n===void 0||n.call(e,e.openElements.current)),e.openElements.pop(),e.insertionMode=e.originalInsertionMode}function Yz(e,t){e._err(t,be.eofInElementThatCanContainOnlyText),e.openElements.pop(),e.insertionMode=e.originalInsertionMode,e.onEof(t)}function Z1(e,t){if(e.openElements.currentTagId!==void 0&&wT.has(e.openElements.currentTagId))switch(e.pendingCharacterTokens.length=0,e.hasNonWhitespacePendingCharacterToken=!1,e.originalInsertionMode=e.insertionMode,e.insertionMode=G.IN_TABLE_TEXT,t.type){case Nt.CHARACTER:{IT(e,t);break}case Nt.WHITESPACE_CHARACTER:{MT(e,t);break}}else M0(e,t)}function Vz(e,t){e.openElements.clearBackToTableContext(),e.activeFormattingElements.insertMarker(),e._insertElement(t,ke.HTML),e.insertionMode=G.IN_CAPTION}function Kz(e,t){e.openElements.clearBackToTableContext(),e._insertElement(t,ke.HTML),e.insertionMode=G.IN_COLUMN_GROUP}function Wz(e,t){e.openElements.clearBackToTableContext(),e._insertFakeElement(re.COLGROUP,y.COLGROUP),e.insertionMode=G.IN_COLUMN_GROUP,M2(e,t)}function Xz(e,t){e.openElements.clearBackToTableContext(),e._insertElement(t,ke.HTML),e.insertionMode=G.IN_TABLE_BODY}function Qz(e,t){e.openElements.clearBackToTableContext(),e._insertFakeElement(re.TBODY,y.TBODY),e.insertionMode=G.IN_TABLE_BODY,Wf(e,t)}function Zz(e,t){e.openElements.hasInTableScope(y.TABLE)&&(e.openElements.popUntilTagNamePopped(y.TABLE),e._resetInsertionMode(),e._processStartTag(t))}function Jz(e,t){NT(t)?e._appendElement(t,ke.HTML):M0(e,t),t.ackSelfClosing=!0}function eF(e,t){!e.formElement&&e.openElements.tmplCount===0&&(e._insertElement(t,ke.HTML),e.formElement=e.openElements.current,e.openElements.pop())}function su(e,t){switch(t.tagID){case y.TD:case y.TH:case y.TR:{Qz(e,t);break}case y.STYLE:case y.SCRIPT:case y.TEMPLATE:{Xi(e,t);break}case y.COL:{Wz(e,t);break}case y.FORM:{eF(e,t);break}case y.TABLE:{Zz(e,t);break}case y.TBODY:case y.TFOOT:case y.THEAD:{Xz(e,t);break}case y.INPUT:{Jz(e,t);break}case y.CAPTION:{Vz(e,t);break}case y.COLGROUP:{Kz(e,t);break}default:M0(e,t)}}function d0(e,t){switch(t.tagID){case y.TABLE:{e.openElements.hasInTableScope(y.TABLE)&&(e.openElements.popUntilTagNamePopped(y.TABLE),e._resetInsertionMode());break}case y.TEMPLATE:{Ql(e,t);break}case y.BODY:case y.CAPTION:case y.COL:case y.COLGROUP:case y.HTML:case y.TBODY:case y.TD:case y.TFOOT:case y.TH:case y.THEAD:case y.TR:break;default:M0(e,t)}}function M0(e,t){const n=e.fosterParentingEnabled;e.fosterParentingEnabled=!0,Vf(e,t),e.fosterParentingEnabled=n}function MT(e,t){e.pendingCharacterTokens.push(t)}function IT(e,t){e.pendingCharacterTokens.push(t),e.hasNonWhitespacePendingCharacterToken=!0}function wc(e,t){let n=0;if(e.hasNonWhitespacePendingCharacterToken)for(;n<e.pendingCharacterTokens.length;n++)M0(e,e.pendingCharacterTokens[n]);else for(;n<e.pendingCharacterTokens.length;n++)e._insertCharacters(e.pendingCharacterTokens[n]);e.insertionMode=e.originalInsertionMode,e._processToken(t)}const DT=new Set([y.CAPTION,y.COL,y.COLGROUP,y.TBODY,y.TD,y.TFOOT,y.TH,y.THEAD,y.TR]);function tF(e,t){const n=t.tagID;DT.has(n)?e.openElements.hasInTableScope(y.CAPTION)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(y.CAPTION),e.activeFormattingElements.clearToLastMarker(),e.insertionMode=G.IN_TABLE,su(e,t)):Rr(e,t)}function nF(e,t){const n=t.tagID;switch(n){case y.CAPTION:case y.TABLE:{e.openElements.hasInTableScope(y.CAPTION)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(y.CAPTION),e.activeFormattingElements.clearToLastMarker(),e.insertionMode=G.IN_TABLE,n===y.TABLE&&d0(e,t));break}case y.BODY:case y.COL:case y.COLGROUP:case y.HTML:case y.TBODY:case y.TD:case y.TFOOT:case y.TH:case y.THEAD:case y.TR:break;default:Kf(e,t)}}function M2(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.COL:{e._appendElement(t,ke.HTML),t.ackSelfClosing=!0;break}case y.TEMPLATE:{Xi(e,t);break}default:rf(e,t)}}function rF(e,t){switch(t.tagID){case y.COLGROUP:{e.openElements.currentTagId===y.COLGROUP&&(e.openElements.pop(),e.insertionMode=G.IN_TABLE);break}case y.TEMPLATE:{Ql(e,t);break}case y.COL:break;default:rf(e,t)}}function rf(e,t){e.openElements.currentTagId===y.COLGROUP&&(e.openElements.pop(),e.insertionMode=G.IN_TABLE,e._processToken(t))}function Wf(e,t){switch(t.tagID){case y.TR:{e.openElements.clearBackToTableBodyContext(),e._insertElement(t,ke.HTML),e.insertionMode=G.IN_ROW;break}case y.TH:case y.TD:{e.openElements.clearBackToTableBodyContext(),e._insertFakeElement(re.TR,y.TR),e.insertionMode=G.IN_ROW,Xf(e,t);break}case y.CAPTION:case y.COL:case y.COLGROUP:case y.TBODY:case y.TFOOT:case y.THEAD:{e.openElements.hasTableBodyContextInTableScope()&&(e.openElements.clearBackToTableBodyContext(),e.openElements.pop(),e.insertionMode=G.IN_TABLE,su(e,t));break}default:su(e,t)}}function fb(e,t){const n=t.tagID;switch(t.tagID){case y.TBODY:case y.TFOOT:case y.THEAD:{e.openElements.hasInTableScope(n)&&(e.openElements.clearBackToTableBodyContext(),e.openElements.pop(),e.insertionMode=G.IN_TABLE);break}case y.TABLE:{e.openElements.hasTableBodyContextInTableScope()&&(e.openElements.clearBackToTableBodyContext(),e.openElements.pop(),e.insertionMode=G.IN_TABLE,d0(e,t));break}case y.BODY:case y.CAPTION:case y.COL:case y.COLGROUP:case y.HTML:case y.TD:case y.TH:case y.TR:break;default:d0(e,t)}}function Xf(e,t){switch(t.tagID){case y.TH:case y.TD:{e.openElements.clearBackToTableRowContext(),e._insertElement(t,ke.HTML),e.insertionMode=G.IN_CELL,e.activeFormattingElements.insertMarker();break}case y.CAPTION:case y.COL:case y.COLGROUP:case y.TBODY:case y.TFOOT:case y.THEAD:case y.TR:{e.openElements.hasInTableScope(y.TR)&&(e.openElements.clearBackToTableRowContext(),e.openElements.pop(),e.insertionMode=G.IN_TABLE_BODY,Wf(e,t));break}default:su(e,t)}}function LT(e,t){switch(t.tagID){case y.TR:{e.openElements.hasInTableScope(y.TR)&&(e.openElements.clearBackToTableRowContext(),e.openElements.pop(),e.insertionMode=G.IN_TABLE_BODY);break}case y.TABLE:{e.openElements.hasInTableScope(y.TR)&&(e.openElements.clearBackToTableRowContext(),e.openElements.pop(),e.insertionMode=G.IN_TABLE_BODY,fb(e,t));break}case y.TBODY:case y.TFOOT:case y.THEAD:{(e.openElements.hasInTableScope(t.tagID)||e.openElements.hasInTableScope(y.TR))&&(e.openElements.clearBackToTableRowContext(),e.openElements.pop(),e.insertionMode=G.IN_TABLE_BODY,fb(e,t));break}case y.BODY:case y.CAPTION:case y.COL:case y.COLGROUP:case y.HTML:case y.TD:case y.TH:break;default:d0(e,t)}}function iF(e,t){const n=t.tagID;DT.has(n)?(e.openElements.hasInTableScope(y.TD)||e.openElements.hasInTableScope(y.TH))&&(e._closeTableCell(),Xf(e,t)):Rr(e,t)}function aF(e,t){const n=t.tagID;switch(n){case y.TD:case y.TH:{e.openElements.hasInTableScope(n)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(n),e.activeFormattingElements.clearToLastMarker(),e.insertionMode=G.IN_ROW);break}case y.TABLE:case y.TBODY:case y.TFOOT:case y.THEAD:case y.TR:{e.openElements.hasInTableScope(n)&&(e._closeTableCell(),LT(e,t));break}case y.BODY:case y.CAPTION:case y.COL:case y.COLGROUP:case y.HTML:break;default:Kf(e,t)}}function PT(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.OPTION:{e.openElements.currentTagId===y.OPTION&&e.openElements.pop(),e._insertElement(t,ke.HTML);break}case y.OPTGROUP:{e.openElements.currentTagId===y.OPTION&&e.openElements.pop(),e.openElements.currentTagId===y.OPTGROUP&&e.openElements.pop(),e._insertElement(t,ke.HTML);break}case y.HR:{e.openElements.currentTagId===y.OPTION&&e.openElements.pop(),e.openElements.currentTagId===y.OPTGROUP&&e.openElements.pop(),e._appendElement(t,ke.HTML),t.ackSelfClosing=!0;break}case y.INPUT:case y.KEYGEN:case y.TEXTAREA:case y.SELECT:{e.openElements.hasInSelectScope(y.SELECT)&&(e.openElements.popUntilTagNamePopped(y.SELECT),e._resetInsertionMode(),t.tagID!==y.SELECT&&e._processStartTag(t));break}case y.SCRIPT:case y.TEMPLATE:{Xi(e,t);break}}}function BT(e,t){switch(t.tagID){case y.OPTGROUP:{e.openElements.stackTop>0&&e.openElements.currentTagId===y.OPTION&&e.openElements.tagIDs[e.openElements.stackTop-1]===y.OPTGROUP&&e.openElements.pop(),e.openElements.currentTagId===y.OPTGROUP&&e.openElements.pop();break}case y.OPTION:{e.openElements.currentTagId===y.OPTION&&e.openElements.pop();break}case y.SELECT:{e.openElements.hasInSelectScope(y.SELECT)&&(e.openElements.popUntilTagNamePopped(y.SELECT),e._resetInsertionMode());break}case y.TEMPLATE:{Ql(e,t);break}}}function sF(e,t){const n=t.tagID;n===y.CAPTION||n===y.TABLE||n===y.TBODY||n===y.TFOOT||n===y.THEAD||n===y.TR||n===y.TD||n===y.TH?(e.openElements.popUntilTagNamePopped(y.SELECT),e._resetInsertionMode(),e._processStartTag(t)):PT(e,t)}function lF(e,t){const n=t.tagID;n===y.CAPTION||n===y.TABLE||n===y.TBODY||n===y.TFOOT||n===y.THEAD||n===y.TR||n===y.TD||n===y.TH?e.openElements.hasInTableScope(n)&&(e.openElements.popUntilTagNamePopped(y.SELECT),e._resetInsertionMode(),e.onEndTag(t)):BT(e,t)}function oF(e,t){switch(t.tagID){case y.BASE:case y.BASEFONT:case y.BGSOUND:case y.LINK:case y.META:case y.NOFRAMES:case y.SCRIPT:case y.STYLE:case y.TEMPLATE:case y.TITLE:{Xi(e,t);break}case y.CAPTION:case y.COLGROUP:case y.TBODY:case y.TFOOT:case y.THEAD:{e.tmplInsertionModeStack[0]=G.IN_TABLE,e.insertionMode=G.IN_TABLE,su(e,t);break}case y.COL:{e.tmplInsertionModeStack[0]=G.IN_COLUMN_GROUP,e.insertionMode=G.IN_COLUMN_GROUP,M2(e,t);break}case y.TR:{e.tmplInsertionModeStack[0]=G.IN_TABLE_BODY,e.insertionMode=G.IN_TABLE_BODY,Wf(e,t);break}case y.TD:case y.TH:{e.tmplInsertionModeStack[0]=G.IN_ROW,e.insertionMode=G.IN_ROW,Xf(e,t);break}default:e.tmplInsertionModeStack[0]=G.IN_BODY,e.insertionMode=G.IN_BODY,Rr(e,t)}}function uF(e,t){t.tagID===y.TEMPLATE&&Ql(e,t)}function UT(e,t){e.openElements.tmplCount>0?(e.openElements.popUntilTagNamePopped(y.TEMPLATE),e.activeFormattingElements.clearToLastMarker(),e.tmplInsertionModeStack.shift(),e._resetInsertionMode(),e.onEof(t)):R2(e,t)}function cF(e,t){t.tagID===y.HTML?Rr(e,t):af(e,t)}function zT(e,t){var n;if(t.tagID===y.HTML){if(e.fragmentContext||(e.insertionMode=G.AFTER_AFTER_BODY),e.options.sourceCodeLocationInfo&&e.openElements.tagIDs[0]===y.HTML){e._setEndLocation(e.openElements.items[0],t);const r=e.openElements.items[1];r&&!(!((n=e.treeAdapter.getNodeSourceCodeLocation(r))===null||n===void 0)&&n.endTag)&&e._setEndLocation(r,t)}}else af(e,t)}function af(e,t){e.insertionMode=G.IN_BODY,Vf(e,t)}function dF(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.FRAMESET:{e._insertElement(t,ke.HTML);break}case y.FRAME:{e._appendElement(t,ke.HTML),t.ackSelfClosing=!0;break}case y.NOFRAMES:{Xi(e,t);break}}}function hF(e,t){t.tagID===y.FRAMESET&&!e.openElements.isRootHtmlElementCurrent()&&(e.openElements.pop(),!e.fragmentContext&&e.openElements.currentTagId!==y.FRAMESET&&(e.insertionMode=G.AFTER_FRAMESET))}function fF(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.NOFRAMES:{Xi(e,t);break}}}function mF(e,t){t.tagID===y.HTML&&(e.insertionMode=G.AFTER_AFTER_FRAMESET)}function pF(e,t){t.tagID===y.HTML?Rr(e,t):qh(e,t)}function qh(e,t){e.insertionMode=G.IN_BODY,Vf(e,t)}function gF(e,t){switch(t.tagID){case y.HTML:{Rr(e,t);break}case y.NOFRAMES:{Xi(e,t);break}}}function bF(e,t){t.chars=On,e._insertCharacters(t)}function vF(e,t){e._insertCharacters(t),e.framesetOk=!1}function FT(e){for(;e.treeAdapter.getNamespaceURI(e.openElements.current)!==ke.HTML&&e.openElements.currentTagId!==void 0&&!e._isIntegrationPoint(e.openElements.currentTagId,e.openElements.current);)e.openElements.pop()}function _F(e,t){if(DU(t))FT(e),e._startTagOutsideForeignContent(t);else{const n=e._getAdjustedCurrentElement(),r=e.treeAdapter.getNamespaceURI(n);r===ke.MATHML?xT(t):r===ke.SVG&&(LU(t),ST(t)),N2(t),t.selfClosing?e._appendElement(t,r):e._insertElement(t,r),t.ackSelfClosing=!0}}function yF(e,t){if(t.tagID===y.P||t.tagID===y.BR){FT(e),e._endTagOutsideForeignContent(t);return}for(let n=e.openElements.stackTop;n>0;n--){const r=e.openElements.items[n];if(e.treeAdapter.getNamespaceURI(r)===ke.HTML){e._endTagOutsideForeignContent(t);break}const i=e.treeAdapter.getTagName(r);if(i.toLowerCase()===t.tagName){t.tagName=i,e.openElements.shortenToLength(n);break}}}re.AREA,re.BASE,re.BASEFONT,re.BGSOUND,re.BR,re.COL,re.EMBED,re.FRAME,re.HR,re.IMG,re.INPUT,re.KEYGEN,re.LINK,re.META,re.PARAM,re.SOURCE,re.TRACK,re.WBR;const EF=/<(\/?)(iframe|noembed|noframes|plaintext|script|style|textarea|title|xmp)(?=[\t\n\f\r />])/gi,TF=new Set(["mdxFlowExpression","mdxJsxFlowElement","mdxJsxTextElement","mdxTextExpression","mdxjsEsm"]),$E={sourceCodeLocationInfo:!0,scriptingEnabled:!1};function HT(e,t){const n=MF(e),r=H7("type",{handlers:{root:xF,element:SF,text:wF,comment:qT,doctype:AF,raw:CF},unknown:NF}),i={parser:n?new HE($E):HE.getFragmentParser(void 0,$E),handle(c){r(c,i)},stitches:!1,options:t||{}};r(e,i),_u(i,pa());const s=n?i.parser.document:i.parser.getFragment(),o=IB(s,{file:i.options.file});return i.stitches&&O0(o,"comment",function(c,d,f){const m=c;if(m.value.stitch&&f&&d!==void 0){const p=f.children;return p[d]=m.value.stitch,d}}),o.type==="root"&&o.children.length===1&&o.children[0].type===e.type?o.children[0]:o}function jT(e,t){let n=-1;if(e)for(;++n<e.length;)t.handle(e[n])}function xF(e,t){jT(e.children,t)}function SF(e,t){OF(e,t),jT(e.children,t),RF(e,t)}function wF(e,t){t.parser.tokenizer.state>4&&(t.parser.tokenizer.state=0);const n={type:Nt.CHARACTER,chars:e.value,location:I0(e)};_u(t,pa(e)),t.parser.currentToken=n,t.parser._processToken(t.parser.currentToken)}function AF(e,t){const n={type:Nt.DOCTYPE,name:"html",forceQuirks:!1,publicId:"",systemId:"",location:I0(e)};_u(t,pa(e)),t.parser.currentToken=n,t.parser._processToken(t.parser.currentToken)}function kF(e,t){t.stitches=!0;const n=IF(e);if("children"in e&&"children"in n){const r=HT({type:"root",children:e.children},t.options);n.children=r.children}qT({type:"comment",value:{stitch:n}},t)}function qT(e,t){const n=e.value,r={type:Nt.COMMENT,data:n,location:I0(e)};_u(t,pa(e)),t.parser.currentToken=r,t.parser._processToken(t.parser.currentToken)}function CF(e,t){if(t.parser.tokenizer.preprocessor.html="",t.parser.tokenizer.preprocessor.pos=-1,t.parser.tokenizer.preprocessor.lastGapPos=-2,t.parser.tokenizer.preprocessor.gapStack=[],t.parser.tokenizer.preprocessor.skipNextNewLine=!1,t.parser.tokenizer.preprocessor.lastChunkWritten=!1,t.parser.tokenizer.preprocessor.endOfChunkHit=!1,t.parser.tokenizer.preprocessor.isEol=!1,$T(t,pa(e)),t.parser.tokenizer.write(t.options.tagfilter?e.value.replace(EF,"&lt;$1$2"):e.value,!1),t.parser.tokenizer._runParsingLoop(),t.parser.tokenizer.state===72||t.parser.tokenizer.state===78){t.parser.tokenizer.preprocessor.lastChunkWritten=!0;const n=t.parser.tokenizer._consume();t.parser.tokenizer._callState(n)}}function NF(e,t){const n=e;if(t.options.passThrough&&t.options.passThrough.includes(n.type))kF(n,t);else{let r="";throw TF.has(n.type)&&(r=". It looks like you are using MDX nodes with `hast-util-raw` (or `rehype-raw`). If you use this because you are using remark or rehype plugins that inject `'html'` nodes, then please raise an issue with that plugin, as its a bad and slow idea. If you use this because you are using markdown syntax, then you have to configure this utility (or plugin) to pass through these nodes (see `passThrough` in docs), but you can also migrate to use the MDX syntax"),new Error("Cannot compile `"+n.type+"` node"+r)}}function _u(e,t){$T(e,t);const n=e.parser.tokenizer.currentCharacterToken;n&&n.location&&(n.location.endLine=e.parser.tokenizer.preprocessor.line,n.location.endCol=e.parser.tokenizer.preprocessor.col+1,n.location.endOffset=e.parser.tokenizer.preprocessor.offset+1,e.parser.currentToken=n,e.parser._processToken(e.parser.currentToken)),e.parser.tokenizer.paused=!1,e.parser.tokenizer.inLoop=!1,e.parser.tokenizer.active=!1,e.parser.tokenizer.returnState=Kn.DATA,e.parser.tokenizer.charRefCode=-1,e.parser.tokenizer.consumedAfterSnapshot=-1,e.parser.tokenizer.currentLocation=null,e.parser.tokenizer.currentCharacterToken=null,e.parser.tokenizer.currentToken=null,e.parser.tokenizer.currentAttr={name:"",value:""}}function $T(e,t){if(t&&t.offset!==void 0){const n={startLine:t.line,startCol:t.column,startOffset:t.offset,endLine:-1,endCol:-1,endOffset:-1};e.parser.tokenizer.preprocessor.lineStartPos=-t.column+1,e.parser.tokenizer.preprocessor.droppedBufferSize=t.offset,e.parser.tokenizer.preprocessor.line=t.line,e.parser.tokenizer.currentLocation=n}}function OF(e,t){const n=e.tagName.toLowerCase();if(t.parser.tokenizer.state===Kn.PLAINTEXT)return;_u(t,pa(e));const r=t.parser.openElements.current;let i="namespaceURI"in r?r.namespaceURI:ca.html;i===ca.html&&n==="svg"&&(i=ca.svg);const s=UB({...e,children:[]},{space:i===ca.svg?"svg":"html"}),o={type:Nt.START_TAG,tagName:n,tagID:vu(n),selfClosing:!1,ackSelfClosing:!1,attrs:"attrs"in s?s.attrs:[],location:I0(e)};t.parser.currentToken=o,t.parser._processToken(t.parser.currentToken),t.parser.tokenizer.lastStartTagName=n}function RF(e,t){const n=e.tagName.toLowerCase();if(!t.parser.tokenizer.inForeignNode&&YB.includes(n)||t.parser.tokenizer.state===Kn.PLAINTEXT)return;_u(t,jf(e));const r={type:Nt.END_TAG,tagName:n,tagID:vu(n),selfClosing:!1,ackSelfClosing:!1,attrs:[],location:I0(e)};t.parser.currentToken=r,t.parser._processToken(t.parser.currentToken),n===t.parser.tokenizer.lastStartTagName&&(t.parser.tokenizer.state===Kn.RCDATA||t.parser.tokenizer.state===Kn.RAWTEXT||t.parser.tokenizer.state===Kn.SCRIPT_DATA)&&(t.parser.tokenizer.state=Kn.DATA)}function MF(e){const t=e.type==="root"?e.children[0]:e;return!!(t&&(t.type==="doctype"||t.type==="element"&&t.tagName.toLowerCase()==="html"))}function I0(e){const t=pa(e)||{line:void 0,column:void 0,offset:void 0},n=jf(e)||{line:void 0,column:void 0,offset:void 0};return{startLine:t.line,startCol:t.column,startOffset:t.offset,endLine:n.line,endCol:n.column,endOffset:n.offset}}function IF(e){return"children"in e?au({...e,children:[]}):au(e)}function DF(e){return function(t,n){return HT(t,{...e,file:n})}}const GE=(function(e,t,n){const r=N0(n);if(!e||!e.type||!e.children)throw new Error("Expected parent node");if(typeof t=="number"){if(t<0||t===Number.POSITIVE_INFINITY)throw new Error("Expected positive finite number as index")}else if(t=e.children.indexOf(t),t<0)throw new Error("Expected child node or index");for(;++t<e.children.length;)if(r(e.children[t],t,e))return e.children[t]}),Zl=(function(e){if(e==null)return BF;if(typeof e=="string")return PF(e);if(typeof e=="object")return LF(e);if(typeof e=="function")return I2(e);throw new Error("Expected function, string, or array as `test`")});function LF(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=Zl(e[n]);return I2(r);function r(...i){let s=-1;for(;++s<t.length;)if(t[s].apply(this,i))return!0;return!1}}function PF(e){return I2(t);function t(n){return n.tagName===e}}function I2(e){return t;function t(n,r,i){return!!(UF(n)&&e.call(this,n,typeof r=="number"?r:void 0,i||void 0))}}function BF(e){return!!(e&&typeof e=="object"&&"type"in e&&e.type==="element"&&"tagName"in e&&typeof e.tagName=="string")}function UF(e){return e!==null&&typeof e=="object"&&"type"in e&&"tagName"in e}const YE=/\n/g,VE=/[\t ]+/g,mb=Zl("br"),KE=Zl(GF),zF=Zl("p"),WE=Zl("tr"),FF=Zl(["datalist","head","noembed","noframes","noscript","rp","script","style","template","title",$F,YF]),GT=Zl(["address","article","aside","blockquote","body","caption","center","dd","dialog","dir","dl","dt","div","figure","figcaption","footer","form,","h1","h2","h3","h4","h5","h6","header","hgroup","hr","html","legend","li","listing","main","menu","nav","ol","p","plaintext","pre","section","ul","xmp"]);function YT(e,t){const n=t||{},r="children"in e?e.children:[],i=GT(e),s=WT(e,{whitespace:n.whitespace||"normal"}),o=[];(e.type==="text"||e.type==="comment")&&o.push(...KT(e,{breakBefore:!0,breakAfter:!0}));let c=-1;for(;++c<r.length;)o.push(...VT(r[c],e,{whitespace:s,breakBefore:c?void 0:i,breakAfter:c<r.length-1?mb(r[c+1]):i}));const d=[];let f;for(c=-1;++c<o.length;){const m=o[c];typeof m=="number"?f!==void 0&&m>f&&(f=m):m&&(f!==void 0&&f>-1&&d.push(`
`.repeat(f)||" "),f=-1,d.push(m))}return d.join("")}function VT(e,t,n){return e.type==="element"?HF(e,t,n):e.type==="text"?n.whitespace==="normal"?KT(e,n):jF(e):[]}function HF(e,t,n){const r=WT(e,n),i=e.children||[];let s=-1,o=[];if(FF(e))return o;let c,d;for(mb(e)||WE(e)&&GE(t,e,WE)?d=`
`:zF(e)?(c=2,d=2):GT(e)&&(c=1,d=1);++s<i.length;)o=o.concat(VT(i[s],e,{whitespace:r,breakBefore:s?void 0:c,breakAfter:s<i.length-1?mb(i[s+1]):d}));return KE(e)&&GE(t,e,KE)&&o.push("	"),c&&o.unshift(c),d&&o.push(d),o}function KT(e,t){const n=String(e.value),r=[],i=[];let s=0;for(;s<=n.length;){YE.lastIndex=s;const d=YE.exec(n),f=d&&"index"in d?d.index:n.length;r.push(qF(n.slice(s,f).replace(/[\u061C\u200E\u200F\u202A-\u202E\u2066-\u2069]/g,""),s===0?t.breakBefore:!0,f===n.length?t.breakAfter:!0)),s=f+1}let o=-1,c;for(;++o<r.length;)r[o].charCodeAt(r[o].length-1)===8203||o<r.length-1&&r[o+1].charCodeAt(0)===8203?(i.push(r[o]),c=void 0):r[o]?(typeof c=="number"&&i.push(c),i.push(r[o]),c=0):(o===0||o===r.length-1)&&i.push(0);return i}function jF(e){return[String(e.value)]}function qF(e,t,n){const r=[];let i=0,s;for(;i<e.length;){VE.lastIndex=i;const o=VE.exec(e);s=o?o.index:e.length,!i&&!s&&o&&!t&&r.push(""),i!==s&&r.push(e.slice(i,s)),i=o?s+o[0].length:s}return i!==s&&!n&&r.push(""),r.join(" ")}function WT(e,t){if(e.type==="element"){const n=e.properties||{};switch(e.tagName){case"listing":case"plaintext":case"xmp":return"pre";case"nobr":return"nowrap";case"pre":return n.wrap?"pre-wrap":"pre";case"td":case"th":return n.noWrap?"nowrap":t.whitespace;case"textarea":return"pre-wrap"}}return t.whitespace}function $F(e){return!!(e.properties||{}).hidden}function GF(e){return e.tagName==="td"||e.tagName==="th"}function YF(e){return e.tagName==="dialog"&&!(e.properties||{}).open}function VF(e){const t=e.regex,n=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",i="[a-zA-Z_]\\w*::",o="(?!struct)("+r+"|"+t.optional(i)+"[a-zA-Z_]\\w*"+t.optional("<[^<>]+>")+")",c={className:"type",begin:"\\b[a-z\\d_]*_t\\b"},f={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},m={className:"number",variants:[{begin:"[+-]?(?:(?:[0-9](?:'?[0-9])*\\.(?:[0-9](?:'?[0-9])*)?|\\.[0-9](?:'?[0-9])*)(?:[Ee][+-]?[0-9](?:'?[0-9])*)?|[0-9](?:'?[0-9])*[Ee][+-]?[0-9](?:'?[0-9])*|0[Xx](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*(?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)?)?|\\.[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)[Pp][+-]?[0-9](?:'?[0-9])*)(?:[Ff](?:16|32|64|128)?|(BF|bf)16|[Ll]|)"},{begin:"[+-]?\\b(?:0[Bb][01](?:'?[01])*|0[Xx][0-9A-Fa-f](?:'?[0-9A-Fa-f])*|0(?:'?[0-7])*|[1-9](?:'?[0-9])*)(?:[Uu](?:LL?|ll?)|[Uu][Zz]?|(?:LL?|ll?)[Uu]?|[Zz][Uu]|)"}],relevance:0},p={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(f,{className:"string"}),{className:"string",begin:/<.*?>/},n,e.C_BLOCK_COMMENT_MODE]},v={className:"title",begin:t.optional(i)+e.IDENT_RE,relevance:0},_=t.optional(i)+e.IDENT_RE+"\\s*\\(",T=["alignas","alignof","and","and_eq","asm","atomic_cancel","atomic_commit","atomic_noexcept","auto","bitand","bitor","break","case","catch","class","co_await","co_return","co_yield","compl","concept","const_cast|10","consteval","constexpr","constinit","continue","decltype","default","delete","do","dynamic_cast|10","else","enum","explicit","export","extern","false","final","for","friend","goto","if","import","inline","module","mutable","namespace","new","noexcept","not","not_eq","nullptr","operator","or","or_eq","override","private","protected","public","reflexpr","register","reinterpret_cast|10","requires","return","sizeof","static_assert","static_cast|10","struct","switch","synchronized","template","this","thread_local","throw","transaction_safe","transaction_safe_dynamic","true","try","typedef","typeid","typename","union","using","virtual","volatile","while","xor","xor_eq"],x=["bool","char","char16_t","char32_t","char8_t","double","float","int","long","short","void","wchar_t","unsigned","signed","const","static"],k=["any","auto_ptr","barrier","binary_semaphore","bitset","complex","condition_variable","condition_variable_any","counting_semaphore","deque","false_type","flat_map","flat_set","future","imaginary","initializer_list","istringstream","jthread","latch","lock_guard","multimap","multiset","mutex","optional","ostringstream","packaged_task","pair","promise","priority_queue","queue","recursive_mutex","recursive_timed_mutex","scoped_lock","set","shared_future","shared_lock","shared_mutex","shared_timed_mutex","shared_ptr","stack","string_view","stringstream","timed_mutex","thread","true_type","tuple","unique_lock","unique_ptr","unordered_map","unordered_multimap","unordered_multiset","unordered_set","variant","vector","weak_ptr","wstring","wstring_view"],A=["abort","abs","acos","apply","as_const","asin","atan","atan2","calloc","ceil","cerr","cin","clog","cos","cosh","cout","declval","endl","exchange","exit","exp","fabs","floor","fmod","forward","fprintf","fputs","free","frexp","fscanf","future","invoke","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","labs","launder","ldexp","log","log10","make_pair","make_shared","make_shared_for_overwrite","make_tuple","make_unique","malloc","memchr","memcmp","memcpy","memset","modf","move","pow","printf","putchar","puts","realloc","scanf","sin","sinh","snprintf","sprintf","sqrt","sscanf","std","stderr","stdin","stdout","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","swap","tan","tanh","terminate","to_underlying","tolower","toupper","vfprintf","visit","vprintf","vsprintf"],$={type:x,keyword:T,literal:["NULL","false","nullopt","nullptr","true"],built_in:["_Pragma"],_type_hints:k},V={className:"function.dispatch",relevance:0,keywords:{_hint:A},begin:t.concat(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!switch)/,/(?!while)/,e.IDENT_RE,t.lookahead(/(<[^<>]+>|)\s*\(/))},B=[V,p,c,n,e.C_BLOCK_COMMENT_MODE,m,f],Z={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:$,contains:B.concat([{begin:/\(/,end:/\)/,keywords:$,contains:B.concat(["self"]),relevance:0}]),relevance:0},ee={className:"function",begin:"("+o+"[\\*&\\s]+)+"+_,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:$,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:$,relevance:0},{begin:_,returnBegin:!0,contains:[v],relevance:0},{begin:/::/,relevance:0},{begin:/:/,endsWithParent:!0,contains:[f,m]},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:$,relevance:0,contains:[n,e.C_BLOCK_COMMENT_MODE,f,m,c,{begin:/\(/,end:/\)/,keywords:$,relevance:0,contains:["self",n,e.C_BLOCK_COMMENT_MODE,f,m,c]}]},c,n,e.C_BLOCK_COMMENT_MODE,p]};return{name:"C++",aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:$,illegal:"</",classNameAliases:{"function.dispatch":"built_in"},contains:[].concat(Z,ee,V,B,[p,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function|flat_map|flat_set)\\s*<(?!<)",end:">",keywords:$,contains:["self",c]},{begin:e.IDENT_RE+"::",keywords:$},{match:[/\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,/\s+/,/\w+/],className:{1:"keyword",3:"title.class"}}])}}function KF(e){const t={type:["boolean","byte","word","String"],built_in:["KeyboardController","MouseController","SoftwareSerial","EthernetServer","EthernetClient","LiquidCrystal","RobotControl","GSMVoiceCall","EthernetUDP","EsploraTFT","HttpClient","RobotMotor","WiFiClient","GSMScanner","FileSystem","Scheduler","GSMServer","YunClient","YunServer","IPAddress","GSMClient","GSMModem","Keyboard","Ethernet","Console","GSMBand","Esplora","Stepper","Process","WiFiUDP","GSM_SMS","Mailbox","USBHost","Firmata","PImage","Client","Server","GSMPIN","FileIO","Bridge","Serial","EEPROM","Stream","Mouse","Audio","Servo","File","Task","GPRS","WiFi","Wire","TFT","GSM","SPI","SD"],_hints:["setup","loop","runShellCommandAsynchronously","analogWriteResolution","retrieveCallingNumber","printFirmwareVersion","analogReadResolution","sendDigitalPortPair","noListenOnLocalhost","readJoystickButton","setFirmwareVersion","readJoystickSwitch","scrollDisplayRight","getVoiceCallStatus","scrollDisplayLeft","writeMicroseconds","delayMicroseconds","beginTransmission","getSignalStrength","runAsynchronously","getAsynchronously","listenOnLocalhost","getCurrentCarrier","readAccelerometer","messageAvailable","sendDigitalPorts","lineFollowConfig","countryNameWrite","runShellCommand","readStringUntil","rewindDirectory","readTemperature","setClockDivider","readLightSensor","endTransmission","analogReference","detachInterrupt","countryNameRead","attachInterrupt","encryptionType","readBytesUntil","robotNameWrite","readMicrophone","robotNameRead","cityNameWrite","userNameWrite","readJoystickY","readJoystickX","mouseReleased","openNextFile","scanNetworks","noInterrupts","digitalWrite","beginSpeaker","mousePressed","isActionDone","mouseDragged","displayLogos","noAutoscroll","addParameter","remoteNumber","getModifiers","keyboardRead","userNameRead","waitContinue","processInput","parseCommand","printVersion","readNetworks","writeMessage","blinkVersion","cityNameRead","readMessage","setDataMode","parsePacket","isListening","setBitOrder","beginPacket","isDirectory","motorsWrite","drawCompass","digitalRead","clearScreen","serialEvent","rightToLeft","setTextSize","leftToRight","requestFrom","keyReleased","compassRead","analogWrite","interrupts","WiFiServer","disconnect","playMelody","parseFloat","autoscroll","getPINUsed","setPINUsed","setTimeout","sendAnalog","readSlider","analogRead","beginWrite","createChar","motorsStop","keyPressed","tempoWrite","readButton","subnetMask","debugPrint","macAddress","writeGreen","randomSeed","attachGPRS","readString","sendString","remotePort","releaseAll","mouseMoved","background","getXChange","getYChange","answerCall","getResult","voiceCall","endPacket","constrain","getSocket","writeJSON","getButton","available","connected","findUntil","readBytes","exitValue","readGreen","writeBlue","startLoop","IPAddress","isPressed","sendSysex","pauseMode","gatewayIP","setCursor","getOemKey","tuneWrite","noDisplay","loadImage","switchPIN","onRequest","onReceive","changePIN","playFile","noBuffer","parseInt","overflow","checkPIN","knobRead","beginTFT","bitClear","updateIR","bitWrite","position","writeRGB","highByte","writeRed","setSpeed","readBlue","noStroke","remoteIP","transfer","shutdown","hangCall","beginSMS","endWrite","attached","maintain","noCursor","checkReg","checkPUK","shiftOut","isValid","shiftIn","pulseIn","connect","println","localIP","pinMode","getIMEI","display","noBlink","process","getBand","running","beginSD","drawBMP","lowByte","setBand","release","bitRead","prepare","pointTo","readRed","setMode","noFill","remove","listen","stroke","detach","attach","noTone","exists","buffer","height","bitSet","circle","config","cursor","random","IRread","setDNS","endSMS","getKey","micros","millis","begin","print","write","ready","flush","width","isPIN","blink","clear","press","mkdir","rmdir","close","point","yield","image","BSSID","click","delay","read","text","move","peek","beep","rect","line","open","seek","fill","size","turn","stop","home","find","step","tone","sqrt","RSSI","SSID","end","bit","tan","cos","sin","pow","map","abs","max","min","get","run","put"],literal:["DIGITAL_MESSAGE","FIRMATA_STRING","ANALOG_MESSAGE","REPORT_DIGITAL","REPORT_ANALOG","INPUT_PULLUP","SET_PIN_MODE","INTERNAL2V56","SYSTEM_RESET","LED_BUILTIN","INTERNAL1V1","SYSEX_START","INTERNAL","EXTERNAL","DEFAULT","OUTPUT","INPUT","HIGH","LOW"]},n=VF(e),r=n.keywords;return r.type=[...r.type,...t.type],r.literal=[...r.literal,...t.literal],r.built_in=[...r.built_in,...t.built_in],r._hints=t._hints,n.name="Arduino",n.aliases=["ino"],n.supersetOf="cpp",n}function WF(e){const t=e.regex,n={},r={begin:/\$\{/,end:/\}/,contains:["self",{begin:/:-/,contains:[n]}]};Object.assign(n,{className:"variable",variants:[{begin:t.concat(/\$[\w\d#@][\w\d_]*/,"(?![\\w\\d])(?![$])")},r]});const i={className:"subst",begin:/\$\(/,end:/\)/,contains:[e.BACKSLASH_ESCAPE]},s=e.inherit(e.COMMENT(),{match:[/(^|\s)/,/#.*$/],scope:{2:"comment"}}),o={begin:/<<-?\s*(?=\w+)/,starts:{contains:[e.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,className:"string"})]}},c={className:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,n,i]};i.contains.push(c);const d={match:/\\"/},f={className:"string",begin:/'/,end:/'/},m={match:/\\'/},p={begin:/\$?\(\(/,end:/\)\)/,contains:[{begin:/\d+#[0-9a-f]+/,className:"number"},e.NUMBER_MODE,n]},v=["fish","bash","zsh","sh","csh","ksh","tcsh","dash","scsh"],_=e.SHEBANG({binary:`(${v.join("|")})`,relevance:10}),T={className:"function",begin:/\w[\w\d_]*\s*\(\s*\)\s*\{/,returnBegin:!0,contains:[e.inherit(e.TITLE_MODE,{begin:/\w[\w\d_]*/})],relevance:0},x=["if","then","else","elif","fi","time","for","while","until","in","do","done","case","esac","coproc","function","select"],k=["true","false"],A={match:/(\/[a-z._-]+)+/},O=["break","cd","continue","eval","exec","exit","export","getopts","hash","pwd","readonly","return","shift","test","times","trap","umask","unset"],I=["alias","bind","builtin","caller","command","declare","echo","enable","help","let","local","logout","mapfile","printf","read","readarray","source","sudo","type","typeset","ulimit","unalias"],$=["autoload","bg","bindkey","bye","cap","chdir","clone","comparguments","compcall","compctl","compdescribe","compfiles","compgroups","compquote","comptags","comptry","compvalues","dirs","disable","disown","echotc","echoti","emulate","fc","fg","float","functions","getcap","getln","history","integer","jobs","kill","limit","log","noglob","popd","print","pushd","pushln","rehash","sched","setcap","setopt","stat","suspend","ttyctl","unfunction","unhash","unlimit","unsetopt","vared","wait","whence","where","which","zcompile","zformat","zftp","zle","zmodload","zparseopts","zprof","zpty","zregexparse","zsocket","zstyle","ztcp"],V=["chcon","chgrp","chown","chmod","cp","dd","df","dir","dircolors","ln","ls","mkdir","mkfifo","mknod","mktemp","mv","realpath","rm","rmdir","shred","sync","touch","truncate","vdir","b2sum","base32","base64","cat","cksum","comm","csplit","cut","expand","fmt","fold","head","join","md5sum","nl","numfmt","od","paste","ptx","pr","sha1sum","sha224sum","sha256sum","sha384sum","sha512sum","shuf","sort","split","sum","tac","tail","tr","tsort","unexpand","uniq","wc","arch","basename","chroot","date","dirname","du","echo","env","expr","factor","groups","hostid","id","link","logname","nice","nohup","nproc","pathchk","pinky","printenv","printf","pwd","readlink","runcon","seq","sleep","stat","stdbuf","stty","tee","test","timeout","tty","uname","unlink","uptime","users","who","whoami","yes"];return{name:"Bash",aliases:["sh","zsh"],keywords:{$pattern:/\b[a-z][a-z0-9._-]+\b/,keyword:x,literal:k,built_in:[...O,...I,"set","shopt",...$,...V]},contains:[_,e.SHEBANG(),T,p,s,o,A,c,d,f,m,n]}}function XF(e){const t=e.regex,n=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",i="[a-zA-Z_]\\w*::",o="("+r+"|"+t.optional(i)+"[a-zA-Z_]\\w*"+t.optional("<[^<>]+>")+")",c={className:"type",variants:[{begin:"\\b[a-z\\d_]*_t\\b"},{match:/\batomic_[a-z]{3,6}\b/}]},f={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},m={className:"number",variants:[{match:/\b(0b[01']+)/},{match:/(-?)\b([\d']+(\.[\d']*)?|\.[\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)/},{match:/(-?)\b(0[xX][a-fA-F0-9]+(?:'[a-fA-F0-9]+)*(?:\.[a-fA-F0-9]*(?:'[a-fA-F0-9]*)*)?(?:[pP][-+]?[0-9]+)?(l|L)?(u|U)?)/},{match:/(-?)\b\d+(?:'\d+)*(?:\.\d*(?:'\d*)*)?(?:[eE][-+]?\d+)?/}],relevance:0},p={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef elifdef elifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(f,{className:"string"}),{className:"string",begin:/<.*?>/},n,e.C_BLOCK_COMMENT_MODE]},v={className:"title",begin:t.optional(i)+e.IDENT_RE,relevance:0},_=t.optional(i)+e.IDENT_RE+"\\s*\\(",k={keyword:["asm","auto","break","case","continue","default","do","else","enum","extern","for","fortran","goto","if","inline","register","restrict","return","sizeof","typeof","typeof_unqual","struct","switch","typedef","union","volatile","while","_Alignas","_Alignof","_Atomic","_Generic","_Noreturn","_Static_assert","_Thread_local","alignas","alignof","noreturn","static_assert","thread_local","_Pragma"],type:["float","double","signed","unsigned","int","short","long","char","void","_Bool","_BitInt","_Complex","_Imaginary","_Decimal32","_Decimal64","_Decimal96","_Decimal128","_Decimal64x","_Decimal128x","_Float16","_Float32","_Float64","_Float128","_Float32x","_Float64x","_Float128x","const","static","constexpr","complex","bool","imaginary"],literal:"true false NULL",built_in:"std string wstring cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set pair bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap priority_queue make_pair array shared_ptr abort terminate abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf future isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr"},A=[p,c,n,e.C_BLOCK_COMMENT_MODE,m,f],O={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:k,contains:A.concat([{begin:/\(/,end:/\)/,keywords:k,contains:A.concat(["self"]),relevance:0}]),relevance:0},I={begin:"("+o+"[\\*&\\s]+)+"+_,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:k,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:k,relevance:0},{begin:_,returnBegin:!0,contains:[e.inherit(v,{className:"title.function"})],relevance:0},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:k,relevance:0,contains:[n,e.C_BLOCK_COMMENT_MODE,f,m,c,{begin:/\(/,end:/\)/,keywords:k,relevance:0,contains:["self",n,e.C_BLOCK_COMMENT_MODE,f,m,c]}]},c,n,e.C_BLOCK_COMMENT_MODE,p]};return{name:"C",aliases:["h"],keywords:k,disableAutodetect:!0,illegal:"</",contains:[].concat(O,I,A,[p,{begin:e.IDENT_RE+"::",keywords:k},{className:"class",beginKeywords:"enum class struct union",end:/[{;:<>=]/,contains:[{beginKeywords:"final class struct"},e.TITLE_MODE]}]),exports:{preprocessor:p,strings:f,keywords:k}}}function QF(e){const t=e.regex,n=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",i="[a-zA-Z_]\\w*::",o="(?!struct)("+r+"|"+t.optional(i)+"[a-zA-Z_]\\w*"+t.optional("<[^<>]+>")+")",c={className:"type",begin:"\\b[a-z\\d_]*_t\\b"},f={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},m={className:"number",variants:[{begin:"[+-]?(?:(?:[0-9](?:'?[0-9])*\\.(?:[0-9](?:'?[0-9])*)?|\\.[0-9](?:'?[0-9])*)(?:[Ee][+-]?[0-9](?:'?[0-9])*)?|[0-9](?:'?[0-9])*[Ee][+-]?[0-9](?:'?[0-9])*|0[Xx](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*(?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)?)?|\\.[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)[Pp][+-]?[0-9](?:'?[0-9])*)(?:[Ff](?:16|32|64|128)?|(BF|bf)16|[Ll]|)"},{begin:"[+-]?\\b(?:0[Bb][01](?:'?[01])*|0[Xx][0-9A-Fa-f](?:'?[0-9A-Fa-f])*|0(?:'?[0-7])*|[1-9](?:'?[0-9])*)(?:[Uu](?:LL?|ll?)|[Uu][Zz]?|(?:LL?|ll?)[Uu]?|[Zz][Uu]|)"}],relevance:0},p={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(f,{className:"string"}),{className:"string",begin:/<.*?>/},n,e.C_BLOCK_COMMENT_MODE]},v={className:"title",begin:t.optional(i)+e.IDENT_RE,relevance:0},_=t.optional(i)+e.IDENT_RE+"\\s*\\(",T=["alignas","alignof","and","and_eq","asm","atomic_cancel","atomic_commit","atomic_noexcept","auto","bitand","bitor","break","case","catch","class","co_await","co_return","co_yield","compl","concept","const_cast|10","consteval","constexpr","constinit","continue","decltype","default","delete","do","dynamic_cast|10","else","enum","explicit","export","extern","false","final","for","friend","goto","if","import","inline","module","mutable","namespace","new","noexcept","not","not_eq","nullptr","operator","or","or_eq","override","private","protected","public","reflexpr","register","reinterpret_cast|10","requires","return","sizeof","static_assert","static_cast|10","struct","switch","synchronized","template","this","thread_local","throw","transaction_safe","transaction_safe_dynamic","true","try","typedef","typeid","typename","union","using","virtual","volatile","while","xor","xor_eq"],x=["bool","char","char16_t","char32_t","char8_t","double","float","int","long","short","void","wchar_t","unsigned","signed","const","static"],k=["any","auto_ptr","barrier","binary_semaphore","bitset","complex","condition_variable","condition_variable_any","counting_semaphore","deque","false_type","flat_map","flat_set","future","imaginary","initializer_list","istringstream","jthread","latch","lock_guard","multimap","multiset","mutex","optional","ostringstream","packaged_task","pair","promise","priority_queue","queue","recursive_mutex","recursive_timed_mutex","scoped_lock","set","shared_future","shared_lock","shared_mutex","shared_timed_mutex","shared_ptr","stack","string_view","stringstream","timed_mutex","thread","true_type","tuple","unique_lock","unique_ptr","unordered_map","unordered_multimap","unordered_multiset","unordered_set","variant","vector","weak_ptr","wstring","wstring_view"],A=["abort","abs","acos","apply","as_const","asin","atan","atan2","calloc","ceil","cerr","cin","clog","cos","cosh","cout","declval","endl","exchange","exit","exp","fabs","floor","fmod","forward","fprintf","fputs","free","frexp","fscanf","future","invoke","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","labs","launder","ldexp","log","log10","make_pair","make_shared","make_shared_for_overwrite","make_tuple","make_unique","malloc","memchr","memcmp","memcpy","memset","modf","move","pow","printf","putchar","puts","realloc","scanf","sin","sinh","snprintf","sprintf","sqrt","sscanf","std","stderr","stdin","stdout","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","swap","tan","tanh","terminate","to_underlying","tolower","toupper","vfprintf","visit","vprintf","vsprintf"],$={type:x,keyword:T,literal:["NULL","false","nullopt","nullptr","true"],built_in:["_Pragma"],_type_hints:k},V={className:"function.dispatch",relevance:0,keywords:{_hint:A},begin:t.concat(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!switch)/,/(?!while)/,e.IDENT_RE,t.lookahead(/(<[^<>]+>|)\s*\(/))},B=[V,p,c,n,e.C_BLOCK_COMMENT_MODE,m,f],Z={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:$,contains:B.concat([{begin:/\(/,end:/\)/,keywords:$,contains:B.concat(["self"]),relevance:0}]),relevance:0},ee={className:"function",begin:"("+o+"[\\*&\\s]+)+"+_,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:$,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:$,relevance:0},{begin:_,returnBegin:!0,contains:[v],relevance:0},{begin:/::/,relevance:0},{begin:/:/,endsWithParent:!0,contains:[f,m]},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:$,relevance:0,contains:[n,e.C_BLOCK_COMMENT_MODE,f,m,c,{begin:/\(/,end:/\)/,keywords:$,relevance:0,contains:["self",n,e.C_BLOCK_COMMENT_MODE,f,m,c]}]},c,n,e.C_BLOCK_COMMENT_MODE,p]};return{name:"C++",aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:$,illegal:"</",classNameAliases:{"function.dispatch":"built_in"},contains:[].concat(Z,ee,V,B,[p,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function|flat_map|flat_set)\\s*<(?!<)",end:">",keywords:$,contains:["self",c]},{begin:e.IDENT_RE+"::",keywords:$},{match:[/\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,/\s+/,/\w+/],className:{1:"keyword",3:"title.class"}}])}}function ZF(e){const t=["bool","byte","char","decimal","delegate","double","dynamic","enum","float","int","long","nint","nuint","object","sbyte","short","string","ulong","uint","ushort"],n=["public","private","protected","static","internal","protected","abstract","async","extern","override","unsafe","virtual","new","sealed","partial"],r=["default","false","null","true"],i=["abstract","as","base","break","case","catch","class","const","continue","do","else","event","explicit","extern","finally","fixed","for","foreach","goto","if","implicit","in","interface","internal","is","lock","namespace","new","operator","out","override","params","private","protected","public","readonly","record","ref","return","scoped","sealed","sizeof","stackalloc","static","struct","switch","this","throw","try","typeof","unchecked","unsafe","using","virtual","void","volatile","while"],s=["add","alias","and","ascending","args","async","await","by","descending","dynamic","equals","file","from","get","global","group","init","into","join","let","nameof","not","notnull","on","or","orderby","partial","record","remove","required","scoped","select","set","unmanaged","value|0","var","when","where","with","yield"],o={keyword:i.concat(s),built_in:t,literal:r},c=e.inherit(e.TITLE_MODE,{begin:"[a-zA-Z](\\.?\\w)*"}),d={className:"number",variants:[{begin:"\\b(0b[01']+)"},{begin:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{begin:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],relevance:0},f={className:"string",begin:/"""("*)(?!")(.|\n)*?"""\1/,relevance:1},m={className:"string",begin:'@"',end:'"',contains:[{begin:'""'}]},p=e.inherit(m,{illegal:/\n/}),v={className:"subst",begin:/\{/,end:/\}/,keywords:o},_=e.inherit(v,{illegal:/\n/}),T={className:"string",begin:/\$"/,end:'"',illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/},e.BACKSLASH_ESCAPE,_]},x={className:"string",begin:/\$@"/,end:'"',contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},v]},k=e.inherit(x,{illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},_]});v.contains=[x,T,m,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,d,e.C_BLOCK_COMMENT_MODE],_.contains=[k,T,p,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,d,e.inherit(e.C_BLOCK_COMMENT_MODE,{illegal:/\n/})];const A={variants:[f,x,T,m,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},O={begin:"<",end:">",contains:[{beginKeywords:"in out"},c]},I=e.IDENT_RE+"(<"+e.IDENT_RE+"(\\s*,\\s*"+e.IDENT_RE+")*>)?(\\[\\])?",$={begin:"@"+e.IDENT_RE,relevance:0};return{name:"C#",aliases:["cs","c#"],keywords:o,illegal:/::/,contains:[e.COMMENT("///","$",{returnBegin:!0,contains:[{className:"doctag",variants:[{begin:"///",relevance:0},{begin:"<!--|-->"},{begin:"</?",end:">"}]}]}),e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{className:"meta",begin:"#",end:"$",keywords:{keyword:"if else elif endif define undef warning error line region endregion pragma checksum"}},A,d,{beginKeywords:"class interface",relevance:0,end:/[{;=]/,illegal:/[^\s:,]/,contains:[{beginKeywords:"where class"},c,O,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"namespace",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,contains:[c,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"record",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,contains:[c,O,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"meta",begin:"^\\s*\\[(?=[\\w])",excludeBegin:!0,end:"\\]",excludeEnd:!0,contains:[{className:"string",begin:/"/,end:/"/}]},{beginKeywords:"new return throw await else",relevance:0},{className:"function",begin:"("+I+"\\s+)+"+e.IDENT_RE+"\\s*(<[^=]+>\\s*)?\\(",returnBegin:!0,end:/\s*[{;=]/,excludeEnd:!0,keywords:o,contains:[{beginKeywords:n.join(" "),relevance:0},{begin:e.IDENT_RE+"\\s*(<[^=]+>\\s*)?\\(",returnBegin:!0,contains:[e.TITLE_MODE,O],relevance:0},{match:/\(\)/},{className:"params",begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:o,relevance:0,contains:[A,d,e.C_BLOCK_COMMENT_MODE]},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},$]}}const JF=e=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),eH=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],tH=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],nH=[...eH,...tH],rH=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),iH=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),aH=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),sH=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse();function lH(e){const t=e.regex,n=JF(e),r={begin:/-(webkit|moz|ms|o)-(?=[a-z])/},i="and or not only",s=/@-?\w[\w]*(-\w+)*/,o="[a-zA-Z-][a-zA-Z0-9_-]*",c=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE];return{name:"CSS",case_insensitive:!0,illegal:/[=|'\$]/,keywords:{keyframePosition:"from to"},classNameAliases:{keyframePosition:"selector-tag"},contains:[n.BLOCK_COMMENT,r,n.CSS_NUMBER_MODE,{className:"selector-id",begin:/#[A-Za-z0-9_-]+/,relevance:0},{className:"selector-class",begin:"\\."+o,relevance:0},n.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",variants:[{begin:":("+iH.join("|")+")"},{begin:":(:)?("+aH.join("|")+")"}]},n.CSS_VARIABLE,{className:"attribute",begin:"\\b("+sH.join("|")+")\\b"},{begin:/:/,end:/[;}{]/,contains:[n.BLOCK_COMMENT,n.HEXCOLOR,n.IMPORTANT,n.CSS_NUMBER_MODE,...c,{begin:/(url|data-uri)\(/,end:/\)/,relevance:0,keywords:{built_in:"url data-uri"},contains:[...c,{className:"string",begin:/[^)]/,endsWithParent:!0,excludeEnd:!0}]},n.FUNCTION_DISPATCH]},{begin:t.lookahead(/@/),end:"[{;]",relevance:0,illegal:/:/,contains:[{className:"keyword",begin:s},{begin:/\s/,endsWithParent:!0,excludeEnd:!0,relevance:0,keywords:{$pattern:/[a-z-]+/,keyword:i,attribute:rH.join(" ")},contains:[{begin:/[a-z-]+(?=:)/,className:"attribute"},...c,n.CSS_NUMBER_MODE]}]},{className:"selector-tag",begin:"\\b("+nH.join("|")+")\\b"}]}}function oH(e){const t=e.regex;return{name:"Diff",aliases:["patch"],contains:[{className:"meta",relevance:10,match:t.either(/^@@ +-\d+,\d+ +\+\d+,\d+ +@@/,/^\*\*\* +\d+,\d+ +\*\*\*\*$/,/^--- +\d+,\d+ +----$/)},{className:"comment",variants:[{begin:t.either(/Index: /,/^index/,/={3,}/,/^-{3}/,/^\*{3} /,/^\+{3}/,/^diff --git/),end:/$/},{match:/^\*{15}$/}]},{className:"addition",begin:/^\+/,end:/$/},{className:"deletion",begin:/^-/,end:/$/},{className:"addition",begin:/^!/,end:/$/}]}}function uH(e){const s={keyword:["break","case","chan","const","continue","default","defer","else","fallthrough","for","func","go","goto","if","import","interface","map","package","range","return","select","struct","switch","type","var"],type:["bool","byte","complex64","complex128","error","float32","float64","int8","int16","int32","int64","string","uint8","uint16","uint32","uint64","int","uint","uintptr","rune"],literal:["true","false","iota","nil"],built_in:["append","cap","close","complex","copy","imag","len","make","new","panic","print","println","real","recover","delete"]};return{name:"Go",aliases:["golang"],keywords:s,illegal:"</",contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{className:"string",variants:[e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,{begin:"`",end:"`"}]},{className:"number",variants:[{match:/-?\b0[xX]\.[a-fA-F0-9](_?[a-fA-F0-9])*[pP][+-]?\d(_?\d)*i?/,relevance:0},{match:/-?\b0[xX](_?[a-fA-F0-9])+((\.([a-fA-F0-9](_?[a-fA-F0-9])*)?)?[pP][+-]?\d(_?\d)*)?i?/,relevance:0},{match:/-?\b0[oO](_?[0-7])*i?/,relevance:0},{match:/-?\.\d(_?\d)*([eE][+-]?\d(_?\d)*)?i?/,relevance:0},{match:/-?\b\d(_?\d)*(\.(\d(_?\d)*)?)?([eE][+-]?\d(_?\d)*)?i?/,relevance:0}]},{begin:/:=/},{className:"function",beginKeywords:"func",end:"\\s*(\\{|$)",excludeEnd:!0,contains:[e.TITLE_MODE,{className:"params",begin:/\(/,end:/\)/,endsParent:!0,keywords:s,illegal:/["']/}]}]}}function cH(e){const t=e.regex,n=/[_A-Za-z][_0-9A-Za-z]*/;return{name:"GraphQL",aliases:["gql"],case_insensitive:!0,disableAutodetect:!1,keywords:{keyword:["query","mutation","subscription","type","input","schema","directive","interface","union","scalar","fragment","enum","on"],literal:["true","false","null"]},contains:[e.HASH_COMMENT_MODE,e.QUOTE_STRING_MODE,e.NUMBER_MODE,{scope:"punctuation",match:/[.]{3}/,relevance:0},{scope:"punctuation",begin:/[\!\(\)\:\=\[\]\{\|\}]{1}/,relevance:0},{scope:"variable",begin:/\$/,end:/\W/,excludeEnd:!0,relevance:0},{scope:"meta",match:/@\w+/,excludeEnd:!0},{scope:"symbol",begin:t.concat(n,t.lookahead(/\s*:/)),relevance:0}],illegal:[/[;<']/,/BEGIN/]}}function dH(e){const t=e.regex,n={className:"number",relevance:0,variants:[{begin:/([+-]+)?[\d]+_[\d_]+/},{begin:e.NUMBER_RE}]},r=e.COMMENT();r.variants=[{begin:/;/,end:/$/},{begin:/#/,end:/$/}];const i={className:"variable",variants:[{begin:/\$[\w\d"][\w\d_]*/},{begin:/\$\{(.*?)\}/}]},s={className:"literal",begin:/\bon|off|true|false|yes|no\b/},o={className:"string",contains:[e.BACKSLASH_ESCAPE],variants:[{begin:"'''",end:"'''",relevance:10},{begin:'"""',end:'"""',relevance:10},{begin:'"',end:'"'},{begin:"'",end:"'"}]},c={begin:/\[/,end:/\]/,contains:[r,s,i,o,n,"self"],relevance:0},d=/[A-Za-z0-9_-]+/,f=/"(\\"|[^"])*"/,m=/'[^']*'/,p=t.either(d,f,m),v=t.concat(p,"(\\s*\\.\\s*",p,")*",t.lookahead(/\s*=\s*[^#\s]/));return{name:"TOML, also INI",aliases:["toml"],case_insensitive:!0,illegal:/\S/,contains:[r,{className:"section",begin:/\[+/,end:/\]+/},{begin:v,className:"attr",starts:{end:/$/,contains:[r,c,s,i,o,n]}}]}}var Yo="[0-9](_*[0-9])*",mh=`\\.(${Yo})`,ph="[0-9a-fA-F](_*[0-9a-fA-F])*",XE={className:"number",variants:[{begin:`(\\b(${Yo})((${mh})|\\.)?|(${mh}))[eE][+-]?(${Yo})[fFdD]?\\b`},{begin:`\\b(${Yo})((${mh})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{begin:`(${mh})[fFdD]?\\b`},{begin:`\\b(${Yo})[fFdD]\\b`},{begin:`\\b0[xX]((${ph})\\.?|(${ph})?\\.(${ph}))[pP][+-]?(${Yo})[fFdD]?\\b`},{begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${ph})[lL]?\\b`},{begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],relevance:0};function XT(e,t,n){return n===-1?"":e.replace(t,r=>XT(e,t,n-1))}function hH(e){const t=e.regex,n="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",r=n+XT("(?:<"+n+"~~~(?:\\s*,\\s*"+n+"~~~)*>)?",/~~~/g,2),d={keyword:["synchronized","abstract","private","var","static","if","const ","for","while","strictfp","finally","protected","import","native","final","void","enum","else","break","transient","catch","instanceof","volatile","case","assert","package","default","public","try","switch","continue","throws","protected","public","private","module","requires","exports","do","sealed","yield","permits","goto","when"],literal:["false","true","null"],type:["char","boolean","long","float","int","byte","short","double"],built_in:["super","this"]},f={className:"meta",begin:"@"+n,contains:[{begin:/\(/,end:/\)/,contains:["self"]}]},m={className:"params",begin:/\(/,end:/\)/,keywords:d,relevance:0,contains:[e.C_BLOCK_COMMENT_MODE],endsParent:!0};return{name:"Java",aliases:["jsp"],keywords:d,illegal:/<\/|#/,contains:[e.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{begin:/\w+@/,relevance:0},{className:"doctag",begin:"@[A-Za-z]+"}]}),{begin:/import java\.[a-z]+\./,keywords:"import",relevance:2},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{begin:/"""/,end:/"""/,className:"string",contains:[e.BACKSLASH_ESCAPE]},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,{match:[/\b(?:class|interface|enum|extends|implements|new)/,/\s+/,n],className:{1:"keyword",3:"title.class"}},{match:/non-sealed/,scope:"keyword"},{begin:[t.concat(/(?!else)/,n),/\s+/,n,/\s+/,/=(?!=)/],className:{1:"type",3:"variable",5:"operator"}},{begin:[/record/,/\s+/,n],className:{1:"keyword",3:"title.class"},contains:[m,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"new throw return else",relevance:0},{begin:["(?:"+r+"\\s+)",e.UNDERSCORE_IDENT_RE,/\s*(?=\()/],className:{2:"title.function"},keywords:d,contains:[{className:"params",begin:/\(/,end:/\)/,keywords:d,relevance:0,contains:[f,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,XE,e.C_BLOCK_COMMENT_MODE]},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},XE,f]}}const QE="[A-Za-z$_][0-9A-Za-z$_]*",fH=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends","using"],mH=["true","false","null","undefined","NaN","Infinity"],QT=["Object","Function","Boolean","Symbol","Math","Date","Number","BigInt","String","RegExp","Array","Float32Array","Float64Array","Int8Array","Uint8Array","Uint8ClampedArray","Int16Array","Int32Array","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array","Set","Map","WeakSet","WeakMap","ArrayBuffer","SharedArrayBuffer","Atomics","DataView","JSON","Promise","Generator","GeneratorFunction","AsyncFunction","Reflect","Proxy","Intl","WebAssembly"],ZT=["Error","EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],JT=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],pH=["arguments","this","super","console","window","document","localStorage","sessionStorage","module","global"],gH=[].concat(JT,QT,ZT);function bH(e){const t=e.regex,n=(ve,{after:xe})=>{const P="</"+ve[0].slice(1);return ve.input.indexOf(P,xe)!==-1},r=QE,i={begin:"<>",end:"</>"},s=/<[A-Za-z0-9\\._:-]+\s*\/>/,o={begin:/<[A-Za-z0-9\\._:-]+/,end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(ve,xe)=>{const P=ve[0].length+ve.index,z=ve.input[P];if(z==="<"||z===","){xe.ignoreMatch();return}z===">"&&(n(ve,{after:P})||xe.ignoreMatch());let J;const D=ve.input.substring(P);if(J=D.match(/^\s*=/)){xe.ignoreMatch();return}if((J=D.match(/^\s+extends\s+/))&&J.index===0){xe.ignoreMatch();return}}},c={$pattern:QE,keyword:fH,literal:mH,built_in:gH,"variable.language":pH},d="[0-9](_?[0-9])*",f=`\\.(${d})`,m="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",p={className:"number",variants:[{begin:`(\\b(${m})((${f})|\\.)?|(${f}))[eE][+-]?(${d})\\b`},{begin:`\\b(${m})\\b((${f})\\b|\\.)?|(${f})\\b`},{begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{begin:"\\b0[0-7]+n?\\b"}],relevance:0},v={className:"subst",begin:"\\$\\{",end:"\\}",keywords:c,contains:[]},_={begin:".?html`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,v],subLanguage:"xml"}},T={begin:".?css`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,v],subLanguage:"css"}},x={begin:".?gql`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,v],subLanguage:"graphql"}},k={className:"string",begin:"`",end:"`",contains:[e.BACKSLASH_ESCAPE,v]},O={className:"comment",variants:[e.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{begin:"(?=@[A-Za-z]+)",relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"},{className:"type",begin:"\\{",end:"\\}",excludeEnd:!0,excludeBegin:!0,relevance:0},{className:"variable",begin:r+"(?=\\s*(-)|$)",endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]}),e.C_BLOCK_COMMENT_MODE,e.C_LINE_COMMENT_MODE]},I=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,_,T,x,k,{match:/\$\d+/},p];v.contains=I.concat({begin:/\{/,end:/\}/,keywords:c,contains:["self"].concat(I)});const $=[].concat(O,v.contains),V=$.concat([{begin:/(\s*)\(/,end:/\)/,keywords:c,contains:["self"].concat($)}]),B={className:"params",begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:c,contains:V},Z={variants:[{match:[/class/,/\s+/,r,/\s+/,/extends/,/\s+/,t.concat(r,"(",t.concat(/\./,r),")*")],scope:{1:"keyword",3:"title.class",5:"keyword",7:"title.class.inherited"}},{match:[/class/,/\s+/,r],scope:{1:"keyword",3:"title.class"}}]},ee={relevance:0,match:t.either(/\bJSON/,/\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,/\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,/\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/),className:"title.class",keywords:{_:[...QT,...ZT]}},te={label:"use_strict",className:"meta",relevance:10,begin:/^\s*['"]use (strict|asm)['"]/},Y={variants:[{match:[/function/,/\s+/,r,/(?=\s*\()/]},{match:[/function/,/\s*(?=\()/]}],className:{1:"keyword",3:"title.function"},label:"func.def",contains:[B],illegal:/%/},oe={relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"};function he(ve){return t.concat("(?!",ve.join("|"),")")}const Se={match:t.concat(/\b/,he([...JT,"super","import"].map(ve=>`${ve}\\s*\\(`)),r,t.lookahead(/\s*\(/)),className:"title.function",relevance:0},fe={begin:t.concat(/\./,t.lookahead(t.concat(r,/(?![0-9A-Za-z$_(])/))),end:r,excludeBegin:!0,keywords:"prototype",className:"property",relevance:0},de={match:[/get|set/,/\s+/,r,/(?=\()/],className:{1:"keyword",3:"title.function"},contains:[{begin:/\(\)/},B]},H="(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+e.UNDERSCORE_IDENT_RE+")\\s*=>",ie={match:[/const|var|let/,/\s+/,r,/\s*/,/=\s*/,/(async\s*)?/,t.lookahead(H)],keywords:"async",className:{1:"keyword",3:"title.function"},contains:[B]};return{name:"JavaScript",aliases:["js","jsx","mjs","cjs"],keywords:c,exports:{PARAMS_CONTAINS:V,CLASS_REFERENCE:ee},illegal:/#(?![$_A-z])/,contains:[e.SHEBANG({label:"shebang",binary:"node",relevance:5}),te,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,_,T,x,k,O,{match:/\$\d+/},p,ee,{scope:"attr",match:r+t.lookahead(":"),relevance:0},ie,{begin:"("+e.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",keywords:"return throw case",relevance:0,contains:[O,e.REGEXP_MODE,{className:"function",begin:H,returnBegin:!0,end:"\\s*=>",contains:[{className:"params",variants:[{begin:e.UNDERSCORE_IDENT_RE,relevance:0},{className:null,begin:/\(\s*\)/,skip:!0},{begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:c,contains:V}]}]},{begin:/,/,relevance:0},{match:/\s+/,relevance:0},{variants:[{begin:i.begin,end:i.end},{match:s},{begin:o.begin,"on:begin":o.isTrulyOpeningTag,end:o.end}],subLanguage:"xml",contains:[{begin:o.begin,end:o.end,skip:!0,contains:["self"]}]}]},Y,{beginKeywords:"while if switch catch for"},{begin:"\\b(?!function)"+e.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",returnBegin:!0,label:"func.def",contains:[B,e.inherit(e.TITLE_MODE,{begin:r,className:"title.function"})]},{match:/\.\.\./,relevance:0},fe,{match:"\\$"+r,relevance:0},{match:[/\bconstructor(?=\s*\()/],className:{1:"title.function"},contains:[B]},Se,oe,Z,de,{match:/\$[(.]/}]}}function vH(e){const t={className:"attr",begin:/"(\\.|[^\\"\r\n])*"(?=\s*:)/,relevance:1.01},n={match:/[{}[\],:]/,className:"punctuation",relevance:0},r=["true","false","null"],i={scope:"literal",beginKeywords:r.join(" ")};return{name:"JSON",aliases:["jsonc"],keywords:{literal:r},contains:[t,n,e.QUOTE_STRING_MODE,i,e.C_NUMBER_MODE,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE],illegal:"\\S"}}var Vo="[0-9](_*[0-9])*",gh=`\\.(${Vo})`,bh="[0-9a-fA-F](_*[0-9a-fA-F])*",_H={className:"number",variants:[{begin:`(\\b(${Vo})((${gh})|\\.)?|(${gh}))[eE][+-]?(${Vo})[fFdD]?\\b`},{begin:`\\b(${Vo})((${gh})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{begin:`(${gh})[fFdD]?\\b`},{begin:`\\b(${Vo})[fFdD]\\b`},{begin:`\\b0[xX]((${bh})\\.?|(${bh})?\\.(${bh}))[pP][+-]?(${Vo})[fFdD]?\\b`},{begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${bh})[lL]?\\b`},{begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],relevance:0};function yH(e){const t={keyword:"abstract as val var vararg get set class object open private protected public noinline crossinline dynamic final enum if else do while for when throw try catch finally import package is in fun override companion reified inline lateinit init interface annotation data sealed internal infix operator out by constructor super tailrec where const inner suspend typealias external expect actual",built_in:"Byte Short Char Int Long Boolean Float Double Void Unit Nothing",literal:"true false null"},n={className:"keyword",begin:/\b(break|continue|return|this)\b/,starts:{contains:[{className:"symbol",begin:/@\w+/}]}},r={className:"symbol",begin:e.UNDERSCORE_IDENT_RE+"@"},i={className:"subst",begin:/\$\{/,end:/\}/,contains:[e.C_NUMBER_MODE]},s={className:"variable",begin:"\\$"+e.UNDERSCORE_IDENT_RE},o={className:"string",variants:[{begin:'"""',end:'"""(?=[^"])',contains:[s,i]},{begin:"'",end:"'",illegal:/\n/,contains:[e.BACKSLASH_ESCAPE]},{begin:'"',end:'"',illegal:/\n/,contains:[e.BACKSLASH_ESCAPE,s,i]}]};i.contains.push(o);const c={className:"meta",begin:"@(?:file|property|field|get|set|receiver|param|setparam|delegate)\\s*:(?:\\s*"+e.UNDERSCORE_IDENT_RE+")?"},d={className:"meta",begin:"@"+e.UNDERSCORE_IDENT_RE,contains:[{begin:/\(/,end:/\)/,contains:[e.inherit(o,{className:"string"}),"self"]}]},f=_H,m=e.COMMENT("/\\*","\\*/",{contains:[e.C_BLOCK_COMMENT_MODE]}),p={variants:[{className:"type",begin:e.UNDERSCORE_IDENT_RE},{begin:/\(/,end:/\)/,contains:[]}]},v=p;return v.variants[1].contains=[p],p.variants[1].contains=[v],{name:"Kotlin",aliases:["kt","kts"],keywords:t,contains:[e.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"}]}),e.C_LINE_COMMENT_MODE,m,n,r,c,d,{className:"function",beginKeywords:"fun",end:"[(]|$",returnBegin:!0,excludeEnd:!0,keywords:t,relevance:5,contains:[{begin:e.UNDERSCORE_IDENT_RE+"\\s*\\(",returnBegin:!0,relevance:0,contains:[e.UNDERSCORE_TITLE_MODE]},{className:"type",begin:/</,end:/>/,keywords:"reified",relevance:0},{className:"params",begin:/\(/,end:/\)/,endsParent:!0,keywords:t,relevance:0,contains:[{begin:/:/,end:/[=,\/]/,endsWithParent:!0,contains:[p,e.C_LINE_COMMENT_MODE,m],relevance:0},e.C_LINE_COMMENT_MODE,m,c,d,o,e.C_NUMBER_MODE]},m]},{begin:[/class|interface|trait/,/\s+/,e.UNDERSCORE_IDENT_RE],beginScope:{3:"title.class"},keywords:"class interface trait",end:/[:\{(]|$/,excludeEnd:!0,illegal:"extends implements",contains:[{beginKeywords:"public protected internal private constructor"},e.UNDERSCORE_TITLE_MODE,{className:"type",begin:/</,end:/>/,excludeBegin:!0,excludeEnd:!0,relevance:0},{className:"type",begin:/[,:]\s*/,end:/[<\(,){\s]|$/,excludeBegin:!0,returnEnd:!0},c,d]},o,{className:"meta",begin:"^#!/usr/bin/env",end:"$",illegal:`
`},f]}}const EH=e=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),TH=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],xH=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],SH=[...TH,...xH],wH=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),ex=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),tx=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),AH=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse(),kH=ex.concat(tx).sort().reverse();function CH(e){const t=EH(e),n=kH,r="and or not only",i="[\\w-]+",s="("+i+"|@\\{"+i+"\\})",o=[],c=[],d=function(I){return{className:"string",begin:"~?"+I+".*?"+I}},f=function(I,$,V){return{className:I,begin:$,relevance:V}},m={$pattern:/[a-z-]+/,keyword:r,attribute:wH.join(" ")},p={begin:"\\(",end:"\\)",contains:c,keywords:m,relevance:0};c.push(e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,d("'"),d('"'),t.CSS_NUMBER_MODE,{begin:"(url|data-uri)\\(",starts:{className:"string",end:"[\\)\\n]",excludeEnd:!0}},t.HEXCOLOR,p,f("variable","@@?"+i,10),f("variable","@\\{"+i+"\\}"),f("built_in","~?`[^`]*?`"),{className:"attribute",begin:i+"\\s*:",end:":",returnBegin:!0,excludeEnd:!0},t.IMPORTANT,{beginKeywords:"and not"},t.FUNCTION_DISPATCH);const v=c.concat({begin:/\{/,end:/\}/,contains:o}),_={beginKeywords:"when",endsWithParent:!0,contains:[{beginKeywords:"and not"}].concat(c)},T={begin:s+"\\s*:",returnBegin:!0,end:/[;}]/,relevance:0,contains:[{begin:/-(webkit|moz|ms|o)-/},t.CSS_VARIABLE,{className:"attribute",begin:"\\b("+AH.join("|")+")\\b",end:/(?=:)/,starts:{endsWithParent:!0,illegal:"[<=$]",relevance:0,contains:c}}]},x={className:"keyword",begin:"@(import|media|charset|font-face|(-[a-z]+-)?keyframes|supports|document|namespace|page|viewport|host)\\b",starts:{end:"[;{}]",keywords:m,returnEnd:!0,contains:c,relevance:0}},k={className:"variable",variants:[{begin:"@"+i+"\\s*:",relevance:15},{begin:"@"+i}],starts:{end:"[;}]",returnEnd:!0,contains:v}},A={variants:[{begin:"[\\.#:&\\[>]",end:"[;{}]"},{begin:s,end:/\{/}],returnBegin:!0,returnEnd:!0,illegal:`[<='$"]`,relevance:0,contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,_,f("keyword","all\\b"),f("variable","@\\{"+i+"\\}"),{begin:"\\b("+SH.join("|")+")\\b",className:"selector-tag"},t.CSS_NUMBER_MODE,f("selector-tag",s,0),f("selector-id","#"+s),f("selector-class","\\."+s,0),f("selector-tag","&",0),t.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",begin:":("+ex.join("|")+")"},{className:"selector-pseudo",begin:":(:)?("+tx.join("|")+")"},{begin:/\(/,end:/\)/,relevance:0,contains:v},{begin:"!important"},t.FUNCTION_DISPATCH]},O={begin:i+`:(:)?(${n.join("|")})`,returnBegin:!0,contains:[A]};return o.push(e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,x,k,O,T,A,_,t.FUNCTION_DISPATCH),{name:"Less",case_insensitive:!0,illegal:`[=>'/<($"]`,contains:o}}function NH(e){const t="\\[=*\\[",n="\\]=*\\]",r={begin:t,end:n,contains:["self"]},i=[e.COMMENT("--(?!"+t+")","$"),e.COMMENT("--"+t,n,{contains:[r],relevance:10})];return{name:"Lua",aliases:["pluto"],keywords:{$pattern:e.UNDERSCORE_IDENT_RE,literal:"true false nil",keyword:"and break do else elseif end for goto if in local not or repeat return then until while",built_in:"_G _ENV _VERSION __index __newindex __mode __call __metatable __tostring __len __gc __add __sub __mul __div __mod __pow __concat __unm __eq __lt __le assert collectgarbage dofile error getfenv getmetatable ipairs load loadfile loadstring module next pairs pcall print rawequal rawget rawset require select setfenv setmetatable tonumber tostring type unpack xpcall arg self coroutine resume yield status wrap create running debug getupvalue debug sethook getmetatable gethook setmetatable setlocal traceback setfenv getinfo setupvalue getlocal getregistry getfenv io lines write close flush open output type read stderr stdin input stdout popen tmpfile math log max acos huge ldexp pi cos tanh pow deg tan cosh sinh random randomseed frexp ceil floor rad abs sqrt modf asin min mod fmod log10 atan2 exp sin atan os exit setlocale date getenv difftime remove time clock tmpname rename execute package preload loadlib loaded loaders cpath config path seeall string sub upper len gfind rep find match char dump gmatch reverse byte format gsub lower table setn insert getn foreachi maxn foreach concat sort remove"},contains:i.concat([{className:"function",beginKeywords:"function",end:"\\)",contains:[e.inherit(e.TITLE_MODE,{begin:"([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*"}),{className:"params",begin:"\\(",endsWithParent:!0,contains:i}].concat(i)},e.C_NUMBER_MODE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,{className:"string",begin:t,end:n,contains:[r],relevance:5}])}}function OH(e){const t={className:"variable",variants:[{begin:"\\$\\("+e.UNDERSCORE_IDENT_RE+"\\)",contains:[e.BACKSLASH_ESCAPE]},{begin:/\$[@%<?\^\+\*]/}]},n={className:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,t]},r={className:"variable",begin:/\$\([\w-]+\s/,end:/\)/,keywords:{built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"},contains:[t,n]},i={begin:"^"+e.UNDERSCORE_IDENT_RE+"\\s*(?=[:+?]?=)"},s={className:"meta",begin:/^\.PHONY:/,end:/$/,keywords:{$pattern:/[\.\w]+/,keyword:".PHONY"}},o={className:"section",begin:/^[^\s]+:/,end:/$/,contains:[t]};return{name:"Makefile",aliases:["mk","mak","make"],keywords:{$pattern:/[\w-]+/,keyword:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath"},contains:[e.HASH_COMMENT_MODE,t,n,r,i,s,o]}}function RH(e){const t=e.regex,n={begin:/<\/?[A-Za-z_]/,end:">",subLanguage:"xml",relevance:0},r={begin:"^[-\\*]{3,}",end:"$"},i={className:"code",variants:[{begin:"(`{3,})[^`](.|\\n)*?\\1`*[ ]*"},{begin:"(~{3,})[^~](.|\\n)*?\\1~*[ ]*"},{begin:"```",end:"```+[ ]*$"},{begin:"~~~",end:"~~~+[ ]*$"},{begin:"`.+?`"},{begin:"(?=^( {4}|\\t))",contains:[{begin:"^( {4}|\\t)",end:"(\\n)$"}],relevance:0}]},s={className:"bullet",begin:"^[ 	]*([*+-]|(\\d+\\.))(?=\\s+)",end:"\\s+",excludeEnd:!0},o={begin:/^\[[^\n]+\]:/,returnBegin:!0,contains:[{className:"symbol",begin:/\[/,end:/\]/,excludeBegin:!0,excludeEnd:!0},{className:"link",begin:/:\s*/,end:/$/,excludeBegin:!0}]},c=/[A-Za-z][A-Za-z0-9+.-]*/,d={variants:[{begin:/\[.+?\]\[.*?\]/,relevance:0},{begin:/\[.+?\]\(((data|javascript|mailto):|(?:http|ftp)s?:\/\/).*?\)/,relevance:2},{begin:t.concat(/\[.+?\]\(/,c,/:\/\/.*?\)/),relevance:2},{begin:/\[.+?\]\([./?&#].*?\)/,relevance:1},{begin:/\[.*?\]\(.*?\)/,relevance:0}],returnBegin:!0,contains:[{match:/\[(?=\])/},{className:"string",relevance:0,begin:"\\[",end:"\\]",excludeBegin:!0,returnEnd:!0},{className:"link",relevance:0,begin:"\\]\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0},{className:"symbol",relevance:0,begin:"\\]\\[",end:"\\]",excludeBegin:!0,excludeEnd:!0}]},f={className:"strong",contains:[],variants:[{begin:/_{2}(?!\s)/,end:/_{2}/},{begin:/\*{2}(?!\s)/,end:/\*{2}/}]},m={className:"emphasis",contains:[],variants:[{begin:/\*(?![*\s])/,end:/\*/},{begin:/_(?![_\s])/,end:/_/,relevance:0}]},p=e.inherit(f,{contains:[]}),v=e.inherit(m,{contains:[]});f.contains.push(v),m.contains.push(p);let _=[n,d];return[f,m,p,v].forEach(A=>{A.contains=A.contains.concat(_)}),_=_.concat(f,m),{name:"Markdown",aliases:["md","mkdown","mkd"],contains:[{className:"section",variants:[{begin:"^#{1,6}",end:"$",contains:_},{begin:"(?=^.+?\\n[=-]{2,}$)",contains:[{begin:"^[=-]*$"},{begin:"^",end:"\\n",contains:_}]}]},n,s,f,m,{className:"quote",begin:"^>\\s+",contains:_,end:"$"},i,r,d,o,{scope:"literal",match:/&([a-zA-Z0-9]+|#[0-9]{1,7}|#[Xx][0-9a-fA-F]{1,6});/}]}}function MH(e){const t={className:"built_in",begin:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"},n=/[a-zA-Z@][a-zA-Z0-9_]*/,c={"variable.language":["this","super"],$pattern:n,keyword:["while","export","sizeof","typedef","const","struct","for","union","volatile","static","mutable","if","do","return","goto","enum","else","break","extern","asm","case","default","register","explicit","typename","switch","continue","inline","readonly","assign","readwrite","self","@synchronized","id","typeof","nonatomic","IBOutlet","IBAction","strong","weak","copy","in","out","inout","bycopy","byref","oneway","__strong","__weak","__block","__autoreleasing","@private","@protected","@public","@try","@property","@end","@throw","@catch","@finally","@autoreleasepool","@synthesize","@dynamic","@selector","@optional","@required","@encode","@package","@import","@defs","@compatibility_alias","__bridge","__bridge_transfer","__bridge_retained","__bridge_retain","__covariant","__contravariant","__kindof","_Nonnull","_Nullable","_Null_unspecified","__FUNCTION__","__PRETTY_FUNCTION__","__attribute__","getter","setter","retain","unsafe_unretained","nonnull","nullable","null_unspecified","null_resettable","class","instancetype","NS_DESIGNATED_INITIALIZER","NS_UNAVAILABLE","NS_REQUIRES_SUPER","NS_RETURNS_INNER_POINTER","NS_INLINE","NS_AVAILABLE","NS_DEPRECATED","NS_ENUM","NS_OPTIONS","NS_SWIFT_UNAVAILABLE","NS_ASSUME_NONNULL_BEGIN","NS_ASSUME_NONNULL_END","NS_REFINED_FOR_SWIFT","NS_SWIFT_NAME","NS_SWIFT_NOTHROW","NS_DURING","NS_HANDLER","NS_ENDHANDLER","NS_VALUERETURN","NS_VOIDRETURN"],literal:["false","true","FALSE","TRUE","nil","YES","NO","NULL"],built_in:["dispatch_once_t","dispatch_queue_t","dispatch_sync","dispatch_async","dispatch_once"],type:["int","float","char","unsigned","signed","short","long","double","wchar_t","unichar","void","bool","BOOL","id|0","_Bool"]},d={$pattern:n,keyword:["@interface","@class","@protocol","@implementation"]};return{name:"Objective-C",aliases:["mm","objc","obj-c","obj-c++","objective-c++"],keywords:c,illegal:"</",contains:[t,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,e.C_NUMBER_MODE,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,{className:"string",variants:[{begin:'@"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]}]},{className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(e.QUOTE_STRING_MODE,{className:"string"}),{className:"string",begin:/<.*?>/,end:/$/,illegal:"\\n"},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"class",begin:"("+d.keyword.join("|")+")\\b",end:/(\{|$)/,excludeEnd:!0,keywords:d,contains:[e.UNDERSCORE_TITLE_MODE]},{begin:"\\."+e.UNDERSCORE_IDENT_RE,relevance:0}]}}function IH(e){const t=e.regex,n=["abs","accept","alarm","and","atan2","bind","binmode","bless","break","caller","chdir","chmod","chomp","chop","chown","chr","chroot","class","close","closedir","connect","continue","cos","crypt","dbmclose","dbmopen","defined","delete","die","do","dump","each","else","elsif","endgrent","endhostent","endnetent","endprotoent","endpwent","endservent","eof","eval","exec","exists","exit","exp","fcntl","field","fileno","flock","for","foreach","fork","format","formline","getc","getgrent","getgrgid","getgrnam","gethostbyaddr","gethostbyname","gethostent","getlogin","getnetbyaddr","getnetbyname","getnetent","getpeername","getpgrp","getpriority","getprotobyname","getprotobynumber","getprotoent","getpwent","getpwnam","getpwuid","getservbyname","getservbyport","getservent","getsockname","getsockopt","given","glob","gmtime","goto","grep","gt","hex","if","index","int","ioctl","join","keys","kill","last","lc","lcfirst","length","link","listen","local","localtime","log","lstat","lt","ma","map","method","mkdir","msgctl","msgget","msgrcv","msgsnd","my","ne","next","no","not","oct","open","opendir","or","ord","our","pack","package","pipe","pop","pos","print","printf","prototype","push","q|0","qq","quotemeta","qw","qx","rand","read","readdir","readline","readlink","readpipe","recv","redo","ref","rename","require","reset","return","reverse","rewinddir","rindex","rmdir","say","scalar","seek","seekdir","select","semctl","semget","semop","send","setgrent","sethostent","setnetent","setpgrp","setpriority","setprotoent","setpwent","setservent","setsockopt","shift","shmctl","shmget","shmread","shmwrite","shutdown","sin","sleep","socket","socketpair","sort","splice","split","sprintf","sqrt","srand","stat","state","study","sub","substr","symlink","syscall","sysopen","sysread","sysseek","system","syswrite","tell","telldir","tie","tied","time","times","tr","truncate","uc","ucfirst","umask","undef","unless","unlink","unpack","unshift","untie","until","use","utime","values","vec","wait","waitpid","wantarray","warn","when","while","write","x|0","xor","y|0"],r=/[dualxmsipngr]{0,12}/,i={$pattern:/[\w.]+/,keyword:n.join(" ")},s={className:"subst",begin:"[$@]\\{",end:"\\}",keywords:i},o={begin:/->\{/,end:/\}/},c={scope:"attr",match:/\s+:\s*\w+(\s*\(.*?\))?/},d={scope:"variable",variants:[{begin:/\$\d/},{begin:t.concat(/[$%@](?!")(\^\w\b|#\w+(::\w+)*|\{\w+\}|\w+(::\w*)*)/,"(?![A-Za-z])(?![@$%])")},{begin:/[$%@](?!")[^\s\w{=]|\$=/,relevance:0}],contains:[c]},f={className:"number",variants:[{match:/0?\.[0-9][0-9_]+\b/},{match:/\bv?(0|[1-9][0-9_]*(\.[0-9_]+)?|[1-9][0-9_]*)\b/},{match:/\b0[0-7][0-7_]*\b/},{match:/\b0x[0-9a-fA-F][0-9a-fA-F_]*\b/},{match:/\b0b[0-1][0-1_]*\b/}],relevance:0},m=[e.BACKSLASH_ESCAPE,s,d],p=[/!/,/\//,/\|/,/\?/,/'/,/"/,/#/],v=(x,k,A="\\1")=>{const O=A==="\\1"?A:t.concat(A,k);return t.concat(t.concat("(?:",x,")"),k,/(?:\\.|[^\\\/])*?/,O,/(?:\\.|[^\\\/])*?/,A,r)},_=(x,k,A)=>t.concat(t.concat("(?:",x,")"),k,/(?:\\.|[^\\\/])*?/,A,r),T=[d,e.HASH_COMMENT_MODE,e.COMMENT(/^=\w/,/=cut/,{endsWithParent:!0}),o,{className:"string",contains:m,variants:[{begin:"q[qwxr]?\\s*\\(",end:"\\)",relevance:5},{begin:"q[qwxr]?\\s*\\[",end:"\\]",relevance:5},{begin:"q[qwxr]?\\s*\\{",end:"\\}",relevance:5},{begin:"q[qwxr]?\\s*\\|",end:"\\|",relevance:5},{begin:"q[qwxr]?\\s*<",end:">",relevance:5},{begin:"qw\\s+q",end:"q",relevance:5},{begin:"'",end:"'",contains:[e.BACKSLASH_ESCAPE]},{begin:'"',end:'"'},{begin:"`",end:"`",contains:[e.BACKSLASH_ESCAPE]},{begin:/\{\w+\}/,relevance:0},{begin:"-?\\w+\\s*=>",relevance:0}]},f,{begin:"(\\/\\/|"+e.RE_STARTERS_RE+"|\\b(split|return|print|reverse|grep)\\b)\\s*",keywords:"split return print reverse grep",relevance:0,contains:[e.HASH_COMMENT_MODE,{className:"regexp",variants:[{begin:v("s|tr|y",t.either(...p,{capture:!0}))},{begin:v("s|tr|y","\\(","\\)")},{begin:v("s|tr|y","\\[","\\]")},{begin:v("s|tr|y","\\{","\\}")}],relevance:2},{className:"regexp",variants:[{begin:/(m|qr)\/\//,relevance:0},{begin:_("(?:m|qr)?",/\//,/\//)},{begin:_("m|qr",t.either(...p,{capture:!0}),/\1/)},{begin:_("m|qr",/\(/,/\)/)},{begin:_("m|qr",/\[/,/\]/)},{begin:_("m|qr",/\{/,/\}/)}]}]},{className:"function",beginKeywords:"sub method",end:"(\\s*\\(.*?\\))?[;{]",excludeEnd:!0,relevance:5,contains:[e.TITLE_MODE,c]},{className:"class",beginKeywords:"class",end:"[;{]",excludeEnd:!0,relevance:5,contains:[e.TITLE_MODE,c,f]},{begin:"-\\w\\b",relevance:0},{begin:"^__DATA__$",end:"^__END__$",subLanguage:"mojolicious",contains:[{begin:"^@@.*",end:"$",className:"comment"}]}];return s.contains=T,o.contains=T,{name:"Perl",aliases:["pl","pm"],keywords:i,contains:T}}function DH(e){const t=e.regex,n=/(?![A-Za-z0-9])(?![$])/,r=t.concat(/[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/,n),i=t.concat(/(\\?[A-Z][a-z0-9_\x7f-\xff]+|\\?[A-Z]+(?=[A-Z][a-z0-9_\x7f-\xff])){1,}/,n),s=t.concat(/[A-Z]+/,n),o={scope:"variable",match:"\\$+"+r},c={scope:"meta",variants:[{begin:/<\?php/,relevance:10},{begin:/<\?=/},{begin:/<\?/,relevance:.1},{begin:/\?>/}]},d={scope:"subst",variants:[{begin:/\$\w+/},{begin:/\{\$/,end:/\}/}]},f=e.inherit(e.APOS_STRING_MODE,{illegal:null}),m=e.inherit(e.QUOTE_STRING_MODE,{illegal:null,contains:e.QUOTE_STRING_MODE.contains.concat(d)}),p={begin:/<<<[ \t]*(?:(\w+)|"(\w+)")\n/,end:/[ \t]*(\w+)\b/,contains:e.QUOTE_STRING_MODE.contains.concat(d),"on:begin":(fe,de)=>{de.data._beginMatch=fe[1]||fe[2]},"on:end":(fe,de)=>{de.data._beginMatch!==fe[1]&&de.ignoreMatch()}},v=e.END_SAME_AS_BEGIN({begin:/<<<[ \t]*'(\w+)'\n/,end:/[ \t]*(\w+)\b/}),_=`[ 	
]`,T={scope:"string",variants:[m,f,p,v]},x={scope:"number",variants:[{begin:"\\b0[bB][01]+(?:_[01]+)*\\b"},{begin:"\\b0[oO][0-7]+(?:_[0-7]+)*\\b"},{begin:"\\b0[xX][\\da-fA-F]+(?:_[\\da-fA-F]+)*\\b"},{begin:"(?:\\b\\d+(?:_\\d+)*(\\.(?:\\d+(?:_\\d+)*))?|\\B\\.\\d+)(?:[eE][+-]?\\d+)?"}],relevance:0},k=["false","null","true"],A=["__CLASS__","__DIR__","__FILE__","__FUNCTION__","__COMPILER_HALT_OFFSET__","__LINE__","__METHOD__","__NAMESPACE__","__TRAIT__","die","echo","exit","include","include_once","print","require","require_once","array","abstract","and","as","binary","bool","boolean","break","callable","case","catch","class","clone","const","continue","declare","default","do","double","else","elseif","empty","enddeclare","endfor","endforeach","endif","endswitch","endwhile","enum","eval","extends","final","finally","float","for","foreach","from","global","goto","if","implements","instanceof","insteadof","int","integer","interface","isset","iterable","list","match|0","mixed","new","never","object","or","private","protected","public","readonly","real","return","string","switch","throw","trait","try","unset","use","var","void","while","xor","yield"],O=["Error|0","AppendIterator","ArgumentCountError","ArithmeticError","ArrayIterator","ArrayObject","AssertionError","BadFunctionCallException","BadMethodCallException","CachingIterator","CallbackFilterIterator","CompileError","Countable","DirectoryIterator","DivisionByZeroError","DomainException","EmptyIterator","ErrorException","Exception","FilesystemIterator","FilterIterator","GlobIterator","InfiniteIterator","InvalidArgumentException","IteratorIterator","LengthException","LimitIterator","LogicException","MultipleIterator","NoRewindIterator","OutOfBoundsException","OutOfRangeException","OuterIterator","OverflowException","ParentIterator","ParseError","RangeException","RecursiveArrayIterator","RecursiveCachingIterator","RecursiveCallbackFilterIterator","RecursiveDirectoryIterator","RecursiveFilterIterator","RecursiveIterator","RecursiveIteratorIterator","RecursiveRegexIterator","RecursiveTreeIterator","RegexIterator","RuntimeException","SeekableIterator","SplDoublyLinkedList","SplFileInfo","SplFileObject","SplFixedArray","SplHeap","SplMaxHeap","SplMinHeap","SplObjectStorage","SplObserver","SplPriorityQueue","SplQueue","SplStack","SplSubject","SplTempFileObject","TypeError","UnderflowException","UnexpectedValueException","UnhandledMatchError","ArrayAccess","BackedEnum","Closure","Fiber","Generator","Iterator","IteratorAggregate","Serializable","Stringable","Throwable","Traversable","UnitEnum","WeakReference","WeakMap","Directory","__PHP_Incomplete_Class","parent","php_user_filter","self","static","stdClass"],$={keyword:A,literal:(fe=>{const de=[];return fe.forEach(H=>{de.push(H),H.toLowerCase()===H?de.push(H.toUpperCase()):de.push(H.toLowerCase())}),de})(k),built_in:O},V=fe=>fe.map(de=>de.replace(/\|\d+$/,"")),B={variants:[{match:[/new/,t.concat(_,"+"),t.concat("(?!",V(O).join("\\b|"),"\\b)"),i],scope:{1:"keyword",4:"title.class"}}]},Z=t.concat(r,"\\b(?!\\()"),ee={variants:[{match:[t.concat(/::/,t.lookahead(/(?!class\b)/)),Z],scope:{2:"variable.constant"}},{match:[/::/,/class/],scope:{2:"variable.language"}},{match:[i,t.concat(/::/,t.lookahead(/(?!class\b)/)),Z],scope:{1:"title.class",3:"variable.constant"}},{match:[i,t.concat("::",t.lookahead(/(?!class\b)/))],scope:{1:"title.class"}},{match:[i,/::/,/class/],scope:{1:"title.class",3:"variable.language"}}]},te={scope:"attr",match:t.concat(r,t.lookahead(":"),t.lookahead(/(?!::)/))},Y={relevance:0,begin:/\(/,end:/\)/,keywords:$,contains:[te,o,ee,e.C_BLOCK_COMMENT_MODE,T,x,B]},oe={relevance:0,match:[/\b/,t.concat("(?!fn\\b|function\\b|",V(A).join("\\b|"),"|",V(O).join("\\b|"),"\\b)"),r,t.concat(_,"*"),t.lookahead(/(?=\()/)],scope:{3:"title.function.invoke"},contains:[Y]};Y.contains.push(oe);const he=[te,ee,e.C_BLOCK_COMMENT_MODE,T,x,B],Se={begin:t.concat(/#\[\s*\\?/,t.either(i,s)),beginScope:"meta",end:/]/,endScope:"meta",keywords:{literal:k,keyword:["new","array"]},contains:[{begin:/\[/,end:/]/,keywords:{literal:k,keyword:["new","array"]},contains:["self",...he]},...he,{scope:"meta",variants:[{match:i},{match:s}]}]};return{case_insensitive:!1,keywords:$,contains:[Se,e.HASH_COMMENT_MODE,e.COMMENT("//","$"),e.COMMENT("/\\*","\\*/",{contains:[{scope:"doctag",match:"@[A-Za-z]+"}]}),{match:/__halt_compiler\(\);/,keywords:"__halt_compiler",starts:{scope:"comment",end:e.MATCH_NOTHING_RE,contains:[{match:/\?>/,scope:"meta",endsParent:!0}]}},c,{scope:"variable.language",match:/\$this\b/},o,oe,ee,{match:[/const/,/\s/,r],scope:{1:"keyword",3:"variable.constant"}},B,{scope:"function",relevance:0,beginKeywords:"fn function",end:/[;{]/,excludeEnd:!0,illegal:"[$%\\[]",contains:[{beginKeywords:"use"},e.UNDERSCORE_TITLE_MODE,{begin:"=>",endsParent:!0},{scope:"params",begin:"\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0,keywords:$,contains:["self",Se,o,ee,e.C_BLOCK_COMMENT_MODE,T,x]}]},{scope:"class",variants:[{beginKeywords:"enum",illegal:/[($"]/},{beginKeywords:"class interface trait",illegal:/[:($"]/}],relevance:0,end:/\{/,excludeEnd:!0,contains:[{beginKeywords:"extends implements"},e.UNDERSCORE_TITLE_MODE]},{beginKeywords:"namespace",relevance:0,end:";",illegal:/[.']/,contains:[e.inherit(e.UNDERSCORE_TITLE_MODE,{scope:"title.class"})]},{beginKeywords:"use",relevance:0,end:";",contains:[{match:/\b(as|const|function)\b/,scope:"keyword"},e.UNDERSCORE_TITLE_MODE]},T,x]}}function LH(e){return{name:"PHP template",subLanguage:"xml",contains:[{begin:/<\?(php|=)?/,end:/\?>/,subLanguage:"php",contains:[{begin:"/\\*",end:"\\*/",skip:!0},{begin:'b"',end:'"',skip:!0},{begin:"b'",end:"'",skip:!0},e.inherit(e.APOS_STRING_MODE,{illegal:null,className:null,contains:null,skip:!0}),e.inherit(e.QUOTE_STRING_MODE,{illegal:null,className:null,contains:null,skip:!0})]}]}}function PH(e){return{name:"Plain text",aliases:["text","txt"],disableAutodetect:!0}}function BH(e){const t=e.regex,n=new RegExp("[\\p{XID_Start}_]\\p{XID_Continue}*","u"),r=["and","as","assert","async","await","break","case","class","continue","def","del","elif","else","except","finally","for","from","global","if","import","in","is","lambda","match","nonlocal|10","not","or","pass","raise","return","try","while","with","yield"],c={$pattern:/[A-Za-z]\w+|__\w+__/,keyword:r,built_in:["__import__","abs","all","any","ascii","bin","bool","breakpoint","bytearray","bytes","callable","chr","classmethod","compile","complex","delattr","dict","dir","divmod","enumerate","eval","exec","filter","float","format","frozenset","getattr","globals","hasattr","hash","help","hex","id","input","int","isinstance","issubclass","iter","len","list","locals","map","max","memoryview","min","next","object","oct","open","ord","pow","print","property","range","repr","reversed","round","set","setattr","slice","sorted","staticmethod","str","sum","super","tuple","type","vars","zip"],literal:["__debug__","Ellipsis","False","None","NotImplemented","True"],type:["Any","Callable","Coroutine","Dict","List","Literal","Generic","Optional","Sequence","Set","Tuple","Type","Union"]},d={className:"meta",begin:/^(>>>|\.\.\.) /},f={className:"subst",begin:/\{/,end:/\}/,keywords:c,illegal:/#/},m={begin:/\{\{/,relevance:0},p={className:"string",contains:[e.BACKSLASH_ESCAPE],variants:[{begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?'''/,end:/'''/,contains:[e.BACKSLASH_ESCAPE,d],relevance:10},{begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?"""/,end:/"""/,contains:[e.BACKSLASH_ESCAPE,d],relevance:10},{begin:/([fF][rR]|[rR][fF]|[fF])'''/,end:/'''/,contains:[e.BACKSLASH_ESCAPE,d,m,f]},{begin:/([fF][rR]|[rR][fF]|[fF])"""/,end:/"""/,contains:[e.BACKSLASH_ESCAPE,d,m,f]},{begin:/([uU]|[rR])'/,end:/'/,relevance:10},{begin:/([uU]|[rR])"/,end:/"/,relevance:10},{begin:/([bB]|[bB][rR]|[rR][bB])'/,end:/'/},{begin:/([bB]|[bB][rR]|[rR][bB])"/,end:/"/},{begin:/([fF][rR]|[rR][fF]|[fF])'/,end:/'/,contains:[e.BACKSLASH_ESCAPE,m,f]},{begin:/([fF][rR]|[rR][fF]|[fF])"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,m,f]},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},v="[0-9](_?[0-9])*",_=`(\\b(${v}))?\\.(${v})|\\b(${v})\\.`,T=`\\b|${r.join("|")}`,x={className:"number",relevance:0,variants:[{begin:`(\\b(${v})|(${_}))[eE][+-]?(${v})[jJ]?(?=${T})`},{begin:`(${_})[jJ]?`},{begin:`\\b([1-9](_?[0-9])*|0+(_?0)*)[lLjJ]?(?=${T})`},{begin:`\\b0[bB](_?[01])+[lL]?(?=${T})`},{begin:`\\b0[oO](_?[0-7])+[lL]?(?=${T})`},{begin:`\\b0[xX](_?[0-9a-fA-F])+[lL]?(?=${T})`},{begin:`\\b(${v})[jJ](?=${T})`}]},k={className:"comment",begin:t.lookahead(/# type:/),end:/$/,keywords:c,contains:[{begin:/# type:/},{begin:/#/,end:/\b\B/,endsWithParent:!0}]},A={className:"params",variants:[{className:"",begin:/\(\s*\)/,skip:!0},{begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:c,contains:["self",d,x,p,e.HASH_COMMENT_MODE]}]};return f.contains=[p,x,d],{name:"Python",aliases:["py","gyp","ipython"],unicodeRegex:!0,keywords:c,illegal:/(<\/|\?)|=>/,contains:[d,x,{scope:"variable.language",match:/\bself\b/},{beginKeywords:"if",relevance:0},{match:/\bor\b/,scope:"keyword"},p,k,e.HASH_COMMENT_MODE,{match:[/\bdef/,/\s+/,n],scope:{1:"keyword",3:"title.function"},contains:[A]},{variants:[{match:[/\bclass/,/\s+/,n,/\s*/,/\(\s*/,n,/\s*\)/]},{match:[/\bclass/,/\s+/,n]}],scope:{1:"keyword",3:"title.class",6:"title.class.inherited"}},{className:"meta",begin:/^[\t ]*@/,end:/(?=#)|$/,contains:[x,A,p]}]}}function UH(e){return{aliases:["pycon"],contains:[{className:"meta.prompt",starts:{end:/ |$/,starts:{end:"$",subLanguage:"python"}},variants:[{begin:/^>>>(?=[ ]|$)/},{begin:/^\.\.\.(?=[ ]|$)/}]}]}}function zH(e){const t=e.regex,n=/(?:(?:[a-zA-Z]|\.[._a-zA-Z])[._a-zA-Z0-9]*)|\.(?!\d)/,r=t.either(/0[xX][0-9a-fA-F]+\.[0-9a-fA-F]*[pP][+-]?\d+i?/,/0[xX][0-9a-fA-F]+(?:[pP][+-]?\d+)?[Li]?/,/(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?[Li]?/),i=/[=!<>:]=|\|\||&&|:::?|<-|<<-|->>|->|\|>|[-+*\/?!$&|:<=>@^~]|\*\*/,s=t.either(/[()]/,/[{}]/,/\[\[/,/[[\]]/,/\\/,/,/);return{name:"R",keywords:{$pattern:n,keyword:"function if in break next repeat else for while",literal:"NULL NA TRUE FALSE Inf NaN NA_integer_|10 NA_real_|10 NA_character_|10 NA_complex_|10",built_in:"LETTERS letters month.abb month.name pi T F abs acos acosh all any anyNA Arg as.call as.character as.complex as.double as.environment as.integer as.logical as.null.default as.numeric as.raw asin asinh atan atanh attr attributes baseenv browser c call ceiling class Conj cos cosh cospi cummax cummin cumprod cumsum digamma dim dimnames emptyenv exp expression floor forceAndCall gamma gc.time globalenv Im interactive invisible is.array is.atomic is.call is.character is.complex is.double is.environment is.expression is.finite is.function is.infinite is.integer is.language is.list is.logical is.matrix is.na is.name is.nan is.null is.numeric is.object is.pairlist is.raw is.recursive is.single is.symbol lazyLoadDBfetch length lgamma list log max min missing Mod names nargs nzchar oldClass on.exit pos.to.env proc.time prod quote range Re rep retracemem return round seq_along seq_len seq.int sign signif sin sinh sinpi sqrt standardGeneric substitute sum switch tan tanh tanpi tracemem trigamma trunc unclass untracemem UseMethod xtfrm"},contains:[e.COMMENT(/#'/,/$/,{contains:[{scope:"doctag",match:/@examples/,starts:{end:t.lookahead(t.either(/\n^#'\s*(?=@[a-zA-Z]+)/,/\n^(?!#')/)),endsParent:!0}},{scope:"doctag",begin:"@param",end:/$/,contains:[{scope:"variable",variants:[{match:n},{match:/`(?:\\.|[^`\\])+`/}],endsParent:!0}]},{scope:"doctag",match:/@[a-zA-Z]+/},{scope:"keyword",match:/\\[a-zA-Z]+/}]}),e.HASH_COMMENT_MODE,{scope:"string",contains:[e.BACKSLASH_ESCAPE],variants:[e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\(/,end:/\)(-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\{/,end:/\}(-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\[/,end:/\](-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\(/,end:/\)(-*)'/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\{/,end:/\}(-*)'/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\[/,end:/\](-*)'/}),{begin:'"',end:'"',relevance:0},{begin:"'",end:"'",relevance:0}]},{relevance:0,variants:[{scope:{1:"operator",2:"number"},match:[i,r]},{scope:{1:"operator",2:"number"},match:[/%[^%]*%/,r]},{scope:{1:"punctuation",2:"number"},match:[s,r]},{scope:{2:"number"},match:[/[^a-zA-Z0-9._]|^/,r]}]},{scope:{3:"operator"},match:[n,/\s+/,/<-/,/\s+/]},{scope:"operator",relevance:0,variants:[{match:i},{match:/%[^%]*%/}]},{scope:"punctuation",relevance:0,match:s},{begin:"`",end:"`",contains:[{begin:/\\./}]}]}}function FH(e){const t=e.regex,n="([a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?)",r=t.either(/\b([A-Z]+[a-z0-9]+)+/,/\b([A-Z]+[a-z0-9]+)+[A-Z]+/),i=t.concat(r,/(::\w+)*/),o={"variable.constant":["__FILE__","__LINE__","__ENCODING__"],"variable.language":["self","super"],keyword:["alias","and","begin","BEGIN","break","case","class","defined","do","else","elsif","end","END","ensure","for","if","in","module","next","not","or","redo","require","rescue","retry","return","then","undef","unless","until","when","while","yield",...["include","extend","prepend","public","private","protected","raise","throw"]],built_in:["proc","lambda","attr_accessor","attr_reader","attr_writer","define_method","private_constant","module_function"],literal:["true","false","nil"]},c={className:"doctag",begin:"@[A-Za-z]+"},d={begin:"#<",end:">"},f=[e.COMMENT("#","$",{contains:[c]}),e.COMMENT("^=begin","^=end",{contains:[c],relevance:10}),e.COMMENT("^__END__",e.MATCH_NOTHING_RE)],m={className:"subst",begin:/#\{/,end:/\}/,keywords:o},p={className:"string",contains:[e.BACKSLASH_ESCAPE,m],variants:[{begin:/'/,end:/'/},{begin:/"/,end:/"/},{begin:/`/,end:/`/},{begin:/%[qQwWx]?\(/,end:/\)/},{begin:/%[qQwWx]?\[/,end:/\]/},{begin:/%[qQwWx]?\{/,end:/\}/},{begin:/%[qQwWx]?</,end:/>/},{begin:/%[qQwWx]?\//,end:/\//},{begin:/%[qQwWx]?%/,end:/%/},{begin:/%[qQwWx]?-/,end:/-/},{begin:/%[qQwWx]?\|/,end:/\|/},{begin:/\B\?(\\\d{1,3})/},{begin:/\B\?(\\x[A-Fa-f0-9]{1,2})/},{begin:/\B\?(\\u\{?[A-Fa-f0-9]{1,6}\}?)/},{begin:/\B\?(\\M-\\C-|\\M-\\c|\\c\\M-|\\M-|\\C-\\M-)[\x20-\x7e]/},{begin:/\B\?\\(c|C-)[\x20-\x7e]/},{begin:/\B\?\\?\S/},{begin:t.concat(/<<[-~]?'?/,t.lookahead(/(\w+)(?=\W)[^\n]*\n(?:[^\n]*\n)*?\s*\1\b/)),contains:[e.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,contains:[e.BACKSLASH_ESCAPE,m]})]}]},v="[1-9](_?[0-9])*|0",_="[0-9](_?[0-9])*",T={className:"number",relevance:0,variants:[{begin:`\\b(${v})(\\.(${_}))?([eE][+-]?(${_})|r)?i?\\b`},{begin:"\\b0[dD][0-9](_?[0-9])*r?i?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*r?i?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*r?i?\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*r?i?\\b"},{begin:"\\b0(_?[0-7])+r?i?\\b"}]},x={variants:[{match:/\(\)/},{className:"params",begin:/\(/,end:/(?=\))/,excludeBegin:!0,endsParent:!0,keywords:o}]},B=[p,{variants:[{match:[/class\s+/,i,/\s+<\s+/,i]},{match:[/\b(class|module)\s+/,i]}],scope:{2:"title.class",4:"title.class.inherited"},keywords:o},{match:[/(include|extend)\s+/,i],scope:{2:"title.class"},keywords:o},{relevance:0,match:[i,/\.new[. (]/],scope:{1:"title.class"}},{relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"},{relevance:0,match:r,scope:"title.class"},{match:[/def/,/\s+/,n],scope:{1:"keyword",3:"title.function"},contains:[x]},{begin:e.IDENT_RE+"::"},{className:"symbol",begin:e.UNDERSCORE_IDENT_RE+"(!|\\?)?:",relevance:0},{className:"symbol",begin:":(?!\\s)",contains:[p,{begin:n}],relevance:0},T,{className:"variable",begin:"(\\$\\W)|((\\$|@@?)(\\w+))(?=[^@$?])(?![A-Za-z])(?![@$?'])"},{className:"params",begin:/\|(?!=)/,end:/\|/,excludeBegin:!0,excludeEnd:!0,relevance:0,keywords:o},{begin:"("+e.RE_STARTERS_RE+"|unless)\\s*",keywords:"unless",contains:[{className:"regexp",contains:[e.BACKSLASH_ESCAPE,m],illegal:/\n/,variants:[{begin:"/",end:"/[a-z]*"},{begin:/%r\{/,end:/\}[a-z]*/},{begin:"%r\\(",end:"\\)[a-z]*"},{begin:"%r!",end:"![a-z]*"},{begin:"%r\\[",end:"\\][a-z]*"}]}].concat(d,f),relevance:0}].concat(d,f);m.contains=B,x.contains=B;const Y=[{begin:/^\s*=>/,starts:{end:"$",contains:B}},{className:"meta.prompt",begin:"^("+"[>?]>"+"|"+"[\\w#]+\\(\\w+\\):\\d+:\\d+[>*]"+"|"+"(\\w+-)?\\d+\\.\\d+\\.\\d+(p\\d+)?[^\\d][^>]+>"+")(?=[ ])",starts:{end:"$",keywords:o,contains:B}}];return f.unshift(d),{name:"Ruby",aliases:["rb","gemspec","podspec","thor","irb"],keywords:o,illegal:/\/\*/,contains:[e.SHEBANG({binary:"ruby"})].concat(Y).concat(f).concat(B)}}function HH(e){const t=e.regex,n=/(r#)?/,r=t.concat(n,e.UNDERSCORE_IDENT_RE),i=t.concat(n,e.IDENT_RE),s={className:"title.function.invoke",relevance:0,begin:t.concat(/\b/,/(?!let|for|while|if|else|match\b)/,i,t.lookahead(/\s*\(/))},o="([ui](8|16|32|64|128|size)|f(32|64))?",c=["abstract","as","async","await","become","box","break","const","continue","crate","do","dyn","else","enum","extern","false","final","fn","for","if","impl","in","let","loop","macro","match","mod","move","mut","override","priv","pub","ref","return","self","Self","static","struct","super","trait","true","try","type","typeof","union","unsafe","unsized","use","virtual","where","while","yield"],d=["true","false","Some","None","Ok","Err"],f=["drop ","Copy","Send","Sized","Sync","Drop","Fn","FnMut","FnOnce","ToOwned","Clone","Debug","PartialEq","PartialOrd","Eq","Ord","AsRef","AsMut","Into","From","Default","Iterator","Extend","IntoIterator","DoubleEndedIterator","ExactSizeIterator","SliceConcatExt","ToString","assert!","assert_eq!","bitflags!","bytes!","cfg!","col!","concat!","concat_idents!","debug_assert!","debug_assert_eq!","env!","eprintln!","panic!","file!","format!","format_args!","include_bytes!","include_str!","line!","local_data_key!","module_path!","option_env!","print!","println!","select!","stringify!","try!","unimplemented!","unreachable!","vec!","write!","writeln!","macro_rules!","assert_ne!","debug_assert_ne!"],m=["i8","i16","i32","i64","i128","isize","u8","u16","u32","u64","u128","usize","f32","f64","str","char","bool","Box","Option","Result","String","Vec"];return{name:"Rust",aliases:["rs"],keywords:{$pattern:e.IDENT_RE+"!?",type:m,keyword:c,literal:d,built_in:f},illegal:"</",contains:[e.C_LINE_COMMENT_MODE,e.COMMENT("/\\*","\\*/",{contains:["self"]}),e.inherit(e.QUOTE_STRING_MODE,{begin:/b?"/,illegal:null}),{className:"symbol",begin:/'[a-zA-Z_][a-zA-Z0-9_]*(?!')/},{scope:"string",variants:[{begin:/b?r(#*)"(.|\n)*?"\1(?!#)/},{begin:/b?'/,end:/'/,contains:[{scope:"char.escape",match:/\\('|\w|x\w{2}|u\w{4}|U\w{8})/}]}]},{className:"number",variants:[{begin:"\\b0b([01_]+)"+o},{begin:"\\b0o([0-7_]+)"+o},{begin:"\\b0x([A-Fa-f0-9_]+)"+o},{begin:"\\b(\\d[\\d_]*(\\.[0-9_]+)?([eE][+-]?[0-9_]+)?)"+o}],relevance:0},{begin:[/fn/,/\s+/,r],className:{1:"keyword",3:"title.function"}},{className:"meta",begin:"#!?\\[",end:"\\]",contains:[{className:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE]}]},{begin:[/let/,/\s+/,/(?:mut\s+)?/,r],className:{1:"keyword",3:"keyword",4:"variable"}},{begin:[/for/,/\s+/,r,/\s+/,/in/],className:{1:"keyword",3:"variable",5:"keyword"}},{begin:[/type/,/\s+/,r],className:{1:"keyword",3:"title.class"}},{begin:[/(?:trait|enum|struct|union|impl|for)/,/\s+/,r],className:{1:"keyword",3:"title.class"}},{begin:e.IDENT_RE+"::",keywords:{keyword:"Self",built_in:f,type:m}},{className:"punctuation",begin:"->"},s]}}const jH=e=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),qH=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],$H=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],GH=[...qH,...$H],YH=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),VH=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),KH=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),WH=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse();function XH(e){const t=jH(e),n=KH,r=VH,i="@[a-z-]+",s="and or not only",c={className:"variable",begin:"(\\$"+"[a-zA-Z-][a-zA-Z0-9_-]*"+")\\b",relevance:0};return{name:"SCSS",case_insensitive:!0,illegal:"[=/|']",contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,t.CSS_NUMBER_MODE,{className:"selector-id",begin:"#[A-Za-z0-9_-]+",relevance:0},{className:"selector-class",begin:"\\.[A-Za-z0-9_-]+",relevance:0},t.ATTRIBUTE_SELECTOR_MODE,{className:"selector-tag",begin:"\\b("+GH.join("|")+")\\b",relevance:0},{className:"selector-pseudo",begin:":("+r.join("|")+")"},{className:"selector-pseudo",begin:":(:)?("+n.join("|")+")"},c,{begin:/\(/,end:/\)/,contains:[t.CSS_NUMBER_MODE]},t.CSS_VARIABLE,{className:"attribute",begin:"\\b("+WH.join("|")+")\\b"},{begin:"\\b(whitespace|wait|w-resize|visible|vertical-text|vertical-ideographic|uppercase|upper-roman|upper-alpha|underline|transparent|top|thin|thick|text|text-top|text-bottom|tb-rl|table-header-group|table-footer-group|sw-resize|super|strict|static|square|solid|small-caps|separate|se-resize|scroll|s-resize|rtl|row-resize|ridge|right|repeat|repeat-y|repeat-x|relative|progress|pointer|overline|outside|outset|oblique|nowrap|not-allowed|normal|none|nw-resize|no-repeat|no-drop|newspaper|ne-resize|n-resize|move|middle|medium|ltr|lr-tb|lowercase|lower-roman|lower-alpha|loose|list-item|line|line-through|line-edge|lighter|left|keep-all|justify|italic|inter-word|inter-ideograph|inside|inset|inline|inline-block|inherit|inactive|ideograph-space|ideograph-parenthesis|ideograph-numeric|ideograph-alpha|horizontal|hidden|help|hand|groove|fixed|ellipsis|e-resize|double|dotted|distribute|distribute-space|distribute-letter|distribute-all-lines|disc|disabled|default|decimal|dashed|crosshair|collapse|col-resize|circle|char|center|capitalize|break-word|break-all|bottom|both|bolder|bold|block|bidi-override|below|baseline|auto|always|all-scroll|absolute|table|table-cell)\\b"},{begin:/:/,end:/[;}{]/,relevance:0,contains:[t.BLOCK_COMMENT,c,t.HEXCOLOR,t.CSS_NUMBER_MODE,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,t.IMPORTANT,t.FUNCTION_DISPATCH]},{begin:"@(page|font-face)",keywords:{$pattern:i,keyword:"@page @font-face"}},{begin:"@",end:"[{;]",returnBegin:!0,keywords:{$pattern:/[a-z-]+/,keyword:s,attribute:YH.join(" ")},contains:[{begin:i,className:"keyword"},{begin:/[a-z-]+(?=:)/,className:"attribute"},c,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,t.HEXCOLOR,t.CSS_NUMBER_MODE]},t.FUNCTION_DISPATCH]}}function QH(e){return{name:"Shell Session",aliases:["console","shellsession"],contains:[{className:"meta.prompt",begin:/^\s{0,3}[/~\w\d[\]()@-]*[>%$#][ ]?/,starts:{end:/[^\\](?=\s*$)/,subLanguage:"bash"}}]}}function ZH(e){const t=e.regex,n=e.COMMENT("--","$"),r={scope:"string",variants:[{begin:/'/,end:/'/,contains:[{match:/''/}]}]},i={begin:/"/,end:/"/,contains:[{match:/""/}]},s=["true","false","unknown"],o=["double precision","large object","with timezone","without timezone"],c=["bigint","binary","blob","boolean","char","character","clob","date","dec","decfloat","decimal","float","int","integer","interval","nchar","nclob","national","numeric","real","row","smallint","time","timestamp","varchar","varying","varbinary"],d=["add","asc","collation","desc","final","first","last","view"],f=["abs","acos","all","allocate","alter","and","any","are","array","array_agg","array_max_cardinality","as","asensitive","asin","asymmetric","at","atan","atomic","authorization","avg","begin","begin_frame","begin_partition","between","bigint","binary","blob","boolean","both","by","call","called","cardinality","cascaded","case","cast","ceil","ceiling","char","char_length","character","character_length","check","classifier","clob","close","coalesce","collate","collect","column","commit","condition","connect","constraint","contains","convert","copy","corr","corresponding","cos","cosh","count","covar_pop","covar_samp","create","cross","cube","cume_dist","current","current_catalog","current_date","current_default_transform_group","current_path","current_role","current_row","current_schema","current_time","current_timestamp","current_path","current_role","current_transform_group_for_type","current_user","cursor","cycle","date","day","deallocate","dec","decimal","decfloat","declare","default","define","delete","dense_rank","deref","describe","deterministic","disconnect","distinct","double","drop","dynamic","each","element","else","empty","end","end_frame","end_partition","end-exec","equals","escape","every","except","exec","execute","exists","exp","external","extract","false","fetch","filter","first_value","float","floor","for","foreign","frame_row","free","from","full","function","fusion","get","global","grant","group","grouping","groups","having","hold","hour","identity","in","indicator","initial","inner","inout","insensitive","insert","int","integer","intersect","intersection","interval","into","is","join","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","language","large","last_value","lateral","lead","leading","left","like","like_regex","listagg","ln","local","localtime","localtimestamp","log","log10","lower","match","match_number","match_recognize","matches","max","member","merge","method","min","minute","mod","modifies","module","month","multiset","national","natural","nchar","nclob","new","no","none","normalize","not","nth_value","ntile","null","nullif","numeric","octet_length","occurrences_regex","of","offset","old","omit","on","one","only","open","or","order","out","outer","over","overlaps","overlay","parameter","partition","pattern","per","percent","percent_rank","percentile_cont","percentile_disc","period","portion","position","position_regex","power","precedes","precision","prepare","primary","procedure","ptf","range","rank","reads","real","recursive","ref","references","referencing","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","release","result","return","returns","revoke","right","rollback","rollup","row","row_number","rows","running","savepoint","scope","scroll","search","second","seek","select","sensitive","session_user","set","show","similar","sin","sinh","skip","smallint","some","specific","specifictype","sql","sqlexception","sqlstate","sqlwarning","sqrt","start","static","stddev_pop","stddev_samp","submultiset","subset","substring","substring_regex","succeeds","sum","symmetric","system","system_time","system_user","table","tablesample","tan","tanh","then","time","timestamp","timezone_hour","timezone_minute","to","trailing","translate","translate_regex","translation","treat","trigger","trim","trim_array","true","truncate","uescape","union","unique","unknown","unnest","update","upper","user","using","value","values","value_of","var_pop","var_samp","varbinary","varchar","varying","versioning","when","whenever","where","width_bucket","window","with","within","without","year"],m=["abs","acos","array_agg","asin","atan","avg","cast","ceil","ceiling","coalesce","corr","cos","cosh","count","covar_pop","covar_samp","cume_dist","dense_rank","deref","element","exp","extract","first_value","floor","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","last_value","lead","listagg","ln","log","log10","lower","max","min","mod","nth_value","ntile","nullif","percent_rank","percentile_cont","percentile_disc","position","position_regex","power","rank","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","row_number","sin","sinh","sqrt","stddev_pop","stddev_samp","substring","substring_regex","sum","tan","tanh","translate","translate_regex","treat","trim","trim_array","unnest","upper","value_of","var_pop","var_samp","width_bucket"],p=["current_catalog","current_date","current_default_transform_group","current_path","current_role","current_schema","current_transform_group_for_type","current_user","session_user","system_time","system_user","current_time","localtime","current_timestamp","localtimestamp"],v=["create table","insert into","primary key","foreign key","not null","alter table","add constraint","grouping sets","on overflow","character set","respect nulls","ignore nulls","nulls first","nulls last","depth first","breadth first"],_=m,T=[...f,...d].filter(V=>!m.includes(V)),x={scope:"variable",match:/@[a-z0-9][a-z0-9_]*/},k={scope:"operator",match:/[-+*/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?/,relevance:0},A={match:t.concat(/\b/,t.either(..._),/\s*\(/),relevance:0,keywords:{built_in:_}};function O(V){return t.concat(/\b/,t.either(...V.map(B=>B.replace(/\s+/,"\\s+"))),/\b/)}const I={scope:"keyword",match:O(v),relevance:0};function $(V,{exceptions:B,when:Z}={}){const ee=Z;return B=B||[],V.map(te=>te.match(/\|\d+$/)||B.includes(te)?te:ee(te)?`${te}|0`:te)}return{name:"SQL",case_insensitive:!0,illegal:/[{}]|<\//,keywords:{$pattern:/\b[\w\.]+/,keyword:$(T,{when:V=>V.length<3}),literal:s,type:c,built_in:p},contains:[{scope:"type",match:O(o)},I,A,x,r,i,e.C_NUMBER_MODE,e.C_BLOCK_COMMENT_MODE,n,k]}}function nx(e){return e?typeof e=="string"?e:e.source:null}function Ac(e){return on("(?=",e,")")}function on(...e){return e.map(n=>nx(n)).join("")}function JH(e){const t=e[e.length-1];return typeof t=="object"&&t.constructor===Object?(e.splice(e.length-1,1),t):{}}function Br(...e){return"("+(JH(e).capture?"":"?:")+e.map(r=>nx(r)).join("|")+")"}const D2=e=>on(/\b/,e,/\w$/.test(e)?/\b/:/\B/),ej=["Protocol","Type"].map(D2),ZE=["init","self"].map(D2),tj=["Any","Self"],J1=["actor","any","associatedtype","async","await",/as\?/,/as!/,"as","borrowing","break","case","catch","class","consume","consuming","continue","convenience","copy","default","defer","deinit","didSet","distributed","do","dynamic","each","else","enum","extension","fallthrough",/fileprivate\(set\)/,"fileprivate","final","for","func","get","guard","if","import","indirect","infix",/init\?/,/init!/,"inout",/internal\(set\)/,"internal","in","is","isolated","nonisolated","lazy","let","macro","mutating","nonmutating",/open\(set\)/,"open","operator","optional","override","package","postfix","precedencegroup","prefix",/private\(set\)/,"private","protocol",/public\(set\)/,"public","repeat","required","rethrows","return","set","some","static","struct","subscript","super","switch","throws","throw",/try\?/,/try!/,"try","typealias",/unowned\(safe\)/,/unowned\(unsafe\)/,"unowned","var","weak","where","while","willSet"],JE=["false","nil","true"],nj=["assignment","associativity","higherThan","left","lowerThan","none","right"],rj=["#colorLiteral","#column","#dsohandle","#else","#elseif","#endif","#error","#file","#fileID","#fileLiteral","#filePath","#function","#if","#imageLiteral","#keyPath","#line","#selector","#sourceLocation","#warning"],e6=["abs","all","any","assert","assertionFailure","debugPrint","dump","fatalError","getVaList","isKnownUniquelyReferenced","max","min","numericCast","pointwiseMax","pointwiseMin","precondition","preconditionFailure","print","readLine","repeatElement","sequence","stride","swap","swift_unboxFromSwiftValueWithType","transcode","type","unsafeBitCast","unsafeDowncast","withExtendedLifetime","withUnsafeMutablePointer","withUnsafePointer","withVaList","withoutActuallyEscaping","zip"],rx=Br(/[/=\-+!*%<>&|^~?]/,/[\u00A1-\u00A7]/,/[\u00A9\u00AB]/,/[\u00AC\u00AE]/,/[\u00B0\u00B1]/,/[\u00B6\u00BB\u00BF\u00D7\u00F7]/,/[\u2016-\u2017]/,/[\u2020-\u2027]/,/[\u2030-\u203E]/,/[\u2041-\u2053]/,/[\u2055-\u205E]/,/[\u2190-\u23FF]/,/[\u2500-\u2775]/,/[\u2794-\u2BFF]/,/[\u2E00-\u2E7F]/,/[\u3001-\u3003]/,/[\u3008-\u3020]/,/[\u3030]/),ix=Br(rx,/[\u0300-\u036F]/,/[\u1DC0-\u1DFF]/,/[\u20D0-\u20FF]/,/[\uFE00-\uFE0F]/,/[\uFE20-\uFE2F]/),eg=on(rx,ix,"*"),ax=Br(/[a-zA-Z_]/,/[\u00A8\u00AA\u00AD\u00AF\u00B2-\u00B5\u00B7-\u00BA]/,/[\u00BC-\u00BE\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF]/,/[\u0100-\u02FF\u0370-\u167F\u1681-\u180D\u180F-\u1DBF]/,/[\u1E00-\u1FFF]/,/[\u200B-\u200D\u202A-\u202E\u203F-\u2040\u2054\u2060-\u206F]/,/[\u2070-\u20CF\u2100-\u218F\u2460-\u24FF\u2776-\u2793]/,/[\u2C00-\u2DFF\u2E80-\u2FFF]/,/[\u3004-\u3007\u3021-\u302F\u3031-\u303F\u3040-\uD7FF]/,/[\uF900-\uFD3D\uFD40-\uFDCF\uFDF0-\uFE1F\uFE30-\uFE44]/,/[\uFE47-\uFEFE\uFF00-\uFFFD]/),sf=Br(ax,/\d/,/[\u0300-\u036F\u1DC0-\u1DFF\u20D0-\u20FF\uFE20-\uFE2F]/),aa=on(ax,sf,"*"),vh=on(/[A-Z]/,sf,"*"),ij=["attached","autoclosure",on(/convention\(/,Br("swift","block","c"),/\)/),"discardableResult","dynamicCallable","dynamicMemberLookup","escaping","freestanding","frozen","GKInspectable","IBAction","IBDesignable","IBInspectable","IBOutlet","IBSegueAction","inlinable","main","nonobjc","NSApplicationMain","NSCopying","NSManaged",on(/objc\(/,aa,/\)/),"objc","objcMembers","propertyWrapper","requires_stored_property_inits","resultBuilder","Sendable","testable","UIApplicationMain","unchecked","unknown","usableFromInline","warn_unqualified_access"],aj=["iOS","iOSApplicationExtension","macOS","macOSApplicationExtension","macCatalyst","macCatalystApplicationExtension","watchOS","watchOSApplicationExtension","tvOS","tvOSApplicationExtension","swift"];function sj(e){const t={match:/\s+/,relevance:0},n=e.COMMENT("/\\*","\\*/",{contains:["self"]}),r=[e.C_LINE_COMMENT_MODE,n],i={match:[/\./,Br(...ej,...ZE)],className:{2:"keyword"}},s={match:on(/\./,Br(...J1)),relevance:0},o=J1.filter(Xe=>typeof Xe=="string").concat(["_|0"]),c=J1.filter(Xe=>typeof Xe!="string").concat(tj).map(D2),d={variants:[{className:"keyword",match:Br(...c,...ZE)}]},f={$pattern:Br(/\b\w+/,/#\w+/),keyword:o.concat(rj),literal:JE},m=[i,s,d],p={match:on(/\./,Br(...e6)),relevance:0},v={className:"built_in",match:on(/\b/,Br(...e6),/(?=\()/)},_=[p,v],T={match:/->/,relevance:0},x={className:"operator",relevance:0,variants:[{match:eg},{match:`\\.(\\.|${ix})+`}]},k=[T,x],A="([0-9]_*)+",O="([0-9a-fA-F]_*)+",I={className:"number",relevance:0,variants:[{match:`\\b(${A})(\\.(${A}))?([eE][+-]?(${A}))?\\b`},{match:`\\b0x(${O})(\\.(${O}))?([pP][+-]?(${A}))?\\b`},{match:/\b0o([0-7]_*)+\b/},{match:/\b0b([01]_*)+\b/}]},$=(Xe="")=>({className:"subst",variants:[{match:on(/\\/,Xe,/[0\\tnr"']/)},{match:on(/\\/,Xe,/u\{[0-9a-fA-F]{1,8}\}/)}]}),V=(Xe="")=>({className:"subst",match:on(/\\/,Xe,/[\t ]*(?:[\r\n]|\r\n)/)}),B=(Xe="")=>({className:"subst",label:"interpol",begin:on(/\\/,Xe,/\(/),end:/\)/}),Z=(Xe="")=>({begin:on(Xe,/"""/),end:on(/"""/,Xe),contains:[$(Xe),V(Xe),B(Xe)]}),ee=(Xe="")=>({begin:on(Xe,/"/),end:on(/"/,Xe),contains:[$(Xe),B(Xe)]}),te={className:"string",variants:[Z(),Z("#"),Z("##"),Z("###"),ee(),ee("#"),ee("##"),ee("###")]},Y=[e.BACKSLASH_ESCAPE,{begin:/\[/,end:/\]/,relevance:0,contains:[e.BACKSLASH_ESCAPE]}],oe={begin:/\/[^\s](?=[^/\n]*\/)/,end:/\//,contains:Y},he=Xe=>{const jt=on(Xe,/\//),pn=on(/\//,Xe);return{begin:jt,end:pn,contains:[...Y,{scope:"comment",begin:`#(?!.*${pn})`,end:/$/}]}},Se={scope:"regexp",variants:[he("###"),he("##"),he("#"),oe]},fe={match:on(/`/,aa,/`/)},de={className:"variable",match:/\$\d+/},H={className:"variable",match:`\\$${sf}+`},ie=[fe,de,H],ve={match:/(@|#(un)?)available/,scope:"keyword",starts:{contains:[{begin:/\(/,end:/\)/,keywords:aj,contains:[...k,I,te]}]}},xe={scope:"keyword",match:on(/@/,Br(...ij),Ac(Br(/\(/,/\s+/)))},P={scope:"meta",match:on(/@/,aa)},z=[ve,xe,P],J={match:Ac(/\b[A-Z]/),relevance:0,contains:[{className:"type",match:on(/(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)/,sf,"+")},{className:"type",match:vh,relevance:0},{match:/[?!]+/,relevance:0},{match:/\.\.\./,relevance:0},{match:on(/\s+&\s+/,Ac(vh)),relevance:0}]},D={begin:/</,end:/>/,keywords:f,contains:[...r,...m,...z,T,J]};J.contains.push(D);const Ae={match:on(aa,/\s*:/),keywords:"_|0",relevance:0},Le={begin:/\(/,end:/\)/,relevance:0,keywords:f,contains:["self",Ae,...r,Se,...m,..._,...k,I,te,...ie,...z,J]},ze={begin:/</,end:/>/,keywords:"repeat each",contains:[...r,J]},at={begin:Br(Ac(on(aa,/\s*:/)),Ac(on(aa,/\s+/,aa,/\s*:/))),end:/:/,relevance:0,contains:[{className:"keyword",match:/\b_\b/},{className:"params",match:aa}]},_t={begin:/\(/,end:/\)/,keywords:f,contains:[at,...r,...m,...k,I,te,...z,J,Le],endsParent:!0,illegal:/["']/},pt={match:[/(func|macro)/,/\s+/,Br(fe.match,aa,eg)],className:{1:"keyword",3:"title.function"},contains:[ze,_t,t],illegal:[/\[/,/%/]},Tt={match:[/\b(?:subscript|init[?!]?)/,/\s*(?=[<(])/],className:{1:"keyword"},contains:[ze,_t,t],illegal:/\[|%/},kn={match:[/operator/,/\s+/,eg],className:{1:"keyword",3:"title"}},pr={begin:[/precedencegroup/,/\s+/,vh],className:{1:"keyword",3:"title"},contains:[J],keywords:[...nj,...JE],end:/}/},yt={match:[/class\b/,/\s+/,/func\b/,/\s+/,/\b[A-Za-z_][A-Za-z0-9_]*\b/],scope:{1:"keyword",3:"keyword",5:"title.function"}},ct={match:[/class\b/,/\s+/,/var\b/],scope:{1:"keyword",3:"keyword"}},Ft={begin:[/(struct|protocol|class|extension|enum|actor)/,/\s+/,aa,/\s*/],beginScope:{1:"keyword",3:"title.class"},keywords:f,contains:[ze,...m,{begin:/:/,end:/\{/,keywords:f,contains:[{scope:"title.class.inherited",match:vh},...m],relevance:0}]};for(const Xe of te.variants){const jt=Xe.contains.find(Pt=>Pt.label==="interpol");jt.keywords=f;const pn=[...m,..._,...k,I,te,...ie];jt.contains=[...pn,{begin:/\(/,end:/\)/,contains:["self",...pn]}]}return{name:"Swift",keywords:f,contains:[...r,pt,Tt,yt,ct,Ft,kn,pr,{beginKeywords:"import",end:/$/,contains:[...r],relevance:0},Se,...m,..._,...k,I,te,...ie,...z,J,Le]}}const lf="[A-Za-z$_][0-9A-Za-z$_]*",sx=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends","using"],lx=["true","false","null","undefined","NaN","Infinity"],ox=["Object","Function","Boolean","Symbol","Math","Date","Number","BigInt","String","RegExp","Array","Float32Array","Float64Array","Int8Array","Uint8Array","Uint8ClampedArray","Int16Array","Int32Array","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array","Set","Map","WeakSet","WeakMap","ArrayBuffer","SharedArrayBuffer","Atomics","DataView","JSON","Promise","Generator","GeneratorFunction","AsyncFunction","Reflect","Proxy","Intl","WebAssembly"],ux=["Error","EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],cx=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],dx=["arguments","this","super","console","window","document","localStorage","sessionStorage","module","global"],hx=[].concat(cx,ox,ux);function lj(e){const t=e.regex,n=(ve,{after:xe})=>{const P="</"+ve[0].slice(1);return ve.input.indexOf(P,xe)!==-1},r=lf,i={begin:"<>",end:"</>"},s=/<[A-Za-z0-9\\._:-]+\s*\/>/,o={begin:/<[A-Za-z0-9\\._:-]+/,end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(ve,xe)=>{const P=ve[0].length+ve.index,z=ve.input[P];if(z==="<"||z===","){xe.ignoreMatch();return}z===">"&&(n(ve,{after:P})||xe.ignoreMatch());let J;const D=ve.input.substring(P);if(J=D.match(/^\s*=/)){xe.ignoreMatch();return}if((J=D.match(/^\s+extends\s+/))&&J.index===0){xe.ignoreMatch();return}}},c={$pattern:lf,keyword:sx,literal:lx,built_in:hx,"variable.language":dx},d="[0-9](_?[0-9])*",f=`\\.(${d})`,m="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",p={className:"number",variants:[{begin:`(\\b(${m})((${f})|\\.)?|(${f}))[eE][+-]?(${d})\\b`},{begin:`\\b(${m})\\b((${f})\\b|\\.)?|(${f})\\b`},{begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{begin:"\\b0[0-7]+n?\\b"}],relevance:0},v={className:"subst",begin:"\\$\\{",end:"\\}",keywords:c,contains:[]},_={begin:".?html`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,v],subLanguage:"xml"}},T={begin:".?css`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,v],subLanguage:"css"}},x={begin:".?gql`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,v],subLanguage:"graphql"}},k={className:"string",begin:"`",end:"`",contains:[e.BACKSLASH_ESCAPE,v]},O={className:"comment",variants:[e.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{begin:"(?=@[A-Za-z]+)",relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"},{className:"type",begin:"\\{",end:"\\}",excludeEnd:!0,excludeBegin:!0,relevance:0},{className:"variable",begin:r+"(?=\\s*(-)|$)",endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]}),e.C_BLOCK_COMMENT_MODE,e.C_LINE_COMMENT_MODE]},I=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,_,T,x,k,{match:/\$\d+/},p];v.contains=I.concat({begin:/\{/,end:/\}/,keywords:c,contains:["self"].concat(I)});const $=[].concat(O,v.contains),V=$.concat([{begin:/(\s*)\(/,end:/\)/,keywords:c,contains:["self"].concat($)}]),B={className:"params",begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:c,contains:V},Z={variants:[{match:[/class/,/\s+/,r,/\s+/,/extends/,/\s+/,t.concat(r,"(",t.concat(/\./,r),")*")],scope:{1:"keyword",3:"title.class",5:"keyword",7:"title.class.inherited"}},{match:[/class/,/\s+/,r],scope:{1:"keyword",3:"title.class"}}]},ee={relevance:0,match:t.either(/\bJSON/,/\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,/\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,/\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/),className:"title.class",keywords:{_:[...ox,...ux]}},te={label:"use_strict",className:"meta",relevance:10,begin:/^\s*['"]use (strict|asm)['"]/},Y={variants:[{match:[/function/,/\s+/,r,/(?=\s*\()/]},{match:[/function/,/\s*(?=\()/]}],className:{1:"keyword",3:"title.function"},label:"func.def",contains:[B],illegal:/%/},oe={relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"};function he(ve){return t.concat("(?!",ve.join("|"),")")}const Se={match:t.concat(/\b/,he([...cx,"super","import"].map(ve=>`${ve}\\s*\\(`)),r,t.lookahead(/\s*\(/)),className:"title.function",relevance:0},fe={begin:t.concat(/\./,t.lookahead(t.concat(r,/(?![0-9A-Za-z$_(])/))),end:r,excludeBegin:!0,keywords:"prototype",className:"property",relevance:0},de={match:[/get|set/,/\s+/,r,/(?=\()/],className:{1:"keyword",3:"title.function"},contains:[{begin:/\(\)/},B]},H="(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+e.UNDERSCORE_IDENT_RE+")\\s*=>",ie={match:[/const|var|let/,/\s+/,r,/\s*/,/=\s*/,/(async\s*)?/,t.lookahead(H)],keywords:"async",className:{1:"keyword",3:"title.function"},contains:[B]};return{name:"JavaScript",aliases:["js","jsx","mjs","cjs"],keywords:c,exports:{PARAMS_CONTAINS:V,CLASS_REFERENCE:ee},illegal:/#(?![$_A-z])/,contains:[e.SHEBANG({label:"shebang",binary:"node",relevance:5}),te,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,_,T,x,k,O,{match:/\$\d+/},p,ee,{scope:"attr",match:r+t.lookahead(":"),relevance:0},ie,{begin:"("+e.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",keywords:"return throw case",relevance:0,contains:[O,e.REGEXP_MODE,{className:"function",begin:H,returnBegin:!0,end:"\\s*=>",contains:[{className:"params",variants:[{begin:e.UNDERSCORE_IDENT_RE,relevance:0},{className:null,begin:/\(\s*\)/,skip:!0},{begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:c,contains:V}]}]},{begin:/,/,relevance:0},{match:/\s+/,relevance:0},{variants:[{begin:i.begin,end:i.end},{match:s},{begin:o.begin,"on:begin":o.isTrulyOpeningTag,end:o.end}],subLanguage:"xml",contains:[{begin:o.begin,end:o.end,skip:!0,contains:["self"]}]}]},Y,{beginKeywords:"while if switch catch for"},{begin:"\\b(?!function)"+e.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",returnBegin:!0,label:"func.def",contains:[B,e.inherit(e.TITLE_MODE,{begin:r,className:"title.function"})]},{match:/\.\.\./,relevance:0},fe,{match:"\\$"+r,relevance:0},{match:[/\bconstructor(?=\s*\()/],className:{1:"title.function"},contains:[B]},Se,oe,Z,de,{match:/\$[(.]/}]}}function oj(e){const t=e.regex,n=lj(e),r=lf,i=["any","void","number","boolean","string","object","never","symbol","bigint","unknown"],s={begin:[/namespace/,/\s+/,e.IDENT_RE],beginScope:{1:"keyword",3:"title.class"}},o={beginKeywords:"interface",end:/\{/,excludeEnd:!0,keywords:{keyword:"interface extends",built_in:i},contains:[n.exports.CLASS_REFERENCE]},c={className:"meta",relevance:10,begin:/^\s*['"]use strict['"]/},d=["type","interface","public","private","protected","implements","declare","abstract","readonly","enum","override","satisfies"],f={$pattern:lf,keyword:sx.concat(d),literal:lx,built_in:hx.concat(i),"variable.language":dx},m={className:"meta",begin:"@"+r},p=(x,k,A)=>{const O=x.contains.findIndex(I=>I.label===k);if(O===-1)throw new Error("can not find mode to replace");x.contains.splice(O,1,A)};Object.assign(n.keywords,f),n.exports.PARAMS_CONTAINS.push(m);const v=n.contains.find(x=>x.scope==="attr"),_=Object.assign({},v,{match:t.concat(r,t.lookahead(/\s*\?:/))});n.exports.PARAMS_CONTAINS.push([n.exports.CLASS_REFERENCE,v,_]),n.contains=n.contains.concat([m,s,o,_]),p(n,"shebang",e.SHEBANG()),p(n,"use_strict",c);const T=n.contains.find(x=>x.label==="func.def");return T.relevance=0,Object.assign(n,{name:"TypeScript",aliases:["ts","tsx","mts","cts"]}),n}function uj(e){const t=e.regex,n={className:"string",begin:/"(""|[^/n])"C\b/},r={className:"string",begin:/"/,end:/"/,illegal:/\n/,contains:[{begin:/""/}]},i=/\d{1,2}\/\d{1,2}\/\d{4}/,s=/\d{4}-\d{1,2}-\d{1,2}/,o=/(\d|1[012])(:\d+){0,2} *(AM|PM)/,c=/\d{1,2}(:\d{1,2}){1,2}/,d={className:"literal",variants:[{begin:t.concat(/# */,t.either(s,i),/ *#/)},{begin:t.concat(/# */,c,/ *#/)},{begin:t.concat(/# */,o,/ *#/)},{begin:t.concat(/# */,t.either(s,i),/ +/,t.either(o,c),/ *#/)}]},f={className:"number",relevance:0,variants:[{begin:/\b\d[\d_]*((\.[\d_]+(E[+-]?[\d_]+)?)|(E[+-]?[\d_]+))[RFD@!#]?/},{begin:/\b\d[\d_]*((U?[SIL])|[%&])?/},{begin:/&H[\dA-F_]+((U?[SIL])|[%&])?/},{begin:/&O[0-7_]+((U?[SIL])|[%&])?/},{begin:/&B[01_]+((U?[SIL])|[%&])?/}]},m={className:"label",begin:/^\w+:/},p=e.COMMENT(/'''/,/$/,{contains:[{className:"doctag",begin:/<\/?/,end:/>/}]}),v=e.COMMENT(null,/$/,{variants:[{begin:/'/},{begin:/([\t ]|^)REM(?=\s)/}]});return{name:"Visual Basic .NET",aliases:["vb"],case_insensitive:!0,classNameAliases:{label:"symbol"},keywords:{keyword:"addhandler alias aggregate ansi as async assembly auto binary by byref byval call case catch class compare const continue custom declare default delegate dim distinct do each equals else elseif end enum erase error event exit explicit finally for friend from function get global goto group handles if implements imports in inherits interface into iterator join key let lib loop me mid module mustinherit mustoverride mybase myclass namespace narrowing new next notinheritable notoverridable of off on operator option optional order overloads overridable overrides paramarray partial preserve private property protected public raiseevent readonly redim removehandler resume return select set shadows shared skip static step stop structure strict sub synclock take text then throw to try unicode until using when where while widening with withevents writeonly yield",built_in:"addressof and andalso await directcast gettype getxmlnamespace is isfalse isnot istrue like mod nameof new not or orelse trycast typeof xor cbool cbyte cchar cdate cdbl cdec cint clng cobj csbyte cshort csng cstr cuint culng cushort",type:"boolean byte char date decimal double integer long object sbyte short single string uinteger ulong ushort",literal:"true false nothing"},illegal:"//|\\{|\\}|endif|gosub|variant|wend|^\\$ ",contains:[n,r,d,f,m,p,v,{className:"meta",begin:/[\t ]*#(const|disable|else|elseif|enable|end|externalsource|if|region)\b/,end:/$/,keywords:{keyword:"const disable else elseif enable end externalsource if region then"},contains:[v]}]}}function cj(e){e.regex;const t=e.COMMENT(/\(;/,/;\)/);t.contains.push("self");const n=e.COMMENT(/;;/,/$/),r=["anyfunc","block","br","br_if","br_table","call","call_indirect","data","drop","elem","else","end","export","func","global.get","global.set","local.get","local.set","local.tee","get_global","get_local","global","if","import","local","loop","memory","memory.grow","memory.size","module","mut","nop","offset","param","result","return","select","set_global","set_local","start","table","tee_local","then","type","unreachable"],i={begin:[/(?:func|call|call_indirect)/,/\s+/,/\$[^\s)]+/],className:{1:"keyword",3:"title.function"}},s={className:"variable",begin:/\$[\w_]+/},o={match:/(\((?!;)|\))+/,className:"punctuation",relevance:0},c={className:"number",relevance:0,match:/[+-]?\b(?:\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:[eE][+-]?\d(?:_?\d)*)?|0x[\da-fA-F](?:_?[\da-fA-F])*(?:\.[\da-fA-F](?:_?[\da-fA-D])*)?(?:[pP][+-]?\d(?:_?\d)*)?)\b|\binf\b|\bnan(?::0x[\da-fA-F](?:_?[\da-fA-D])*)?\b/},d={match:/(i32|i64|f32|f64)(?!\.)/,className:"type"},f={className:"keyword",match:/\b(f32|f64|i32|i64)(?:\.(?:abs|add|and|ceil|clz|const|convert_[su]\/i(?:32|64)|copysign|ctz|demote\/f64|div(?:_[su])?|eqz?|extend_[su]\/i32|floor|ge(?:_[su])?|gt(?:_[su])?|le(?:_[su])?|load(?:(?:8|16|32)_[su])?|lt(?:_[su])?|max|min|mul|nearest|neg?|or|popcnt|promote\/f32|reinterpret\/[fi](?:32|64)|rem_[su]|rot[lr]|shl|shr_[su]|store(?:8|16|32)?|sqrt|sub|trunc(?:_[su]\/f(?:32|64))?|wrap\/i64|xor))\b/};return{name:"WebAssembly",keywords:{$pattern:/[\w.]+/,keyword:r},contains:[n,t,{match:[/(?:offset|align)/,/\s*/,/=/],className:{1:"keyword",3:"operator"}},s,o,i,e.QUOTE_STRING_MODE,d,f,c]}}function dj(e){const t=e.regex,n=t.concat(/[\p{L}_]/u,t.optional(/[\p{L}0-9_.-]*:/u),/[\p{L}0-9_.-]*/u),r=/[\p{L}0-9._:-]+/u,i={className:"symbol",begin:/&[a-z]+;|&#[0-9]+;|&#x[a-f0-9]+;/},s={begin:/\s/,contains:[{className:"keyword",begin:/#?[a-z_][a-z1-9_-]+/,illegal:/\n/}]},o=e.inherit(s,{begin:/\(/,end:/\)/}),c=e.inherit(e.APOS_STRING_MODE,{className:"string"}),d=e.inherit(e.QUOTE_STRING_MODE,{className:"string"}),f={endsWithParent:!0,illegal:/</,relevance:0,contains:[{className:"attr",begin:r,relevance:0},{begin:/=\s*/,relevance:0,contains:[{className:"string",endsParent:!0,variants:[{begin:/"/,end:/"/,contains:[i]},{begin:/'/,end:/'/,contains:[i]},{begin:/[^\s"'=<>`]+/}]}]}]};return{name:"HTML, XML",aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist","wsf","svg"],case_insensitive:!0,unicodeRegex:!0,contains:[{className:"meta",begin:/<![a-z]/,end:/>/,relevance:10,contains:[s,d,c,o,{begin:/\[/,end:/\]/,contains:[{className:"meta",begin:/<![a-z]/,end:/>/,contains:[s,o,d,c]}]}]},e.COMMENT(/<!--/,/-->/,{relevance:10}),{begin:/<!\[CDATA\[/,end:/\]\]>/,relevance:10},i,{className:"meta",end:/\?>/,variants:[{begin:/<\?xml/,relevance:10,contains:[d]},{begin:/<\?[a-z][a-z0-9]+/}]},{className:"tag",begin:/<style(?=\s|>)/,end:/>/,keywords:{name:"style"},contains:[f],starts:{end:/<\/style>/,returnEnd:!0,subLanguage:["css","xml"]}},{className:"tag",begin:/<script(?=\s|>)/,end:/>/,keywords:{name:"script"},contains:[f],starts:{end:/<\/script>/,returnEnd:!0,subLanguage:["javascript","handlebars","xml"]}},{className:"tag",begin:/<>|<\/>/},{className:"tag",begin:t.concat(/</,t.lookahead(t.concat(n,t.either(/\/>/,/>/,/\s/)))),end:/\/?>/,contains:[{className:"name",begin:n,relevance:0,starts:f}]},{className:"tag",begin:t.concat(/<\//,t.lookahead(t.concat(n,/>/))),contains:[{className:"name",begin:n,relevance:0},{begin:/>/,relevance:0,endsParent:!0}]}]}}function hj(e){const t="true false yes no null",n="[\\w#;/?:@&=+$,.~*'()[\\]]+",r={className:"attr",variants:[{begin:/[\w*@][\w*@ :()\./-]*:(?=[ \t]|$)/},{begin:/"[\w*@][\w*@ :()\./-]*":(?=[ \t]|$)/},{begin:/'[\w*@][\w*@ :()\./-]*':(?=[ \t]|$)/}]},i={className:"template-variable",variants:[{begin:/\{\{/,end:/\}\}/},{begin:/%\{/,end:/\}/}]},s={className:"string",relevance:0,begin:/'/,end:/'/,contains:[{match:/''/,scope:"char.escape",relevance:0}]},o={className:"string",relevance:0,variants:[{begin:/"/,end:/"/},{begin:/\S+/}],contains:[e.BACKSLASH_ESCAPE,i]},c=e.inherit(o,{variants:[{begin:/'/,end:/'/,contains:[{begin:/''/,relevance:0}]},{begin:/"/,end:/"/},{begin:/[^\s,{}[\]]+/}]}),v={className:"number",begin:"\\b"+"[0-9]{4}(-[0-9][0-9]){0,2}"+"([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?"+"(\\.[0-9]*)?"+"([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?"+"\\b"},_={end:",",endsWithParent:!0,excludeEnd:!0,keywords:t,relevance:0},T={begin:/\{/,end:/\}/,contains:[_],illegal:"\\n",relevance:0},x={begin:"\\[",end:"\\]",contains:[_],illegal:"\\n",relevance:0},k=[r,{className:"meta",begin:"^---\\s*$",relevance:10},{className:"string",begin:"[\\|>]([1-9]?[+-])?[ ]*\\n( +)[^ ][^\\n]*\\n(\\2[^\\n]+\\n?)*"},{begin:"<%[%=-]?",end:"[%-]?%>",subLanguage:"ruby",excludeBegin:!0,excludeEnd:!0,relevance:0},{className:"type",begin:"!\\w+!"+n},{className:"type",begin:"!<"+n+">"},{className:"type",begin:"!"+n},{className:"type",begin:"!!"+n},{className:"meta",begin:"&"+e.UNDERSCORE_IDENT_RE+"$"},{className:"meta",begin:"\\*"+e.UNDERSCORE_IDENT_RE+"$"},{className:"bullet",begin:"-(?=[ ]|$)",relevance:0},e.HASH_COMMENT_MODE,{beginKeywords:t,keywords:{literal:t}},v,{className:"number",begin:e.C_NUMBER_RE+"\\b",relevance:0},T,x,s,o],A=[...k];return A.pop(),A.push(c),_.contains=A,{name:"YAML",case_insensitive:!0,aliases:["yml"],contains:k}}const fj={arduino:KF,bash:WF,c:XF,cpp:QF,csharp:ZF,css:lH,diff:oH,go:uH,graphql:cH,ini:dH,java:hH,javascript:bH,json:vH,kotlin:yH,less:CH,lua:NH,makefile:OH,markdown:RH,objectivec:MH,perl:IH,php:DH,"php-template":LH,plaintext:PH,python:BH,"python-repl":UH,r:zH,ruby:FH,rust:HH,scss:XH,shell:QH,sql:ZH,swift:sj,typescript:oj,vbnet:uj,wasm:cj,xml:dj,yaml:hj};var tg,t6;function mj(){if(t6)return tg;t6=1;function e(W){return W instanceof Map?W.clear=W.delete=W.set=function(){throw new Error("map is read-only")}:W instanceof Set&&(W.add=W.clear=W.delete=function(){throw new Error("set is read-only")}),Object.freeze(W),Object.getOwnPropertyNames(W).forEach(ye=>{const Fe=W[ye],mt=typeof Fe;(mt==="object"||mt==="function")&&!Object.isFrozen(Fe)&&e(Fe)}),W}class t{constructor(ye){ye.data===void 0&&(ye.data={}),this.data=ye.data,this.isMatchIgnored=!1}ignoreMatch(){this.isMatchIgnored=!0}}function n(W){return W.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&#x27;")}function r(W,...ye){const Fe=Object.create(null);for(const mt in W)Fe[mt]=W[mt];return ye.forEach(function(mt){for(const Tn in mt)Fe[Tn]=mt[Tn]}),Fe}const i="</span>",s=W=>!!W.scope,o=(W,{prefix:ye})=>{if(W.startsWith("language:"))return W.replace("language:","language-");if(W.includes(".")){const Fe=W.split(".");return[`${ye}${Fe.shift()}`,...Fe.map((mt,Tn)=>`${mt}${"_".repeat(Tn+1)}`)].join(" ")}return`${ye}${W}`};class c{constructor(ye,Fe){this.buffer="",this.classPrefix=Fe.classPrefix,ye.walk(this)}addText(ye){this.buffer+=n(ye)}openNode(ye){if(!s(ye))return;const Fe=o(ye.scope,{prefix:this.classPrefix});this.span(Fe)}closeNode(ye){s(ye)&&(this.buffer+=i)}value(){return this.buffer}span(ye){this.buffer+=`<span class="${ye}">`}}const d=(W={})=>{const ye={children:[]};return Object.assign(ye,W),ye};class f{constructor(){this.rootNode=d(),this.stack=[this.rootNode]}get top(){return this.stack[this.stack.length-1]}get root(){return this.rootNode}add(ye){this.top.children.push(ye)}openNode(ye){const Fe=d({scope:ye});this.add(Fe),this.stack.push(Fe)}closeNode(){if(this.stack.length>1)return this.stack.pop()}closeAllNodes(){for(;this.closeNode(););}toJSON(){return JSON.stringify(this.rootNode,null,4)}walk(ye){return this.constructor._walk(ye,this.rootNode)}static _walk(ye,Fe){return typeof Fe=="string"?ye.addText(Fe):Fe.children&&(ye.openNode(Fe),Fe.children.forEach(mt=>this._walk(ye,mt)),ye.closeNode(Fe)),ye}static _collapse(ye){typeof ye!="string"&&ye.children&&(ye.children.every(Fe=>typeof Fe=="string")?ye.children=[ye.children.join("")]:ye.children.forEach(Fe=>{f._collapse(Fe)}))}}class m extends f{constructor(ye){super(),this.options=ye}addText(ye){ye!==""&&this.add(ye)}startScope(ye){this.openNode(ye)}endScope(){this.closeNode()}__addSublanguage(ye,Fe){const mt=ye.root;Fe&&(mt.scope=`language:${Fe}`),this.add(mt)}toHTML(){return new c(this,this.options).value()}finalize(){return this.closeAllNodes(),!0}}function p(W){return W?typeof W=="string"?W:W.source:null}function v(W){return x("(?=",W,")")}function _(W){return x("(?:",W,")*")}function T(W){return x("(?:",W,")?")}function x(...W){return W.map(Fe=>p(Fe)).join("")}function k(W){const ye=W[W.length-1];return typeof ye=="object"&&ye.constructor===Object?(W.splice(W.length-1,1),ye):{}}function A(...W){return"("+(k(W).capture?"":"?:")+W.map(mt=>p(mt)).join("|")+")"}function O(W){return new RegExp(W.toString()+"|").exec("").length-1}function I(W,ye){const Fe=W&&W.exec(ye);return Fe&&Fe.index===0}const $=/\[(?:[^\\\]]|\\.)*\]|\(\??|\\([1-9][0-9]*)|\\./;function V(W,{joinWith:ye}){let Fe=0;return W.map(mt=>{Fe+=1;const Tn=Fe;let cn=p(mt),Ze="";for(;cn.length>0;){const We=$.exec(cn);if(!We){Ze+=cn;break}Ze+=cn.substring(0,We.index),cn=cn.substring(We.index+We[0].length),We[0][0]==="\\"&&We[1]?Ze+="\\"+String(Number(We[1])+Tn):(Ze+=We[0],We[0]==="("&&Fe++)}return Ze}).map(mt=>`(${mt})`).join(ye)}const B=/\b\B/,Z="[a-zA-Z]\\w*",ee="[a-zA-Z_]\\w*",te="\\b\\d+(\\.\\d+)?",Y="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",oe="\\b(0b[01]+)",he="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",Se=(W={})=>{const ye=/^#![ ]*\//;return W.binary&&(W.begin=x(ye,/.*\b/,W.binary,/\b.*/)),r({scope:"meta",begin:ye,end:/$/,relevance:0,"on:begin":(Fe,mt)=>{Fe.index!==0&&mt.ignoreMatch()}},W)},fe={begin:"\\\\[\\s\\S]",relevance:0},de={scope:"string",begin:"'",end:"'",illegal:"\\n",contains:[fe]},H={scope:"string",begin:'"',end:'"',illegal:"\\n",contains:[fe]},ie={begin:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},ve=function(W,ye,Fe={}){const mt=r({scope:"comment",begin:W,end:ye,contains:[]},Fe);mt.contains.push({scope:"doctag",begin:"[ ]*(?=(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):)",end:/(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):/,excludeBegin:!0,relevance:0});const Tn=A("I","a","is","so","us","to","at","if","in","it","on",/[A-Za-z]+['](d|ve|re|ll|t|s|n)/,/[A-Za-z]+[-][a-z]+/,/[A-Za-z][a-z]{2,}/);return mt.contains.push({begin:x(/[ ]+/,"(",Tn,/[.]?[:]?([.][ ]|[ ])/,"){3}")}),mt},xe=ve("//","$"),P=ve("/\\*","\\*/"),z=ve("#","$"),J={scope:"number",begin:te,relevance:0},D={scope:"number",begin:Y,relevance:0},Ae={scope:"number",begin:oe,relevance:0},Le={scope:"regexp",begin:/\/(?=[^/\n]*\/)/,end:/\/[gimuy]*/,contains:[fe,{begin:/\[/,end:/\]/,relevance:0,contains:[fe]}]},ze={scope:"title",begin:Z,relevance:0},at={scope:"title",begin:ee,relevance:0},_t={begin:"\\.\\s*"+ee,relevance:0};var Tt=Object.freeze({__proto__:null,APOS_STRING_MODE:de,BACKSLASH_ESCAPE:fe,BINARY_NUMBER_MODE:Ae,BINARY_NUMBER_RE:oe,COMMENT:ve,C_BLOCK_COMMENT_MODE:P,C_LINE_COMMENT_MODE:xe,C_NUMBER_MODE:D,C_NUMBER_RE:Y,END_SAME_AS_BEGIN:function(W){return Object.assign(W,{"on:begin":(ye,Fe)=>{Fe.data._beginMatch=ye[1]},"on:end":(ye,Fe)=>{Fe.data._beginMatch!==ye[1]&&Fe.ignoreMatch()}})},HASH_COMMENT_MODE:z,IDENT_RE:Z,MATCH_NOTHING_RE:B,METHOD_GUARD:_t,NUMBER_MODE:J,NUMBER_RE:te,PHRASAL_WORDS_MODE:ie,QUOTE_STRING_MODE:H,REGEXP_MODE:Le,RE_STARTERS_RE:he,SHEBANG:Se,TITLE_MODE:ze,UNDERSCORE_IDENT_RE:ee,UNDERSCORE_TITLE_MODE:at});function kn(W,ye){W.input[W.index-1]==="."&&ye.ignoreMatch()}function pr(W,ye){W.className!==void 0&&(W.scope=W.className,delete W.className)}function yt(W,ye){ye&&W.beginKeywords&&(W.begin="\\b("+W.beginKeywords.split(" ").join("|")+")(?!\\.)(?=\\b|\\s)",W.__beforeBegin=kn,W.keywords=W.keywords||W.beginKeywords,delete W.beginKeywords,W.relevance===void 0&&(W.relevance=0))}function ct(W,ye){Array.isArray(W.illegal)&&(W.illegal=A(...W.illegal))}function Ft(W,ye){if(W.match){if(W.begin||W.end)throw new Error("begin & end are not supported with match");W.begin=W.match,delete W.match}}function Xe(W,ye){W.relevance===void 0&&(W.relevance=1)}const jt=(W,ye)=>{if(!W.beforeMatch)return;if(W.starts)throw new Error("beforeMatch cannot be used with starts");const Fe=Object.assign({},W);Object.keys(W).forEach(mt=>{delete W[mt]}),W.keywords=Fe.keywords,W.begin=x(Fe.beforeMatch,v(Fe.begin)),W.starts={relevance:0,contains:[Object.assign(Fe,{endsParent:!0})]},W.relevance=0,delete Fe.beforeMatch},pn=["of","and","for","in","not","or","if","then","parent","list","value"],Pt="keyword";function un(W,ye,Fe=Pt){const mt=Object.create(null);return typeof W=="string"?Tn(Fe,W.split(" ")):Array.isArray(W)?Tn(Fe,W):Object.keys(W).forEach(function(cn){Object.assign(mt,un(W[cn],ye,cn))}),mt;function Tn(cn,Ze){ye&&(Ze=Ze.map(We=>We.toLowerCase())),Ze.forEach(function(We){const ht=We.split("|");mt[ht[0]]=[cn,Ge(ht[0],ht[1])]})}}function Ge(W,ye){return ye?Number(ye):gn(W)?0:1}function gn(W){return pn.includes(W.toLowerCase())}const In={},Xt=W=>{console.error(W)},En=(W,...ye)=>{console.log(`WARN: ${W}`,...ye)},me=(W,ye)=>{In[`${W}/${ye}`]||(console.log(`Deprecated as of ${W}. ${ye}`),In[`${W}/${ye}`]=!0)},Ce=new Error;function Ye(W,ye,{key:Fe}){let mt=0;const Tn=W[Fe],cn={},Ze={};for(let We=1;We<=ye.length;We++)Ze[We+mt]=Tn[We],cn[We+mt]=!0,mt+=O(ye[We-1]);W[Fe]=Ze,W[Fe]._emit=cn,W[Fe]._multi=!0}function dt(W){if(Array.isArray(W.begin)){if(W.skip||W.excludeBegin||W.returnBegin)throw Xt("skip, excludeBegin, returnBegin not compatible with beginScope: {}"),Ce;if(typeof W.beginScope!="object"||W.beginScope===null)throw Xt("beginScope must be object"),Ce;Ye(W,W.begin,{key:"beginScope"}),W.begin=V(W.begin,{joinWith:""})}}function Ue(W){if(Array.isArray(W.end)){if(W.skip||W.excludeEnd||W.returnEnd)throw Xt("skip, excludeEnd, returnEnd not compatible with endScope: {}"),Ce;if(typeof W.endScope!="object"||W.endScope===null)throw Xt("endScope must be object"),Ce;Ye(W,W.end,{key:"endScope"}),W.end=V(W.end,{joinWith:""})}}function bt(W){W.scope&&typeof W.scope=="object"&&W.scope!==null&&(W.beginScope=W.scope,delete W.scope)}function Re(W){bt(W),typeof W.beginScope=="string"&&(W.beginScope={_wrap:W.beginScope}),typeof W.endScope=="string"&&(W.endScope={_wrap:W.endScope}),dt(W),Ue(W)}function Rt(W){function ye(Ze,We){return new RegExp(p(Ze),"m"+(W.case_insensitive?"i":"")+(W.unicodeRegex?"u":"")+(We?"g":""))}class Fe{constructor(){this.matchIndexes={},this.regexes=[],this.matchAt=1,this.position=0}addRule(We,ht){ht.position=this.position++,this.matchIndexes[this.matchAt]=ht,this.regexes.push([ht,We]),this.matchAt+=O(We)+1}compile(){this.regexes.length===0&&(this.exec=()=>null);const We=this.regexes.map(ht=>ht[1]);this.matcherRe=ye(V(We,{joinWith:"|"}),!0),this.lastIndex=0}exec(We){this.matcherRe.lastIndex=this.lastIndex;const ht=this.matcherRe.exec(We);if(!ht)return null;const jn=ht.findIndex((ya,to)=>to>0&&ya!==void 0),Cn=this.matchIndexes[jn];return ht.splice(0,jn),Object.assign(ht,Cn)}}class mt{constructor(){this.rules=[],this.multiRegexes=[],this.count=0,this.lastIndex=0,this.regexIndex=0}getMatcher(We){if(this.multiRegexes[We])return this.multiRegexes[We];const ht=new Fe;return this.rules.slice(We).forEach(([jn,Cn])=>ht.addRule(jn,Cn)),ht.compile(),this.multiRegexes[We]=ht,ht}resumingScanAtSamePosition(){return this.regexIndex!==0}considerAll(){this.regexIndex=0}addRule(We,ht){this.rules.push([We,ht]),ht.type==="begin"&&this.count++}exec(We){const ht=this.getMatcher(this.regexIndex);ht.lastIndex=this.lastIndex;let jn=ht.exec(We);if(this.resumingScanAtSamePosition()&&!(jn&&jn.index===this.lastIndex)){const Cn=this.getMatcher(0);Cn.lastIndex=this.lastIndex+1,jn=Cn.exec(We)}return jn&&(this.regexIndex+=jn.position+1,this.regexIndex===this.count&&this.considerAll()),jn}}function Tn(Ze){const We=new mt;return Ze.contains.forEach(ht=>We.addRule(ht.begin,{rule:ht,type:"begin"})),Ze.terminatorEnd&&We.addRule(Ze.terminatorEnd,{type:"end"}),Ze.illegal&&We.addRule(Ze.illegal,{type:"illegal"}),We}function cn(Ze,We){const ht=Ze;if(Ze.isCompiled)return ht;[pr,Ft,Re,jt].forEach(Cn=>Cn(Ze,We)),W.compilerExtensions.forEach(Cn=>Cn(Ze,We)),Ze.__beforeBegin=null,[yt,ct,Xe].forEach(Cn=>Cn(Ze,We)),Ze.isCompiled=!0;let jn=null;return typeof Ze.keywords=="object"&&Ze.keywords.$pattern&&(Ze.keywords=Object.assign({},Ze.keywords),jn=Ze.keywords.$pattern,delete Ze.keywords.$pattern),jn=jn||/\w+/,Ze.keywords&&(Ze.keywords=un(Ze.keywords,W.case_insensitive)),ht.keywordPatternRe=ye(jn,!0),We&&(Ze.begin||(Ze.begin=/\B|\b/),ht.beginRe=ye(ht.begin),!Ze.end&&!Ze.endsWithParent&&(Ze.end=/\B|\b/),Ze.end&&(ht.endRe=ye(ht.end)),ht.terminatorEnd=p(ht.end)||"",Ze.endsWithParent&&We.terminatorEnd&&(ht.terminatorEnd+=(Ze.end?"|":"")+We.terminatorEnd)),Ze.illegal&&(ht.illegalRe=ye(Ze.illegal)),Ze.contains||(Ze.contains=[]),Ze.contains=[].concat(...Ze.contains.map(function(Cn){return kt(Cn==="self"?Ze:Cn)})),Ze.contains.forEach(function(Cn){cn(Cn,ht)}),Ze.starts&&cn(Ze.starts,We),ht.matcher=Tn(ht),ht}if(W.compilerExtensions||(W.compilerExtensions=[]),W.contains&&W.contains.includes("self"))throw new Error("ERR: contains `self` is not supported at the top-level of a language.  See documentation.");return W.classNameAliases=r(W.classNameAliases||{}),cn(W)}function At(W){return W?W.endsWithParent||At(W.starts):!1}function kt(W){return W.variants&&!W.cachedVariants&&(W.cachedVariants=W.variants.map(function(ye){return r(W,{variants:null},ye)})),W.cachedVariants?W.cachedVariants:At(W)?r(W,{starts:W.starts?r(W.starts):null}):Object.isFrozen(W)?r(W):W}var Zt="11.11.1";class Zi extends Error{constructor(ye,Fe){super(ye),this.name="HTMLInjectionError",this.html=Fe}}const Mr=n,H0=r,dl=Symbol("nomatch"),eo=7,hl=function(W){const ye=Object.create(null),Fe=Object.create(null),mt=[];let Tn=!0;const cn="Could not find the language '{}', did you forget to load/include a language module?",Ze={disableAutodetect:!0,name:"Plain text",contains:[]};let We={ignoreUnescapedHTML:!1,throwUnescapedHTML:!1,noHighlightRe:/^(no-?highlight)$/i,languageDetectRe:/\blang(?:uage)?-([\w-]+)\b/i,classPrefix:"hljs-",cssSelector:"pre code",languages:null,__emitter:m};function ht(Me){return We.noHighlightRe.test(Me)}function jn(Me){let nt=Me.className+" ";nt+=Me.parentNode?Me.parentNode.className:"";const Ct=We.languageDetectRe.exec(nt);if(Ct){const Jt=Ir(Ct[1]);return Jt||(En(cn.replace("{}",Ct[1])),En("Falling back to no-highlight mode for this block.",Me)),Jt?Ct[1]:"no-highlight"}return nt.split(/\s+/).find(Jt=>ht(Jt)||Ir(Jt))}function Cn(Me,nt,Ct){let Jt="",$n="";typeof nt=="object"?(Jt=Me,Ct=nt.ignoreIllegals,$n=nt.language):(me("10.7.0","highlight(lang, code, ...args) has been deprecated."),me("10.7.0",`Please use highlight(code, options) instead.
https://github.com/highlightjs/highlight.js/issues/2277`),$n=Me,Jt=nt),Ct===void 0&&(Ct=!0);const wr={code:Jt,language:$n};ml("before:highlight",wr);const oi=wr.result?wr.result:ya(wr.language,wr.code,Ct);return oi.code=wr.code,ml("after:highlight",oi),oi}function ya(Me,nt,Ct,Jt){const $n=Object.create(null);function wr(Pe,Je){return Pe.keywords[Je]}function oi(){if(!ut.keywords){Qn.addText(en);return}let Pe=0;ut.keywordPatternRe.lastIndex=0;let Je=ut.keywordPatternRe.exec(en),vt="";for(;Je;){vt+=en.substring(Pe,Je.index);const Bt=gr.case_insensitive?Je[0].toLowerCase():Je[0],Dn=wr(ut,Bt);if(Dn){const[wi,Nu]=Dn;if(Qn.addText(vt),vt="",$n[Bt]=($n[Bt]||0)+1,$n[Bt]<=eo&&(gs+=Nu),wi.startsWith("_"))vt+=Je[0];else{const K0=gr.classNameAliases[wi]||wi;ui(Je[0],K0)}}else vt+=Je[0];Pe=ut.keywordPatternRe.lastIndex,Je=ut.keywordPatternRe.exec(en)}vt+=en.substring(Pe),Qn.addText(vt)}function Gr(){if(en==="")return;let Pe=null;if(typeof ut.subLanguage=="string"){if(!ye[ut.subLanguage]){Qn.addText(en);return}Pe=ya(ut.subLanguage,en,!0,V0[ut.subLanguage]),V0[ut.subLanguage]=Pe._top}else Pe=no(en,ut.subLanguage.length?ut.subLanguage:null);ut.relevance>0&&(gs+=Pe.relevance),Qn.__addSublanguage(Pe._emitter,Pe.language)}function bn(){ut.subLanguage!=null?Gr():oi(),en=""}function ui(Pe,Je){Pe!==""&&(Qn.startScope(Je),Qn.addText(Pe),Qn.endScope())}function G0(Pe,Je){let vt=1;const Bt=Je.length-1;for(;vt<=Bt;){if(!Pe._emit[vt]){vt++;continue}const Dn=gr.classNameAliases[Pe[vt]]||Pe[vt],wi=Je[vt];Dn?ui(wi,Dn):(en=wi,oi(),en=""),vt++}}function io(Pe,Je){return Pe.scope&&typeof Pe.scope=="string"&&Qn.openNode(gr.classNameAliases[Pe.scope]||Pe.scope),Pe.beginScope&&(Pe.beginScope._wrap?(ui(en,gr.classNameAliases[Pe.beginScope._wrap]||Pe.beginScope._wrap),en=""):Pe.beginScope._multi&&(G0(Pe.beginScope,Je),en="")),ut=Object.create(Pe,{parent:{value:ut}}),ut}function Au(Pe,Je,vt){let Bt=I(Pe.endRe,vt);if(Bt){if(Pe["on:end"]){const Dn=new t(Pe);Pe["on:end"](Je,Dn),Dn.isMatchIgnored&&(Bt=!1)}if(Bt){for(;Pe.endsParent&&Pe.parent;)Pe=Pe.parent;return Pe}}if(Pe.endsWithParent)return Au(Pe.parent,Je,vt)}function ao(Pe){return ut.matcher.regexIndex===0?(en+=Pe[0],1):(bs=!0,0)}function om(Pe){const Je=Pe[0],vt=Pe.rule,Bt=new t(vt),Dn=[vt.__beforeBegin,vt["on:begin"]];for(const wi of Dn)if(wi&&(wi(Pe,Bt),Bt.isMatchIgnored))return ao(Je);return vt.skip?en+=Je:(vt.excludeBegin&&(en+=Je),bn(),!vt.returnBegin&&!vt.excludeBegin&&(en=Je)),io(vt,Pe),vt.returnBegin?0:Je.length}function Yr(Pe){const Je=Pe[0],vt=nt.substring(Pe.index),Bt=Au(ut,Pe,vt);if(!Bt)return dl;const Dn=ut;ut.endScope&&ut.endScope._wrap?(bn(),ui(Je,ut.endScope._wrap)):ut.endScope&&ut.endScope._multi?(bn(),G0(ut.endScope,Pe)):Dn.skip?en+=Je:(Dn.returnEnd||Dn.excludeEnd||(en+=Je),bn(),Dn.excludeEnd&&(en=Je));do ut.scope&&Qn.closeNode(),!ut.skip&&!ut.subLanguage&&(gs+=ut.relevance),ut=ut.parent;while(ut!==Bt.parent);return Bt.starts&&io(Bt.starts,Pe),Dn.returnEnd?0:Je.length}function ku(){const Pe=[];for(let Je=ut;Je!==gr;Je=Je.parent)Je.scope&&Pe.unshift(Je.scope);Pe.forEach(Je=>Qn.openNode(Je))}let pl={};function so(Pe,Je){const vt=Je&&Je[0];if(en+=Pe,vt==null)return bn(),0;if(pl.type==="begin"&&Je.type==="end"&&pl.index===Je.index&&vt===""){if(en+=nt.slice(Je.index,Je.index+1),!Tn){const Bt=new Error(`0 width match regex (${Me})`);throw Bt.languageName=Me,Bt.badRule=pl.rule,Bt}return 1}if(pl=Je,Je.type==="begin")return om(Je);if(Je.type==="illegal"&&!Ct){const Bt=new Error('Illegal lexeme "'+vt+'" for mode "'+(ut.scope||"<unnamed>")+'"');throw Bt.mode=ut,Bt}else if(Je.type==="end"){const Bt=Yr(Je);if(Bt!==dl)return Bt}if(Je.type==="illegal"&&vt==="")return en+=`
`,1;if(Cu>1e5&&Cu>Je.index*3)throw new Error("potential infinite loop, way more iterations than matches");return en+=vt,vt.length}const gr=Ir(Me);if(!gr)throw Xt(cn.replace("{}",Me)),new Error('Unknown language: "'+Me+'"');const Y0=Rt(gr);let lo="",ut=Jt||Y0;const V0={},Qn=new We.__emitter(We);ku();let en="",gs=0,xa=0,Cu=0,bs=!1;try{if(gr.__emitTokens)gr.__emitTokens(nt,Qn);else{for(ut.matcher.considerAll();;){Cu++,bs?bs=!1:ut.matcher.considerAll(),ut.matcher.lastIndex=xa;const Pe=ut.matcher.exec(nt);if(!Pe)break;const Je=nt.substring(xa,Pe.index),vt=so(Je,Pe);xa=Pe.index+vt}so(nt.substring(xa))}return Qn.finalize(),lo=Qn.toHTML(),{language:Me,value:lo,relevance:gs,illegal:!1,_emitter:Qn,_top:ut}}catch(Pe){if(Pe.message&&Pe.message.includes("Illegal"))return{language:Me,value:Mr(nt),illegal:!0,relevance:0,_illegalBy:{message:Pe.message,index:xa,context:nt.slice(xa-100,xa+100),mode:Pe.mode,resultSoFar:lo},_emitter:Qn};if(Tn)return{language:Me,value:Mr(nt),illegal:!1,relevance:0,errorRaised:Pe,_emitter:Qn,_top:ut};throw Pe}}function to(Me){const nt={value:Mr(Me),illegal:!1,relevance:0,_top:Ze,_emitter:new We.__emitter(We)};return nt._emitter.addText(Me),nt}function no(Me,nt){nt=nt||We.languages||Object.keys(ye);const Ct=to(Me),Jt=nt.filter(Ir).filter(ms).map(bn=>ya(bn,Me,!1));Jt.unshift(Ct);const $n=Jt.sort((bn,ui)=>{if(bn.relevance!==ui.relevance)return ui.relevance-bn.relevance;if(bn.language&&ui.language){if(Ir(bn.language).supersetOf===ui.language)return 1;if(Ir(ui.language).supersetOf===bn.language)return-1}return 0}),[wr,oi]=$n,Gr=wr;return Gr.secondBest=oi,Gr}function Ji(Me,nt,Ct){const Jt=nt&&Fe[nt]||Ct;Me.classList.add("hljs"),Me.classList.add(`language-${Jt}`)}function qn(Me){let nt=null;const Ct=jn(Me);if(ht(Ct))return;if(ml("before:highlightElement",{el:Me,language:Ct}),Me.dataset.highlighted){console.log("Element previously highlighted. To highlight again, first unset `dataset.highlighted`.",Me);return}if(Me.children.length>0&&(We.ignoreUnescapedHTML||(console.warn("One of your code blocks includes unescaped HTML. This is a potentially serious security risk."),console.warn("https://github.com/highlightjs/highlight.js/wiki/security"),console.warn("The element with unescaped HTML:"),console.warn(Me)),We.throwUnescapedHTML))throw new Zi("One of your code blocks includes unescaped HTML.",Me.innerHTML);nt=Me;const Jt=nt.textContent,$n=Ct?Cn(Jt,{language:Ct,ignoreIllegals:!0}):no(Jt);Me.innerHTML=$n.value,Me.dataset.highlighted="yes",Ji(Me,Ct,$n.language),Me.result={language:$n.language,re:$n.relevance,relevance:$n.relevance},$n.secondBest&&(Me.secondBest={language:$n.secondBest.language,relevance:$n.secondBest.relevance}),ml("after:highlightElement",{el:Me,result:$n,text:Jt})}function Sr(Me){We=H0(We,Me)}const fs=()=>{ro(),me("10.6.0","initHighlighting() deprecated.  Use highlightAll() now.")};function Su(){ro(),me("10.6.0","initHighlightingOnLoad() deprecated.  Use highlightAll() now.")}let j0=!1;function ro(){function Me(){ro()}if(document.readyState==="loading"){j0||window.addEventListener("DOMContentLoaded",Me,!1),j0=!0;return}document.querySelectorAll(We.cssSelector).forEach(qn)}function q0(Me,nt){let Ct=null;try{Ct=nt(W)}catch(Jt){if(Xt("Language definition for '{}' could not be registered.".replace("{}",Me)),Tn)Xt(Jt);else throw Jt;Ct=Ze}Ct.name||(Ct.name=Me),ye[Me]=Ct,Ct.rawDefinition=nt.bind(null,W),Ct.aliases&&Ea(Ct.aliases,{languageName:Me})}function fl(Me){delete ye[Me];for(const nt of Object.keys(Fe))Fe[nt]===Me&&delete Fe[nt]}function wu(){return Object.keys(ye)}function Ir(Me){return Me=(Me||"").toLowerCase(),ye[Me]||ye[Fe[Me]]}function Ea(Me,{languageName:nt}){typeof Me=="string"&&(Me=[Me]),Me.forEach(Ct=>{Fe[Ct.toLowerCase()]=nt})}function ms(Me){const nt=Ir(Me);return nt&&!nt.disableAutodetect}function ps(Me){Me["before:highlightBlock"]&&!Me["before:highlightElement"]&&(Me["before:highlightElement"]=nt=>{Me["before:highlightBlock"](Object.assign({block:nt.el},nt))}),Me["after:highlightBlock"]&&!Me["after:highlightElement"]&&(Me["after:highlightElement"]=nt=>{Me["after:highlightBlock"](Object.assign({block:nt.el},nt))})}function Xn(Me){ps(Me),mt.push(Me)}function $0(Me){const nt=mt.indexOf(Me);nt!==-1&&mt.splice(nt,1)}function ml(Me,nt){const Ct=Me;mt.forEach(function(Jt){Jt[Ct]&&Jt[Ct](nt)})}function Ta(Me){return me("10.7.0","highlightBlock will be removed entirely in v12.0"),me("10.7.0","Please use highlightElement now."),qn(Me)}Object.assign(W,{highlight:Cn,highlightAuto:no,highlightAll:ro,highlightElement:qn,highlightBlock:Ta,configure:Sr,initHighlighting:fs,initHighlightingOnLoad:Su,registerLanguage:q0,unregisterLanguage:fl,listLanguages:wu,getLanguage:Ir,registerAliases:Ea,autoDetection:ms,inherit:H0,addPlugin:Xn,removePlugin:$0}),W.debugMode=function(){Tn=!1},W.safeMode=function(){Tn=!0},W.versionString=Zt,W.regex={concat:x,lookahead:v,either:A,optional:T,anyNumberOfTimes:_};for(const Me in Tt)typeof Tt[Me]=="object"&&e(Tt[Me]);return Object.assign(W,Tt),W},$r=hl({});return $r.newInstance=()=>hl({}),tg=$r,$r.HighlightJS=$r,$r.default=$r,tg}var pj=mj();const gj=Of(pj),n6={},bj="hljs-";function vj(e){const t=gj.newInstance();return e&&s(e),{highlight:n,highlightAuto:r,listLanguages:i,register:s,registerAlias:o,registered:c};function n(d,f,m){const p=m||n6,v=typeof p.prefix=="string"?p.prefix:bj;if(!t.getLanguage(d))throw new Error("Unknown language: `"+d+"` is not registered");t.configure({__emitter:_j,classPrefix:v});const _=t.highlight(f,{ignoreIllegals:!0,language:d});if(_.errorRaised)throw new Error("Could not highlight with `Highlight.js`",{cause:_.errorRaised});const T=_._emitter.root,x=T.data;return x.language=_.language,x.relevance=_.relevance,T}function r(d,f){const p=(f||n6).subset||i();let v=-1,_=0,T;for(;++v<p.length;){const x=p[v];if(!t.getLanguage(x))continue;const k=n(x,d,f);k.data&&k.data.relevance!==void 0&&k.data.relevance>_&&(_=k.data.relevance,T=k)}return T||{type:"root",children:[],data:{language:void 0,relevance:_}}}function i(){return t.listLanguages()}function s(d,f){if(typeof d=="string")t.registerLanguage(d,f);else{let m;for(m in d)Object.hasOwn(d,m)&&t.registerLanguage(m,d[m])}}function o(d,f){if(typeof d=="string")t.registerAliases(typeof f=="string"?f:[...f],{languageName:d});else{let m;for(m in d)if(Object.hasOwn(d,m)){const p=d[m];t.registerAliases(typeof p=="string"?p:[...p],{languageName:m})}}}function c(d){return!!t.getLanguage(d)}}class _j{constructor(t){this.options=t,this.root={type:"root",children:[],data:{language:void 0,relevance:0}},this.stack=[this.root]}addText(t){if(t==="")return;const n=this.stack[this.stack.length-1],r=n.children[n.children.length-1];r&&r.type==="text"?r.value+=t:n.children.push({type:"text",value:t})}startScope(t){this.openNode(String(t))}endScope(){this.closeNode()}__addSublanguage(t,n){const r=this.stack[this.stack.length-1],i=t.root.children;n?r.children.push({type:"element",tagName:"span",properties:{className:[n]},children:i}):r.children.push(...i)}openNode(t){const n=this,r=t.split(".").map(function(o,c){return c?o+"_".repeat(c):n.options.classPrefix+o}),i=this.stack[this.stack.length-1],s={type:"element",tagName:"span",properties:{className:r},children:[]};i.children.push(s),this.stack.push(s)}closeNode(){this.stack.pop()}finalize(){}toHTML(){return""}}const yj={};function Ej(e){const t=e||yj,n=t.aliases,r=t.detect||!1,i=t.languages||fj,s=t.plainText,o=t.prefix,c=t.subset;let d="hljs";const f=vj(i);if(n&&f.registerAlias(n),o){const m=o.indexOf("-");d=m===-1?o:o.slice(0,m)}return function(m,p){O0(m,"element",function(v,_,T){if(v.tagName!=="code"||!T||T.type!=="element"||T.tagName!=="pre")return;const x=Tj(v);if(x===!1||!x&&!r||x&&s&&s.includes(x))return;Array.isArray(v.properties.className)||(v.properties.className=[]),v.properties.className.includes(d)||v.properties.className.unshift(d);const k=YT(v,{whitespace:"pre"});let A;try{A=x?f.highlight(x,k,{prefix:o}):f.highlightAuto(k,{prefix:o,subset:c})}catch(O){const I=O;if(x&&/Unknown language/.test(I.message)){p.message("Cannot highlight as `"+x+"`, it’s not registered",{ancestors:[T,v],cause:I,place:v.position,ruleId:"missing-language",source:"rehype-highlight"});return}throw I}!x&&A.data&&A.data.language&&v.properties.className.push("language-"+A.data.language),A.children.length>0&&(v.children=A.children)})}}function Tj(e){const t=e.properties.className;let n=-1;if(!Array.isArray(t))return;let r;for(;++n<t.length;){const i=String(t[n]);if(i==="no-highlight"||i==="nohighlight")return!1;!r&&i.slice(0,5)==="lang-"&&(r=i.slice(5)),!r&&i.slice(0,9)==="language-"&&(r=i.slice(9))}return r}function xj(e,t){return fx(e,{})||{type:"root",children:[]}}function fx(e,t){const n=Sj(e,t);return n&&t.afterTransform&&t.afterTransform(e,n),n}function Sj(e,t){switch(e.nodeType){case 1:return Cj(e,t);case 3:return Aj(e);case 8:return kj(e);case 9:return r6(e,t);case 10:return wj();case 11:return r6(e,t);default:return}}function r6(e,t){return{type:"root",children:mx(e,t)}}function wj(){return{type:"doctype"}}function Aj(e){return{type:"text",value:e.nodeValue||""}}function kj(e){return{type:"comment",value:e.nodeValue||""}}function Cj(e,t){const n=e.namespaceURI,r=n===ca.svg?cT:uT,i=n===ca.html?e.tagName.toLowerCase():e.tagName,s=n===ca.html&&i==="template"?e.content:e,o=e.getAttributeNames(),c={};let d=-1;for(;++d<o.length;)c[o[d]]=e.getAttribute(o[d])||"";return r(i,c,mx(s,t))}function mx(e,t){const n=e.childNodes,r=[];let i=-1;for(;++i<n.length;){const s=fx(n[i],t);s!==void 0&&r.push(s)}return r}new DOMParser;function Nj(e,t){const n=Oj(e);return xj(n)}function Oj(e){const t=document.createElement("template");return t.innerHTML=e,t.content}class ri{constructor(t,n,r){this.lexer=void 0,this.start=void 0,this.end=void 0,this.lexer=t,this.start=n,this.end=r}static range(t,n){return n?!t||!t.loc||!n.loc||t.loc.lexer!==n.loc.lexer?null:new ri(t.loc.lexer,t.loc.start,n.loc.end):t&&t.loc}}class Ti{constructor(t,n){this.text=void 0,this.loc=void 0,this.noexpand=void 0,this.treatAsRelax=void 0,this.text=t,this.loc=n}range(t,n){return new Ti(n,ri.range(this,t))}}class Ie{constructor(t,n){this.name=void 0,this.position=void 0,this.length=void 0,this.rawMessage=void 0;var r="KaTeX parse error: "+t,i,s,o=n&&n.loc;if(o&&o.start<=o.end){var c=o.lexer.input;i=o.start,s=o.end,i===c.length?r+=" at end of input: ":r+=" at position "+(i+1)+": ";var d=c.slice(i,s).replace(/[^]/g,"$&̲"),f;i>15?f="…"+c.slice(i-15,i):f=c.slice(0,i);var m;s+15<c.length?m=c.slice(s,s+15)+"…":m=c.slice(s),r+=f+d+m}var p=new Error(r);return p.name="ParseError",p.__proto__=Ie.prototype,p.position=i,i!=null&&s!=null&&(p.length=s-i),p.rawMessage=t,p}}Ie.prototype.__proto__=Error.prototype;var Rj=function(t,n){return t===void 0?n:t},Mj=/([A-Z])/g,Ij=function(t){return t.replace(Mj,"-$1").toLowerCase()},Dj={"&":"&amp;",">":"&gt;","<":"&lt;",'"':"&quot;","'":"&#x27;"},Lj=/[&><"']/g;function Pj(e){return String(e).replace(Lj,t=>Dj[t])}var px=function e(t){return t.type==="ordgroup"||t.type==="color"?t.body.length===1?e(t.body[0]):t:t.type==="font"?e(t.body):t},Bj=function(t){var n=px(t);return n.type==="mathord"||n.type==="textord"||n.type==="atom"},Uj=function(t){if(!t)throw new Error("Expected non-null, but got "+String(t));return t},zj=function(t){var n=/^[\x00-\x20]*([^\\/#?]*?)(:|&#0*58|&#x0*3a|&colon)/i.exec(t);return n?n[2]!==":"||!/^[a-zA-Z][a-zA-Z0-9+\-.]*$/.test(n[1])?null:n[1].toLowerCase():"_relative"},Vt={deflt:Rj,escape:Pj,hyphenate:Ij,getBaseElem:px,isCharacterBox:Bj,protocolFromUrl:zj},$h={displayMode:{type:"boolean",description:"Render math in display mode, which puts the math in display style (so \\int and \\sum are large, for example), and centers the math on the page on its own line.",cli:"-d, --display-mode"},output:{type:{enum:["htmlAndMathml","html","mathml"]},description:"Determines the markup language of the output.",cli:"-F, --format <type>"},leqno:{type:"boolean",description:"Render display math in leqno style (left-justified tags)."},fleqn:{type:"boolean",description:"Render display math flush left."},throwOnError:{type:"boolean",default:!0,cli:"-t, --no-throw-on-error",cliDescription:"Render errors (in the color given by --error-color) instead of throwing a ParseError exception when encountering an error."},errorColor:{type:"string",default:"#cc0000",cli:"-c, --error-color <color>",cliDescription:"A color string given in the format 'rgb' or 'rrggbb' (no #). This option determines the color of errors rendered by the -t option.",cliProcessor:e=>"#"+e},macros:{type:"object",cli:"-m, --macro <def>",cliDescription:"Define custom macro of the form '\\foo:expansion' (use multiple -m arguments for multiple macros).",cliDefault:[],cliProcessor:(e,t)=>(t.push(e),t)},minRuleThickness:{type:"number",description:"Specifies a minimum thickness, in ems, for fraction lines, `\\sqrt` top lines, `{array}` vertical lines, `\\hline`, `\\hdashline`, `\\underline`, `\\overline`, and the borders of `\\fbox`, `\\boxed`, and `\\fcolorbox`.",processor:e=>Math.max(0,e),cli:"--min-rule-thickness <size>",cliProcessor:parseFloat},colorIsTextColor:{type:"boolean",description:"Makes \\color behave like LaTeX's 2-argument \\textcolor, instead of LaTeX's one-argument \\color mode change.",cli:"-b, --color-is-text-color"},strict:{type:[{enum:["warn","ignore","error"]},"boolean","function"],description:"Turn on strict / LaTeX faithfulness mode, which throws an error if the input uses features that are not supported by LaTeX.",cli:"-S, --strict",cliDefault:!1},trust:{type:["boolean","function"],description:"Trust the input, enabling all HTML features such as \\url.",cli:"-T, --trust"},maxSize:{type:"number",default:1/0,description:"If non-zero, all user-specified sizes, e.g. in \\rule{500em}{500em}, will be capped to maxSize ems. Otherwise, elements and spaces can be arbitrarily large",processor:e=>Math.max(0,e),cli:"-s, --max-size <n>",cliProcessor:parseInt},maxExpand:{type:"number",default:1e3,description:"Limit the number of macro expansions to the specified number, to prevent e.g. infinite macro loops. If set to Infinity, the macro expander will try to fully expand as in LaTeX.",processor:e=>Math.max(0,e),cli:"-e, --max-expand <n>",cliProcessor:e=>e==="Infinity"?1/0:parseInt(e)},globalGroup:{type:"boolean",cli:!1}};function Fj(e){if(e.default)return e.default;var t=e.type,n=Array.isArray(t)?t[0]:t;if(typeof n!="string")return n.enum[0];switch(n){case"boolean":return!1;case"string":return"";case"number":return 0;case"object":return{}}}class L2{constructor(t){this.displayMode=void 0,this.output=void 0,this.leqno=void 0,this.fleqn=void 0,this.throwOnError=void 0,this.errorColor=void 0,this.macros=void 0,this.minRuleThickness=void 0,this.colorIsTextColor=void 0,this.strict=void 0,this.trust=void 0,this.maxSize=void 0,this.maxExpand=void 0,this.globalGroup=void 0,t=t||{};for(var n in $h)if($h.hasOwnProperty(n)){var r=$h[n];this[n]=t[n]!==void 0?r.processor?r.processor(t[n]):t[n]:Fj(r)}}reportNonstrict(t,n,r){var i=this.strict;if(typeof i=="function"&&(i=i(t,n,r)),!(!i||i==="ignore")){if(i===!0||i==="error")throw new Ie("LaTeX-incompatible input and strict mode is set to 'error': "+(n+" ["+t+"]"),r);i==="warn"?typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(n+" ["+t+"]")):typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+i+"': "+n+" ["+t+"]"))}}useStrictBehavior(t,n,r){var i=this.strict;if(typeof i=="function")try{i=i(t,n,r)}catch{i="error"}return!i||i==="ignore"?!1:i===!0||i==="error"?!0:i==="warn"?(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(n+" ["+t+"]")),!1):(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+i+"': "+n+" ["+t+"]")),!1)}isTrusted(t){if(t.url&&!t.protocol){var n=Vt.protocolFromUrl(t.url);if(n==null)return!1;t.protocol=n}var r=typeof this.trust=="function"?this.trust(t):this.trust;return!!r}}class js{constructor(t,n,r){this.id=void 0,this.size=void 0,this.cramped=void 0,this.id=t,this.size=n,this.cramped=r}sup(){return oa[Hj[this.id]]}sub(){return oa[jj[this.id]]}fracNum(){return oa[qj[this.id]]}fracDen(){return oa[$j[this.id]]}cramp(){return oa[Gj[this.id]]}text(){return oa[Yj[this.id]]}isTight(){return this.size>=2}}var P2=0,of=1,tu=2,es=3,h0=4,Bi=5,lu=6,Hr=7,oa=[new js(P2,0,!1),new js(of,0,!0),new js(tu,1,!1),new js(es,1,!0),new js(h0,2,!1),new js(Bi,2,!0),new js(lu,3,!1),new js(Hr,3,!0)],Hj=[h0,Bi,h0,Bi,lu,Hr,lu,Hr],jj=[Bi,Bi,Bi,Bi,Hr,Hr,Hr,Hr],qj=[tu,es,h0,Bi,lu,Hr,lu,Hr],$j=[es,es,Bi,Bi,Hr,Hr,Hr,Hr],Gj=[of,of,es,es,Bi,Bi,Hr,Hr],Yj=[P2,of,tu,es,tu,es,tu,es],lt={DISPLAY:oa[P2],TEXT:oa[tu],SCRIPT:oa[h0],SCRIPTSCRIPT:oa[lu]},pb=[{name:"latin",blocks:[[256,591],[768,879]]},{name:"cyrillic",blocks:[[1024,1279]]},{name:"armenian",blocks:[[1328,1423]]},{name:"brahmic",blocks:[[2304,4255]]},{name:"georgian",blocks:[[4256,4351]]},{name:"cjk",blocks:[[12288,12543],[19968,40879],[65280,65376]]},{name:"hangul",blocks:[[44032,55215]]}];function Vj(e){for(var t=0;t<pb.length;t++)for(var n=pb[t],r=0;r<n.blocks.length;r++){var i=n.blocks[r];if(e>=i[0]&&e<=i[1])return n.name}return null}var Gh=[];pb.forEach(e=>e.blocks.forEach(t=>Gh.push(...t)));function gx(e){for(var t=0;t<Gh.length;t+=2)if(e>=Gh[t]&&e<=Gh[t+1])return!0;return!1}var Fo=80,Kj=function(t,n){return"M95,"+(622+t+n)+`
c-2.7,0,-7.17,-2.7,-13.5,-8c-5.8,-5.3,-9.5,-10,-9.5,-14
c0,-2,0.3,-3.3,1,-4c1.3,-2.7,23.83,-20.7,67.5,-54
c44.2,-33.3,65.8,-50.3,66.5,-51c1.3,-1.3,3,-2,5,-2c4.7,0,8.7,3.3,12,10
s173,378,173,378c0.7,0,35.3,-71,104,-213c68.7,-142,137.5,-285,206.5,-429
c69,-144,104.5,-217.7,106.5,-221
l`+t/2.075+" -"+t+`
c5.3,-9.3,12,-14,20,-14
H400000v`+(40+t)+`H845.2724
s-225.272,467,-225.272,467s-235,486,-235,486c-2.7,4.7,-9,7,-19,7
c-6,0,-10,-1,-12,-3s-194,-422,-194,-422s-65,47,-65,47z
M`+(834+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},Wj=function(t,n){return"M263,"+(601+t+n)+`c0.7,0,18,39.7,52,119
c34,79.3,68.167,158.7,102.5,238c34.3,79.3,51.8,119.3,52.5,120
c340,-704.7,510.7,-1060.3,512,-1067
l`+t/2.084+" -"+t+`
c4.7,-7.3,11,-11,19,-11
H40000v`+(40+t)+`H1012.3
s-271.3,567,-271.3,567c-38.7,80.7,-84,175,-136,283c-52,108,-89.167,185.3,-111.5,232
c-22.3,46.7,-33.8,70.3,-34.5,71c-4.7,4.7,-12.3,7,-23,7s-12,-1,-12,-1
s-109,-253,-109,-253c-72.7,-168,-109.3,-252,-110,-252c-10.7,8,-22,16.7,-34,26
c-22,17.3,-33.3,26,-34,26s-26,-26,-26,-26s76,-59,76,-59s76,-60,76,-60z
M`+(1001+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},Xj=function(t,n){return"M983 "+(10+t+n)+`
l`+t/3.13+" -"+t+`
c4,-6.7,10,-10,18,-10 H400000v`+(40+t)+`
H1013.1s-83.4,268,-264.1,840c-180.7,572,-277,876.3,-289,913c-4.7,4.7,-12.7,7,-24,7
s-12,0,-12,0c-1.3,-3.3,-3.7,-11.7,-7,-25c-35.3,-125.3,-106.7,-373.3,-214,-744
c-10,12,-21,25,-33,39s-32,39,-32,39c-6,-5.3,-15,-14,-27,-26s25,-30,25,-30
c26.7,-32.7,52,-63,76,-91s52,-60,52,-60s208,722,208,722
c56,-175.3,126.3,-397.3,211,-666c84.7,-268.7,153.8,-488.2,207.5,-658.5
c53.7,-170.3,84.5,-266.8,92.5,-289.5z
M`+(1001+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},Qj=function(t,n){return"M424,"+(2398+t+n)+`
c-1.3,-0.7,-38.5,-172,-111.5,-514c-73,-342,-109.8,-513.3,-110.5,-514
c0,-2,-10.7,14.3,-32,49c-4.7,7.3,-9.8,15.7,-15.5,25c-5.7,9.3,-9.8,16,-12.5,20
s-5,7,-5,7c-4,-3.3,-8.3,-7.7,-13,-13s-13,-13,-13,-13s76,-122,76,-122s77,-121,77,-121
s209,968,209,968c0,-2,84.7,-361.7,254,-1079c169.3,-717.3,254.7,-1077.7,256,-1081
l`+t/4.223+" -"+t+`c4,-6.7,10,-10,18,-10 H400000
v`+(40+t)+`H1014.6
s-87.3,378.7,-272.6,1166c-185.3,787.3,-279.3,1182.3,-282,1185
c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2z M`+(1001+t)+" "+n+`
h400000v`+(40+t)+"h-400000z"},Zj=function(t,n){return"M473,"+(2713+t+n)+`
c339.3,-1799.3,509.3,-2700,510,-2702 l`+t/5.298+" -"+t+`
c3.3,-7.3,9.3,-11,18,-11 H400000v`+(40+t)+`H1017.7
s-90.5,478,-276.2,1466c-185.7,988,-279.5,1483,-281.5,1485c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2c0,-1.3,-5.3,-32,-16,-92c-50.7,-293.3,-119.7,-693.3,-207,-1200
c0,-1.3,-5.3,8.7,-16,30c-10.7,21.3,-21.3,42.7,-32,64s-16,33,-16,33s-26,-26,-26,-26
s76,-153,76,-153s77,-151,77,-151c0.7,0.7,35.7,202,105,604c67.3,400.7,102,602.7,104,
606zM`+(1001+t)+" "+n+"h400000v"+(40+t)+"H1017.7z"},Jj=function(t){var n=t/2;return"M400000 "+t+" H0 L"+n+" 0 l65 45 L145 "+(t-80)+" H400000z"},eq=function(t,n,r){var i=r-54-n-t;return"M702 "+(t+n)+"H400000"+(40+t)+`
H742v`+i+`l-4 4-4 4c-.667.7 -2 1.5-4 2.5s-4.167 1.833-6.5 2.5-5.5 1-9.5 1
h-12l-28-84c-16.667-52-96.667 -294.333-240-727l-212 -643 -85 170
c-4-3.333-8.333-7.667-13 -13l-13-13l77-155 77-156c66 199.333 139 419.667
219 661 l218 661zM702 `+n+"H400000v"+(40+t)+"H742z"},tq=function(t,n,r){n=1e3*n;var i="";switch(t){case"sqrtMain":i=Kj(n,Fo);break;case"sqrtSize1":i=Wj(n,Fo);break;case"sqrtSize2":i=Xj(n,Fo);break;case"sqrtSize3":i=Qj(n,Fo);break;case"sqrtSize4":i=Zj(n,Fo);break;case"sqrtTall":i=eq(n,Fo,r)}return i},nq=function(t,n){switch(t){case"⎜":return"M291 0 H417 V"+n+" H291z M291 0 H417 V"+n+" H291z";case"∣":return"M145 0 H188 V"+n+" H145z M145 0 H188 V"+n+" H145z";case"∥":return"M145 0 H188 V"+n+" H145z M145 0 H188 V"+n+" H145z"+("M367 0 H410 V"+n+" H367z M367 0 H410 V"+n+" H367z");case"⎟":return"M457 0 H583 V"+n+" H457z M457 0 H583 V"+n+" H457z";case"⎢":return"M319 0 H403 V"+n+" H319z M319 0 H403 V"+n+" H319z";case"⎥":return"M263 0 H347 V"+n+" H263z M263 0 H347 V"+n+" H263z";case"⎪":return"M384 0 H504 V"+n+" H384z M384 0 H504 V"+n+" H384z";case"⏐":return"M312 0 H355 V"+n+" H312z M312 0 H355 V"+n+" H312z";case"‖":return"M257 0 H300 V"+n+" H257z M257 0 H300 V"+n+" H257z"+("M478 0 H521 V"+n+" H478z M478 0 H521 V"+n+" H478z");default:return""}},i6={doubleleftarrow:`M262 157
l10-10c34-36 62.7-77 86-123 3.3-8 5-13.3 5-16 0-5.3-6.7-8-20-8-7.3
 0-12.2.5-14.5 1.5-2.3 1-4.8 4.5-7.5 10.5-49.3 97.3-121.7 169.3-217 216-28
 14-57.3 25-88 33-6.7 2-11 3.8-13 5.5-2 1.7-3 4.2-3 7.5s1 5.8 3 7.5
c2 1.7 6.3 3.5 13 5.5 68 17.3 128.2 47.8 180.5 91.5 52.3 43.7 93.8 96.2 124.5
 157.5 9.3 8 15.3 12.3 18 13h6c12-.7 18-4 18-10 0-2-1.7-7-5-15-23.3-46-52-87
-86-123l-10-10h399738v-40H218c328 0 0 0 0 0l-10-8c-26.7-20-65.7-43-117-69 2.7
-2 6-3.7 10-5 36.7-16 72.3-37.3 107-64l10-8h399782v-40z
m8 0v40h399730v-40zm0 194v40h399730v-40z`,doublerightarrow:`M399738 392l
-10 10c-34 36-62.7 77-86 123-3.3 8-5 13.3-5 16 0 5.3 6.7 8 20 8 7.3 0 12.2-.5
 14.5-1.5 2.3-1 4.8-4.5 7.5-10.5 49.3-97.3 121.7-169.3 217-216 28-14 57.3-25 88
-33 6.7-2 11-3.8 13-5.5 2-1.7 3-4.2 3-7.5s-1-5.8-3-7.5c-2-1.7-6.3-3.5-13-5.5-68
-17.3-128.2-47.8-180.5-91.5-52.3-43.7-93.8-96.2-124.5-157.5-9.3-8-15.3-12.3-18
-13h-6c-12 .7-18 4-18 10 0 2 1.7 7 5 15 23.3 46 52 87 86 123l10 10H0v40h399782
c-328 0 0 0 0 0l10 8c26.7 20 65.7 43 117 69-2.7 2-6 3.7-10 5-36.7 16-72.3 37.3
-107 64l-10 8H0v40zM0 157v40h399730v-40zm0 194v40h399730v-40z`,leftarrow:`M400000 241H110l3-3c68.7-52.7 113.7-120
 135-202 4-14.7 6-23 6-25 0-7.3-7-11-21-11-8 0-13.2.8-15.5 2.5-2.3 1.7-4.2 5.8
-5.5 12.5-1.3 4.7-2.7 10.3-4 17-12 48.7-34.8 92-68.5 130S65.3 228.3 18 247
c-10 4-16 7.7-18 11 0 8.7 6 14.3 18 17 47.3 18.7 87.8 47 121.5 85S196 441.3 208
 490c.7 2 1.3 5 2 9s1.2 6.7 1.5 8c.3 1.3 1 3.3 2 6s2.2 4.5 3.5 5.5c1.3 1 3.3
 1.8 6 2.5s6 1 10 1c14 0 21-3.7 21-11 0-2-2-10.3-6-25-20-79.3-65-146.7-135-202
 l-3-3h399890zM100 241v40h399900v-40z`,leftbrace:`M6 548l-6-6v-35l6-11c56-104 135.3-181.3 238-232 57.3-28.7 117
-45 179-50h399577v120H403c-43.3 7-81 15-113 26-100.7 33-179.7 91-237 174-2.7
 5-6 9-10 13-.7 1-7.3 1-20 1H6z`,leftbraceunder:`M0 6l6-6h17c12.688 0 19.313.3 20 1 4 4 7.313 8.3 10 13
 35.313 51.3 80.813 93.8 136.5 127.5 55.688 33.7 117.188 55.8 184.5 66.5.688
 0 2 .3 4 1 18.688 2.7 76 4.3 172 5h399450v120H429l-6-1c-124.688-8-235-61.7
-331-161C60.687 138.7 32.312 99.3 7 54L0 41V6z`,leftgroup:`M400000 80
H435C64 80 168.3 229.4 21 260c-5.9 1.2-18 0-18 0-2 0-3-1-3-3v-38C76 61 257 0
 435 0h399565z`,leftgroupunder:`M400000 262
H435C64 262 168.3 112.6 21 82c-5.9-1.2-18 0-18 0-2 0-3 1-3 3v38c76 158 257 219
 435 219h399565z`,leftharpoon:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3
-3.3 10.2-9.5 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5
-18.3 3-21-1.3-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7
-196 228-6.7 4.7-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40z`,leftharpoonplus:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3-3.3 10.2-9.5
 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5-18.3 3-21-1.3
-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7-196 228-6.7 4.7
-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40zM0 435v40h400000v-40z
m0 0v40h400000v-40z`,leftharpoondown:`M7 241c-4 4-6.333 8.667-7 14 0 5.333.667 9 2 11s5.333
 5.333 12 10c90.667 54 156 130 196 228 3.333 10.667 6.333 16.333 9 17 2 .667 5
 1 9 1h5c10.667 0 16.667-2 18-6 2-2.667 1-9.667-3-21-32-87.333-82.667-157.667
-152-211l-3-3h399907v-40zM93 281 H400000 v-40L7 241z`,leftharpoondownplus:`M7 435c-4 4-6.3 8.7-7 14 0 5.3.7 9 2 11s5.3 5.3 12
 10c90.7 54 156 130 196 228 3.3 10.7 6.3 16.3 9 17 2 .7 5 1 9 1h5c10.7 0 16.7
-2 18-6 2-2.7 1-9.7-3-21-32-87.3-82.7-157.7-152-211l-3-3h399907v-40H7zm93 0
v40h399900v-40zM0 241v40h399900v-40zm0 0v40h399900v-40z`,lefthook:`M400000 281 H103s-33-11.2-61-33.5S0 197.3 0 164s14.2-61.2 42.5
-83.5C70.8 58.2 104 47 142 47 c16.7 0 25 6.7 25 20 0 12-8.7 18.7-26 20-40 3.3
-68.7 15.7-86 37-10 12-15 25.3-15 40 0 22.7 9.8 40.7 29.5 54 19.7 13.3 43.5 21
 71.5 23h399859zM103 281v-40h399897v40z`,leftlinesegment:`M40 281 V428 H0 V94 H40 V241 H400000 v40z
M40 281 V428 H0 V94 H40 V241 H400000 v40z`,leftmapsto:`M40 281 V448H0V74H40V241H400000v40z
M40 281 V448H0V74H40V241H400000v40z`,leftToFrom:`M0 147h400000v40H0zm0 214c68 40 115.7 95.7 143 167h22c15.3 0 23
-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69-70-101l-7-8h399905v-40H95l7-8
c28.7-32 52-65.7 70-101 10.7-23.3 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 265.3
 68 321 0 361zm0-174v-40h399900v40zm100 154v40h399900v-40z`,longequal:`M0 50 h400000 v40H0z m0 194h40000v40H0z
M0 50 h400000 v40H0z m0 194h40000v40H0z`,midbrace:`M200428 334
c-100.7-8.3-195.3-44-280-108-55.3-42-101.7-93-139-153l-9-14c-2.7 4-5.7 8.7-9 14
-53.3 86.7-123.7 153-211 199-66.7 36-137.3 56.3-212 62H0V214h199568c178.3-11.7
 311.7-78.3 403-201 6-8 9.7-12 11-12 .7-.7 6.7-1 18-1s17.3.3 18 1c1.3 0 5 4 11
 12 44.7 59.3 101.3 106.3 170 141s145.3 54.3 229 60h199572v120z`,midbraceunder:`M199572 214
c100.7 8.3 195.3 44 280 108 55.3 42 101.7 93 139 153l9 14c2.7-4 5.7-8.7 9-14
 53.3-86.7 123.7-153 211-199 66.7-36 137.3-56.3 212-62h199568v120H200432c-178.3
 11.7-311.7 78.3-403 201-6 8-9.7 12-11 12-.7.7-6.7 1-18 1s-17.3-.3-18-1c-1.3 0
-5-4-11-12-44.7-59.3-101.3-106.3-170-141s-145.3-54.3-229-60H0V214z`,oiintSize1:`M512.6 71.6c272.6 0 320.3 106.8 320.3 178.2 0 70.8-47.7 177.6
-320.3 177.6S193.1 320.6 193.1 249.8c0-71.4 46.9-178.2 319.5-178.2z
m368.1 178.2c0-86.4-60.9-215.4-368.1-215.4-306.4 0-367.3 129-367.3 215.4 0 85.8
60.9 214.8 367.3 214.8 307.2 0 368.1-129 368.1-214.8z`,oiintSize2:`M757.8 100.1c384.7 0 451.1 137.6 451.1 230 0 91.3-66.4 228.8
-451.1 228.8-386.3 0-452.7-137.5-452.7-228.8 0-92.4 66.4-230 452.7-230z
m502.4 230c0-111.2-82.4-277.2-502.4-277.2s-504 166-504 277.2
c0 110 84 276 504 276s502.4-166 502.4-276z`,oiiintSize1:`M681.4 71.6c408.9 0 480.5 106.8 480.5 178.2 0 70.8-71.6 177.6
-480.5 177.6S202.1 320.6 202.1 249.8c0-71.4 70.5-178.2 479.3-178.2z
m525.8 178.2c0-86.4-86.8-215.4-525.7-215.4-437.9 0-524.7 129-524.7 215.4 0
85.8 86.8 214.8 524.7 214.8 438.9 0 525.7-129 525.7-214.8z`,oiiintSize2:`M1021.2 53c603.6 0 707.8 165.8 707.8 277.2 0 110-104.2 275.8
-707.8 275.8-606 0-710.2-165.8-710.2-275.8C311 218.8 415.2 53 1021.2 53z
m770.4 277.1c0-131.2-126.4-327.6-770.5-327.6S248.4 198.9 248.4 330.1
c0 130 128.8 326.4 772.7 326.4s770.5-196.4 770.5-326.4z`,rightarrow:`M0 241v40h399891c-47.3 35.3-84 78-110 128
-16.7 32-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20
 11 8 0 13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7
 39-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85
-40.5-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
 151.7 139 205zm0 0v40h399900v-40z`,rightbrace:`M400000 542l
-6 6h-17c-12.7 0-19.3-.3-20-1-4-4-7.3-8.3-10-13-35.3-51.3-80.8-93.8-136.5-127.5
s-117.2-55.8-184.5-66.5c-.7 0-2-.3-4-1-18.7-2.7-76-4.3-172-5H0V214h399571l6 1
c124.7 8 235 61.7 331 161 31.3 33.3 59.7 72.7 85 118l7 13v35z`,rightbraceunder:`M399994 0l6 6v35l-6 11c-56 104-135.3 181.3-238 232-57.3
 28.7-117 45-179 50H-300V214h399897c43.3-7 81-15 113-26 100.7-33 179.7-91 237
-174 2.7-5 6-9 10-13 .7-1 7.3-1 20-1h17z`,rightgroup:`M0 80h399565c371 0 266.7 149.4 414 180 5.9 1.2 18 0 18 0 2 0
 3-1 3-3v-38c-76-158-257-219-435-219H0z`,rightgroupunder:`M0 262h399565c371 0 266.7-149.4 414-180 5.9-1.2 18 0 18
 0 2 0 3 1 3 3v38c-76 158-257 219-435 219H0z`,rightharpoon:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3
-3.7-15.3-11-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2
-10.7 0-16.7 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58
 69.2 92 94.5zm0 0v40h399900v-40z`,rightharpoonplus:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3-3.7-15.3-11
-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2-10.7 0-16.7
 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58 69.2 92 94.5z
m0 0v40h399900v-40z m100 194v40h399900v-40zm0 0v40h399900v-40z`,rightharpoondown:`M399747 511c0 7.3 6.7 11 20 11 8 0 13-.8 15-2.5s4.7-6.8
 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3 8.5-5.8 9.5
-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3-64.7 57-92 95
-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 241v40h399900v-40z`,rightharpoondownplus:`M399747 705c0 7.3 6.7 11 20 11 8 0 13-.8
 15-2.5s4.7-6.8 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3
 8.5-5.8 9.5-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3
-64.7 57-92 95-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 435v40h399900v-40z
m0-194v40h400000v-40zm0 0v40h400000v-40z`,righthook:`M399859 241c-764 0 0 0 0 0 40-3.3 68.7-15.7 86-37 10-12 15-25.3
 15-40 0-22.7-9.8-40.7-29.5-54-19.7-13.3-43.5-21-71.5-23-17.3-1.3-26-8-26-20 0
-13.3 8.7-20 26-20 38 0 71 11.2 99 33.5 0 0 7 5.6 21 16.7 14 11.2 21 33.5 21
 66.8s-14 61.2-42 83.5c-28 22.3-61 33.5-99 33.5L0 241z M0 281v-40h399859v40z`,rightlinesegment:`M399960 241 V94 h40 V428 h-40 V281 H0 v-40z
M399960 241 V94 h40 V428 h-40 V281 H0 v-40z`,rightToFrom:`M400000 167c-70.7-42-118-97.7-142-167h-23c-15.3 0-23 .3-23
 1 0 1.3 5.3 13.7 16 37 18 35.3 41.3 69 70 101l7 8H0v40h399905l-7 8c-28.7 32
-52 65.7-70 101-10.7 23.3-16 35.7-16 37 0 .7 7.7 1 23 1h23c24-69.3 71.3-125 142
-167z M100 147v40h399900v-40zM0 341v40h399900v-40z`,twoheadleftarrow:`M0 167c68 40
 115.7 95.7 143 167h22c15.3 0 23-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69
-70-101l-7-8h125l9 7c50.7 39.3 85 86 103 140h46c0-4.7-6.3-18.7-19-42-18-35.3
-40-67.3-66-96l-9-9h399716v-40H284l9-9c26-28.7 48-60.7 66-96 12.7-23.333 19
-37.333 19-42h-46c-18 54-52.3 100.7-103 140l-9 7H95l7-8c28.7-32 52-65.7 70-101
 10.7-23.333 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 71.3 68 127 0 167z`,twoheadrightarrow:`M400000 167
c-68-40-115.7-95.7-143-167h-22c-15.3 0-23 .3-23 1 0 1.3 5.3 13.7 16 37 18 35.3
 41.3 69 70 101l7 8h-125l-9-7c-50.7-39.3-85-86-103-140h-46c0 4.7 6.3 18.7 19 42
 18 35.3 40 67.3 66 96l9 9H0v40h399716l-9 9c-26 28.7-48 60.7-66 96-12.7 23.333
-19 37.333-19 42h46c18-54 52.3-100.7 103-140l9-7h125l-7 8c-28.7 32-52 65.7-70
 101-10.7 23.333-16 35.7-16 37 0 .7 7.7 1 23 1h22c27.3-71.3 75-127 143-167z`,tilde1:`M200 55.538c-77 0-168 73.953-177 73.953-3 0-7
-2.175-9-5.437L2 97c-1-2-2-4-2-6 0-4 2-7 5-9l20-12C116 12 171 0 207 0c86 0
 114 68 191 68 78 0 168-68 177-68 4 0 7 2 9 5l12 19c1 2.175 2 4.35 2 6.525 0
 4.35-2 7.613-5 9.788l-19 13.05c-92 63.077-116.937 75.308-183 76.128
-68.267.847-113-73.952-191-73.952z`,tilde2:`M344 55.266c-142 0-300.638 81.316-311.5 86.418
-8.01 3.762-22.5 10.91-23.5 5.562L1 120c-1-2-1-3-1-4 0-5 3-9 8-10l18.4-9C160.9
 31.9 283 0 358 0c148 0 188 122 331 122s314-97 326-97c4 0 8 2 10 7l7 21.114
c1 2.14 1 3.21 1 4.28 0 5.347-3 9.626-7 10.696l-22.3 12.622C852.6 158.372 751
 181.476 676 181.476c-149 0-189-126.21-332-126.21z`,tilde3:`M786 59C457 59 32 175.242 13 175.242c-6 0-10-3.457
-11-10.37L.15 138c-1-7 3-12 10-13l19.2-6.4C378.4 40.7 634.3 0 804.3 0c337 0
 411.8 157 746.8 157 328 0 754-112 773-112 5 0 10 3 11 9l1 14.075c1 8.066-.697
 16.595-6.697 17.492l-21.052 7.31c-367.9 98.146-609.15 122.696-778.15 122.696
 -338 0-409-156.573-744-156.573z`,tilde4:`M786 58C457 58 32 177.487 13 177.487c-6 0-10-3.345
-11-10.035L.15 143c-1-7 3-12 10-13l22-6.7C381.2 35 637.15 0 807.15 0c337 0 409
 177 744 177 328 0 754-127 773-127 5 0 10 3 11 9l1 14.794c1 7.805-3 13.38-9
 14.495l-20.7 5.574c-366.85 99.79-607.3 139.372-776.3 139.372-338 0-409
 -175.236-744-175.236z`,vec:`M377 20c0-5.333 1.833-10 5.5-14S391 0 397 0c4.667 0 8.667 1.667 12 5
3.333 2.667 6.667 9 10 19 6.667 24.667 20.333 43.667 41 57 7.333 4.667 11
10.667 11 18 0 6-1 10-3 12s-6.667 5-14 9c-28.667 14.667-53.667 35.667-75 63
-1.333 1.333-3.167 3.5-5.5 6.5s-4 4.833-5 5.5c-1 .667-2.5 1.333-4.5 2s-4.333 1
-7 1c-4.667 0-9.167-1.833-13.5-5.5S337 184 337 178c0-12.667 15.667-32.333 47-59
H213l-171-1c-8.667-6-13-12.333-13-19 0-4.667 4.333-11.333 13-20h359
c-16-25.333-24-45-24-59z`,widehat1:`M529 0h5l519 115c5 1 9 5 9 10 0 1-1 2-1 3l-4 22
c-1 5-5 9-11 9h-2L532 67 19 159h-2c-5 0-9-4-11-9l-5-22c-1-6 2-12 8-13z`,widehat2:`M1181 0h2l1171 176c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 220h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat3:`M1181 0h2l1171 236c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 280h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat4:`M1181 0h2l1171 296c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 340h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widecheck1:`M529,159h5l519,-115c5,-1,9,-5,9,-10c0,-1,-1,-2,-1,-3l-4,-22c-1,
-5,-5,-9,-11,-9h-2l-512,92l-513,-92h-2c-5,0,-9,4,-11,9l-5,22c-1,6,2,12,8,13z`,widecheck2:`M1181,220h2l1171,-176c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,153l-1167,-153h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck3:`M1181,280h2l1171,-236c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,213l-1167,-213h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck4:`M1181,340h2l1171,-296c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,273l-1167,-273h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,baraboveleftarrow:`M400000 620h-399890l3 -3c68.7 -52.7 113.7 -120 135 -202
c4 -14.7 6 -23 6 -25c0 -7.3 -7 -11 -21 -11c-8 0 -13.2 0.8 -15.5 2.5
c-2.3 1.7 -4.2 5.8 -5.5 12.5c-1.3 4.7 -2.7 10.3 -4 17c-12 48.7 -34.8 92 -68.5 130
s-74.2 66.3 -121.5 85c-10 4 -16 7.7 -18 11c0 8.7 6 14.3 18 17c47.3 18.7 87.8 47
121.5 85s56.5 81.3 68.5 130c0.7 2 1.3 5 2 9s1.2 6.7 1.5 8c0.3 1.3 1 3.3 2 6
s2.2 4.5 3.5 5.5c1.3 1 3.3 1.8 6 2.5s6 1 10 1c14 0 21 -3.7 21 -11
c0 -2 -2 -10.3 -6 -25c-20 -79.3 -65 -146.7 -135 -202l-3 -3h399890z
M100 620v40h399900v-40z M0 241v40h399900v-40zM0 241v40h399900v-40z`,rightarrowabovebar:`M0 241v40h399891c-47.3 35.3-84 78-110 128-16.7 32
-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20 11 8 0
13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7 39
-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85-40.5
-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
151.7 139 205zm96 379h399894v40H0zm0 0h399904v40H0z`,baraboveshortleftharpoon:`M507,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17
c2,0.7,5,1,9,1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21
c-32,-87.3,-82.7,-157.7,-152,-211c0,0,-3,-3,-3,-3l399351,0l0,-40
c-398570,0,-399437,0,-399437,0z M593 435 v40 H399500 v-40z
M0 281 v-40 H399908 v40z M0 281 v-40 H399908 v40z`,rightharpoonaboveshortbar:`M0,241 l0,40c399126,0,399993,0,399993,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M0 241 v40 H399908 v-40z M0 475 v-40 H399500 v40z M0 475 v-40 H399500 v40z`,shortbaraboveleftharpoon:`M7,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17c2,0.7,5,1,9,
1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21c-32,-87.3,-82.7,-157.7,
-152,-211c0,0,-3,-3,-3,-3l399907,0l0,-40c-399126,0,-399993,0,-399993,0z
M93 435 v40 H400000 v-40z M500 241 v40 H400000 v-40z M500 241 v40 H400000 v-40z`,shortrightharpoonabovebar:`M53,241l0,40c398570,0,399437,0,399437,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M500 241 v40 H399408 v-40z M500 435 v40 H400000 v-40z`},rq=function(t,n){switch(t){case"lbrack":return"M403 1759 V84 H666 V0 H319 V1759 v"+n+` v1759 h347 v-84
H403z M403 1759 V0 H319 V1759 v`+n+" v1759 h84z";case"rbrack":return"M347 1759 V0 H0 V84 H263 V1759 v"+n+` v1759 H0 v84 H347z
M347 1759 V0 H263 V1759 v`+n+" v1759 h84z";case"vert":return"M145 15 v585 v"+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+n+" v585 h43z";case"doublevert":return"M145 15 v585 v"+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+n+` v585 h43z
M367 15 v585 v`+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M410 15 H367 v585 v`+n+" v585 h43z";case"lfloor":return"M319 602 V0 H403 V602 v"+n+` v1715 h263 v84 H319z
MM319 602 V0 H403 V602 v`+n+" v1715 H319z";case"rfloor":return"M319 602 V0 H403 V602 v"+n+` v1799 H0 v-84 H319z
MM319 602 V0 H403 V602 v`+n+" v1715 H319z";case"lceil":return"M403 1759 V84 H666 V0 H319 V1759 v"+n+` v602 h84z
M403 1759 V0 H319 V1759 v`+n+" v602 h84z";case"rceil":return"M347 1759 V0 H0 V84 H263 V1759 v"+n+` v602 h84z
M347 1759 V0 h-84 V1759 v`+n+" v602 h84z";case"lparen":return`M863,9c0,-2,-2,-5,-6,-9c0,0,-17,0,-17,0c-12.7,0,-19.3,0.3,-20,1
c-5.3,5.3,-10.3,11,-15,17c-242.7,294.7,-395.3,682,-458,1162c-21.3,163.3,-33.3,349,
-36,557 l0,`+(n+84)+`c0.2,6,0,26,0,60c2,159.3,10,310.7,24,454c53.3,528,210,
949.7,470,1265c4.7,6,9.7,11.7,15,17c0.7,0.7,7,1,19,1c0,0,18,0,18,0c4,-4,6,-7,6,-9
c0,-2.7,-3.3,-8.7,-10,-18c-135.3,-192.7,-235.5,-414.3,-300.5,-665c-65,-250.7,-102.5,
-544.7,-112.5,-882c-2,-104,-3,-167,-3,-189
l0,-`+(n+92)+`c0,-162.7,5.7,-314,17,-454c20.7,-272,63.7,-513,129,-723c65.3,
-210,155.3,-396.3,270,-559c6.7,-9.3,10,-15.3,10,-18z`;case"rparen":return`M76,0c-16.7,0,-25,3,-25,9c0,2,2,6.3,6,13c21.3,28.7,42.3,60.3,
63,95c96.7,156.7,172.8,332.5,228.5,527.5c55.7,195,92.8,416.5,111.5,664.5
c11.3,139.3,17,290.7,17,454c0,28,1.7,43,3.3,45l0,`+(n+9)+`
c-3,4,-3.3,16.7,-3.3,38c0,162,-5.7,313.7,-17,455c-18.7,248,-55.8,469.3,-111.5,664
c-55.7,194.7,-131.8,370.3,-228.5,527c-20.7,34.7,-41.7,66.3,-63,95c-2,3.3,-4,7,-6,11
c0,7.3,5.7,11,17,11c0,0,11,0,11,0c9.3,0,14.3,-0.3,15,-1c5.3,-5.3,10.3,-11,15,-17
c242.7,-294.7,395.3,-681.7,458,-1161c21.3,-164.7,33.3,-350.7,36,-558
l0,-`+(n+144)+`c-2,-159.3,-10,-310.7,-24,-454c-53.3,-528,-210,-949.7,
-470,-1265c-4.7,-6,-9.7,-11.7,-15,-17c-0.7,-0.7,-6.7,-1,-18,-1z`;default:throw new Error("Unknown stretchy delimiter.")}};class D0{constructor(t){this.children=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.children=t,this.classes=[],this.height=0,this.depth=0,this.maxFontSize=0,this.style={}}hasClass(t){return this.classes.includes(t)}toNode(){for(var t=document.createDocumentFragment(),n=0;n<this.children.length;n++)t.appendChild(this.children[n].toNode());return t}toMarkup(){for(var t="",n=0;n<this.children.length;n++)t+=this.children[n].toMarkup();return t}toText(){var t=n=>n.toText();return this.children.map(t).join("")}}var da={"AMS-Regular":{32:[0,0,0,0,.25],65:[0,.68889,0,0,.72222],66:[0,.68889,0,0,.66667],67:[0,.68889,0,0,.72222],68:[0,.68889,0,0,.72222],69:[0,.68889,0,0,.66667],70:[0,.68889,0,0,.61111],71:[0,.68889,0,0,.77778],72:[0,.68889,0,0,.77778],73:[0,.68889,0,0,.38889],74:[.16667,.68889,0,0,.5],75:[0,.68889,0,0,.77778],76:[0,.68889,0,0,.66667],77:[0,.68889,0,0,.94445],78:[0,.68889,0,0,.72222],79:[.16667,.68889,0,0,.77778],80:[0,.68889,0,0,.61111],81:[.16667,.68889,0,0,.77778],82:[0,.68889,0,0,.72222],83:[0,.68889,0,0,.55556],84:[0,.68889,0,0,.66667],85:[0,.68889,0,0,.72222],86:[0,.68889,0,0,.72222],87:[0,.68889,0,0,1],88:[0,.68889,0,0,.72222],89:[0,.68889,0,0,.72222],90:[0,.68889,0,0,.66667],107:[0,.68889,0,0,.55556],160:[0,0,0,0,.25],165:[0,.675,.025,0,.75],174:[.15559,.69224,0,0,.94666],240:[0,.68889,0,0,.55556],295:[0,.68889,0,0,.54028],710:[0,.825,0,0,2.33334],732:[0,.9,0,0,2.33334],770:[0,.825,0,0,2.33334],771:[0,.9,0,0,2.33334],989:[.08167,.58167,0,0,.77778],1008:[0,.43056,.04028,0,.66667],8245:[0,.54986,0,0,.275],8463:[0,.68889,0,0,.54028],8487:[0,.68889,0,0,.72222],8498:[0,.68889,0,0,.55556],8502:[0,.68889,0,0,.66667],8503:[0,.68889,0,0,.44445],8504:[0,.68889,0,0,.66667],8513:[0,.68889,0,0,.63889],8592:[-.03598,.46402,0,0,.5],8594:[-.03598,.46402,0,0,.5],8602:[-.13313,.36687,0,0,1],8603:[-.13313,.36687,0,0,1],8606:[.01354,.52239,0,0,1],8608:[.01354,.52239,0,0,1],8610:[.01354,.52239,0,0,1.11111],8611:[.01354,.52239,0,0,1.11111],8619:[0,.54986,0,0,1],8620:[0,.54986,0,0,1],8621:[-.13313,.37788,0,0,1.38889],8622:[-.13313,.36687,0,0,1],8624:[0,.69224,0,0,.5],8625:[0,.69224,0,0,.5],8630:[0,.43056,0,0,1],8631:[0,.43056,0,0,1],8634:[.08198,.58198,0,0,.77778],8635:[.08198,.58198,0,0,.77778],8638:[.19444,.69224,0,0,.41667],8639:[.19444,.69224,0,0,.41667],8642:[.19444,.69224,0,0,.41667],8643:[.19444,.69224,0,0,.41667],8644:[.1808,.675,0,0,1],8646:[.1808,.675,0,0,1],8647:[.1808,.675,0,0,1],8648:[.19444,.69224,0,0,.83334],8649:[.1808,.675,0,0,1],8650:[.19444,.69224,0,0,.83334],8651:[.01354,.52239,0,0,1],8652:[.01354,.52239,0,0,1],8653:[-.13313,.36687,0,0,1],8654:[-.13313,.36687,0,0,1],8655:[-.13313,.36687,0,0,1],8666:[.13667,.63667,0,0,1],8667:[.13667,.63667,0,0,1],8669:[-.13313,.37788,0,0,1],8672:[-.064,.437,0,0,1.334],8674:[-.064,.437,0,0,1.334],8705:[0,.825,0,0,.5],8708:[0,.68889,0,0,.55556],8709:[.08167,.58167,0,0,.77778],8717:[0,.43056,0,0,.42917],8722:[-.03598,.46402,0,0,.5],8724:[.08198,.69224,0,0,.77778],8726:[.08167,.58167,0,0,.77778],8733:[0,.69224,0,0,.77778],8736:[0,.69224,0,0,.72222],8737:[0,.69224,0,0,.72222],8738:[.03517,.52239,0,0,.72222],8739:[.08167,.58167,0,0,.22222],8740:[.25142,.74111,0,0,.27778],8741:[.08167,.58167,0,0,.38889],8742:[.25142,.74111,0,0,.5],8756:[0,.69224,0,0,.66667],8757:[0,.69224,0,0,.66667],8764:[-.13313,.36687,0,0,.77778],8765:[-.13313,.37788,0,0,.77778],8769:[-.13313,.36687,0,0,.77778],8770:[-.03625,.46375,0,0,.77778],8774:[.30274,.79383,0,0,.77778],8776:[-.01688,.48312,0,0,.77778],8778:[.08167,.58167,0,0,.77778],8782:[.06062,.54986,0,0,.77778],8783:[.06062,.54986,0,0,.77778],8785:[.08198,.58198,0,0,.77778],8786:[.08198,.58198,0,0,.77778],8787:[.08198,.58198,0,0,.77778],8790:[0,.69224,0,0,.77778],8791:[.22958,.72958,0,0,.77778],8796:[.08198,.91667,0,0,.77778],8806:[.25583,.75583,0,0,.77778],8807:[.25583,.75583,0,0,.77778],8808:[.25142,.75726,0,0,.77778],8809:[.25142,.75726,0,0,.77778],8812:[.25583,.75583,0,0,.5],8814:[.20576,.70576,0,0,.77778],8815:[.20576,.70576,0,0,.77778],8816:[.30274,.79383,0,0,.77778],8817:[.30274,.79383,0,0,.77778],8818:[.22958,.72958,0,0,.77778],8819:[.22958,.72958,0,0,.77778],8822:[.1808,.675,0,0,.77778],8823:[.1808,.675,0,0,.77778],8828:[.13667,.63667,0,0,.77778],8829:[.13667,.63667,0,0,.77778],8830:[.22958,.72958,0,0,.77778],8831:[.22958,.72958,0,0,.77778],8832:[.20576,.70576,0,0,.77778],8833:[.20576,.70576,0,0,.77778],8840:[.30274,.79383,0,0,.77778],8841:[.30274,.79383,0,0,.77778],8842:[.13597,.63597,0,0,.77778],8843:[.13597,.63597,0,0,.77778],8847:[.03517,.54986,0,0,.77778],8848:[.03517,.54986,0,0,.77778],8858:[.08198,.58198,0,0,.77778],8859:[.08198,.58198,0,0,.77778],8861:[.08198,.58198,0,0,.77778],8862:[0,.675,0,0,.77778],8863:[0,.675,0,0,.77778],8864:[0,.675,0,0,.77778],8865:[0,.675,0,0,.77778],8872:[0,.69224,0,0,.61111],8873:[0,.69224,0,0,.72222],8874:[0,.69224,0,0,.88889],8876:[0,.68889,0,0,.61111],8877:[0,.68889,0,0,.61111],8878:[0,.68889,0,0,.72222],8879:[0,.68889,0,0,.72222],8882:[.03517,.54986,0,0,.77778],8883:[.03517,.54986,0,0,.77778],8884:[.13667,.63667,0,0,.77778],8885:[.13667,.63667,0,0,.77778],8888:[0,.54986,0,0,1.11111],8890:[.19444,.43056,0,0,.55556],8891:[.19444,.69224,0,0,.61111],8892:[.19444,.69224,0,0,.61111],8901:[0,.54986,0,0,.27778],8903:[.08167,.58167,0,0,.77778],8905:[.08167,.58167,0,0,.77778],8906:[.08167,.58167,0,0,.77778],8907:[0,.69224,0,0,.77778],8908:[0,.69224,0,0,.77778],8909:[-.03598,.46402,0,0,.77778],8910:[0,.54986,0,0,.76042],8911:[0,.54986,0,0,.76042],8912:[.03517,.54986,0,0,.77778],8913:[.03517,.54986,0,0,.77778],8914:[0,.54986,0,0,.66667],8915:[0,.54986,0,0,.66667],8916:[0,.69224,0,0,.66667],8918:[.0391,.5391,0,0,.77778],8919:[.0391,.5391,0,0,.77778],8920:[.03517,.54986,0,0,1.33334],8921:[.03517,.54986,0,0,1.33334],8922:[.38569,.88569,0,0,.77778],8923:[.38569,.88569,0,0,.77778],8926:[.13667,.63667,0,0,.77778],8927:[.13667,.63667,0,0,.77778],8928:[.30274,.79383,0,0,.77778],8929:[.30274,.79383,0,0,.77778],8934:[.23222,.74111,0,0,.77778],8935:[.23222,.74111,0,0,.77778],8936:[.23222,.74111,0,0,.77778],8937:[.23222,.74111,0,0,.77778],8938:[.20576,.70576,0,0,.77778],8939:[.20576,.70576,0,0,.77778],8940:[.30274,.79383,0,0,.77778],8941:[.30274,.79383,0,0,.77778],8994:[.19444,.69224,0,0,.77778],8995:[.19444,.69224,0,0,.77778],9416:[.15559,.69224,0,0,.90222],9484:[0,.69224,0,0,.5],9488:[0,.69224,0,0,.5],9492:[0,.37788,0,0,.5],9496:[0,.37788,0,0,.5],9585:[.19444,.68889,0,0,.88889],9586:[.19444,.74111,0,0,.88889],9632:[0,.675,0,0,.77778],9633:[0,.675,0,0,.77778],9650:[0,.54986,0,0,.72222],9651:[0,.54986,0,0,.72222],9654:[.03517,.54986,0,0,.77778],9660:[0,.54986,0,0,.72222],9661:[0,.54986,0,0,.72222],9664:[.03517,.54986,0,0,.77778],9674:[.11111,.69224,0,0,.66667],9733:[.19444,.69224,0,0,.94445],10003:[0,.69224,0,0,.83334],10016:[0,.69224,0,0,.83334],10731:[.11111,.69224,0,0,.66667],10846:[.19444,.75583,0,0,.61111],10877:[.13667,.63667,0,0,.77778],10878:[.13667,.63667,0,0,.77778],10885:[.25583,.75583,0,0,.77778],10886:[.25583,.75583,0,0,.77778],10887:[.13597,.63597,0,0,.77778],10888:[.13597,.63597,0,0,.77778],10889:[.26167,.75726,0,0,.77778],10890:[.26167,.75726,0,0,.77778],10891:[.48256,.98256,0,0,.77778],10892:[.48256,.98256,0,0,.77778],10901:[.13667,.63667,0,0,.77778],10902:[.13667,.63667,0,0,.77778],10933:[.25142,.75726,0,0,.77778],10934:[.25142,.75726,0,0,.77778],10935:[.26167,.75726,0,0,.77778],10936:[.26167,.75726,0,0,.77778],10937:[.26167,.75726,0,0,.77778],10938:[.26167,.75726,0,0,.77778],10949:[.25583,.75583,0,0,.77778],10950:[.25583,.75583,0,0,.77778],10955:[.28481,.79383,0,0,.77778],10956:[.28481,.79383,0,0,.77778],57350:[.08167,.58167,0,0,.22222],57351:[.08167,.58167,0,0,.38889],57352:[.08167,.58167,0,0,.77778],57353:[0,.43056,.04028,0,.66667],57356:[.25142,.75726,0,0,.77778],57357:[.25142,.75726,0,0,.77778],57358:[.41951,.91951,0,0,.77778],57359:[.30274,.79383,0,0,.77778],57360:[.30274,.79383,0,0,.77778],57361:[.41951,.91951,0,0,.77778],57366:[.25142,.75726,0,0,.77778],57367:[.25142,.75726,0,0,.77778],57368:[.25142,.75726,0,0,.77778],57369:[.25142,.75726,0,0,.77778],57370:[.13597,.63597,0,0,.77778],57371:[.13597,.63597,0,0,.77778]},"Caligraphic-Regular":{32:[0,0,0,0,.25],65:[0,.68333,0,.19445,.79847],66:[0,.68333,.03041,.13889,.65681],67:[0,.68333,.05834,.13889,.52653],68:[0,.68333,.02778,.08334,.77139],69:[0,.68333,.08944,.11111,.52778],70:[0,.68333,.09931,.11111,.71875],71:[.09722,.68333,.0593,.11111,.59487],72:[0,.68333,.00965,.11111,.84452],73:[0,.68333,.07382,0,.54452],74:[.09722,.68333,.18472,.16667,.67778],75:[0,.68333,.01445,.05556,.76195],76:[0,.68333,0,.13889,.68972],77:[0,.68333,0,.13889,1.2009],78:[0,.68333,.14736,.08334,.82049],79:[0,.68333,.02778,.11111,.79611],80:[0,.68333,.08222,.08334,.69556],81:[.09722,.68333,0,.11111,.81667],82:[0,.68333,0,.08334,.8475],83:[0,.68333,.075,.13889,.60556],84:[0,.68333,.25417,0,.54464],85:[0,.68333,.09931,.08334,.62583],86:[0,.68333,.08222,0,.61278],87:[0,.68333,.08222,.08334,.98778],88:[0,.68333,.14643,.13889,.7133],89:[.09722,.68333,.08222,.08334,.66834],90:[0,.68333,.07944,.13889,.72473],160:[0,0,0,0,.25]},"Fraktur-Regular":{32:[0,0,0,0,.25],33:[0,.69141,0,0,.29574],34:[0,.69141,0,0,.21471],38:[0,.69141,0,0,.73786],39:[0,.69141,0,0,.21201],40:[.24982,.74947,0,0,.38865],41:[.24982,.74947,0,0,.38865],42:[0,.62119,0,0,.27764],43:[.08319,.58283,0,0,.75623],44:[0,.10803,0,0,.27764],45:[.08319,.58283,0,0,.75623],46:[0,.10803,0,0,.27764],47:[.24982,.74947,0,0,.50181],48:[0,.47534,0,0,.50181],49:[0,.47534,0,0,.50181],50:[0,.47534,0,0,.50181],51:[.18906,.47534,0,0,.50181],52:[.18906,.47534,0,0,.50181],53:[.18906,.47534,0,0,.50181],54:[0,.69141,0,0,.50181],55:[.18906,.47534,0,0,.50181],56:[0,.69141,0,0,.50181],57:[.18906,.47534,0,0,.50181],58:[0,.47534,0,0,.21606],59:[.12604,.47534,0,0,.21606],61:[-.13099,.36866,0,0,.75623],63:[0,.69141,0,0,.36245],65:[0,.69141,0,0,.7176],66:[0,.69141,0,0,.88397],67:[0,.69141,0,0,.61254],68:[0,.69141,0,0,.83158],69:[0,.69141,0,0,.66278],70:[.12604,.69141,0,0,.61119],71:[0,.69141,0,0,.78539],72:[.06302,.69141,0,0,.7203],73:[0,.69141,0,0,.55448],74:[.12604,.69141,0,0,.55231],75:[0,.69141,0,0,.66845],76:[0,.69141,0,0,.66602],77:[0,.69141,0,0,1.04953],78:[0,.69141,0,0,.83212],79:[0,.69141,0,0,.82699],80:[.18906,.69141,0,0,.82753],81:[.03781,.69141,0,0,.82699],82:[0,.69141,0,0,.82807],83:[0,.69141,0,0,.82861],84:[0,.69141,0,0,.66899],85:[0,.69141,0,0,.64576],86:[0,.69141,0,0,.83131],87:[0,.69141,0,0,1.04602],88:[0,.69141,0,0,.71922],89:[.18906,.69141,0,0,.83293],90:[.12604,.69141,0,0,.60201],91:[.24982,.74947,0,0,.27764],93:[.24982,.74947,0,0,.27764],94:[0,.69141,0,0,.49965],97:[0,.47534,0,0,.50046],98:[0,.69141,0,0,.51315],99:[0,.47534,0,0,.38946],100:[0,.62119,0,0,.49857],101:[0,.47534,0,0,.40053],102:[.18906,.69141,0,0,.32626],103:[.18906,.47534,0,0,.5037],104:[.18906,.69141,0,0,.52126],105:[0,.69141,0,0,.27899],106:[0,.69141,0,0,.28088],107:[0,.69141,0,0,.38946],108:[0,.69141,0,0,.27953],109:[0,.47534,0,0,.76676],110:[0,.47534,0,0,.52666],111:[0,.47534,0,0,.48885],112:[.18906,.52396,0,0,.50046],113:[.18906,.47534,0,0,.48912],114:[0,.47534,0,0,.38919],115:[0,.47534,0,0,.44266],116:[0,.62119,0,0,.33301],117:[0,.47534,0,0,.5172],118:[0,.52396,0,0,.5118],119:[0,.52396,0,0,.77351],120:[.18906,.47534,0,0,.38865],121:[.18906,.47534,0,0,.49884],122:[.18906,.47534,0,0,.39054],160:[0,0,0,0,.25],8216:[0,.69141,0,0,.21471],8217:[0,.69141,0,0,.21471],58112:[0,.62119,0,0,.49749],58113:[0,.62119,0,0,.4983],58114:[.18906,.69141,0,0,.33328],58115:[.18906,.69141,0,0,.32923],58116:[.18906,.47534,0,0,.50343],58117:[0,.69141,0,0,.33301],58118:[0,.62119,0,0,.33409],58119:[0,.47534,0,0,.50073]},"Main-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.35],34:[0,.69444,0,0,.60278],35:[.19444,.69444,0,0,.95833],36:[.05556,.75,0,0,.575],37:[.05556,.75,0,0,.95833],38:[0,.69444,0,0,.89444],39:[0,.69444,0,0,.31944],40:[.25,.75,0,0,.44722],41:[.25,.75,0,0,.44722],42:[0,.75,0,0,.575],43:[.13333,.63333,0,0,.89444],44:[.19444,.15556,0,0,.31944],45:[0,.44444,0,0,.38333],46:[0,.15556,0,0,.31944],47:[.25,.75,0,0,.575],48:[0,.64444,0,0,.575],49:[0,.64444,0,0,.575],50:[0,.64444,0,0,.575],51:[0,.64444,0,0,.575],52:[0,.64444,0,0,.575],53:[0,.64444,0,0,.575],54:[0,.64444,0,0,.575],55:[0,.64444,0,0,.575],56:[0,.64444,0,0,.575],57:[0,.64444,0,0,.575],58:[0,.44444,0,0,.31944],59:[.19444,.44444,0,0,.31944],60:[.08556,.58556,0,0,.89444],61:[-.10889,.39111,0,0,.89444],62:[.08556,.58556,0,0,.89444],63:[0,.69444,0,0,.54305],64:[0,.69444,0,0,.89444],65:[0,.68611,0,0,.86944],66:[0,.68611,0,0,.81805],67:[0,.68611,0,0,.83055],68:[0,.68611,0,0,.88194],69:[0,.68611,0,0,.75555],70:[0,.68611,0,0,.72361],71:[0,.68611,0,0,.90416],72:[0,.68611,0,0,.9],73:[0,.68611,0,0,.43611],74:[0,.68611,0,0,.59444],75:[0,.68611,0,0,.90138],76:[0,.68611,0,0,.69166],77:[0,.68611,0,0,1.09166],78:[0,.68611,0,0,.9],79:[0,.68611,0,0,.86388],80:[0,.68611,0,0,.78611],81:[.19444,.68611,0,0,.86388],82:[0,.68611,0,0,.8625],83:[0,.68611,0,0,.63889],84:[0,.68611,0,0,.8],85:[0,.68611,0,0,.88472],86:[0,.68611,.01597,0,.86944],87:[0,.68611,.01597,0,1.18888],88:[0,.68611,0,0,.86944],89:[0,.68611,.02875,0,.86944],90:[0,.68611,0,0,.70277],91:[.25,.75,0,0,.31944],92:[.25,.75,0,0,.575],93:[.25,.75,0,0,.31944],94:[0,.69444,0,0,.575],95:[.31,.13444,.03194,0,.575],97:[0,.44444,0,0,.55902],98:[0,.69444,0,0,.63889],99:[0,.44444,0,0,.51111],100:[0,.69444,0,0,.63889],101:[0,.44444,0,0,.52708],102:[0,.69444,.10903,0,.35139],103:[.19444,.44444,.01597,0,.575],104:[0,.69444,0,0,.63889],105:[0,.69444,0,0,.31944],106:[.19444,.69444,0,0,.35139],107:[0,.69444,0,0,.60694],108:[0,.69444,0,0,.31944],109:[0,.44444,0,0,.95833],110:[0,.44444,0,0,.63889],111:[0,.44444,0,0,.575],112:[.19444,.44444,0,0,.63889],113:[.19444,.44444,0,0,.60694],114:[0,.44444,0,0,.47361],115:[0,.44444,0,0,.45361],116:[0,.63492,0,0,.44722],117:[0,.44444,0,0,.63889],118:[0,.44444,.01597,0,.60694],119:[0,.44444,.01597,0,.83055],120:[0,.44444,0,0,.60694],121:[.19444,.44444,.01597,0,.60694],122:[0,.44444,0,0,.51111],123:[.25,.75,0,0,.575],124:[.25,.75,0,0,.31944],125:[.25,.75,0,0,.575],126:[.35,.34444,0,0,.575],160:[0,0,0,0,.25],163:[0,.69444,0,0,.86853],168:[0,.69444,0,0,.575],172:[0,.44444,0,0,.76666],176:[0,.69444,0,0,.86944],177:[.13333,.63333,0,0,.89444],184:[.17014,0,0,0,.51111],198:[0,.68611,0,0,1.04166],215:[.13333,.63333,0,0,.89444],216:[.04861,.73472,0,0,.89444],223:[0,.69444,0,0,.59722],230:[0,.44444,0,0,.83055],247:[.13333,.63333,0,0,.89444],248:[.09722,.54167,0,0,.575],305:[0,.44444,0,0,.31944],338:[0,.68611,0,0,1.16944],339:[0,.44444,0,0,.89444],567:[.19444,.44444,0,0,.35139],710:[0,.69444,0,0,.575],711:[0,.63194,0,0,.575],713:[0,.59611,0,0,.575],714:[0,.69444,0,0,.575],715:[0,.69444,0,0,.575],728:[0,.69444,0,0,.575],729:[0,.69444,0,0,.31944],730:[0,.69444,0,0,.86944],732:[0,.69444,0,0,.575],733:[0,.69444,0,0,.575],915:[0,.68611,0,0,.69166],916:[0,.68611,0,0,.95833],920:[0,.68611,0,0,.89444],923:[0,.68611,0,0,.80555],926:[0,.68611,0,0,.76666],928:[0,.68611,0,0,.9],931:[0,.68611,0,0,.83055],933:[0,.68611,0,0,.89444],934:[0,.68611,0,0,.83055],936:[0,.68611,0,0,.89444],937:[0,.68611,0,0,.83055],8211:[0,.44444,.03194,0,.575],8212:[0,.44444,.03194,0,1.14999],8216:[0,.69444,0,0,.31944],8217:[0,.69444,0,0,.31944],8220:[0,.69444,0,0,.60278],8221:[0,.69444,0,0,.60278],8224:[.19444,.69444,0,0,.51111],8225:[.19444,.69444,0,0,.51111],8242:[0,.55556,0,0,.34444],8407:[0,.72444,.15486,0,.575],8463:[0,.69444,0,0,.66759],8465:[0,.69444,0,0,.83055],8467:[0,.69444,0,0,.47361],8472:[.19444,.44444,0,0,.74027],8476:[0,.69444,0,0,.83055],8501:[0,.69444,0,0,.70277],8592:[-.10889,.39111,0,0,1.14999],8593:[.19444,.69444,0,0,.575],8594:[-.10889,.39111,0,0,1.14999],8595:[.19444,.69444,0,0,.575],8596:[-.10889,.39111,0,0,1.14999],8597:[.25,.75,0,0,.575],8598:[.19444,.69444,0,0,1.14999],8599:[.19444,.69444,0,0,1.14999],8600:[.19444,.69444,0,0,1.14999],8601:[.19444,.69444,0,0,1.14999],8636:[-.10889,.39111,0,0,1.14999],8637:[-.10889,.39111,0,0,1.14999],8640:[-.10889,.39111,0,0,1.14999],8641:[-.10889,.39111,0,0,1.14999],8656:[-.10889,.39111,0,0,1.14999],8657:[.19444,.69444,0,0,.70277],8658:[-.10889,.39111,0,0,1.14999],8659:[.19444,.69444,0,0,.70277],8660:[-.10889,.39111,0,0,1.14999],8661:[.25,.75,0,0,.70277],8704:[0,.69444,0,0,.63889],8706:[0,.69444,.06389,0,.62847],8707:[0,.69444,0,0,.63889],8709:[.05556,.75,0,0,.575],8711:[0,.68611,0,0,.95833],8712:[.08556,.58556,0,0,.76666],8715:[.08556,.58556,0,0,.76666],8722:[.13333,.63333,0,0,.89444],8723:[.13333,.63333,0,0,.89444],8725:[.25,.75,0,0,.575],8726:[.25,.75,0,0,.575],8727:[-.02778,.47222,0,0,.575],8728:[-.02639,.47361,0,0,.575],8729:[-.02639,.47361,0,0,.575],8730:[.18,.82,0,0,.95833],8733:[0,.44444,0,0,.89444],8734:[0,.44444,0,0,1.14999],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.31944],8741:[.25,.75,0,0,.575],8743:[0,.55556,0,0,.76666],8744:[0,.55556,0,0,.76666],8745:[0,.55556,0,0,.76666],8746:[0,.55556,0,0,.76666],8747:[.19444,.69444,.12778,0,.56875],8764:[-.10889,.39111,0,0,.89444],8768:[.19444,.69444,0,0,.31944],8771:[.00222,.50222,0,0,.89444],8773:[.027,.638,0,0,.894],8776:[.02444,.52444,0,0,.89444],8781:[.00222,.50222,0,0,.89444],8801:[.00222,.50222,0,0,.89444],8804:[.19667,.69667,0,0,.89444],8805:[.19667,.69667,0,0,.89444],8810:[.08556,.58556,0,0,1.14999],8811:[.08556,.58556,0,0,1.14999],8826:[.08556,.58556,0,0,.89444],8827:[.08556,.58556,0,0,.89444],8834:[.08556,.58556,0,0,.89444],8835:[.08556,.58556,0,0,.89444],8838:[.19667,.69667,0,0,.89444],8839:[.19667,.69667,0,0,.89444],8846:[0,.55556,0,0,.76666],8849:[.19667,.69667,0,0,.89444],8850:[.19667,.69667,0,0,.89444],8851:[0,.55556,0,0,.76666],8852:[0,.55556,0,0,.76666],8853:[.13333,.63333,0,0,.89444],8854:[.13333,.63333,0,0,.89444],8855:[.13333,.63333,0,0,.89444],8856:[.13333,.63333,0,0,.89444],8857:[.13333,.63333,0,0,.89444],8866:[0,.69444,0,0,.70277],8867:[0,.69444,0,0,.70277],8868:[0,.69444,0,0,.89444],8869:[0,.69444,0,0,.89444],8900:[-.02639,.47361,0,0,.575],8901:[-.02639,.47361,0,0,.31944],8902:[-.02778,.47222,0,0,.575],8968:[.25,.75,0,0,.51111],8969:[.25,.75,0,0,.51111],8970:[.25,.75,0,0,.51111],8971:[.25,.75,0,0,.51111],8994:[-.13889,.36111,0,0,1.14999],8995:[-.13889,.36111,0,0,1.14999],9651:[.19444,.69444,0,0,1.02222],9657:[-.02778,.47222,0,0,.575],9661:[.19444,.69444,0,0,1.02222],9667:[-.02778,.47222,0,0,.575],9711:[.19444,.69444,0,0,1.14999],9824:[.12963,.69444,0,0,.89444],9825:[.12963,.69444,0,0,.89444],9826:[.12963,.69444,0,0,.89444],9827:[.12963,.69444,0,0,.89444],9837:[0,.75,0,0,.44722],9838:[.19444,.69444,0,0,.44722],9839:[.19444,.69444,0,0,.44722],10216:[.25,.75,0,0,.44722],10217:[.25,.75,0,0,.44722],10815:[0,.68611,0,0,.9],10927:[.19667,.69667,0,0,.89444],10928:[.19667,.69667,0,0,.89444],57376:[.19444,.69444,0,0,0]},"Main-BoldItalic":{32:[0,0,0,0,.25],33:[0,.69444,.11417,0,.38611],34:[0,.69444,.07939,0,.62055],35:[.19444,.69444,.06833,0,.94444],37:[.05556,.75,.12861,0,.94444],38:[0,.69444,.08528,0,.88555],39:[0,.69444,.12945,0,.35555],40:[.25,.75,.15806,0,.47333],41:[.25,.75,.03306,0,.47333],42:[0,.75,.14333,0,.59111],43:[.10333,.60333,.03306,0,.88555],44:[.19444,.14722,0,0,.35555],45:[0,.44444,.02611,0,.41444],46:[0,.14722,0,0,.35555],47:[.25,.75,.15806,0,.59111],48:[0,.64444,.13167,0,.59111],49:[0,.64444,.13167,0,.59111],50:[0,.64444,.13167,0,.59111],51:[0,.64444,.13167,0,.59111],52:[.19444,.64444,.13167,0,.59111],53:[0,.64444,.13167,0,.59111],54:[0,.64444,.13167,0,.59111],55:[.19444,.64444,.13167,0,.59111],56:[0,.64444,.13167,0,.59111],57:[0,.64444,.13167,0,.59111],58:[0,.44444,.06695,0,.35555],59:[.19444,.44444,.06695,0,.35555],61:[-.10889,.39111,.06833,0,.88555],63:[0,.69444,.11472,0,.59111],64:[0,.69444,.09208,0,.88555],65:[0,.68611,0,0,.86555],66:[0,.68611,.0992,0,.81666],67:[0,.68611,.14208,0,.82666],68:[0,.68611,.09062,0,.87555],69:[0,.68611,.11431,0,.75666],70:[0,.68611,.12903,0,.72722],71:[0,.68611,.07347,0,.89527],72:[0,.68611,.17208,0,.8961],73:[0,.68611,.15681,0,.47166],74:[0,.68611,.145,0,.61055],75:[0,.68611,.14208,0,.89499],76:[0,.68611,0,0,.69777],77:[0,.68611,.17208,0,1.07277],78:[0,.68611,.17208,0,.8961],79:[0,.68611,.09062,0,.85499],80:[0,.68611,.0992,0,.78721],81:[.19444,.68611,.09062,0,.85499],82:[0,.68611,.02559,0,.85944],83:[0,.68611,.11264,0,.64999],84:[0,.68611,.12903,0,.7961],85:[0,.68611,.17208,0,.88083],86:[0,.68611,.18625,0,.86555],87:[0,.68611,.18625,0,1.15999],88:[0,.68611,.15681,0,.86555],89:[0,.68611,.19803,0,.86555],90:[0,.68611,.14208,0,.70888],91:[.25,.75,.1875,0,.35611],93:[.25,.75,.09972,0,.35611],94:[0,.69444,.06709,0,.59111],95:[.31,.13444,.09811,0,.59111],97:[0,.44444,.09426,0,.59111],98:[0,.69444,.07861,0,.53222],99:[0,.44444,.05222,0,.53222],100:[0,.69444,.10861,0,.59111],101:[0,.44444,.085,0,.53222],102:[.19444,.69444,.21778,0,.4],103:[.19444,.44444,.105,0,.53222],104:[0,.69444,.09426,0,.59111],105:[0,.69326,.11387,0,.35555],106:[.19444,.69326,.1672,0,.35555],107:[0,.69444,.11111,0,.53222],108:[0,.69444,.10861,0,.29666],109:[0,.44444,.09426,0,.94444],110:[0,.44444,.09426,0,.64999],111:[0,.44444,.07861,0,.59111],112:[.19444,.44444,.07861,0,.59111],113:[.19444,.44444,.105,0,.53222],114:[0,.44444,.11111,0,.50167],115:[0,.44444,.08167,0,.48694],116:[0,.63492,.09639,0,.385],117:[0,.44444,.09426,0,.62055],118:[0,.44444,.11111,0,.53222],119:[0,.44444,.11111,0,.76777],120:[0,.44444,.12583,0,.56055],121:[.19444,.44444,.105,0,.56166],122:[0,.44444,.13889,0,.49055],126:[.35,.34444,.11472,0,.59111],160:[0,0,0,0,.25],168:[0,.69444,.11473,0,.59111],176:[0,.69444,0,0,.94888],184:[.17014,0,0,0,.53222],198:[0,.68611,.11431,0,1.02277],216:[.04861,.73472,.09062,0,.88555],223:[.19444,.69444,.09736,0,.665],230:[0,.44444,.085,0,.82666],248:[.09722,.54167,.09458,0,.59111],305:[0,.44444,.09426,0,.35555],338:[0,.68611,.11431,0,1.14054],339:[0,.44444,.085,0,.82666],567:[.19444,.44444,.04611,0,.385],710:[0,.69444,.06709,0,.59111],711:[0,.63194,.08271,0,.59111],713:[0,.59444,.10444,0,.59111],714:[0,.69444,.08528,0,.59111],715:[0,.69444,0,0,.59111],728:[0,.69444,.10333,0,.59111],729:[0,.69444,.12945,0,.35555],730:[0,.69444,0,0,.94888],732:[0,.69444,.11472,0,.59111],733:[0,.69444,.11472,0,.59111],915:[0,.68611,.12903,0,.69777],916:[0,.68611,0,0,.94444],920:[0,.68611,.09062,0,.88555],923:[0,.68611,0,0,.80666],926:[0,.68611,.15092,0,.76777],928:[0,.68611,.17208,0,.8961],931:[0,.68611,.11431,0,.82666],933:[0,.68611,.10778,0,.88555],934:[0,.68611,.05632,0,.82666],936:[0,.68611,.10778,0,.88555],937:[0,.68611,.0992,0,.82666],8211:[0,.44444,.09811,0,.59111],8212:[0,.44444,.09811,0,1.18221],8216:[0,.69444,.12945,0,.35555],8217:[0,.69444,.12945,0,.35555],8220:[0,.69444,.16772,0,.62055],8221:[0,.69444,.07939,0,.62055]},"Main-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.12417,0,.30667],34:[0,.69444,.06961,0,.51444],35:[.19444,.69444,.06616,0,.81777],37:[.05556,.75,.13639,0,.81777],38:[0,.69444,.09694,0,.76666],39:[0,.69444,.12417,0,.30667],40:[.25,.75,.16194,0,.40889],41:[.25,.75,.03694,0,.40889],42:[0,.75,.14917,0,.51111],43:[.05667,.56167,.03694,0,.76666],44:[.19444,.10556,0,0,.30667],45:[0,.43056,.02826,0,.35778],46:[0,.10556,0,0,.30667],47:[.25,.75,.16194,0,.51111],48:[0,.64444,.13556,0,.51111],49:[0,.64444,.13556,0,.51111],50:[0,.64444,.13556,0,.51111],51:[0,.64444,.13556,0,.51111],52:[.19444,.64444,.13556,0,.51111],53:[0,.64444,.13556,0,.51111],54:[0,.64444,.13556,0,.51111],55:[.19444,.64444,.13556,0,.51111],56:[0,.64444,.13556,0,.51111],57:[0,.64444,.13556,0,.51111],58:[0,.43056,.0582,0,.30667],59:[.19444,.43056,.0582,0,.30667],61:[-.13313,.36687,.06616,0,.76666],63:[0,.69444,.1225,0,.51111],64:[0,.69444,.09597,0,.76666],65:[0,.68333,0,0,.74333],66:[0,.68333,.10257,0,.70389],67:[0,.68333,.14528,0,.71555],68:[0,.68333,.09403,0,.755],69:[0,.68333,.12028,0,.67833],70:[0,.68333,.13305,0,.65277],71:[0,.68333,.08722,0,.77361],72:[0,.68333,.16389,0,.74333],73:[0,.68333,.15806,0,.38555],74:[0,.68333,.14028,0,.525],75:[0,.68333,.14528,0,.76888],76:[0,.68333,0,0,.62722],77:[0,.68333,.16389,0,.89666],78:[0,.68333,.16389,0,.74333],79:[0,.68333,.09403,0,.76666],80:[0,.68333,.10257,0,.67833],81:[.19444,.68333,.09403,0,.76666],82:[0,.68333,.03868,0,.72944],83:[0,.68333,.11972,0,.56222],84:[0,.68333,.13305,0,.71555],85:[0,.68333,.16389,0,.74333],86:[0,.68333,.18361,0,.74333],87:[0,.68333,.18361,0,.99888],88:[0,.68333,.15806,0,.74333],89:[0,.68333,.19383,0,.74333],90:[0,.68333,.14528,0,.61333],91:[.25,.75,.1875,0,.30667],93:[.25,.75,.10528,0,.30667],94:[0,.69444,.06646,0,.51111],95:[.31,.12056,.09208,0,.51111],97:[0,.43056,.07671,0,.51111],98:[0,.69444,.06312,0,.46],99:[0,.43056,.05653,0,.46],100:[0,.69444,.10333,0,.51111],101:[0,.43056,.07514,0,.46],102:[.19444,.69444,.21194,0,.30667],103:[.19444,.43056,.08847,0,.46],104:[0,.69444,.07671,0,.51111],105:[0,.65536,.1019,0,.30667],106:[.19444,.65536,.14467,0,.30667],107:[0,.69444,.10764,0,.46],108:[0,.69444,.10333,0,.25555],109:[0,.43056,.07671,0,.81777],110:[0,.43056,.07671,0,.56222],111:[0,.43056,.06312,0,.51111],112:[.19444,.43056,.06312,0,.51111],113:[.19444,.43056,.08847,0,.46],114:[0,.43056,.10764,0,.42166],115:[0,.43056,.08208,0,.40889],116:[0,.61508,.09486,0,.33222],117:[0,.43056,.07671,0,.53666],118:[0,.43056,.10764,0,.46],119:[0,.43056,.10764,0,.66444],120:[0,.43056,.12042,0,.46389],121:[.19444,.43056,.08847,0,.48555],122:[0,.43056,.12292,0,.40889],126:[.35,.31786,.11585,0,.51111],160:[0,0,0,0,.25],168:[0,.66786,.10474,0,.51111],176:[0,.69444,0,0,.83129],184:[.17014,0,0,0,.46],198:[0,.68333,.12028,0,.88277],216:[.04861,.73194,.09403,0,.76666],223:[.19444,.69444,.10514,0,.53666],230:[0,.43056,.07514,0,.71555],248:[.09722,.52778,.09194,0,.51111],338:[0,.68333,.12028,0,.98499],339:[0,.43056,.07514,0,.71555],710:[0,.69444,.06646,0,.51111],711:[0,.62847,.08295,0,.51111],713:[0,.56167,.10333,0,.51111],714:[0,.69444,.09694,0,.51111],715:[0,.69444,0,0,.51111],728:[0,.69444,.10806,0,.51111],729:[0,.66786,.11752,0,.30667],730:[0,.69444,0,0,.83129],732:[0,.66786,.11585,0,.51111],733:[0,.69444,.1225,0,.51111],915:[0,.68333,.13305,0,.62722],916:[0,.68333,0,0,.81777],920:[0,.68333,.09403,0,.76666],923:[0,.68333,0,0,.69222],926:[0,.68333,.15294,0,.66444],928:[0,.68333,.16389,0,.74333],931:[0,.68333,.12028,0,.71555],933:[0,.68333,.11111,0,.76666],934:[0,.68333,.05986,0,.71555],936:[0,.68333,.11111,0,.76666],937:[0,.68333,.10257,0,.71555],8211:[0,.43056,.09208,0,.51111],8212:[0,.43056,.09208,0,1.02222],8216:[0,.69444,.12417,0,.30667],8217:[0,.69444,.12417,0,.30667],8220:[0,.69444,.1685,0,.51444],8221:[0,.69444,.06961,0,.51444],8463:[0,.68889,0,0,.54028]},"Main-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.27778],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.77778],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.19444,.10556,0,0,.27778],45:[0,.43056,0,0,.33333],46:[0,.10556,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.64444,0,0,.5],49:[0,.64444,0,0,.5],50:[0,.64444,0,0,.5],51:[0,.64444,0,0,.5],52:[0,.64444,0,0,.5],53:[0,.64444,0,0,.5],54:[0,.64444,0,0,.5],55:[0,.64444,0,0,.5],56:[0,.64444,0,0,.5],57:[0,.64444,0,0,.5],58:[0,.43056,0,0,.27778],59:[.19444,.43056,0,0,.27778],60:[.0391,.5391,0,0,.77778],61:[-.13313,.36687,0,0,.77778],62:[.0391,.5391,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.77778],65:[0,.68333,0,0,.75],66:[0,.68333,0,0,.70834],67:[0,.68333,0,0,.72222],68:[0,.68333,0,0,.76389],69:[0,.68333,0,0,.68056],70:[0,.68333,0,0,.65278],71:[0,.68333,0,0,.78472],72:[0,.68333,0,0,.75],73:[0,.68333,0,0,.36111],74:[0,.68333,0,0,.51389],75:[0,.68333,0,0,.77778],76:[0,.68333,0,0,.625],77:[0,.68333,0,0,.91667],78:[0,.68333,0,0,.75],79:[0,.68333,0,0,.77778],80:[0,.68333,0,0,.68056],81:[.19444,.68333,0,0,.77778],82:[0,.68333,0,0,.73611],83:[0,.68333,0,0,.55556],84:[0,.68333,0,0,.72222],85:[0,.68333,0,0,.75],86:[0,.68333,.01389,0,.75],87:[0,.68333,.01389,0,1.02778],88:[0,.68333,0,0,.75],89:[0,.68333,.025,0,.75],90:[0,.68333,0,0,.61111],91:[.25,.75,0,0,.27778],92:[.25,.75,0,0,.5],93:[.25,.75,0,0,.27778],94:[0,.69444,0,0,.5],95:[.31,.12056,.02778,0,.5],97:[0,.43056,0,0,.5],98:[0,.69444,0,0,.55556],99:[0,.43056,0,0,.44445],100:[0,.69444,0,0,.55556],101:[0,.43056,0,0,.44445],102:[0,.69444,.07778,0,.30556],103:[.19444,.43056,.01389,0,.5],104:[0,.69444,0,0,.55556],105:[0,.66786,0,0,.27778],106:[.19444,.66786,0,0,.30556],107:[0,.69444,0,0,.52778],108:[0,.69444,0,0,.27778],109:[0,.43056,0,0,.83334],110:[0,.43056,0,0,.55556],111:[0,.43056,0,0,.5],112:[.19444,.43056,0,0,.55556],113:[.19444,.43056,0,0,.52778],114:[0,.43056,0,0,.39167],115:[0,.43056,0,0,.39445],116:[0,.61508,0,0,.38889],117:[0,.43056,0,0,.55556],118:[0,.43056,.01389,0,.52778],119:[0,.43056,.01389,0,.72222],120:[0,.43056,0,0,.52778],121:[.19444,.43056,.01389,0,.52778],122:[0,.43056,0,0,.44445],123:[.25,.75,0,0,.5],124:[.25,.75,0,0,.27778],125:[.25,.75,0,0,.5],126:[.35,.31786,0,0,.5],160:[0,0,0,0,.25],163:[0,.69444,0,0,.76909],167:[.19444,.69444,0,0,.44445],168:[0,.66786,0,0,.5],172:[0,.43056,0,0,.66667],176:[0,.69444,0,0,.75],177:[.08333,.58333,0,0,.77778],182:[.19444,.69444,0,0,.61111],184:[.17014,0,0,0,.44445],198:[0,.68333,0,0,.90278],215:[.08333,.58333,0,0,.77778],216:[.04861,.73194,0,0,.77778],223:[0,.69444,0,0,.5],230:[0,.43056,0,0,.72222],247:[.08333,.58333,0,0,.77778],248:[.09722,.52778,0,0,.5],305:[0,.43056,0,0,.27778],338:[0,.68333,0,0,1.01389],339:[0,.43056,0,0,.77778],567:[.19444,.43056,0,0,.30556],710:[0,.69444,0,0,.5],711:[0,.62847,0,0,.5],713:[0,.56778,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.66786,0,0,.27778],730:[0,.69444,0,0,.75],732:[0,.66786,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.68333,0,0,.625],916:[0,.68333,0,0,.83334],920:[0,.68333,0,0,.77778],923:[0,.68333,0,0,.69445],926:[0,.68333,0,0,.66667],928:[0,.68333,0,0,.75],931:[0,.68333,0,0,.72222],933:[0,.68333,0,0,.77778],934:[0,.68333,0,0,.72222],936:[0,.68333,0,0,.77778],937:[0,.68333,0,0,.72222],8211:[0,.43056,.02778,0,.5],8212:[0,.43056,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5],8224:[.19444,.69444,0,0,.44445],8225:[.19444,.69444,0,0,.44445],8230:[0,.123,0,0,1.172],8242:[0,.55556,0,0,.275],8407:[0,.71444,.15382,0,.5],8463:[0,.68889,0,0,.54028],8465:[0,.69444,0,0,.72222],8467:[0,.69444,0,.11111,.41667],8472:[.19444,.43056,0,.11111,.63646],8476:[0,.69444,0,0,.72222],8501:[0,.69444,0,0,.61111],8592:[-.13313,.36687,0,0,1],8593:[.19444,.69444,0,0,.5],8594:[-.13313,.36687,0,0,1],8595:[.19444,.69444,0,0,.5],8596:[-.13313,.36687,0,0,1],8597:[.25,.75,0,0,.5],8598:[.19444,.69444,0,0,1],8599:[.19444,.69444,0,0,1],8600:[.19444,.69444,0,0,1],8601:[.19444,.69444,0,0,1],8614:[.011,.511,0,0,1],8617:[.011,.511,0,0,1.126],8618:[.011,.511,0,0,1.126],8636:[-.13313,.36687,0,0,1],8637:[-.13313,.36687,0,0,1],8640:[-.13313,.36687,0,0,1],8641:[-.13313,.36687,0,0,1],8652:[.011,.671,0,0,1],8656:[-.13313,.36687,0,0,1],8657:[.19444,.69444,0,0,.61111],8658:[-.13313,.36687,0,0,1],8659:[.19444,.69444,0,0,.61111],8660:[-.13313,.36687,0,0,1],8661:[.25,.75,0,0,.61111],8704:[0,.69444,0,0,.55556],8706:[0,.69444,.05556,.08334,.5309],8707:[0,.69444,0,0,.55556],8709:[.05556,.75,0,0,.5],8711:[0,.68333,0,0,.83334],8712:[.0391,.5391,0,0,.66667],8715:[.0391,.5391,0,0,.66667],8722:[.08333,.58333,0,0,.77778],8723:[.08333,.58333,0,0,.77778],8725:[.25,.75,0,0,.5],8726:[.25,.75,0,0,.5],8727:[-.03472,.46528,0,0,.5],8728:[-.05555,.44445,0,0,.5],8729:[-.05555,.44445,0,0,.5],8730:[.2,.8,0,0,.83334],8733:[0,.43056,0,0,.77778],8734:[0,.43056,0,0,1],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.27778],8741:[.25,.75,0,0,.5],8743:[0,.55556,0,0,.66667],8744:[0,.55556,0,0,.66667],8745:[0,.55556,0,0,.66667],8746:[0,.55556,0,0,.66667],8747:[.19444,.69444,.11111,0,.41667],8764:[-.13313,.36687,0,0,.77778],8768:[.19444,.69444,0,0,.27778],8771:[-.03625,.46375,0,0,.77778],8773:[-.022,.589,0,0,.778],8776:[-.01688,.48312,0,0,.77778],8781:[-.03625,.46375,0,0,.77778],8784:[-.133,.673,0,0,.778],8801:[-.03625,.46375,0,0,.77778],8804:[.13597,.63597,0,0,.77778],8805:[.13597,.63597,0,0,.77778],8810:[.0391,.5391,0,0,1],8811:[.0391,.5391,0,0,1],8826:[.0391,.5391,0,0,.77778],8827:[.0391,.5391,0,0,.77778],8834:[.0391,.5391,0,0,.77778],8835:[.0391,.5391,0,0,.77778],8838:[.13597,.63597,0,0,.77778],8839:[.13597,.63597,0,0,.77778],8846:[0,.55556,0,0,.66667],8849:[.13597,.63597,0,0,.77778],8850:[.13597,.63597,0,0,.77778],8851:[0,.55556,0,0,.66667],8852:[0,.55556,0,0,.66667],8853:[.08333,.58333,0,0,.77778],8854:[.08333,.58333,0,0,.77778],8855:[.08333,.58333,0,0,.77778],8856:[.08333,.58333,0,0,.77778],8857:[.08333,.58333,0,0,.77778],8866:[0,.69444,0,0,.61111],8867:[0,.69444,0,0,.61111],8868:[0,.69444,0,0,.77778],8869:[0,.69444,0,0,.77778],8872:[.249,.75,0,0,.867],8900:[-.05555,.44445,0,0,.5],8901:[-.05555,.44445,0,0,.27778],8902:[-.03472,.46528,0,0,.5],8904:[.005,.505,0,0,.9],8942:[.03,.903,0,0,.278],8943:[-.19,.313,0,0,1.172],8945:[-.1,.823,0,0,1.282],8968:[.25,.75,0,0,.44445],8969:[.25,.75,0,0,.44445],8970:[.25,.75,0,0,.44445],8971:[.25,.75,0,0,.44445],8994:[-.14236,.35764,0,0,1],8995:[-.14236,.35764,0,0,1],9136:[.244,.744,0,0,.412],9137:[.244,.745,0,0,.412],9651:[.19444,.69444,0,0,.88889],9657:[-.03472,.46528,0,0,.5],9661:[.19444,.69444,0,0,.88889],9667:[-.03472,.46528,0,0,.5],9711:[.19444,.69444,0,0,1],9824:[.12963,.69444,0,0,.77778],9825:[.12963,.69444,0,0,.77778],9826:[.12963,.69444,0,0,.77778],9827:[.12963,.69444,0,0,.77778],9837:[0,.75,0,0,.38889],9838:[.19444,.69444,0,0,.38889],9839:[.19444,.69444,0,0,.38889],10216:[.25,.75,0,0,.38889],10217:[.25,.75,0,0,.38889],10222:[.244,.744,0,0,.412],10223:[.244,.745,0,0,.412],10229:[.011,.511,0,0,1.609],10230:[.011,.511,0,0,1.638],10231:[.011,.511,0,0,1.859],10232:[.024,.525,0,0,1.609],10233:[.024,.525,0,0,1.638],10234:[.024,.525,0,0,1.858],10236:[.011,.511,0,0,1.638],10815:[0,.68333,0,0,.75],10927:[.13597,.63597,0,0,.77778],10928:[.13597,.63597,0,0,.77778],57376:[.19444,.69444,0,0,0]},"Math-BoldItalic":{32:[0,0,0,0,.25],48:[0,.44444,0,0,.575],49:[0,.44444,0,0,.575],50:[0,.44444,0,0,.575],51:[.19444,.44444,0,0,.575],52:[.19444,.44444,0,0,.575],53:[.19444,.44444,0,0,.575],54:[0,.64444,0,0,.575],55:[.19444,.44444,0,0,.575],56:[0,.64444,0,0,.575],57:[.19444,.44444,0,0,.575],65:[0,.68611,0,0,.86944],66:[0,.68611,.04835,0,.8664],67:[0,.68611,.06979,0,.81694],68:[0,.68611,.03194,0,.93812],69:[0,.68611,.05451,0,.81007],70:[0,.68611,.15972,0,.68889],71:[0,.68611,0,0,.88673],72:[0,.68611,.08229,0,.98229],73:[0,.68611,.07778,0,.51111],74:[0,.68611,.10069,0,.63125],75:[0,.68611,.06979,0,.97118],76:[0,.68611,0,0,.75555],77:[0,.68611,.11424,0,1.14201],78:[0,.68611,.11424,0,.95034],79:[0,.68611,.03194,0,.83666],80:[0,.68611,.15972,0,.72309],81:[.19444,.68611,0,0,.86861],82:[0,.68611,.00421,0,.87235],83:[0,.68611,.05382,0,.69271],84:[0,.68611,.15972,0,.63663],85:[0,.68611,.11424,0,.80027],86:[0,.68611,.25555,0,.67778],87:[0,.68611,.15972,0,1.09305],88:[0,.68611,.07778,0,.94722],89:[0,.68611,.25555,0,.67458],90:[0,.68611,.06979,0,.77257],97:[0,.44444,0,0,.63287],98:[0,.69444,0,0,.52083],99:[0,.44444,0,0,.51342],100:[0,.69444,0,0,.60972],101:[0,.44444,0,0,.55361],102:[.19444,.69444,.11042,0,.56806],103:[.19444,.44444,.03704,0,.5449],104:[0,.69444,0,0,.66759],105:[0,.69326,0,0,.4048],106:[.19444,.69326,.0622,0,.47083],107:[0,.69444,.01852,0,.6037],108:[0,.69444,.0088,0,.34815],109:[0,.44444,0,0,1.0324],110:[0,.44444,0,0,.71296],111:[0,.44444,0,0,.58472],112:[.19444,.44444,0,0,.60092],113:[.19444,.44444,.03704,0,.54213],114:[0,.44444,.03194,0,.5287],115:[0,.44444,0,0,.53125],116:[0,.63492,0,0,.41528],117:[0,.44444,0,0,.68102],118:[0,.44444,.03704,0,.56666],119:[0,.44444,.02778,0,.83148],120:[0,.44444,0,0,.65903],121:[.19444,.44444,.03704,0,.59028],122:[0,.44444,.04213,0,.55509],160:[0,0,0,0,.25],915:[0,.68611,.15972,0,.65694],916:[0,.68611,0,0,.95833],920:[0,.68611,.03194,0,.86722],923:[0,.68611,0,0,.80555],926:[0,.68611,.07458,0,.84125],928:[0,.68611,.08229,0,.98229],931:[0,.68611,.05451,0,.88507],933:[0,.68611,.15972,0,.67083],934:[0,.68611,0,0,.76666],936:[0,.68611,.11653,0,.71402],937:[0,.68611,.04835,0,.8789],945:[0,.44444,0,0,.76064],946:[.19444,.69444,.03403,0,.65972],947:[.19444,.44444,.06389,0,.59003],948:[0,.69444,.03819,0,.52222],949:[0,.44444,0,0,.52882],950:[.19444,.69444,.06215,0,.50833],951:[.19444,.44444,.03704,0,.6],952:[0,.69444,.03194,0,.5618],953:[0,.44444,0,0,.41204],954:[0,.44444,0,0,.66759],955:[0,.69444,0,0,.67083],956:[.19444,.44444,0,0,.70787],957:[0,.44444,.06898,0,.57685],958:[.19444,.69444,.03021,0,.50833],959:[0,.44444,0,0,.58472],960:[0,.44444,.03704,0,.68241],961:[.19444,.44444,0,0,.6118],962:[.09722,.44444,.07917,0,.42361],963:[0,.44444,.03704,0,.68588],964:[0,.44444,.13472,0,.52083],965:[0,.44444,.03704,0,.63055],966:[.19444,.44444,0,0,.74722],967:[.19444,.44444,0,0,.71805],968:[.19444,.69444,.03704,0,.75833],969:[0,.44444,.03704,0,.71782],977:[0,.69444,0,0,.69155],981:[.19444,.69444,0,0,.7125],982:[0,.44444,.03194,0,.975],1009:[.19444,.44444,0,0,.6118],1013:[0,.44444,0,0,.48333],57649:[0,.44444,0,0,.39352],57911:[.19444,.44444,0,0,.43889]},"Math-Italic":{32:[0,0,0,0,.25],48:[0,.43056,0,0,.5],49:[0,.43056,0,0,.5],50:[0,.43056,0,0,.5],51:[.19444,.43056,0,0,.5],52:[.19444,.43056,0,0,.5],53:[.19444,.43056,0,0,.5],54:[0,.64444,0,0,.5],55:[.19444,.43056,0,0,.5],56:[0,.64444,0,0,.5],57:[.19444,.43056,0,0,.5],65:[0,.68333,0,.13889,.75],66:[0,.68333,.05017,.08334,.75851],67:[0,.68333,.07153,.08334,.71472],68:[0,.68333,.02778,.05556,.82792],69:[0,.68333,.05764,.08334,.7382],70:[0,.68333,.13889,.08334,.64306],71:[0,.68333,0,.08334,.78625],72:[0,.68333,.08125,.05556,.83125],73:[0,.68333,.07847,.11111,.43958],74:[0,.68333,.09618,.16667,.55451],75:[0,.68333,.07153,.05556,.84931],76:[0,.68333,0,.02778,.68056],77:[0,.68333,.10903,.08334,.97014],78:[0,.68333,.10903,.08334,.80347],79:[0,.68333,.02778,.08334,.76278],80:[0,.68333,.13889,.08334,.64201],81:[.19444,.68333,0,.08334,.79056],82:[0,.68333,.00773,.08334,.75929],83:[0,.68333,.05764,.08334,.6132],84:[0,.68333,.13889,.08334,.58438],85:[0,.68333,.10903,.02778,.68278],86:[0,.68333,.22222,0,.58333],87:[0,.68333,.13889,0,.94445],88:[0,.68333,.07847,.08334,.82847],89:[0,.68333,.22222,0,.58056],90:[0,.68333,.07153,.08334,.68264],97:[0,.43056,0,0,.52859],98:[0,.69444,0,0,.42917],99:[0,.43056,0,.05556,.43276],100:[0,.69444,0,.16667,.52049],101:[0,.43056,0,.05556,.46563],102:[.19444,.69444,.10764,.16667,.48959],103:[.19444,.43056,.03588,.02778,.47697],104:[0,.69444,0,0,.57616],105:[0,.65952,0,0,.34451],106:[.19444,.65952,.05724,0,.41181],107:[0,.69444,.03148,0,.5206],108:[0,.69444,.01968,.08334,.29838],109:[0,.43056,0,0,.87801],110:[0,.43056,0,0,.60023],111:[0,.43056,0,.05556,.48472],112:[.19444,.43056,0,.08334,.50313],113:[.19444,.43056,.03588,.08334,.44641],114:[0,.43056,.02778,.05556,.45116],115:[0,.43056,0,.05556,.46875],116:[0,.61508,0,.08334,.36111],117:[0,.43056,0,.02778,.57246],118:[0,.43056,.03588,.02778,.48472],119:[0,.43056,.02691,.08334,.71592],120:[0,.43056,0,.02778,.57153],121:[.19444,.43056,.03588,.05556,.49028],122:[0,.43056,.04398,.05556,.46505],160:[0,0,0,0,.25],915:[0,.68333,.13889,.08334,.61528],916:[0,.68333,0,.16667,.83334],920:[0,.68333,.02778,.08334,.76278],923:[0,.68333,0,.16667,.69445],926:[0,.68333,.07569,.08334,.74236],928:[0,.68333,.08125,.05556,.83125],931:[0,.68333,.05764,.08334,.77986],933:[0,.68333,.13889,.05556,.58333],934:[0,.68333,0,.08334,.66667],936:[0,.68333,.11,.05556,.61222],937:[0,.68333,.05017,.08334,.7724],945:[0,.43056,.0037,.02778,.6397],946:[.19444,.69444,.05278,.08334,.56563],947:[.19444,.43056,.05556,0,.51773],948:[0,.69444,.03785,.05556,.44444],949:[0,.43056,0,.08334,.46632],950:[.19444,.69444,.07378,.08334,.4375],951:[.19444,.43056,.03588,.05556,.49653],952:[0,.69444,.02778,.08334,.46944],953:[0,.43056,0,.05556,.35394],954:[0,.43056,0,0,.57616],955:[0,.69444,0,0,.58334],956:[.19444,.43056,0,.02778,.60255],957:[0,.43056,.06366,.02778,.49398],958:[.19444,.69444,.04601,.11111,.4375],959:[0,.43056,0,.05556,.48472],960:[0,.43056,.03588,0,.57003],961:[.19444,.43056,0,.08334,.51702],962:[.09722,.43056,.07986,.08334,.36285],963:[0,.43056,.03588,0,.57141],964:[0,.43056,.1132,.02778,.43715],965:[0,.43056,.03588,.02778,.54028],966:[.19444,.43056,0,.08334,.65417],967:[.19444,.43056,0,.05556,.62569],968:[.19444,.69444,.03588,.11111,.65139],969:[0,.43056,.03588,0,.62245],977:[0,.69444,0,.08334,.59144],981:[.19444,.69444,0,.08334,.59583],982:[0,.43056,.02778,0,.82813],1009:[.19444,.43056,0,.08334,.51702],1013:[0,.43056,0,.05556,.4059],57649:[0,.43056,0,.02778,.32246],57911:[.19444,.43056,0,.08334,.38403]},"SansSerif-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.36667],34:[0,.69444,0,0,.55834],35:[.19444,.69444,0,0,.91667],36:[.05556,.75,0,0,.55],37:[.05556,.75,0,0,1.02912],38:[0,.69444,0,0,.83056],39:[0,.69444,0,0,.30556],40:[.25,.75,0,0,.42778],41:[.25,.75,0,0,.42778],42:[0,.75,0,0,.55],43:[.11667,.61667,0,0,.85556],44:[.10556,.13056,0,0,.30556],45:[0,.45833,0,0,.36667],46:[0,.13056,0,0,.30556],47:[.25,.75,0,0,.55],48:[0,.69444,0,0,.55],49:[0,.69444,0,0,.55],50:[0,.69444,0,0,.55],51:[0,.69444,0,0,.55],52:[0,.69444,0,0,.55],53:[0,.69444,0,0,.55],54:[0,.69444,0,0,.55],55:[0,.69444,0,0,.55],56:[0,.69444,0,0,.55],57:[0,.69444,0,0,.55],58:[0,.45833,0,0,.30556],59:[.10556,.45833,0,0,.30556],61:[-.09375,.40625,0,0,.85556],63:[0,.69444,0,0,.51945],64:[0,.69444,0,0,.73334],65:[0,.69444,0,0,.73334],66:[0,.69444,0,0,.73334],67:[0,.69444,0,0,.70278],68:[0,.69444,0,0,.79445],69:[0,.69444,0,0,.64167],70:[0,.69444,0,0,.61111],71:[0,.69444,0,0,.73334],72:[0,.69444,0,0,.79445],73:[0,.69444,0,0,.33056],74:[0,.69444,0,0,.51945],75:[0,.69444,0,0,.76389],76:[0,.69444,0,0,.58056],77:[0,.69444,0,0,.97778],78:[0,.69444,0,0,.79445],79:[0,.69444,0,0,.79445],80:[0,.69444,0,0,.70278],81:[.10556,.69444,0,0,.79445],82:[0,.69444,0,0,.70278],83:[0,.69444,0,0,.61111],84:[0,.69444,0,0,.73334],85:[0,.69444,0,0,.76389],86:[0,.69444,.01528,0,.73334],87:[0,.69444,.01528,0,1.03889],88:[0,.69444,0,0,.73334],89:[0,.69444,.0275,0,.73334],90:[0,.69444,0,0,.67223],91:[.25,.75,0,0,.34306],93:[.25,.75,0,0,.34306],94:[0,.69444,0,0,.55],95:[.35,.10833,.03056,0,.55],97:[0,.45833,0,0,.525],98:[0,.69444,0,0,.56111],99:[0,.45833,0,0,.48889],100:[0,.69444,0,0,.56111],101:[0,.45833,0,0,.51111],102:[0,.69444,.07639,0,.33611],103:[.19444,.45833,.01528,0,.55],104:[0,.69444,0,0,.56111],105:[0,.69444,0,0,.25556],106:[.19444,.69444,0,0,.28611],107:[0,.69444,0,0,.53056],108:[0,.69444,0,0,.25556],109:[0,.45833,0,0,.86667],110:[0,.45833,0,0,.56111],111:[0,.45833,0,0,.55],112:[.19444,.45833,0,0,.56111],113:[.19444,.45833,0,0,.56111],114:[0,.45833,.01528,0,.37222],115:[0,.45833,0,0,.42167],116:[0,.58929,0,0,.40417],117:[0,.45833,0,0,.56111],118:[0,.45833,.01528,0,.5],119:[0,.45833,.01528,0,.74445],120:[0,.45833,0,0,.5],121:[.19444,.45833,.01528,0,.5],122:[0,.45833,0,0,.47639],126:[.35,.34444,0,0,.55],160:[0,0,0,0,.25],168:[0,.69444,0,0,.55],176:[0,.69444,0,0,.73334],180:[0,.69444,0,0,.55],184:[.17014,0,0,0,.48889],305:[0,.45833,0,0,.25556],567:[.19444,.45833,0,0,.28611],710:[0,.69444,0,0,.55],711:[0,.63542,0,0,.55],713:[0,.63778,0,0,.55],728:[0,.69444,0,0,.55],729:[0,.69444,0,0,.30556],730:[0,.69444,0,0,.73334],732:[0,.69444,0,0,.55],733:[0,.69444,0,0,.55],915:[0,.69444,0,0,.58056],916:[0,.69444,0,0,.91667],920:[0,.69444,0,0,.85556],923:[0,.69444,0,0,.67223],926:[0,.69444,0,0,.73334],928:[0,.69444,0,0,.79445],931:[0,.69444,0,0,.79445],933:[0,.69444,0,0,.85556],934:[0,.69444,0,0,.79445],936:[0,.69444,0,0,.85556],937:[0,.69444,0,0,.79445],8211:[0,.45833,.03056,0,.55],8212:[0,.45833,.03056,0,1.10001],8216:[0,.69444,0,0,.30556],8217:[0,.69444,0,0,.30556],8220:[0,.69444,0,0,.55834],8221:[0,.69444,0,0,.55834]},"SansSerif-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.05733,0,.31945],34:[0,.69444,.00316,0,.5],35:[.19444,.69444,.05087,0,.83334],36:[.05556,.75,.11156,0,.5],37:[.05556,.75,.03126,0,.83334],38:[0,.69444,.03058,0,.75834],39:[0,.69444,.07816,0,.27778],40:[.25,.75,.13164,0,.38889],41:[.25,.75,.02536,0,.38889],42:[0,.75,.11775,0,.5],43:[.08333,.58333,.02536,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,.01946,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,.13164,0,.5],48:[0,.65556,.11156,0,.5],49:[0,.65556,.11156,0,.5],50:[0,.65556,.11156,0,.5],51:[0,.65556,.11156,0,.5],52:[0,.65556,.11156,0,.5],53:[0,.65556,.11156,0,.5],54:[0,.65556,.11156,0,.5],55:[0,.65556,.11156,0,.5],56:[0,.65556,.11156,0,.5],57:[0,.65556,.11156,0,.5],58:[0,.44444,.02502,0,.27778],59:[.125,.44444,.02502,0,.27778],61:[-.13,.37,.05087,0,.77778],63:[0,.69444,.11809,0,.47222],64:[0,.69444,.07555,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,.08293,0,.66667],67:[0,.69444,.11983,0,.63889],68:[0,.69444,.07555,0,.72223],69:[0,.69444,.11983,0,.59722],70:[0,.69444,.13372,0,.56945],71:[0,.69444,.11983,0,.66667],72:[0,.69444,.08094,0,.70834],73:[0,.69444,.13372,0,.27778],74:[0,.69444,.08094,0,.47222],75:[0,.69444,.11983,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,.08094,0,.875],78:[0,.69444,.08094,0,.70834],79:[0,.69444,.07555,0,.73611],80:[0,.69444,.08293,0,.63889],81:[.125,.69444,.07555,0,.73611],82:[0,.69444,.08293,0,.64584],83:[0,.69444,.09205,0,.55556],84:[0,.69444,.13372,0,.68056],85:[0,.69444,.08094,0,.6875],86:[0,.69444,.1615,0,.66667],87:[0,.69444,.1615,0,.94445],88:[0,.69444,.13372,0,.66667],89:[0,.69444,.17261,0,.66667],90:[0,.69444,.11983,0,.61111],91:[.25,.75,.15942,0,.28889],93:[.25,.75,.08719,0,.28889],94:[0,.69444,.0799,0,.5],95:[.35,.09444,.08616,0,.5],97:[0,.44444,.00981,0,.48056],98:[0,.69444,.03057,0,.51667],99:[0,.44444,.08336,0,.44445],100:[0,.69444,.09483,0,.51667],101:[0,.44444,.06778,0,.44445],102:[0,.69444,.21705,0,.30556],103:[.19444,.44444,.10836,0,.5],104:[0,.69444,.01778,0,.51667],105:[0,.67937,.09718,0,.23889],106:[.19444,.67937,.09162,0,.26667],107:[0,.69444,.08336,0,.48889],108:[0,.69444,.09483,0,.23889],109:[0,.44444,.01778,0,.79445],110:[0,.44444,.01778,0,.51667],111:[0,.44444,.06613,0,.5],112:[.19444,.44444,.0389,0,.51667],113:[.19444,.44444,.04169,0,.51667],114:[0,.44444,.10836,0,.34167],115:[0,.44444,.0778,0,.38333],116:[0,.57143,.07225,0,.36111],117:[0,.44444,.04169,0,.51667],118:[0,.44444,.10836,0,.46111],119:[0,.44444,.10836,0,.68334],120:[0,.44444,.09169,0,.46111],121:[.19444,.44444,.10836,0,.46111],122:[0,.44444,.08752,0,.43472],126:[.35,.32659,.08826,0,.5],160:[0,0,0,0,.25],168:[0,.67937,.06385,0,.5],176:[0,.69444,0,0,.73752],184:[.17014,0,0,0,.44445],305:[0,.44444,.04169,0,.23889],567:[.19444,.44444,.04169,0,.26667],710:[0,.69444,.0799,0,.5],711:[0,.63194,.08432,0,.5],713:[0,.60889,.08776,0,.5],714:[0,.69444,.09205,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,.09483,0,.5],729:[0,.67937,.07774,0,.27778],730:[0,.69444,0,0,.73752],732:[0,.67659,.08826,0,.5],733:[0,.69444,.09205,0,.5],915:[0,.69444,.13372,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,.07555,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,.12816,0,.66667],928:[0,.69444,.08094,0,.70834],931:[0,.69444,.11983,0,.72222],933:[0,.69444,.09031,0,.77778],934:[0,.69444,.04603,0,.72222],936:[0,.69444,.09031,0,.77778],937:[0,.69444,.08293,0,.72222],8211:[0,.44444,.08616,0,.5],8212:[0,.44444,.08616,0,1],8216:[0,.69444,.07816,0,.27778],8217:[0,.69444,.07816,0,.27778],8220:[0,.69444,.14205,0,.5],8221:[0,.69444,.00316,0,.5]},"SansSerif-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.31945],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.75834],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,0,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.65556,0,0,.5],49:[0,.65556,0,0,.5],50:[0,.65556,0,0,.5],51:[0,.65556,0,0,.5],52:[0,.65556,0,0,.5],53:[0,.65556,0,0,.5],54:[0,.65556,0,0,.5],55:[0,.65556,0,0,.5],56:[0,.65556,0,0,.5],57:[0,.65556,0,0,.5],58:[0,.44444,0,0,.27778],59:[.125,.44444,0,0,.27778],61:[-.13,.37,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,0,0,.66667],67:[0,.69444,0,0,.63889],68:[0,.69444,0,0,.72223],69:[0,.69444,0,0,.59722],70:[0,.69444,0,0,.56945],71:[0,.69444,0,0,.66667],72:[0,.69444,0,0,.70834],73:[0,.69444,0,0,.27778],74:[0,.69444,0,0,.47222],75:[0,.69444,0,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,0,0,.875],78:[0,.69444,0,0,.70834],79:[0,.69444,0,0,.73611],80:[0,.69444,0,0,.63889],81:[.125,.69444,0,0,.73611],82:[0,.69444,0,0,.64584],83:[0,.69444,0,0,.55556],84:[0,.69444,0,0,.68056],85:[0,.69444,0,0,.6875],86:[0,.69444,.01389,0,.66667],87:[0,.69444,.01389,0,.94445],88:[0,.69444,0,0,.66667],89:[0,.69444,.025,0,.66667],90:[0,.69444,0,0,.61111],91:[.25,.75,0,0,.28889],93:[.25,.75,0,0,.28889],94:[0,.69444,0,0,.5],95:[.35,.09444,.02778,0,.5],97:[0,.44444,0,0,.48056],98:[0,.69444,0,0,.51667],99:[0,.44444,0,0,.44445],100:[0,.69444,0,0,.51667],101:[0,.44444,0,0,.44445],102:[0,.69444,.06944,0,.30556],103:[.19444,.44444,.01389,0,.5],104:[0,.69444,0,0,.51667],105:[0,.67937,0,0,.23889],106:[.19444,.67937,0,0,.26667],107:[0,.69444,0,0,.48889],108:[0,.69444,0,0,.23889],109:[0,.44444,0,0,.79445],110:[0,.44444,0,0,.51667],111:[0,.44444,0,0,.5],112:[.19444,.44444,0,0,.51667],113:[.19444,.44444,0,0,.51667],114:[0,.44444,.01389,0,.34167],115:[0,.44444,0,0,.38333],116:[0,.57143,0,0,.36111],117:[0,.44444,0,0,.51667],118:[0,.44444,.01389,0,.46111],119:[0,.44444,.01389,0,.68334],120:[0,.44444,0,0,.46111],121:[.19444,.44444,.01389,0,.46111],122:[0,.44444,0,0,.43472],126:[.35,.32659,0,0,.5],160:[0,0,0,0,.25],168:[0,.67937,0,0,.5],176:[0,.69444,0,0,.66667],184:[.17014,0,0,0,.44445],305:[0,.44444,0,0,.23889],567:[.19444,.44444,0,0,.26667],710:[0,.69444,0,0,.5],711:[0,.63194,0,0,.5],713:[0,.60889,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.67937,0,0,.27778],730:[0,.69444,0,0,.66667],732:[0,.67659,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.69444,0,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,0,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,0,0,.66667],928:[0,.69444,0,0,.70834],931:[0,.69444,0,0,.72222],933:[0,.69444,0,0,.77778],934:[0,.69444,0,0,.72222],936:[0,.69444,0,0,.77778],937:[0,.69444,0,0,.72222],8211:[0,.44444,.02778,0,.5],8212:[0,.44444,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5]},"Script-Regular":{32:[0,0,0,0,.25],65:[0,.7,.22925,0,.80253],66:[0,.7,.04087,0,.90757],67:[0,.7,.1689,0,.66619],68:[0,.7,.09371,0,.77443],69:[0,.7,.18583,0,.56162],70:[0,.7,.13634,0,.89544],71:[0,.7,.17322,0,.60961],72:[0,.7,.29694,0,.96919],73:[0,.7,.19189,0,.80907],74:[.27778,.7,.19189,0,1.05159],75:[0,.7,.31259,0,.91364],76:[0,.7,.19189,0,.87373],77:[0,.7,.15981,0,1.08031],78:[0,.7,.3525,0,.9015],79:[0,.7,.08078,0,.73787],80:[0,.7,.08078,0,1.01262],81:[0,.7,.03305,0,.88282],82:[0,.7,.06259,0,.85],83:[0,.7,.19189,0,.86767],84:[0,.7,.29087,0,.74697],85:[0,.7,.25815,0,.79996],86:[0,.7,.27523,0,.62204],87:[0,.7,.27523,0,.80532],88:[0,.7,.26006,0,.94445],89:[0,.7,.2939,0,.70961],90:[0,.7,.24037,0,.8212],160:[0,0,0,0,.25]},"Size1-Regular":{32:[0,0,0,0,.25],40:[.35001,.85,0,0,.45834],41:[.35001,.85,0,0,.45834],47:[.35001,.85,0,0,.57778],91:[.35001,.85,0,0,.41667],92:[.35001,.85,0,0,.57778],93:[.35001,.85,0,0,.41667],123:[.35001,.85,0,0,.58334],125:[.35001,.85,0,0,.58334],160:[0,0,0,0,.25],710:[0,.72222,0,0,.55556],732:[0,.72222,0,0,.55556],770:[0,.72222,0,0,.55556],771:[0,.72222,0,0,.55556],8214:[-99e-5,.601,0,0,.77778],8593:[1e-5,.6,0,0,.66667],8595:[1e-5,.6,0,0,.66667],8657:[1e-5,.6,0,0,.77778],8659:[1e-5,.6,0,0,.77778],8719:[.25001,.75,0,0,.94445],8720:[.25001,.75,0,0,.94445],8721:[.25001,.75,0,0,1.05556],8730:[.35001,.85,0,0,1],8739:[-.00599,.606,0,0,.33333],8741:[-.00599,.606,0,0,.55556],8747:[.30612,.805,.19445,0,.47222],8748:[.306,.805,.19445,0,.47222],8749:[.306,.805,.19445,0,.47222],8750:[.30612,.805,.19445,0,.47222],8896:[.25001,.75,0,0,.83334],8897:[.25001,.75,0,0,.83334],8898:[.25001,.75,0,0,.83334],8899:[.25001,.75,0,0,.83334],8968:[.35001,.85,0,0,.47222],8969:[.35001,.85,0,0,.47222],8970:[.35001,.85,0,0,.47222],8971:[.35001,.85,0,0,.47222],9168:[-99e-5,.601,0,0,.66667],10216:[.35001,.85,0,0,.47222],10217:[.35001,.85,0,0,.47222],10752:[.25001,.75,0,0,1.11111],10753:[.25001,.75,0,0,1.11111],10754:[.25001,.75,0,0,1.11111],10756:[.25001,.75,0,0,.83334],10758:[.25001,.75,0,0,.83334]},"Size2-Regular":{32:[0,0,0,0,.25],40:[.65002,1.15,0,0,.59722],41:[.65002,1.15,0,0,.59722],47:[.65002,1.15,0,0,.81111],91:[.65002,1.15,0,0,.47222],92:[.65002,1.15,0,0,.81111],93:[.65002,1.15,0,0,.47222],123:[.65002,1.15,0,0,.66667],125:[.65002,1.15,0,0,.66667],160:[0,0,0,0,.25],710:[0,.75,0,0,1],732:[0,.75,0,0,1],770:[0,.75,0,0,1],771:[0,.75,0,0,1],8719:[.55001,1.05,0,0,1.27778],8720:[.55001,1.05,0,0,1.27778],8721:[.55001,1.05,0,0,1.44445],8730:[.65002,1.15,0,0,1],8747:[.86225,1.36,.44445,0,.55556],8748:[.862,1.36,.44445,0,.55556],8749:[.862,1.36,.44445,0,.55556],8750:[.86225,1.36,.44445,0,.55556],8896:[.55001,1.05,0,0,1.11111],8897:[.55001,1.05,0,0,1.11111],8898:[.55001,1.05,0,0,1.11111],8899:[.55001,1.05,0,0,1.11111],8968:[.65002,1.15,0,0,.52778],8969:[.65002,1.15,0,0,.52778],8970:[.65002,1.15,0,0,.52778],8971:[.65002,1.15,0,0,.52778],10216:[.65002,1.15,0,0,.61111],10217:[.65002,1.15,0,0,.61111],10752:[.55001,1.05,0,0,1.51112],10753:[.55001,1.05,0,0,1.51112],10754:[.55001,1.05,0,0,1.51112],10756:[.55001,1.05,0,0,1.11111],10758:[.55001,1.05,0,0,1.11111]},"Size3-Regular":{32:[0,0,0,0,.25],40:[.95003,1.45,0,0,.73611],41:[.95003,1.45,0,0,.73611],47:[.95003,1.45,0,0,1.04445],91:[.95003,1.45,0,0,.52778],92:[.95003,1.45,0,0,1.04445],93:[.95003,1.45,0,0,.52778],123:[.95003,1.45,0,0,.75],125:[.95003,1.45,0,0,.75],160:[0,0,0,0,.25],710:[0,.75,0,0,1.44445],732:[0,.75,0,0,1.44445],770:[0,.75,0,0,1.44445],771:[0,.75,0,0,1.44445],8730:[.95003,1.45,0,0,1],8968:[.95003,1.45,0,0,.58334],8969:[.95003,1.45,0,0,.58334],8970:[.95003,1.45,0,0,.58334],8971:[.95003,1.45,0,0,.58334],10216:[.95003,1.45,0,0,.75],10217:[.95003,1.45,0,0,.75]},"Size4-Regular":{32:[0,0,0,0,.25],40:[1.25003,1.75,0,0,.79167],41:[1.25003,1.75,0,0,.79167],47:[1.25003,1.75,0,0,1.27778],91:[1.25003,1.75,0,0,.58334],92:[1.25003,1.75,0,0,1.27778],93:[1.25003,1.75,0,0,.58334],123:[1.25003,1.75,0,0,.80556],125:[1.25003,1.75,0,0,.80556],160:[0,0,0,0,.25],710:[0,.825,0,0,1.8889],732:[0,.825,0,0,1.8889],770:[0,.825,0,0,1.8889],771:[0,.825,0,0,1.8889],8730:[1.25003,1.75,0,0,1],8968:[1.25003,1.75,0,0,.63889],8969:[1.25003,1.75,0,0,.63889],8970:[1.25003,1.75,0,0,.63889],8971:[1.25003,1.75,0,0,.63889],9115:[.64502,1.155,0,0,.875],9116:[1e-5,.6,0,0,.875],9117:[.64502,1.155,0,0,.875],9118:[.64502,1.155,0,0,.875],9119:[1e-5,.6,0,0,.875],9120:[.64502,1.155,0,0,.875],9121:[.64502,1.155,0,0,.66667],9122:[-99e-5,.601,0,0,.66667],9123:[.64502,1.155,0,0,.66667],9124:[.64502,1.155,0,0,.66667],9125:[-99e-5,.601,0,0,.66667],9126:[.64502,1.155,0,0,.66667],9127:[1e-5,.9,0,0,.88889],9128:[.65002,1.15,0,0,.88889],9129:[.90001,0,0,0,.88889],9130:[0,.3,0,0,.88889],9131:[1e-5,.9,0,0,.88889],9132:[.65002,1.15,0,0,.88889],9133:[.90001,0,0,0,.88889],9143:[.88502,.915,0,0,1.05556],10216:[1.25003,1.75,0,0,.80556],10217:[1.25003,1.75,0,0,.80556],57344:[-.00499,.605,0,0,1.05556],57345:[-.00499,.605,0,0,1.05556],57680:[0,.12,0,0,.45],57681:[0,.12,0,0,.45],57682:[0,.12,0,0,.45],57683:[0,.12,0,0,.45]},"Typewriter-Regular":{32:[0,0,0,0,.525],33:[0,.61111,0,0,.525],34:[0,.61111,0,0,.525],35:[0,.61111,0,0,.525],36:[.08333,.69444,0,0,.525],37:[.08333,.69444,0,0,.525],38:[0,.61111,0,0,.525],39:[0,.61111,0,0,.525],40:[.08333,.69444,0,0,.525],41:[.08333,.69444,0,0,.525],42:[0,.52083,0,0,.525],43:[-.08056,.53055,0,0,.525],44:[.13889,.125,0,0,.525],45:[-.08056,.53055,0,0,.525],46:[0,.125,0,0,.525],47:[.08333,.69444,0,0,.525],48:[0,.61111,0,0,.525],49:[0,.61111,0,0,.525],50:[0,.61111,0,0,.525],51:[0,.61111,0,0,.525],52:[0,.61111,0,0,.525],53:[0,.61111,0,0,.525],54:[0,.61111,0,0,.525],55:[0,.61111,0,0,.525],56:[0,.61111,0,0,.525],57:[0,.61111,0,0,.525],58:[0,.43056,0,0,.525],59:[.13889,.43056,0,0,.525],60:[-.05556,.55556,0,0,.525],61:[-.19549,.41562,0,0,.525],62:[-.05556,.55556,0,0,.525],63:[0,.61111,0,0,.525],64:[0,.61111,0,0,.525],65:[0,.61111,0,0,.525],66:[0,.61111,0,0,.525],67:[0,.61111,0,0,.525],68:[0,.61111,0,0,.525],69:[0,.61111,0,0,.525],70:[0,.61111,0,0,.525],71:[0,.61111,0,0,.525],72:[0,.61111,0,0,.525],73:[0,.61111,0,0,.525],74:[0,.61111,0,0,.525],75:[0,.61111,0,0,.525],76:[0,.61111,0,0,.525],77:[0,.61111,0,0,.525],78:[0,.61111,0,0,.525],79:[0,.61111,0,0,.525],80:[0,.61111,0,0,.525],81:[.13889,.61111,0,0,.525],82:[0,.61111,0,0,.525],83:[0,.61111,0,0,.525],84:[0,.61111,0,0,.525],85:[0,.61111,0,0,.525],86:[0,.61111,0,0,.525],87:[0,.61111,0,0,.525],88:[0,.61111,0,0,.525],89:[0,.61111,0,0,.525],90:[0,.61111,0,0,.525],91:[.08333,.69444,0,0,.525],92:[.08333,.69444,0,0,.525],93:[.08333,.69444,0,0,.525],94:[0,.61111,0,0,.525],95:[.09514,0,0,0,.525],96:[0,.61111,0,0,.525],97:[0,.43056,0,0,.525],98:[0,.61111,0,0,.525],99:[0,.43056,0,0,.525],100:[0,.61111,0,0,.525],101:[0,.43056,0,0,.525],102:[0,.61111,0,0,.525],103:[.22222,.43056,0,0,.525],104:[0,.61111,0,0,.525],105:[0,.61111,0,0,.525],106:[.22222,.61111,0,0,.525],107:[0,.61111,0,0,.525],108:[0,.61111,0,0,.525],109:[0,.43056,0,0,.525],110:[0,.43056,0,0,.525],111:[0,.43056,0,0,.525],112:[.22222,.43056,0,0,.525],113:[.22222,.43056,0,0,.525],114:[0,.43056,0,0,.525],115:[0,.43056,0,0,.525],116:[0,.55358,0,0,.525],117:[0,.43056,0,0,.525],118:[0,.43056,0,0,.525],119:[0,.43056,0,0,.525],120:[0,.43056,0,0,.525],121:[.22222,.43056,0,0,.525],122:[0,.43056,0,0,.525],123:[.08333,.69444,0,0,.525],124:[.08333,.69444,0,0,.525],125:[.08333,.69444,0,0,.525],126:[0,.61111,0,0,.525],127:[0,.61111,0,0,.525],160:[0,0,0,0,.525],176:[0,.61111,0,0,.525],184:[.19445,0,0,0,.525],305:[0,.43056,0,0,.525],567:[.22222,.43056,0,0,.525],711:[0,.56597,0,0,.525],713:[0,.56555,0,0,.525],714:[0,.61111,0,0,.525],715:[0,.61111,0,0,.525],728:[0,.61111,0,0,.525],730:[0,.61111,0,0,.525],770:[0,.61111,0,0,.525],771:[0,.61111,0,0,.525],776:[0,.61111,0,0,.525],915:[0,.61111,0,0,.525],916:[0,.61111,0,0,.525],920:[0,.61111,0,0,.525],923:[0,.61111,0,0,.525],926:[0,.61111,0,0,.525],928:[0,.61111,0,0,.525],931:[0,.61111,0,0,.525],933:[0,.61111,0,0,.525],934:[0,.61111,0,0,.525],936:[0,.61111,0,0,.525],937:[0,.61111,0,0,.525],8216:[0,.61111,0,0,.525],8217:[0,.61111,0,0,.525],8242:[0,.61111,0,0,.525],9251:[.11111,.21944,0,0,.525]}},_h={slant:[.25,.25,.25],space:[0,0,0],stretch:[0,0,0],shrink:[0,0,0],xHeight:[.431,.431,.431],quad:[1,1.171,1.472],extraSpace:[0,0,0],num1:[.677,.732,.925],num2:[.394,.384,.387],num3:[.444,.471,.504],denom1:[.686,.752,1.025],denom2:[.345,.344,.532],sup1:[.413,.503,.504],sup2:[.363,.431,.404],sup3:[.289,.286,.294],sub1:[.15,.143,.2],sub2:[.247,.286,.4],supDrop:[.386,.353,.494],subDrop:[.05,.071,.1],delim1:[2.39,1.7,1.98],delim2:[1.01,1.157,1.42],axisHeight:[.25,.25,.25],defaultRuleThickness:[.04,.049,.049],bigOpSpacing1:[.111,.111,.111],bigOpSpacing2:[.166,.166,.166],bigOpSpacing3:[.2,.2,.2],bigOpSpacing4:[.6,.611,.611],bigOpSpacing5:[.1,.143,.143],sqrtRuleThickness:[.04,.04,.04],ptPerEm:[10,10,10],doubleRuleSep:[.2,.2,.2],arrayRuleWidth:[.04,.04,.04],fboxsep:[.3,.3,.3],fboxrule:[.04,.04,.04]},a6={Å:"A",Ð:"D",Þ:"o",å:"a",ð:"d",þ:"o",А:"A",Б:"B",В:"B",Г:"F",Д:"A",Е:"E",Ж:"K",З:"3",И:"N",Й:"N",К:"K",Л:"N",М:"M",Н:"H",О:"O",П:"N",Р:"P",С:"C",Т:"T",У:"y",Ф:"O",Х:"X",Ц:"U",Ч:"h",Ш:"W",Щ:"W",Ъ:"B",Ы:"X",Ь:"B",Э:"3",Ю:"X",Я:"R",а:"a",б:"b",в:"a",г:"r",д:"y",е:"e",ж:"m",з:"e",и:"n",й:"n",к:"n",л:"n",м:"m",н:"n",о:"o",п:"n",р:"p",с:"c",т:"o",у:"y",ф:"b",х:"x",ц:"n",ч:"n",ш:"w",щ:"w",ъ:"a",ы:"m",ь:"a",э:"e",ю:"m",я:"r"};function iq(e,t){da[e]=t}function B2(e,t,n){if(!da[t])throw new Error("Font metrics not found for font: "+t+".");var r=e.charCodeAt(0),i=da[t][r];if(!i&&e[0]in a6&&(r=a6[e[0]].charCodeAt(0),i=da[t][r]),!i&&n==="text"&&gx(r)&&(i=da[t][77]),i)return{depth:i[0],height:i[1],italic:i[2],skew:i[3],width:i[4]}}var ng={};function aq(e){var t;if(e>=5?t=0:e>=3?t=1:t=2,!ng[t]){var n=ng[t]={cssEmPerMu:_h.quad[t]/18};for(var r in _h)_h.hasOwnProperty(r)&&(n[r]=_h[r][t])}return ng[t]}var sq=[[1,1,1],[2,1,1],[3,1,1],[4,2,1],[5,2,1],[6,3,1],[7,4,2],[8,6,3],[9,7,6],[10,8,7],[11,10,9]],s6=[.5,.6,.7,.8,.9,1,1.2,1.44,1.728,2.074,2.488],l6=function(t,n){return n.size<2?t:sq[t-1][n.size-1]};class Va{constructor(t){this.style=void 0,this.color=void 0,this.size=void 0,this.textSize=void 0,this.phantom=void 0,this.font=void 0,this.fontFamily=void 0,this.fontWeight=void 0,this.fontShape=void 0,this.sizeMultiplier=void 0,this.maxSize=void 0,this.minRuleThickness=void 0,this._fontMetrics=void 0,this.style=t.style,this.color=t.color,this.size=t.size||Va.BASESIZE,this.textSize=t.textSize||this.size,this.phantom=!!t.phantom,this.font=t.font||"",this.fontFamily=t.fontFamily||"",this.fontWeight=t.fontWeight||"",this.fontShape=t.fontShape||"",this.sizeMultiplier=s6[this.size-1],this.maxSize=t.maxSize,this.minRuleThickness=t.minRuleThickness,this._fontMetrics=void 0}extend(t){var n={style:this.style,size:this.size,textSize:this.textSize,color:this.color,phantom:this.phantom,font:this.font,fontFamily:this.fontFamily,fontWeight:this.fontWeight,fontShape:this.fontShape,maxSize:this.maxSize,minRuleThickness:this.minRuleThickness};for(var r in t)t.hasOwnProperty(r)&&(n[r]=t[r]);return new Va(n)}havingStyle(t){return this.style===t?this:this.extend({style:t,size:l6(this.textSize,t)})}havingCrampedStyle(){return this.havingStyle(this.style.cramp())}havingSize(t){return this.size===t&&this.textSize===t?this:this.extend({style:this.style.text(),size:t,textSize:t,sizeMultiplier:s6[t-1]})}havingBaseStyle(t){t=t||this.style.text();var n=l6(Va.BASESIZE,t);return this.size===n&&this.textSize===Va.BASESIZE&&this.style===t?this:this.extend({style:t,size:n})}havingBaseSizing(){var t;switch(this.style.id){case 4:case 5:t=3;break;case 6:case 7:t=1;break;default:t=6}return this.extend({style:this.style.text(),size:t})}withColor(t){return this.extend({color:t})}withPhantom(){return this.extend({phantom:!0})}withFont(t){return this.extend({font:t})}withTextFontFamily(t){return this.extend({fontFamily:t,font:""})}withTextFontWeight(t){return this.extend({fontWeight:t,font:""})}withTextFontShape(t){return this.extend({fontShape:t,font:""})}sizingClasses(t){return t.size!==this.size?["sizing","reset-size"+t.size,"size"+this.size]:[]}baseSizingClasses(){return this.size!==Va.BASESIZE?["sizing","reset-size"+this.size,"size"+Va.BASESIZE]:[]}fontMetrics(){return this._fontMetrics||(this._fontMetrics=aq(this.size)),this._fontMetrics}getColor(){return this.phantom?"transparent":this.color}}Va.BASESIZE=6;var gb={pt:1,mm:7227/2540,cm:7227/254,in:72.27,bp:803/800,pc:12,dd:1238/1157,cc:14856/1157,nd:685/642,nc:1370/107,sp:1/65536,px:803/800},lq={ex:!0,em:!0,mu:!0},bx=function(t){return typeof t!="string"&&(t=t.unit),t in gb||t in lq||t==="ex"},Bn=function(t,n){var r;if(t.unit in gb)r=gb[t.unit]/n.fontMetrics().ptPerEm/n.sizeMultiplier;else if(t.unit==="mu")r=n.fontMetrics().cssEmPerMu;else{var i;if(n.style.isTight()?i=n.havingStyle(n.style.text()):i=n,t.unit==="ex")r=i.fontMetrics().xHeight;else if(t.unit==="em")r=i.fontMetrics().quad;else throw new Ie("Invalid unit: '"+t.unit+"'");i!==n&&(r*=i.sizeMultiplier/n.sizeMultiplier)}return Math.min(t.number*r,n.maxSize)},Be=function(t){return+t.toFixed(4)+"em"},al=function(t){return t.filter(n=>n).join(" ")},vx=function(t,n,r){if(this.classes=t||[],this.attributes={},this.height=0,this.depth=0,this.maxFontSize=0,this.style=r||{},n){n.style.isTight()&&this.classes.push("mtight");var i=n.getColor();i&&(this.style.color=i)}},_x=function(t){var n=document.createElement(t);n.className=al(this.classes);for(var r in this.style)this.style.hasOwnProperty(r)&&(n.style[r]=this.style[r]);for(var i in this.attributes)this.attributes.hasOwnProperty(i)&&n.setAttribute(i,this.attributes[i]);for(var s=0;s<this.children.length;s++)n.appendChild(this.children[s].toNode());return n},oq=/[\s"'>/=\x00-\x1f]/,yx=function(t){var n="<"+t;this.classes.length&&(n+=' class="'+Vt.escape(al(this.classes))+'"');var r="";for(var i in this.style)this.style.hasOwnProperty(i)&&(r+=Vt.hyphenate(i)+":"+this.style[i]+";");r&&(n+=' style="'+Vt.escape(r)+'"');for(var s in this.attributes)if(this.attributes.hasOwnProperty(s)){if(oq.test(s))throw new Ie("Invalid attribute name '"+s+"'");n+=" "+s+'="'+Vt.escape(this.attributes[s])+'"'}n+=">";for(var o=0;o<this.children.length;o++)n+=this.children[o].toMarkup();return n+="</"+t+">",n};class L0{constructor(t,n,r,i){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.width=void 0,this.maxFontSize=void 0,this.style=void 0,vx.call(this,t,r,i),this.children=n||[]}setAttribute(t,n){this.attributes[t]=n}hasClass(t){return this.classes.includes(t)}toNode(){return _x.call(this,"span")}toMarkup(){return yx.call(this,"span")}}class U2{constructor(t,n,r,i){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,vx.call(this,n,i),this.children=r||[],this.setAttribute("href",t)}setAttribute(t,n){this.attributes[t]=n}hasClass(t){return this.classes.includes(t)}toNode(){return _x.call(this,"a")}toMarkup(){return yx.call(this,"a")}}class uq{constructor(t,n,r){this.src=void 0,this.alt=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.alt=n,this.src=t,this.classes=["mord"],this.style=r}hasClass(t){return this.classes.includes(t)}toNode(){var t=document.createElement("img");t.src=this.src,t.alt=this.alt,t.className="mord";for(var n in this.style)this.style.hasOwnProperty(n)&&(t.style[n]=this.style[n]);return t}toMarkup(){var t='<img src="'+Vt.escape(this.src)+'"'+(' alt="'+Vt.escape(this.alt)+'"'),n="";for(var r in this.style)this.style.hasOwnProperty(r)&&(n+=Vt.hyphenate(r)+":"+this.style[r]+";");return n&&(t+=' style="'+Vt.escape(n)+'"'),t+="'/>",t}}var cq={î:"ı̂",ï:"ı̈",í:"ı́",ì:"ı̀"};class Hi{constructor(t,n,r,i,s,o,c,d){this.text=void 0,this.height=void 0,this.depth=void 0,this.italic=void 0,this.skew=void 0,this.width=void 0,this.maxFontSize=void 0,this.classes=void 0,this.style=void 0,this.text=t,this.height=n||0,this.depth=r||0,this.italic=i||0,this.skew=s||0,this.width=o||0,this.classes=c||[],this.style=d||{},this.maxFontSize=0;var f=Vj(this.text.charCodeAt(0));f&&this.classes.push(f+"_fallback"),/[îïíì]/.test(this.text)&&(this.text=cq[this.text])}hasClass(t){return this.classes.includes(t)}toNode(){var t=document.createTextNode(this.text),n=null;this.italic>0&&(n=document.createElement("span"),n.style.marginRight=Be(this.italic)),this.classes.length>0&&(n=n||document.createElement("span"),n.className=al(this.classes));for(var r in this.style)this.style.hasOwnProperty(r)&&(n=n||document.createElement("span"),n.style[r]=this.style[r]);return n?(n.appendChild(t),n):t}toMarkup(){var t=!1,n="<span";this.classes.length&&(t=!0,n+=' class="',n+=Vt.escape(al(this.classes)),n+='"');var r="";this.italic>0&&(r+="margin-right:"+this.italic+"em;");for(var i in this.style)this.style.hasOwnProperty(i)&&(r+=Vt.hyphenate(i)+":"+this.style[i]+";");r&&(t=!0,n+=' style="'+Vt.escape(r)+'"');var s=Vt.escape(this.text);return t?(n+=">",n+=s,n+="</span>",n):s}}class as{constructor(t,n){this.children=void 0,this.attributes=void 0,this.children=t||[],this.attributes=n||{}}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"svg");for(var r in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,r)&&n.setAttribute(r,this.attributes[r]);for(var i=0;i<this.children.length;i++)n.appendChild(this.children[i].toNode());return n}toMarkup(){var t='<svg xmlns="http://www.w3.org/2000/svg"';for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(t+=" "+n+'="'+Vt.escape(this.attributes[n])+'"');t+=">";for(var r=0;r<this.children.length;r++)t+=this.children[r].toMarkup();return t+="</svg>",t}}class sl{constructor(t,n){this.pathName=void 0,this.alternate=void 0,this.pathName=t,this.alternate=n}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"path");return this.alternate?n.setAttribute("d",this.alternate):n.setAttribute("d",i6[this.pathName]),n}toMarkup(){return this.alternate?'<path d="'+Vt.escape(this.alternate)+'"/>':'<path d="'+Vt.escape(i6[this.pathName])+'"/>'}}class bb{constructor(t){this.attributes=void 0,this.attributes=t||{}}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"line");for(var r in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,r)&&n.setAttribute(r,this.attributes[r]);return n}toMarkup(){var t="<line";for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(t+=" "+n+'="'+Vt.escape(this.attributes[n])+'"');return t+="/>",t}}function o6(e){if(e instanceof Hi)return e;throw new Error("Expected symbolNode but got "+String(e)+".")}function dq(e){if(e instanceof L0)return e;throw new Error("Expected span<HtmlDomNode> but got "+String(e)+".")}var hq={bin:1,close:1,inner:1,open:1,punct:1,rel:1},fq={"accent-token":1,mathord:1,"op-token":1,spacing:1,textord:1},yn={math:{},text:{}};function E(e,t,n,r,i,s){yn[e][i]={font:t,group:n,replace:r},s&&r&&(yn[e][r]=yn[e][i])}var S="math",we="text",N="main",j="ams",Mn="accent-token",Ke="bin",qr="close",yu="inner",st="mathord",ir="op-token",Si="open",Qf="punct",q="rel",hs="spacing",Q="textord";E(S,N,q,"≡","\\equiv",!0);E(S,N,q,"≺","\\prec",!0);E(S,N,q,"≻","\\succ",!0);E(S,N,q,"∼","\\sim",!0);E(S,N,q,"⊥","\\perp");E(S,N,q,"⪯","\\preceq",!0);E(S,N,q,"⪰","\\succeq",!0);E(S,N,q,"≃","\\simeq",!0);E(S,N,q,"∣","\\mid",!0);E(S,N,q,"≪","\\ll",!0);E(S,N,q,"≫","\\gg",!0);E(S,N,q,"≍","\\asymp",!0);E(S,N,q,"∥","\\parallel");E(S,N,q,"⋈","\\bowtie",!0);E(S,N,q,"⌣","\\smile",!0);E(S,N,q,"⊑","\\sqsubseteq",!0);E(S,N,q,"⊒","\\sqsupseteq",!0);E(S,N,q,"≐","\\doteq",!0);E(S,N,q,"⌢","\\frown",!0);E(S,N,q,"∋","\\ni",!0);E(S,N,q,"∝","\\propto",!0);E(S,N,q,"⊢","\\vdash",!0);E(S,N,q,"⊣","\\dashv",!0);E(S,N,q,"∋","\\owns");E(S,N,Qf,".","\\ldotp");E(S,N,Qf,"⋅","\\cdotp");E(S,N,Q,"#","\\#");E(we,N,Q,"#","\\#");E(S,N,Q,"&","\\&");E(we,N,Q,"&","\\&");E(S,N,Q,"ℵ","\\aleph",!0);E(S,N,Q,"∀","\\forall",!0);E(S,N,Q,"ℏ","\\hbar",!0);E(S,N,Q,"∃","\\exists",!0);E(S,N,Q,"∇","\\nabla",!0);E(S,N,Q,"♭","\\flat",!0);E(S,N,Q,"ℓ","\\ell",!0);E(S,N,Q,"♮","\\natural",!0);E(S,N,Q,"♣","\\clubsuit",!0);E(S,N,Q,"℘","\\wp",!0);E(S,N,Q,"♯","\\sharp",!0);E(S,N,Q,"♢","\\diamondsuit",!0);E(S,N,Q,"ℜ","\\Re",!0);E(S,N,Q,"♡","\\heartsuit",!0);E(S,N,Q,"ℑ","\\Im",!0);E(S,N,Q,"♠","\\spadesuit",!0);E(S,N,Q,"§","\\S",!0);E(we,N,Q,"§","\\S");E(S,N,Q,"¶","\\P",!0);E(we,N,Q,"¶","\\P");E(S,N,Q,"†","\\dag");E(we,N,Q,"†","\\dag");E(we,N,Q,"†","\\textdagger");E(S,N,Q,"‡","\\ddag");E(we,N,Q,"‡","\\ddag");E(we,N,Q,"‡","\\textdaggerdbl");E(S,N,qr,"⎱","\\rmoustache",!0);E(S,N,Si,"⎰","\\lmoustache",!0);E(S,N,qr,"⟯","\\rgroup",!0);E(S,N,Si,"⟮","\\lgroup",!0);E(S,N,Ke,"∓","\\mp",!0);E(S,N,Ke,"⊖","\\ominus",!0);E(S,N,Ke,"⊎","\\uplus",!0);E(S,N,Ke,"⊓","\\sqcap",!0);E(S,N,Ke,"∗","\\ast");E(S,N,Ke,"⊔","\\sqcup",!0);E(S,N,Ke,"◯","\\bigcirc",!0);E(S,N,Ke,"∙","\\bullet",!0);E(S,N,Ke,"‡","\\ddagger");E(S,N,Ke,"≀","\\wr",!0);E(S,N,Ke,"⨿","\\amalg");E(S,N,Ke,"&","\\And");E(S,N,q,"⟵","\\longleftarrow",!0);E(S,N,q,"⇐","\\Leftarrow",!0);E(S,N,q,"⟸","\\Longleftarrow",!0);E(S,N,q,"⟶","\\longrightarrow",!0);E(S,N,q,"⇒","\\Rightarrow",!0);E(S,N,q,"⟹","\\Longrightarrow",!0);E(S,N,q,"↔","\\leftrightarrow",!0);E(S,N,q,"⟷","\\longleftrightarrow",!0);E(S,N,q,"⇔","\\Leftrightarrow",!0);E(S,N,q,"⟺","\\Longleftrightarrow",!0);E(S,N,q,"↦","\\mapsto",!0);E(S,N,q,"⟼","\\longmapsto",!0);E(S,N,q,"↗","\\nearrow",!0);E(S,N,q,"↩","\\hookleftarrow",!0);E(S,N,q,"↪","\\hookrightarrow",!0);E(S,N,q,"↘","\\searrow",!0);E(S,N,q,"↼","\\leftharpoonup",!0);E(S,N,q,"⇀","\\rightharpoonup",!0);E(S,N,q,"↙","\\swarrow",!0);E(S,N,q,"↽","\\leftharpoondown",!0);E(S,N,q,"⇁","\\rightharpoondown",!0);E(S,N,q,"↖","\\nwarrow",!0);E(S,N,q,"⇌","\\rightleftharpoons",!0);E(S,j,q,"≮","\\nless",!0);E(S,j,q,"","\\@nleqslant");E(S,j,q,"","\\@nleqq");E(S,j,q,"⪇","\\lneq",!0);E(S,j,q,"≨","\\lneqq",!0);E(S,j,q,"","\\@lvertneqq");E(S,j,q,"⋦","\\lnsim",!0);E(S,j,q,"⪉","\\lnapprox",!0);E(S,j,q,"⊀","\\nprec",!0);E(S,j,q,"⋠","\\npreceq",!0);E(S,j,q,"⋨","\\precnsim",!0);E(S,j,q,"⪹","\\precnapprox",!0);E(S,j,q,"≁","\\nsim",!0);E(S,j,q,"","\\@nshortmid");E(S,j,q,"∤","\\nmid",!0);E(S,j,q,"⊬","\\nvdash",!0);E(S,j,q,"⊭","\\nvDash",!0);E(S,j,q,"⋪","\\ntriangleleft");E(S,j,q,"⋬","\\ntrianglelefteq",!0);E(S,j,q,"⊊","\\subsetneq",!0);E(S,j,q,"","\\@varsubsetneq");E(S,j,q,"⫋","\\subsetneqq",!0);E(S,j,q,"","\\@varsubsetneqq");E(S,j,q,"≯","\\ngtr",!0);E(S,j,q,"","\\@ngeqslant");E(S,j,q,"","\\@ngeqq");E(S,j,q,"⪈","\\gneq",!0);E(S,j,q,"≩","\\gneqq",!0);E(S,j,q,"","\\@gvertneqq");E(S,j,q,"⋧","\\gnsim",!0);E(S,j,q,"⪊","\\gnapprox",!0);E(S,j,q,"⊁","\\nsucc",!0);E(S,j,q,"⋡","\\nsucceq",!0);E(S,j,q,"⋩","\\succnsim",!0);E(S,j,q,"⪺","\\succnapprox",!0);E(S,j,q,"≆","\\ncong",!0);E(S,j,q,"","\\@nshortparallel");E(S,j,q,"∦","\\nparallel",!0);E(S,j,q,"⊯","\\nVDash",!0);E(S,j,q,"⋫","\\ntriangleright");E(S,j,q,"⋭","\\ntrianglerighteq",!0);E(S,j,q,"","\\@nsupseteqq");E(S,j,q,"⊋","\\supsetneq",!0);E(S,j,q,"","\\@varsupsetneq");E(S,j,q,"⫌","\\supsetneqq",!0);E(S,j,q,"","\\@varsupsetneqq");E(S,j,q,"⊮","\\nVdash",!0);E(S,j,q,"⪵","\\precneqq",!0);E(S,j,q,"⪶","\\succneqq",!0);E(S,j,q,"","\\@nsubseteqq");E(S,j,Ke,"⊴","\\unlhd");E(S,j,Ke,"⊵","\\unrhd");E(S,j,q,"↚","\\nleftarrow",!0);E(S,j,q,"↛","\\nrightarrow",!0);E(S,j,q,"⇍","\\nLeftarrow",!0);E(S,j,q,"⇏","\\nRightarrow",!0);E(S,j,q,"↮","\\nleftrightarrow",!0);E(S,j,q,"⇎","\\nLeftrightarrow",!0);E(S,j,q,"△","\\vartriangle");E(S,j,Q,"ℏ","\\hslash");E(S,j,Q,"▽","\\triangledown");E(S,j,Q,"◊","\\lozenge");E(S,j,Q,"Ⓢ","\\circledS");E(S,j,Q,"®","\\circledR");E(we,j,Q,"®","\\circledR");E(S,j,Q,"∡","\\measuredangle",!0);E(S,j,Q,"∄","\\nexists");E(S,j,Q,"℧","\\mho");E(S,j,Q,"Ⅎ","\\Finv",!0);E(S,j,Q,"⅁","\\Game",!0);E(S,j,Q,"‵","\\backprime");E(S,j,Q,"▲","\\blacktriangle");E(S,j,Q,"▼","\\blacktriangledown");E(S,j,Q,"■","\\blacksquare");E(S,j,Q,"⧫","\\blacklozenge");E(S,j,Q,"★","\\bigstar");E(S,j,Q,"∢","\\sphericalangle",!0);E(S,j,Q,"∁","\\complement",!0);E(S,j,Q,"ð","\\eth",!0);E(we,N,Q,"ð","ð");E(S,j,Q,"╱","\\diagup");E(S,j,Q,"╲","\\diagdown");E(S,j,Q,"□","\\square");E(S,j,Q,"□","\\Box");E(S,j,Q,"◊","\\Diamond");E(S,j,Q,"¥","\\yen",!0);E(we,j,Q,"¥","\\yen",!0);E(S,j,Q,"✓","\\checkmark",!0);E(we,j,Q,"✓","\\checkmark");E(S,j,Q,"ℶ","\\beth",!0);E(S,j,Q,"ℸ","\\daleth",!0);E(S,j,Q,"ℷ","\\gimel",!0);E(S,j,Q,"ϝ","\\digamma",!0);E(S,j,Q,"ϰ","\\varkappa");E(S,j,Si,"┌","\\@ulcorner",!0);E(S,j,qr,"┐","\\@urcorner",!0);E(S,j,Si,"└","\\@llcorner",!0);E(S,j,qr,"┘","\\@lrcorner",!0);E(S,j,q,"≦","\\leqq",!0);E(S,j,q,"⩽","\\leqslant",!0);E(S,j,q,"⪕","\\eqslantless",!0);E(S,j,q,"≲","\\lesssim",!0);E(S,j,q,"⪅","\\lessapprox",!0);E(S,j,q,"≊","\\approxeq",!0);E(S,j,Ke,"⋖","\\lessdot");E(S,j,q,"⋘","\\lll",!0);E(S,j,q,"≶","\\lessgtr",!0);E(S,j,q,"⋚","\\lesseqgtr",!0);E(S,j,q,"⪋","\\lesseqqgtr",!0);E(S,j,q,"≑","\\doteqdot");E(S,j,q,"≓","\\risingdotseq",!0);E(S,j,q,"≒","\\fallingdotseq",!0);E(S,j,q,"∽","\\backsim",!0);E(S,j,q,"⋍","\\backsimeq",!0);E(S,j,q,"⫅","\\subseteqq",!0);E(S,j,q,"⋐","\\Subset",!0);E(S,j,q,"⊏","\\sqsubset",!0);E(S,j,q,"≼","\\preccurlyeq",!0);E(S,j,q,"⋞","\\curlyeqprec",!0);E(S,j,q,"≾","\\precsim",!0);E(S,j,q,"⪷","\\precapprox",!0);E(S,j,q,"⊲","\\vartriangleleft");E(S,j,q,"⊴","\\trianglelefteq");E(S,j,q,"⊨","\\vDash",!0);E(S,j,q,"⊪","\\Vvdash",!0);E(S,j,q,"⌣","\\smallsmile");E(S,j,q,"⌢","\\smallfrown");E(S,j,q,"≏","\\bumpeq",!0);E(S,j,q,"≎","\\Bumpeq",!0);E(S,j,q,"≧","\\geqq",!0);E(S,j,q,"⩾","\\geqslant",!0);E(S,j,q,"⪖","\\eqslantgtr",!0);E(S,j,q,"≳","\\gtrsim",!0);E(S,j,q,"⪆","\\gtrapprox",!0);E(S,j,Ke,"⋗","\\gtrdot");E(S,j,q,"⋙","\\ggg",!0);E(S,j,q,"≷","\\gtrless",!0);E(S,j,q,"⋛","\\gtreqless",!0);E(S,j,q,"⪌","\\gtreqqless",!0);E(S,j,q,"≖","\\eqcirc",!0);E(S,j,q,"≗","\\circeq",!0);E(S,j,q,"≜","\\triangleq",!0);E(S,j,q,"∼","\\thicksim");E(S,j,q,"≈","\\thickapprox");E(S,j,q,"⫆","\\supseteqq",!0);E(S,j,q,"⋑","\\Supset",!0);E(S,j,q,"⊐","\\sqsupset",!0);E(S,j,q,"≽","\\succcurlyeq",!0);E(S,j,q,"⋟","\\curlyeqsucc",!0);E(S,j,q,"≿","\\succsim",!0);E(S,j,q,"⪸","\\succapprox",!0);E(S,j,q,"⊳","\\vartriangleright");E(S,j,q,"⊵","\\trianglerighteq");E(S,j,q,"⊩","\\Vdash",!0);E(S,j,q,"∣","\\shortmid");E(S,j,q,"∥","\\shortparallel");E(S,j,q,"≬","\\between",!0);E(S,j,q,"⋔","\\pitchfork",!0);E(S,j,q,"∝","\\varpropto");E(S,j,q,"◀","\\blacktriangleleft");E(S,j,q,"∴","\\therefore",!0);E(S,j,q,"∍","\\backepsilon");E(S,j,q,"▶","\\blacktriangleright");E(S,j,q,"∵","\\because",!0);E(S,j,q,"⋘","\\llless");E(S,j,q,"⋙","\\gggtr");E(S,j,Ke,"⊲","\\lhd");E(S,j,Ke,"⊳","\\rhd");E(S,j,q,"≂","\\eqsim",!0);E(S,N,q,"⋈","\\Join");E(S,j,q,"≑","\\Doteq",!0);E(S,j,Ke,"∔","\\dotplus",!0);E(S,j,Ke,"∖","\\smallsetminus");E(S,j,Ke,"⋒","\\Cap",!0);E(S,j,Ke,"⋓","\\Cup",!0);E(S,j,Ke,"⩞","\\doublebarwedge",!0);E(S,j,Ke,"⊟","\\boxminus",!0);E(S,j,Ke,"⊞","\\boxplus",!0);E(S,j,Ke,"⋇","\\divideontimes",!0);E(S,j,Ke,"⋉","\\ltimes",!0);E(S,j,Ke,"⋊","\\rtimes",!0);E(S,j,Ke,"⋋","\\leftthreetimes",!0);E(S,j,Ke,"⋌","\\rightthreetimes",!0);E(S,j,Ke,"⋏","\\curlywedge",!0);E(S,j,Ke,"⋎","\\curlyvee",!0);E(S,j,Ke,"⊝","\\circleddash",!0);E(S,j,Ke,"⊛","\\circledast",!0);E(S,j,Ke,"⋅","\\centerdot");E(S,j,Ke,"⊺","\\intercal",!0);E(S,j,Ke,"⋒","\\doublecap");E(S,j,Ke,"⋓","\\doublecup");E(S,j,Ke,"⊠","\\boxtimes",!0);E(S,j,q,"⇢","\\dashrightarrow",!0);E(S,j,q,"⇠","\\dashleftarrow",!0);E(S,j,q,"⇇","\\leftleftarrows",!0);E(S,j,q,"⇆","\\leftrightarrows",!0);E(S,j,q,"⇚","\\Lleftarrow",!0);E(S,j,q,"↞","\\twoheadleftarrow",!0);E(S,j,q,"↢","\\leftarrowtail",!0);E(S,j,q,"↫","\\looparrowleft",!0);E(S,j,q,"⇋","\\leftrightharpoons",!0);E(S,j,q,"↶","\\curvearrowleft",!0);E(S,j,q,"↺","\\circlearrowleft",!0);E(S,j,q,"↰","\\Lsh",!0);E(S,j,q,"⇈","\\upuparrows",!0);E(S,j,q,"↿","\\upharpoonleft",!0);E(S,j,q,"⇃","\\downharpoonleft",!0);E(S,N,q,"⊶","\\origof",!0);E(S,N,q,"⊷","\\imageof",!0);E(S,j,q,"⊸","\\multimap",!0);E(S,j,q,"↭","\\leftrightsquigarrow",!0);E(S,j,q,"⇉","\\rightrightarrows",!0);E(S,j,q,"⇄","\\rightleftarrows",!0);E(S,j,q,"↠","\\twoheadrightarrow",!0);E(S,j,q,"↣","\\rightarrowtail",!0);E(S,j,q,"↬","\\looparrowright",!0);E(S,j,q,"↷","\\curvearrowright",!0);E(S,j,q,"↻","\\circlearrowright",!0);E(S,j,q,"↱","\\Rsh",!0);E(S,j,q,"⇊","\\downdownarrows",!0);E(S,j,q,"↾","\\upharpoonright",!0);E(S,j,q,"⇂","\\downharpoonright",!0);E(S,j,q,"⇝","\\rightsquigarrow",!0);E(S,j,q,"⇝","\\leadsto");E(S,j,q,"⇛","\\Rrightarrow",!0);E(S,j,q,"↾","\\restriction");E(S,N,Q,"‘","`");E(S,N,Q,"$","\\$");E(we,N,Q,"$","\\$");E(we,N,Q,"$","\\textdollar");E(S,N,Q,"%","\\%");E(we,N,Q,"%","\\%");E(S,N,Q,"_","\\_");E(we,N,Q,"_","\\_");E(we,N,Q,"_","\\textunderscore");E(S,N,Q,"∠","\\angle",!0);E(S,N,Q,"∞","\\infty",!0);E(S,N,Q,"′","\\prime");E(S,N,Q,"△","\\triangle");E(S,N,Q,"Γ","\\Gamma",!0);E(S,N,Q,"Δ","\\Delta",!0);E(S,N,Q,"Θ","\\Theta",!0);E(S,N,Q,"Λ","\\Lambda",!0);E(S,N,Q,"Ξ","\\Xi",!0);E(S,N,Q,"Π","\\Pi",!0);E(S,N,Q,"Σ","\\Sigma",!0);E(S,N,Q,"Υ","\\Upsilon",!0);E(S,N,Q,"Φ","\\Phi",!0);E(S,N,Q,"Ψ","\\Psi",!0);E(S,N,Q,"Ω","\\Omega",!0);E(S,N,Q,"A","Α");E(S,N,Q,"B","Β");E(S,N,Q,"E","Ε");E(S,N,Q,"Z","Ζ");E(S,N,Q,"H","Η");E(S,N,Q,"I","Ι");E(S,N,Q,"K","Κ");E(S,N,Q,"M","Μ");E(S,N,Q,"N","Ν");E(S,N,Q,"O","Ο");E(S,N,Q,"P","Ρ");E(S,N,Q,"T","Τ");E(S,N,Q,"X","Χ");E(S,N,Q,"¬","\\neg",!0);E(S,N,Q,"¬","\\lnot");E(S,N,Q,"⊤","\\top");E(S,N,Q,"⊥","\\bot");E(S,N,Q,"∅","\\emptyset");E(S,j,Q,"∅","\\varnothing");E(S,N,st,"α","\\alpha",!0);E(S,N,st,"β","\\beta",!0);E(S,N,st,"γ","\\gamma",!0);E(S,N,st,"δ","\\delta",!0);E(S,N,st,"ϵ","\\epsilon",!0);E(S,N,st,"ζ","\\zeta",!0);E(S,N,st,"η","\\eta",!0);E(S,N,st,"θ","\\theta",!0);E(S,N,st,"ι","\\iota",!0);E(S,N,st,"κ","\\kappa",!0);E(S,N,st,"λ","\\lambda",!0);E(S,N,st,"μ","\\mu",!0);E(S,N,st,"ν","\\nu",!0);E(S,N,st,"ξ","\\xi",!0);E(S,N,st,"ο","\\omicron",!0);E(S,N,st,"π","\\pi",!0);E(S,N,st,"ρ","\\rho",!0);E(S,N,st,"σ","\\sigma",!0);E(S,N,st,"τ","\\tau",!0);E(S,N,st,"υ","\\upsilon",!0);E(S,N,st,"ϕ","\\phi",!0);E(S,N,st,"χ","\\chi",!0);E(S,N,st,"ψ","\\psi",!0);E(S,N,st,"ω","\\omega",!0);E(S,N,st,"ε","\\varepsilon",!0);E(S,N,st,"ϑ","\\vartheta",!0);E(S,N,st,"ϖ","\\varpi",!0);E(S,N,st,"ϱ","\\varrho",!0);E(S,N,st,"ς","\\varsigma",!0);E(S,N,st,"φ","\\varphi",!0);E(S,N,Ke,"∗","*",!0);E(S,N,Ke,"+","+");E(S,N,Ke,"−","-",!0);E(S,N,Ke,"⋅","\\cdot",!0);E(S,N,Ke,"∘","\\circ",!0);E(S,N,Ke,"÷","\\div",!0);E(S,N,Ke,"±","\\pm",!0);E(S,N,Ke,"×","\\times",!0);E(S,N,Ke,"∩","\\cap",!0);E(S,N,Ke,"∪","\\cup",!0);E(S,N,Ke,"∖","\\setminus",!0);E(S,N,Ke,"∧","\\land");E(S,N,Ke,"∨","\\lor");E(S,N,Ke,"∧","\\wedge",!0);E(S,N,Ke,"∨","\\vee",!0);E(S,N,Q,"√","\\surd");E(S,N,Si,"⟨","\\langle",!0);E(S,N,Si,"∣","\\lvert");E(S,N,Si,"∥","\\lVert");E(S,N,qr,"?","?");E(S,N,qr,"!","!");E(S,N,qr,"⟩","\\rangle",!0);E(S,N,qr,"∣","\\rvert");E(S,N,qr,"∥","\\rVert");E(S,N,q,"=","=");E(S,N,q,":",":");E(S,N,q,"≈","\\approx",!0);E(S,N,q,"≅","\\cong",!0);E(S,N,q,"≥","\\ge");E(S,N,q,"≥","\\geq",!0);E(S,N,q,"←","\\gets");E(S,N,q,">","\\gt",!0);E(S,N,q,"∈","\\in",!0);E(S,N,q,"","\\@not");E(S,N,q,"⊂","\\subset",!0);E(S,N,q,"⊃","\\supset",!0);E(S,N,q,"⊆","\\subseteq",!0);E(S,N,q,"⊇","\\supseteq",!0);E(S,j,q,"⊈","\\nsubseteq",!0);E(S,j,q,"⊉","\\nsupseteq",!0);E(S,N,q,"⊨","\\models");E(S,N,q,"←","\\leftarrow",!0);E(S,N,q,"≤","\\le");E(S,N,q,"≤","\\leq",!0);E(S,N,q,"<","\\lt",!0);E(S,N,q,"→","\\rightarrow",!0);E(S,N,q,"→","\\to");E(S,j,q,"≱","\\ngeq",!0);E(S,j,q,"≰","\\nleq",!0);E(S,N,hs," ","\\ ");E(S,N,hs," ","\\space");E(S,N,hs," ","\\nobreakspace");E(we,N,hs," ","\\ ");E(we,N,hs," "," ");E(we,N,hs," ","\\space");E(we,N,hs," ","\\nobreakspace");E(S,N,hs,null,"\\nobreak");E(S,N,hs,null,"\\allowbreak");E(S,N,Qf,",",",");E(S,N,Qf,";",";");E(S,j,Ke,"⊼","\\barwedge",!0);E(S,j,Ke,"⊻","\\veebar",!0);E(S,N,Ke,"⊙","\\odot",!0);E(S,N,Ke,"⊕","\\oplus",!0);E(S,N,Ke,"⊗","\\otimes",!0);E(S,N,Q,"∂","\\partial",!0);E(S,N,Ke,"⊘","\\oslash",!0);E(S,j,Ke,"⊚","\\circledcirc",!0);E(S,j,Ke,"⊡","\\boxdot",!0);E(S,N,Ke,"△","\\bigtriangleup");E(S,N,Ke,"▽","\\bigtriangledown");E(S,N,Ke,"†","\\dagger");E(S,N,Ke,"⋄","\\diamond");E(S,N,Ke,"⋆","\\star");E(S,N,Ke,"◃","\\triangleleft");E(S,N,Ke,"▹","\\triangleright");E(S,N,Si,"{","\\{");E(we,N,Q,"{","\\{");E(we,N,Q,"{","\\textbraceleft");E(S,N,qr,"}","\\}");E(we,N,Q,"}","\\}");E(we,N,Q,"}","\\textbraceright");E(S,N,Si,"{","\\lbrace");E(S,N,qr,"}","\\rbrace");E(S,N,Si,"[","\\lbrack",!0);E(we,N,Q,"[","\\lbrack",!0);E(S,N,qr,"]","\\rbrack",!0);E(we,N,Q,"]","\\rbrack",!0);E(S,N,Si,"(","\\lparen",!0);E(S,N,qr,")","\\rparen",!0);E(we,N,Q,"<","\\textless",!0);E(we,N,Q,">","\\textgreater",!0);E(S,N,Si,"⌊","\\lfloor",!0);E(S,N,qr,"⌋","\\rfloor",!0);E(S,N,Si,"⌈","\\lceil",!0);E(S,N,qr,"⌉","\\rceil",!0);E(S,N,Q,"\\","\\backslash");E(S,N,Q,"∣","|");E(S,N,Q,"∣","\\vert");E(we,N,Q,"|","\\textbar",!0);E(S,N,Q,"∥","\\|");E(S,N,Q,"∥","\\Vert");E(we,N,Q,"∥","\\textbardbl");E(we,N,Q,"~","\\textasciitilde");E(we,N,Q,"\\","\\textbackslash");E(we,N,Q,"^","\\textasciicircum");E(S,N,q,"↑","\\uparrow",!0);E(S,N,q,"⇑","\\Uparrow",!0);E(S,N,q,"↓","\\downarrow",!0);E(S,N,q,"⇓","\\Downarrow",!0);E(S,N,q,"↕","\\updownarrow",!0);E(S,N,q,"⇕","\\Updownarrow",!0);E(S,N,ir,"∐","\\coprod");E(S,N,ir,"⋁","\\bigvee");E(S,N,ir,"⋀","\\bigwedge");E(S,N,ir,"⨄","\\biguplus");E(S,N,ir,"⋂","\\bigcap");E(S,N,ir,"⋃","\\bigcup");E(S,N,ir,"∫","\\int");E(S,N,ir,"∫","\\intop");E(S,N,ir,"∬","\\iint");E(S,N,ir,"∭","\\iiint");E(S,N,ir,"∏","\\prod");E(S,N,ir,"∑","\\sum");E(S,N,ir,"⨂","\\bigotimes");E(S,N,ir,"⨁","\\bigoplus");E(S,N,ir,"⨀","\\bigodot");E(S,N,ir,"∮","\\oint");E(S,N,ir,"∯","\\oiint");E(S,N,ir,"∰","\\oiiint");E(S,N,ir,"⨆","\\bigsqcup");E(S,N,ir,"∫","\\smallint");E(we,N,yu,"…","\\textellipsis");E(S,N,yu,"…","\\mathellipsis");E(we,N,yu,"…","\\ldots",!0);E(S,N,yu,"…","\\ldots",!0);E(S,N,yu,"⋯","\\@cdots",!0);E(S,N,yu,"⋱","\\ddots",!0);E(S,N,Q,"⋮","\\varvdots");E(we,N,Q,"⋮","\\varvdots");E(S,N,Mn,"ˊ","\\acute");E(S,N,Mn,"ˋ","\\grave");E(S,N,Mn,"¨","\\ddot");E(S,N,Mn,"~","\\tilde");E(S,N,Mn,"ˉ","\\bar");E(S,N,Mn,"˘","\\breve");E(S,N,Mn,"ˇ","\\check");E(S,N,Mn,"^","\\hat");E(S,N,Mn,"⃗","\\vec");E(S,N,Mn,"˙","\\dot");E(S,N,Mn,"˚","\\mathring");E(S,N,st,"","\\@imath");E(S,N,st,"","\\@jmath");E(S,N,Q,"ı","ı");E(S,N,Q,"ȷ","ȷ");E(we,N,Q,"ı","\\i",!0);E(we,N,Q,"ȷ","\\j",!0);E(we,N,Q,"ß","\\ss",!0);E(we,N,Q,"æ","\\ae",!0);E(we,N,Q,"œ","\\oe",!0);E(we,N,Q,"ø","\\o",!0);E(we,N,Q,"Æ","\\AE",!0);E(we,N,Q,"Œ","\\OE",!0);E(we,N,Q,"Ø","\\O",!0);E(we,N,Mn,"ˊ","\\'");E(we,N,Mn,"ˋ","\\`");E(we,N,Mn,"ˆ","\\^");E(we,N,Mn,"˜","\\~");E(we,N,Mn,"ˉ","\\=");E(we,N,Mn,"˘","\\u");E(we,N,Mn,"˙","\\.");E(we,N,Mn,"¸","\\c");E(we,N,Mn,"˚","\\r");E(we,N,Mn,"ˇ","\\v");E(we,N,Mn,"¨",'\\"');E(we,N,Mn,"˝","\\H");E(we,N,Mn,"◯","\\textcircled");var Ex={"--":!0,"---":!0,"``":!0,"''":!0};E(we,N,Q,"–","--",!0);E(we,N,Q,"–","\\textendash");E(we,N,Q,"—","---",!0);E(we,N,Q,"—","\\textemdash");E(we,N,Q,"‘","`",!0);E(we,N,Q,"‘","\\textquoteleft");E(we,N,Q,"’","'",!0);E(we,N,Q,"’","\\textquoteright");E(we,N,Q,"“","``",!0);E(we,N,Q,"“","\\textquotedblleft");E(we,N,Q,"”","''",!0);E(we,N,Q,"”","\\textquotedblright");E(S,N,Q,"°","\\degree",!0);E(we,N,Q,"°","\\degree");E(we,N,Q,"°","\\textdegree",!0);E(S,N,Q,"£","\\pounds");E(S,N,Q,"£","\\mathsterling",!0);E(we,N,Q,"£","\\pounds");E(we,N,Q,"£","\\textsterling",!0);E(S,j,Q,"✠","\\maltese");E(we,j,Q,"✠","\\maltese");var u6='0123456789/@."';for(var rg=0;rg<u6.length;rg++){var c6=u6.charAt(rg);E(S,N,Q,c6,c6)}var d6='0123456789!@*()-=+";:?/.,';for(var ig=0;ig<d6.length;ig++){var h6=d6.charAt(ig);E(we,N,Q,h6,h6)}var uf="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";for(var ag=0;ag<uf.length;ag++){var yh=uf.charAt(ag);E(S,N,st,yh,yh),E(we,N,Q,yh,yh)}E(S,j,Q,"C","ℂ");E(we,j,Q,"C","ℂ");E(S,j,Q,"H","ℍ");E(we,j,Q,"H","ℍ");E(S,j,Q,"N","ℕ");E(we,j,Q,"N","ℕ");E(S,j,Q,"P","ℙ");E(we,j,Q,"P","ℙ");E(S,j,Q,"Q","ℚ");E(we,j,Q,"Q","ℚ");E(S,j,Q,"R","ℝ");E(we,j,Q,"R","ℝ");E(S,j,Q,"Z","ℤ");E(we,j,Q,"Z","ℤ");E(S,N,st,"h","ℎ");E(we,N,st,"h","ℎ");var ft="";for(var Lr=0;Lr<uf.length;Lr++){var Fn=uf.charAt(Lr);ft=String.fromCharCode(55349,56320+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56372+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56424+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56580+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56684+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56736+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56788+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56840+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56944+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),Lr<26&&(ft=String.fromCharCode(55349,56632+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft),ft=String.fromCharCode(55349,56476+Lr),E(S,N,st,Fn,ft),E(we,N,Q,Fn,ft))}ft="𝕜";E(S,N,st,"k",ft);E(we,N,Q,"k",ft);for(var Dl=0;Dl<10;Dl++){var qs=Dl.toString();ft=String.fromCharCode(55349,57294+Dl),E(S,N,st,qs,ft),E(we,N,Q,qs,ft),ft=String.fromCharCode(55349,57314+Dl),E(S,N,st,qs,ft),E(we,N,Q,qs,ft),ft=String.fromCharCode(55349,57324+Dl),E(S,N,st,qs,ft),E(we,N,Q,qs,ft),ft=String.fromCharCode(55349,57334+Dl),E(S,N,st,qs,ft),E(we,N,Q,qs,ft)}var vb="ÐÞþ";for(var sg=0;sg<vb.length;sg++){var Eh=vb.charAt(sg);E(S,N,st,Eh,Eh),E(we,N,Q,Eh,Eh)}var Th=[["mathbf","textbf","Main-Bold"],["mathbf","textbf","Main-Bold"],["mathnormal","textit","Math-Italic"],["mathnormal","textit","Math-Italic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["mathscr","textscr","Script-Regular"],["","",""],["","",""],["","",""],["mathfrak","textfrak","Fraktur-Regular"],["mathfrak","textfrak","Fraktur-Regular"],["mathbb","textbb","AMS-Regular"],["mathbb","textbb","AMS-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathitsf","textitsf","SansSerif-Italic"],["mathitsf","textitsf","SansSerif-Italic"],["","",""],["","",""],["mathtt","texttt","Typewriter-Regular"],["mathtt","texttt","Typewriter-Regular"]],f6=[["mathbf","textbf","Main-Bold"],["","",""],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathtt","texttt","Typewriter-Regular"]],mq=function(t,n){var r=t.charCodeAt(0),i=t.charCodeAt(1),s=(r-55296)*1024+(i-56320)+65536,o=n==="math"?0:1;if(119808<=s&&s<120484){var c=Math.floor((s-119808)/26);return[Th[c][2],Th[c][o]]}else if(120782<=s&&s<=120831){var d=Math.floor((s-120782)/10);return[f6[d][2],f6[d][o]]}else{if(s===120485||s===120486)return[Th[0][2],Th[0][o]];if(120486<s&&s<120782)return["",""];throw new Ie("Unsupported character: "+t)}},Zf=function(t,n,r){return yn[r][t]&&yn[r][t].replace&&(t=yn[r][t].replace),{value:t,metrics:B2(t,n,r)}},Yi=function(t,n,r,i,s){var o=Zf(t,n,r),c=o.metrics;t=o.value;var d;if(c){var f=c.italic;(r==="text"||i&&i.font==="mathit")&&(f=0),d=new Hi(t,c.height,c.depth,f,c.skew,c.width,s)}else typeof console<"u"&&console.warn("No character metrics "+("for '"+t+"' in style '"+n+"' and mode '"+r+"'")),d=new Hi(t,0,0,0,0,0,s);if(i){d.maxFontSize=i.sizeMultiplier,i.style.isTight()&&d.classes.push("mtight");var m=i.getColor();m&&(d.style.color=m)}return d},pq=function(t,n,r,i){return i===void 0&&(i=[]),r.font==="boldsymbol"&&Zf(t,"Main-Bold",n).metrics?Yi(t,"Main-Bold",n,r,i.concat(["mathbf"])):t==="\\"||yn[n][t].font==="main"?Yi(t,"Main-Regular",n,r,i):Yi(t,"AMS-Regular",n,r,i.concat(["amsrm"]))},gq=function(t,n,r,i,s){return s!=="textord"&&Zf(t,"Math-BoldItalic",n).metrics?{fontName:"Math-BoldItalic",fontClass:"boldsymbol"}:{fontName:"Main-Bold",fontClass:"mathbf"}},bq=function(t,n,r){var i=t.mode,s=t.text,o=["mord"],c=i==="math"||i==="text"&&n.font,d=c?n.font:n.fontFamily,f="",m="";if(s.charCodeAt(0)===55349&&([f,m]=mq(s,i)),f.length>0)return Yi(s,f,i,n,o.concat(m));if(d){var p,v;if(d==="boldsymbol"){var _=gq(s,i,n,o,r);p=_.fontName,v=[_.fontClass]}else c?(p=Sx[d].fontName,v=[d]):(p=xh(d,n.fontWeight,n.fontShape),v=[d,n.fontWeight,n.fontShape]);if(Zf(s,p,i).metrics)return Yi(s,p,i,n,o.concat(v));if(Ex.hasOwnProperty(s)&&p.slice(0,10)==="Typewriter"){for(var T=[],x=0;x<s.length;x++)T.push(Yi(s[x],p,i,n,o.concat(v)));return xx(T)}}if(r==="mathord")return Yi(s,"Math-Italic",i,n,o.concat(["mathnormal"]));if(r==="textord"){var k=yn[i][s]&&yn[i][s].font;if(k==="ams"){var A=xh("amsrm",n.fontWeight,n.fontShape);return Yi(s,A,i,n,o.concat("amsrm",n.fontWeight,n.fontShape))}else if(k==="main"||!k){var O=xh("textrm",n.fontWeight,n.fontShape);return Yi(s,O,i,n,o.concat(n.fontWeight,n.fontShape))}else{var I=xh(k,n.fontWeight,n.fontShape);return Yi(s,I,i,n,o.concat(I,n.fontWeight,n.fontShape))}}else throw new Error("unexpected type: "+r+" in makeOrd")},vq=(e,t)=>{if(al(e.classes)!==al(t.classes)||e.skew!==t.skew||e.maxFontSize!==t.maxFontSize)return!1;if(e.classes.length===1){var n=e.classes[0];if(n==="mbin"||n==="mord")return!1}for(var r in e.style)if(e.style.hasOwnProperty(r)&&e.style[r]!==t.style[r])return!1;for(var i in t.style)if(t.style.hasOwnProperty(i)&&e.style[i]!==t.style[i])return!1;return!0},_q=e=>{for(var t=0;t<e.length-1;t++){var n=e[t],r=e[t+1];n instanceof Hi&&r instanceof Hi&&vq(n,r)&&(n.text+=r.text,n.height=Math.max(n.height,r.height),n.depth=Math.max(n.depth,r.depth),n.italic=r.italic,e.splice(t+1,1),t--)}return e},z2=function(t){for(var n=0,r=0,i=0,s=0;s<t.children.length;s++){var o=t.children[s];o.height>n&&(n=o.height),o.depth>r&&(r=o.depth),o.maxFontSize>i&&(i=o.maxFontSize)}t.height=n,t.depth=r,t.maxFontSize=i},ti=function(t,n,r,i){var s=new L0(t,n,r,i);return z2(s),s},Tx=(e,t,n,r)=>new L0(e,t,n,r),yq=function(t,n,r){var i=ti([t],[],n);return i.height=Math.max(r||n.fontMetrics().defaultRuleThickness,n.minRuleThickness),i.style.borderBottomWidth=Be(i.height),i.maxFontSize=1,i},Eq=function(t,n,r,i){var s=new U2(t,n,r,i);return z2(s),s},xx=function(t){var n=new D0(t);return z2(n),n},Tq=function(t,n){return t instanceof D0?ti([],[t],n):t},xq=function(t){if(t.positionType==="individualShift"){for(var n=t.children,r=[n[0]],i=-n[0].shift-n[0].elem.depth,s=i,o=1;o<n.length;o++){var c=-n[o].shift-s-n[o].elem.depth,d=c-(n[o-1].elem.height+n[o-1].elem.depth);s=s+c,r.push({type:"kern",size:d}),r.push(n[o])}return{children:r,depth:i}}var f;if(t.positionType==="top"){for(var m=t.positionData,p=0;p<t.children.length;p++){var v=t.children[p];m-=v.type==="kern"?v.size:v.elem.height+v.elem.depth}f=m}else if(t.positionType==="bottom")f=-t.positionData;else{var _=t.children[0];if(_.type!=="elem")throw new Error('First child must have type "elem".');if(t.positionType==="shift")f=-_.elem.depth-t.positionData;else if(t.positionType==="firstBaseline")f=-_.elem.depth;else throw new Error("Invalid positionType "+t.positionType+".")}return{children:t.children,depth:f}},Sq=function(t,n){for(var{children:r,depth:i}=xq(t),s=0,o=0;o<r.length;o++){var c=r[o];if(c.type==="elem"){var d=c.elem;s=Math.max(s,d.maxFontSize,d.height)}}s+=2;var f=ti(["pstrut"],[]);f.style.height=Be(s);for(var m=[],p=i,v=i,_=i,T=0;T<r.length;T++){var x=r[T];if(x.type==="kern")_+=x.size;else{var k=x.elem,A=x.wrapperClasses||[],O=x.wrapperStyle||{},I=ti(A,[f,k],void 0,O);I.style.top=Be(-s-_-k.depth),x.marginLeft&&(I.style.marginLeft=x.marginLeft),x.marginRight&&(I.style.marginRight=x.marginRight),m.push(I),_+=k.height+k.depth}p=Math.min(p,_),v=Math.max(v,_)}var $=ti(["vlist"],m);$.style.height=Be(v);var V;if(p<0){var B=ti([],[]),Z=ti(["vlist"],[B]);Z.style.height=Be(-p);var ee=ti(["vlist-s"],[new Hi("​")]);V=[ti(["vlist-r"],[$,ee]),ti(["vlist-r"],[Z])]}else V=[ti(["vlist-r"],[$])];var te=ti(["vlist-t"],V);return V.length===2&&te.classes.push("vlist-t2"),te.height=v,te.depth=-p,te},wq=(e,t)=>{var n=ti(["mspace"],[],t),r=Bn(e,t);return n.style.marginRight=Be(r),n},xh=function(t,n,r){var i="";switch(t){case"amsrm":i="AMS";break;case"textrm":i="Main";break;case"textsf":i="SansSerif";break;case"texttt":i="Typewriter";break;default:i=t}var s;return n==="textbf"&&r==="textit"?s="BoldItalic":n==="textbf"?s="Bold":n==="textit"?s="Italic":s="Regular",i+"-"+s},Sx={mathbf:{variant:"bold",fontName:"Main-Bold"},mathrm:{variant:"normal",fontName:"Main-Regular"},textit:{variant:"italic",fontName:"Main-Italic"},mathit:{variant:"italic",fontName:"Main-Italic"},mathnormal:{variant:"italic",fontName:"Math-Italic"},mathsfit:{variant:"sans-serif-italic",fontName:"SansSerif-Italic"},mathbb:{variant:"double-struck",fontName:"AMS-Regular"},mathcal:{variant:"script",fontName:"Caligraphic-Regular"},mathfrak:{variant:"fraktur",fontName:"Fraktur-Regular"},mathscr:{variant:"script",fontName:"Script-Regular"},mathsf:{variant:"sans-serif",fontName:"SansSerif-Regular"},mathtt:{variant:"monospace",fontName:"Typewriter-Regular"}},wx={vec:["vec",.471,.714],oiintSize1:["oiintSize1",.957,.499],oiintSize2:["oiintSize2",1.472,.659],oiiintSize1:["oiiintSize1",1.304,.499],oiiintSize2:["oiiintSize2",1.98,.659]},Aq=function(t,n){var[r,i,s]=wx[t],o=new sl(r),c=new as([o],{width:Be(i),height:Be(s),style:"width:"+Be(i),viewBox:"0 0 "+1e3*i+" "+1e3*s,preserveAspectRatio:"xMinYMin"}),d=Tx(["overlay"],[c],n);return d.height=s,d.style.height=Be(s),d.style.width=Be(i),d},se={fontMap:Sx,makeSymbol:Yi,mathsym:pq,makeSpan:ti,makeSvgSpan:Tx,makeLineSpan:yq,makeAnchor:Eq,makeFragment:xx,wrapFragment:Tq,makeVList:Sq,makeOrd:bq,makeGlue:wq,staticSvg:Aq,svgData:wx,tryCombineChars:_q},Ln={number:3,unit:"mu"},Ll={number:4,unit:"mu"},Ha={number:5,unit:"mu"},kq={mord:{mop:Ln,mbin:Ll,mrel:Ha,minner:Ln},mop:{mord:Ln,mop:Ln,mrel:Ha,minner:Ln},mbin:{mord:Ll,mop:Ll,mopen:Ll,minner:Ll},mrel:{mord:Ha,mop:Ha,mopen:Ha,minner:Ha},mopen:{},mclose:{mop:Ln,mbin:Ll,mrel:Ha,minner:Ln},mpunct:{mord:Ln,mop:Ln,mrel:Ha,mopen:Ln,mclose:Ln,mpunct:Ln,minner:Ln},minner:{mord:Ln,mop:Ln,mbin:Ll,mrel:Ha,mopen:Ln,mpunct:Ln,minner:Ln}},Cq={mord:{mop:Ln},mop:{mord:Ln,mop:Ln},mbin:{},mrel:{},mopen:{},mclose:{mop:Ln},mpunct:{},minner:{mop:Ln}},Ax={},cf={},df={};function $e(e){for(var{type:t,names:n,props:r,handler:i,htmlBuilder:s,mathmlBuilder:o}=e,c={type:t,numArgs:r.numArgs,argTypes:r.argTypes,allowedInArgument:!!r.allowedInArgument,allowedInText:!!r.allowedInText,allowedInMath:r.allowedInMath===void 0?!0:r.allowedInMath,numOptionalArgs:r.numOptionalArgs||0,infix:!!r.infix,primitive:!!r.primitive,handler:i},d=0;d<n.length;++d)Ax[n[d]]=c;t&&(s&&(cf[t]=s),o&&(df[t]=o))}function Jl(e){var{type:t,htmlBuilder:n,mathmlBuilder:r}=e;$e({type:t,names:[],props:{numArgs:0},handler(){throw new Error("Should never be called.")},htmlBuilder:n,mathmlBuilder:r})}var hf=function(t){return t.type==="ordgroup"&&t.body.length===1?t.body[0]:t},Wn=function(t){return t.type==="ordgroup"?t.body:[t]},ss=se.makeSpan,Nq=["leftmost","mbin","mopen","mrel","mop","mpunct"],Oq=["rightmost","mrel","mclose","mpunct"],Rq={display:lt.DISPLAY,text:lt.TEXT,script:lt.SCRIPT,scriptscript:lt.SCRIPTSCRIPT},Mq={mord:"mord",mop:"mop",mbin:"mbin",mrel:"mrel",mopen:"mopen",mclose:"mclose",mpunct:"mpunct",minner:"minner"},ur=function(t,n,r,i){i===void 0&&(i=[null,null]);for(var s=[],o=0;o<t.length;o++){var c=$t(t[o],n);if(c instanceof D0){var d=c.children;s.push(...d)}else s.push(c)}if(se.tryCombineChars(s),!r)return s;var f=n;if(t.length===1){var m=t[0];m.type==="sizing"?f=n.havingSize(m.size):m.type==="styling"&&(f=n.havingStyle(Rq[m.style]))}var p=ss([i[0]||"leftmost"],[],n),v=ss([i[1]||"rightmost"],[],n),_=r==="root";return m6(s,(T,x)=>{var k=x.classes[0],A=T.classes[0];k==="mbin"&&Oq.includes(A)?x.classes[0]="mord":A==="mbin"&&Nq.includes(k)&&(T.classes[0]="mord")},{node:p},v,_),m6(s,(T,x)=>{var k=_b(x),A=_b(T),O=k&&A?T.hasClass("mtight")?Cq[k][A]:kq[k][A]:null;if(O)return se.makeGlue(O,f)},{node:p},v,_),s},m6=function e(t,n,r,i,s){i&&t.push(i);for(var o=0;o<t.length;o++){var c=t[o],d=kx(c);if(d){e(d.children,n,r,null,s);continue}var f=!c.hasClass("mspace");if(f){var m=n(c,r.node);m&&(r.insertAfter?r.insertAfter(m):(t.unshift(m),o++))}f?r.node=c:s&&c.hasClass("newline")&&(r.node=ss(["leftmost"])),r.insertAfter=(p=>v=>{t.splice(p+1,0,v),o++})(o)}i&&t.pop()},kx=function(t){return t instanceof D0||t instanceof U2||t instanceof L0&&t.hasClass("enclosing")?t:null},Iq=function e(t,n){var r=kx(t);if(r){var i=r.children;if(i.length){if(n==="right")return e(i[i.length-1],"right");if(n==="left")return e(i[0],"left")}}return t},_b=function(t,n){return t?(n&&(t=Iq(t,n)),Mq[t.classes[0]]||null):null},f0=function(t,n){var r=["nulldelimiter"].concat(t.baseSizingClasses());return ss(n.concat(r))},$t=function(t,n,r){if(!t)return ss();if(cf[t.type]){var i=cf[t.type](t,n);if(r&&n.size!==r.size){i=ss(n.sizingClasses(r),[i],n);var s=n.sizeMultiplier/r.sizeMultiplier;i.height*=s,i.depth*=s}return i}else throw new Ie("Got group of unknown type: '"+t.type+"'")};function Sh(e,t){var n=ss(["base"],e,t),r=ss(["strut"]);return r.style.height=Be(n.height+n.depth),n.depth&&(r.style.verticalAlign=Be(-n.depth)),n.children.unshift(r),n}function yb(e,t){var n=null;e.length===1&&e[0].type==="tag"&&(n=e[0].tag,e=e[0].body);var r=ur(e,t,"root"),i;r.length===2&&r[1].hasClass("tag")&&(i=r.pop());for(var s=[],o=[],c=0;c<r.length;c++)if(o.push(r[c]),r[c].hasClass("mbin")||r[c].hasClass("mrel")||r[c].hasClass("allowbreak")){for(var d=!1;c<r.length-1&&r[c+1].hasClass("mspace")&&!r[c+1].hasClass("newline");)c++,o.push(r[c]),r[c].hasClass("nobreak")&&(d=!0);d||(s.push(Sh(o,t)),o=[])}else r[c].hasClass("newline")&&(o.pop(),o.length>0&&(s.push(Sh(o,t)),o=[]),s.push(r[c]));o.length>0&&s.push(Sh(o,t));var f;n?(f=Sh(ur(n,t,!0)),f.classes=["tag"],s.push(f)):i&&s.push(i);var m=ss(["katex-html"],s);if(m.setAttribute("aria-hidden","true"),f){var p=f.children[0];p.style.height=Be(m.height+m.depth),m.depth&&(p.style.verticalAlign=Be(-m.depth))}return m}function Cx(e){return new D0(e)}class _i{constructor(t,n,r){this.type=void 0,this.attributes=void 0,this.children=void 0,this.classes=void 0,this.type=t,this.attributes={},this.children=n||[],this.classes=r||[]}setAttribute(t,n){this.attributes[t]=n}getAttribute(t){return this.attributes[t]}toNode(){var t=document.createElementNS("http://www.w3.org/1998/Math/MathML",this.type);for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&t.setAttribute(n,this.attributes[n]);this.classes.length>0&&(t.className=al(this.classes));for(var r=0;r<this.children.length;r++)if(this.children[r]instanceof ha&&this.children[r+1]instanceof ha){for(var i=this.children[r].toText()+this.children[++r].toText();this.children[r+1]instanceof ha;)i+=this.children[++r].toText();t.appendChild(new ha(i).toNode())}else t.appendChild(this.children[r].toNode());return t}toMarkup(){var t="<"+this.type;for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(t+=" "+n+'="',t+=Vt.escape(this.attributes[n]),t+='"');this.classes.length>0&&(t+=' class ="'+Vt.escape(al(this.classes))+'"'),t+=">";for(var r=0;r<this.children.length;r++)t+=this.children[r].toMarkup();return t+="</"+this.type+">",t}toText(){return this.children.map(t=>t.toText()).join("")}}class ha{constructor(t){this.text=void 0,this.text=t}toNode(){return document.createTextNode(this.text)}toMarkup(){return Vt.escape(this.toText())}toText(){return this.text}}class Dq{constructor(t){this.width=void 0,this.character=void 0,this.width=t,t>=.05555&&t<=.05556?this.character=" ":t>=.1666&&t<=.1667?this.character=" ":t>=.2222&&t<=.2223?this.character=" ":t>=.2777&&t<=.2778?this.character="  ":t>=-.05556&&t<=-.05555?this.character=" ⁣":t>=-.1667&&t<=-.1666?this.character=" ⁣":t>=-.2223&&t<=-.2222?this.character=" ⁣":t>=-.2778&&t<=-.2777?this.character=" ⁣":this.character=null}toNode(){if(this.character)return document.createTextNode(this.character);var t=document.createElementNS("http://www.w3.org/1998/Math/MathML","mspace");return t.setAttribute("width",Be(this.width)),t}toMarkup(){return this.character?"<mtext>"+this.character+"</mtext>":'<mspace width="'+Be(this.width)+'"/>'}toText(){return this.character?this.character:" "}}var Oe={MathNode:_i,TextNode:ha,SpaceNode:Dq,newDocumentFragment:Cx},ji=function(t,n,r){return yn[n][t]&&yn[n][t].replace&&t.charCodeAt(0)!==55349&&!(Ex.hasOwnProperty(t)&&r&&(r.fontFamily&&r.fontFamily.slice(4,6)==="tt"||r.font&&r.font.slice(4,6)==="tt"))&&(t=yn[n][t].replace),new Oe.TextNode(t)},F2=function(t){return t.length===1?t[0]:new Oe.MathNode("mrow",t)},H2=function(t,n){if(n.fontFamily==="texttt")return"monospace";if(n.fontFamily==="textsf")return n.fontShape==="textit"&&n.fontWeight==="textbf"?"sans-serif-bold-italic":n.fontShape==="textit"?"sans-serif-italic":n.fontWeight==="textbf"?"bold-sans-serif":"sans-serif";if(n.fontShape==="textit"&&n.fontWeight==="textbf")return"bold-italic";if(n.fontShape==="textit")return"italic";if(n.fontWeight==="textbf")return"bold";var r=n.font;if(!r||r==="mathnormal")return null;var i=t.mode;if(r==="mathit")return"italic";if(r==="boldsymbol")return t.type==="textord"?"bold":"bold-italic";if(r==="mathbf")return"bold";if(r==="mathbb")return"double-struck";if(r==="mathsfit")return"sans-serif-italic";if(r==="mathfrak")return"fraktur";if(r==="mathscr"||r==="mathcal")return"script";if(r==="mathsf")return"sans-serif";if(r==="mathtt")return"monospace";var s=t.text;if(["\\imath","\\jmath"].includes(s))return null;yn[i][s]&&yn[i][s].replace&&(s=yn[i][s].replace);var o=se.fontMap[r].fontName;return B2(s,o,i)?se.fontMap[r].variant:null};function lg(e){if(!e)return!1;if(e.type==="mi"&&e.children.length===1){var t=e.children[0];return t instanceof ha&&t.text==="."}else if(e.type==="mo"&&e.children.length===1&&e.getAttribute("separator")==="true"&&e.getAttribute("lspace")==="0em"&&e.getAttribute("rspace")==="0em"){var n=e.children[0];return n instanceof ha&&n.text===","}else return!1}var li=function(t,n,r){if(t.length===1){var i=mn(t[0],n);return r&&i instanceof _i&&i.type==="mo"&&(i.setAttribute("lspace","0em"),i.setAttribute("rspace","0em")),[i]}for(var s=[],o,c=0;c<t.length;c++){var d=mn(t[c],n);if(d instanceof _i&&o instanceof _i){if(d.type==="mtext"&&o.type==="mtext"&&d.getAttribute("mathvariant")===o.getAttribute("mathvariant")){o.children.push(...d.children);continue}else if(d.type==="mn"&&o.type==="mn"){o.children.push(...d.children);continue}else if(lg(d)&&o.type==="mn"){o.children.push(...d.children);continue}else if(d.type==="mn"&&lg(o))d.children=[...o.children,...d.children],s.pop();else if((d.type==="msup"||d.type==="msub")&&d.children.length>=1&&(o.type==="mn"||lg(o))){var f=d.children[0];f instanceof _i&&f.type==="mn"&&(f.children=[...o.children,...f.children],s.pop())}else if(o.type==="mi"&&o.children.length===1){var m=o.children[0];if(m instanceof ha&&m.text==="̸"&&(d.type==="mo"||d.type==="mi"||d.type==="mn")){var p=d.children[0];p instanceof ha&&p.text.length>0&&(p.text=p.text.slice(0,1)+"̸"+p.text.slice(1),s.pop())}}}s.push(d),o=d}return s},ll=function(t,n,r){return F2(li(t,n,r))},mn=function(t,n){if(!t)return new Oe.MathNode("mrow");if(df[t.type]){var r=df[t.type](t,n);return r}else throw new Ie("Got group of unknown type: '"+t.type+"'")};function p6(e,t,n,r,i){var s=li(e,n),o;s.length===1&&s[0]instanceof _i&&["mrow","mtable"].includes(s[0].type)?o=s[0]:o=new Oe.MathNode("mrow",s);var c=new Oe.MathNode("annotation",[new Oe.TextNode(t)]);c.setAttribute("encoding","application/x-tex");var d=new Oe.MathNode("semantics",[o,c]),f=new Oe.MathNode("math",[d]);f.setAttribute("xmlns","http://www.w3.org/1998/Math/MathML"),r&&f.setAttribute("display","block");var m=i?"katex":"katex-mathml";return se.makeSpan([m],[f])}var Nx=function(t){return new Va({style:t.displayMode?lt.DISPLAY:lt.TEXT,maxSize:t.maxSize,minRuleThickness:t.minRuleThickness})},Ox=function(t,n){if(n.displayMode){var r=["katex-display"];n.leqno&&r.push("leqno"),n.fleqn&&r.push("fleqn"),t=se.makeSpan(r,[t])}return t},Lq=function(t,n,r){var i=Nx(r),s;if(r.output==="mathml")return p6(t,n,i,r.displayMode,!0);if(r.output==="html"){var o=yb(t,i);s=se.makeSpan(["katex"],[o])}else{var c=p6(t,n,i,r.displayMode,!1),d=yb(t,i);s=se.makeSpan(["katex"],[c,d])}return Ox(s,r)},Pq=function(t,n,r){var i=Nx(r),s=yb(t,i),o=se.makeSpan(["katex"],[s]);return Ox(o,r)},Bq={widehat:"^",widecheck:"ˇ",widetilde:"~",utilde:"~",overleftarrow:"←",underleftarrow:"←",xleftarrow:"←",overrightarrow:"→",underrightarrow:"→",xrightarrow:"→",underbrace:"⏟",overbrace:"⏞",overgroup:"⏠",undergroup:"⏡",overleftrightarrow:"↔",underleftrightarrow:"↔",xleftrightarrow:"↔",Overrightarrow:"⇒",xRightarrow:"⇒",overleftharpoon:"↼",xleftharpoonup:"↼",overrightharpoon:"⇀",xrightharpoonup:"⇀",xLeftarrow:"⇐",xLeftrightarrow:"⇔",xhookleftarrow:"↩",xhookrightarrow:"↪",xmapsto:"↦",xrightharpoondown:"⇁",xleftharpoondown:"↽",xrightleftharpoons:"⇌",xleftrightharpoons:"⇋",xtwoheadleftarrow:"↞",xtwoheadrightarrow:"↠",xlongequal:"=",xtofrom:"⇄",xrightleftarrows:"⇄",xrightequilibrium:"⇌",xleftequilibrium:"⇋","\\cdrightarrow":"→","\\cdleftarrow":"←","\\cdlongequal":"="},Uq=function(t){var n=new Oe.MathNode("mo",[new Oe.TextNode(Bq[t.replace(/^\\/,"")])]);return n.setAttribute("stretchy","true"),n},zq={overrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],overleftarrow:[["leftarrow"],.888,522,"xMinYMin"],underrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],underleftarrow:[["leftarrow"],.888,522,"xMinYMin"],xrightarrow:[["rightarrow"],1.469,522,"xMaxYMin"],"\\cdrightarrow":[["rightarrow"],3,522,"xMaxYMin"],xleftarrow:[["leftarrow"],1.469,522,"xMinYMin"],"\\cdleftarrow":[["leftarrow"],3,522,"xMinYMin"],Overrightarrow:[["doublerightarrow"],.888,560,"xMaxYMin"],xRightarrow:[["doublerightarrow"],1.526,560,"xMaxYMin"],xLeftarrow:[["doubleleftarrow"],1.526,560,"xMinYMin"],overleftharpoon:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoonup:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoondown:[["leftharpoondown"],.888,522,"xMinYMin"],overrightharpoon:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoonup:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoondown:[["rightharpoondown"],.888,522,"xMaxYMin"],xlongequal:[["longequal"],.888,334,"xMinYMin"],"\\cdlongequal":[["longequal"],3,334,"xMinYMin"],xtwoheadleftarrow:[["twoheadleftarrow"],.888,334,"xMinYMin"],xtwoheadrightarrow:[["twoheadrightarrow"],.888,334,"xMaxYMin"],overleftrightarrow:[["leftarrow","rightarrow"],.888,522],overbrace:[["leftbrace","midbrace","rightbrace"],1.6,548],underbrace:[["leftbraceunder","midbraceunder","rightbraceunder"],1.6,548],underleftrightarrow:[["leftarrow","rightarrow"],.888,522],xleftrightarrow:[["leftarrow","rightarrow"],1.75,522],xLeftrightarrow:[["doubleleftarrow","doublerightarrow"],1.75,560],xrightleftharpoons:[["leftharpoondownplus","rightharpoonplus"],1.75,716],xleftrightharpoons:[["leftharpoonplus","rightharpoondownplus"],1.75,716],xhookleftarrow:[["leftarrow","righthook"],1.08,522],xhookrightarrow:[["lefthook","rightarrow"],1.08,522],overlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],underlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],overgroup:[["leftgroup","rightgroup"],.888,342],undergroup:[["leftgroupunder","rightgroupunder"],.888,342],xmapsto:[["leftmapsto","rightarrow"],1.5,522],xtofrom:[["leftToFrom","rightToFrom"],1.75,528],xrightleftarrows:[["baraboveleftarrow","rightarrowabovebar"],1.75,901],xrightequilibrium:[["baraboveshortleftharpoon","rightharpoonaboveshortbar"],1.75,716],xleftequilibrium:[["shortbaraboveleftharpoon","shortrightharpoonabovebar"],1.75,716]},Fq=function(t){return t.type==="ordgroup"?t.body.length:1},Hq=function(t,n){function r(){var c=4e5,d=t.label.slice(1);if(["widehat","widecheck","widetilde","utilde"].includes(d)){var f=t,m=Fq(f.base),p,v,_;if(m>5)d==="widehat"||d==="widecheck"?(p=420,c=2364,_=.42,v=d+"4"):(p=312,c=2340,_=.34,v="tilde4");else{var T=[1,1,2,2,3,3][m];d==="widehat"||d==="widecheck"?(c=[0,1062,2364,2364,2364][T],p=[0,239,300,360,420][T],_=[0,.24,.3,.3,.36,.42][T],v=d+T):(c=[0,600,1033,2339,2340][T],p=[0,260,286,306,312][T],_=[0,.26,.286,.3,.306,.34][T],v="tilde"+T)}var x=new sl(v),k=new as([x],{width:"100%",height:Be(_),viewBox:"0 0 "+c+" "+p,preserveAspectRatio:"none"});return{span:se.makeSvgSpan([],[k],n),minWidth:0,height:_}}else{var A=[],O=zq[d],[I,$,V]=O,B=V/1e3,Z=I.length,ee,te;if(Z===1){var Y=O[3];ee=["hide-tail"],te=[Y]}else if(Z===2)ee=["halfarrow-left","halfarrow-right"],te=["xMinYMin","xMaxYMin"];else if(Z===3)ee=["brace-left","brace-center","brace-right"],te=["xMinYMin","xMidYMin","xMaxYMin"];else throw new Error(`Correct katexImagesData or update code here to support
                    `+Z+" children.");for(var oe=0;oe<Z;oe++){var he=new sl(I[oe]),Se=new as([he],{width:"400em",height:Be(B),viewBox:"0 0 "+c+" "+V,preserveAspectRatio:te[oe]+" slice"}),fe=se.makeSvgSpan([ee[oe]],[Se],n);if(Z===1)return{span:fe,minWidth:$,height:B};fe.style.height=Be(B),A.push(fe)}return{span:se.makeSpan(["stretchy"],A,n),minWidth:$,height:B}}}var{span:i,minWidth:s,height:o}=r();return i.height=o,i.style.height=Be(o),s>0&&(i.style.minWidth=Be(s)),i},jq=function(t,n,r,i,s){var o,c=t.height+t.depth+r+i;if(/fbox|color|angl/.test(n)){if(o=se.makeSpan(["stretchy",n],[],s),n==="fbox"){var d=s.color&&s.getColor();d&&(o.style.borderColor=d)}}else{var f=[];/^[bx]cancel$/.test(n)&&f.push(new bb({x1:"0",y1:"0",x2:"100%",y2:"100%","stroke-width":"0.046em"})),/^x?cancel$/.test(n)&&f.push(new bb({x1:"0",y1:"100%",x2:"100%",y2:"0","stroke-width":"0.046em"}));var m=new as(f,{width:"100%",height:Be(c)});o=se.makeSvgSpan([],[m],s)}return o.height=c,o.style.height=Be(c),o},ls={encloseSpan:jq,mathMLnode:Uq,svgSpan:Hq};function wt(e,t){if(!e||e.type!==t)throw new Error("Expected node of type "+t+", but got "+(e?"node of type "+e.type:String(e)));return e}function j2(e){var t=Jf(e);if(!t)throw new Error("Expected node of symbol group type, but got "+(e?"node of type "+e.type:String(e)));return t}function Jf(e){return e&&(e.type==="atom"||fq.hasOwnProperty(e.type))?e:null}var q2=(e,t)=>{var n,r,i;e&&e.type==="supsub"?(r=wt(e.base,"accent"),n=r.base,e.base=n,i=dq($t(e,t)),e.base=r):(r=wt(e,"accent"),n=r.base);var s=$t(n,t.havingCrampedStyle()),o=r.isShifty&&Vt.isCharacterBox(n),c=0;if(o){var d=Vt.getBaseElem(n),f=$t(d,t.havingCrampedStyle());c=o6(f).skew}var m=r.label==="\\c",p=m?s.height+s.depth:Math.min(s.height,t.fontMetrics().xHeight),v;if(r.isStretchy)v=ls.svgSpan(r,t),v=se.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:s},{type:"elem",elem:v,wrapperClasses:["svg-align"],wrapperStyle:c>0?{width:"calc(100% - "+Be(2*c)+")",marginLeft:Be(2*c)}:void 0}]},t);else{var _,T;r.label==="\\vec"?(_=se.staticSvg("vec",t),T=se.svgData.vec[1]):(_=se.makeOrd({mode:r.mode,text:r.label},t,"textord"),_=o6(_),_.italic=0,T=_.width,m&&(p+=_.depth)),v=se.makeSpan(["accent-body"],[_]);var x=r.label==="\\textcircled";x&&(v.classes.push("accent-full"),p=s.height);var k=c;x||(k-=T/2),v.style.left=Be(k),r.label==="\\textcircled"&&(v.style.top=".2em"),v=se.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:s},{type:"kern",size:-p},{type:"elem",elem:v}]},t)}var A=se.makeSpan(["mord","accent"],[v],t);return i?(i.children[0]=A,i.height=Math.max(A.height,i.height),i.classes[0]="mord",i):A},Rx=(e,t)=>{var n=e.isStretchy?ls.mathMLnode(e.label):new Oe.MathNode("mo",[ji(e.label,e.mode)]),r=new Oe.MathNode("mover",[mn(e.base,t),n]);return r.setAttribute("accent","true"),r},qq=new RegExp(["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring"].map(e=>"\\"+e).join("|"));$e({type:"accent",names:["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring","\\widecheck","\\widehat","\\widetilde","\\overrightarrow","\\overleftarrow","\\Overrightarrow","\\overleftrightarrow","\\overgroup","\\overlinesegment","\\overleftharpoon","\\overrightharpoon"],props:{numArgs:1},handler:(e,t)=>{var n=hf(t[0]),r=!qq.test(e.funcName),i=!r||e.funcName==="\\widehat"||e.funcName==="\\widetilde"||e.funcName==="\\widecheck";return{type:"accent",mode:e.parser.mode,label:e.funcName,isStretchy:r,isShifty:i,base:n}},htmlBuilder:q2,mathmlBuilder:Rx});$e({type:"accent",names:["\\'","\\`","\\^","\\~","\\=","\\u","\\.",'\\"',"\\c","\\r","\\H","\\v","\\textcircled"],props:{numArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["primitive"]},handler:(e,t)=>{var n=t[0],r=e.parser.mode;return r==="math"&&(e.parser.settings.reportNonstrict("mathVsTextAccents","LaTeX's accent "+e.funcName+" works only in text mode"),r="text"),{type:"accent",mode:r,label:e.funcName,isStretchy:!1,isShifty:!0,base:n}},htmlBuilder:q2,mathmlBuilder:Rx});$e({type:"accentUnder",names:["\\underleftarrow","\\underrightarrow","\\underleftrightarrow","\\undergroup","\\underlinesegment","\\utilde"],props:{numArgs:1},handler:(e,t)=>{var{parser:n,funcName:r}=e,i=t[0];return{type:"accentUnder",mode:n.mode,label:r,base:i}},htmlBuilder:(e,t)=>{var n=$t(e.base,t),r=ls.svgSpan(e,t),i=e.label==="\\utilde"?.12:0,s=se.makeVList({positionType:"top",positionData:n.height,children:[{type:"elem",elem:r,wrapperClasses:["svg-align"]},{type:"kern",size:i},{type:"elem",elem:n}]},t);return se.makeSpan(["mord","accentunder"],[s],t)},mathmlBuilder:(e,t)=>{var n=ls.mathMLnode(e.label),r=new Oe.MathNode("munder",[mn(e.base,t),n]);return r.setAttribute("accentunder","true"),r}});var wh=e=>{var t=new Oe.MathNode("mpadded",e?[e]:[]);return t.setAttribute("width","+0.6em"),t.setAttribute("lspace","0.3em"),t};$e({type:"xArrow",names:["\\xleftarrow","\\xrightarrow","\\xLeftarrow","\\xRightarrow","\\xleftrightarrow","\\xLeftrightarrow","\\xhookleftarrow","\\xhookrightarrow","\\xmapsto","\\xrightharpoondown","\\xrightharpoonup","\\xleftharpoondown","\\xleftharpoonup","\\xrightleftharpoons","\\xleftrightharpoons","\\xlongequal","\\xtwoheadrightarrow","\\xtwoheadleftarrow","\\xtofrom","\\xrightleftarrows","\\xrightequilibrium","\\xleftequilibrium","\\\\cdrightarrow","\\\\cdleftarrow","\\\\cdlongequal"],props:{numArgs:1,numOptionalArgs:1},handler(e,t,n){var{parser:r,funcName:i}=e;return{type:"xArrow",mode:r.mode,label:i,body:t[0],below:n[0]}},htmlBuilder(e,t){var n=t.style,r=t.havingStyle(n.sup()),i=se.wrapFragment($t(e.body,r,t),t),s=e.label.slice(0,2)==="\\x"?"x":"cd";i.classes.push(s+"-arrow-pad");var o;e.below&&(r=t.havingStyle(n.sub()),o=se.wrapFragment($t(e.below,r,t),t),o.classes.push(s+"-arrow-pad"));var c=ls.svgSpan(e,t),d=-t.fontMetrics().axisHeight+.5*c.height,f=-t.fontMetrics().axisHeight-.5*c.height-.111;(i.depth>.25||e.label==="\\xleftequilibrium")&&(f-=i.depth);var m;if(o){var p=-t.fontMetrics().axisHeight+o.height+.5*c.height+.111;m=se.makeVList({positionType:"individualShift",children:[{type:"elem",elem:i,shift:f},{type:"elem",elem:c,shift:d},{type:"elem",elem:o,shift:p}]},t)}else m=se.makeVList({positionType:"individualShift",children:[{type:"elem",elem:i,shift:f},{type:"elem",elem:c,shift:d}]},t);return m.children[0].children[0].children[1].classes.push("svg-align"),se.makeSpan(["mrel","x-arrow"],[m],t)},mathmlBuilder(e,t){var n=ls.mathMLnode(e.label);n.setAttribute("minsize",e.label.charAt(0)==="x"?"1.75em":"3.0em");var r;if(e.body){var i=wh(mn(e.body,t));if(e.below){var s=wh(mn(e.below,t));r=new Oe.MathNode("munderover",[n,s,i])}else r=new Oe.MathNode("mover",[n,i])}else if(e.below){var o=wh(mn(e.below,t));r=new Oe.MathNode("munder",[n,o])}else r=wh(),r=new Oe.MathNode("mover",[n,r]);return r}});var $q=se.makeSpan;function Mx(e,t){var n=ur(e.body,t,!0);return $q([e.mclass],n,t)}function Ix(e,t){var n,r=li(e.body,t);return e.mclass==="minner"?n=new Oe.MathNode("mpadded",r):e.mclass==="mord"?e.isCharacterBox?(n=r[0],n.type="mi"):n=new Oe.MathNode("mi",r):(e.isCharacterBox?(n=r[0],n.type="mo"):n=new Oe.MathNode("mo",r),e.mclass==="mbin"?(n.attributes.lspace="0.22em",n.attributes.rspace="0.22em"):e.mclass==="mpunct"?(n.attributes.lspace="0em",n.attributes.rspace="0.17em"):e.mclass==="mopen"||e.mclass==="mclose"?(n.attributes.lspace="0em",n.attributes.rspace="0em"):e.mclass==="minner"&&(n.attributes.lspace="0.0556em",n.attributes.width="+0.1111em")),n}$e({type:"mclass",names:["\\mathord","\\mathbin","\\mathrel","\\mathopen","\\mathclose","\\mathpunct","\\mathinner"],props:{numArgs:1,primitive:!0},handler(e,t){var{parser:n,funcName:r}=e,i=t[0];return{type:"mclass",mode:n.mode,mclass:"m"+r.slice(5),body:Wn(i),isCharacterBox:Vt.isCharacterBox(i)}},htmlBuilder:Mx,mathmlBuilder:Ix});var em=e=>{var t=e.type==="ordgroup"&&e.body.length?e.body[0]:e;return t.type==="atom"&&(t.family==="bin"||t.family==="rel")?"m"+t.family:"mord"};$e({type:"mclass",names:["\\@binrel"],props:{numArgs:2},handler(e,t){var{parser:n}=e;return{type:"mclass",mode:n.mode,mclass:em(t[0]),body:Wn(t[1]),isCharacterBox:Vt.isCharacterBox(t[1])}}});$e({type:"mclass",names:["\\stackrel","\\overset","\\underset"],props:{numArgs:2},handler(e,t){var{parser:n,funcName:r}=e,i=t[1],s=t[0],o;r!=="\\stackrel"?o=em(i):o="mrel";var c={type:"op",mode:i.mode,limits:!0,alwaysHandleSupSub:!0,parentIsSupSub:!1,symbol:!1,suppressBaseShift:r!=="\\stackrel",body:Wn(i)},d={type:"supsub",mode:s.mode,base:c,sup:r==="\\underset"?null:s,sub:r==="\\underset"?s:null};return{type:"mclass",mode:n.mode,mclass:o,body:[d],isCharacterBox:Vt.isCharacterBox(d)}},htmlBuilder:Mx,mathmlBuilder:Ix});$e({type:"pmb",names:["\\pmb"],props:{numArgs:1,allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"pmb",mode:n.mode,mclass:em(t[0]),body:Wn(t[0])}},htmlBuilder(e,t){var n=ur(e.body,t,!0),r=se.makeSpan([e.mclass],n,t);return r.style.textShadow="0.02em 0.01em 0.04px",r},mathmlBuilder(e,t){var n=li(e.body,t),r=new Oe.MathNode("mstyle",n);return r.setAttribute("style","text-shadow: 0.02em 0.01em 0.04px"),r}});var Gq={">":"\\\\cdrightarrow","<":"\\\\cdleftarrow","=":"\\\\cdlongequal",A:"\\uparrow",V:"\\downarrow","|":"\\Vert",".":"no arrow"},g6=()=>({type:"styling",body:[],mode:"math",style:"display"}),b6=e=>e.type==="textord"&&e.text==="@",Yq=(e,t)=>(e.type==="mathord"||e.type==="atom")&&e.text===t;function Vq(e,t,n){var r=Gq[e];switch(r){case"\\\\cdrightarrow":case"\\\\cdleftarrow":return n.callFunction(r,[t[0]],[t[1]]);case"\\uparrow":case"\\downarrow":{var i=n.callFunction("\\\\cdleft",[t[0]],[]),s={type:"atom",text:r,mode:"math",family:"rel"},o=n.callFunction("\\Big",[s],[]),c=n.callFunction("\\\\cdright",[t[1]],[]),d={type:"ordgroup",mode:"math",body:[i,o,c]};return n.callFunction("\\\\cdparent",[d],[])}case"\\\\cdlongequal":return n.callFunction("\\\\cdlongequal",[],[]);case"\\Vert":{var f={type:"textord",text:"\\Vert",mode:"math"};return n.callFunction("\\Big",[f],[])}default:return{type:"textord",text:" ",mode:"math"}}}function Kq(e){var t=[];for(e.gullet.beginGroup(),e.gullet.macros.set("\\cr","\\\\\\relax"),e.gullet.beginGroup();;){t.push(e.parseExpression(!1,"\\\\")),e.gullet.endGroup(),e.gullet.beginGroup();var n=e.fetch().text;if(n==="&"||n==="\\\\")e.consume();else if(n==="\\end"){t[t.length-1].length===0&&t.pop();break}else throw new Ie("Expected \\\\ or \\cr or \\end",e.nextToken)}for(var r=[],i=[r],s=0;s<t.length;s++){for(var o=t[s],c=g6(),d=0;d<o.length;d++)if(!b6(o[d]))c.body.push(o[d]);else{r.push(c),d+=1;var f=j2(o[d]).text,m=new Array(2);if(m[0]={type:"ordgroup",mode:"math",body:[]},m[1]={type:"ordgroup",mode:"math",body:[]},!("=|.".indexOf(f)>-1))if("<>AV".indexOf(f)>-1)for(var p=0;p<2;p++){for(var v=!0,_=d+1;_<o.length;_++){if(Yq(o[_],f)){v=!1,d=_;break}if(b6(o[_]))throw new Ie("Missing a "+f+" character to complete a CD arrow.",o[_]);m[p].body.push(o[_])}if(v)throw new Ie("Missing a "+f+" character to complete a CD arrow.",o[d])}else throw new Ie('Expected one of "<>AV=|." after @',o[d]);var T=Vq(f,m,e),x={type:"styling",body:[T],mode:"math",style:"display"};r.push(x),c=g6()}s%2===0?r.push(c):r.shift(),r=[],i.push(r)}e.gullet.endGroup(),e.gullet.endGroup();var k=new Array(i[0].length).fill({type:"align",align:"c",pregap:.25,postgap:.25});return{type:"array",mode:"math",body:i,arraystretch:1,addJot:!0,rowGaps:[null],cols:k,colSeparationType:"CD",hLinesBeforeRow:new Array(i.length+1).fill([])}}$e({type:"cdlabel",names:["\\\\cdleft","\\\\cdright"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:r}=e;return{type:"cdlabel",mode:n.mode,side:r.slice(4),label:t[0]}},htmlBuilder(e,t){var n=t.havingStyle(t.style.sup()),r=se.wrapFragment($t(e.label,n,t),t);return r.classes.push("cd-label-"+e.side),r.style.bottom=Be(.8-r.depth),r.height=0,r.depth=0,r},mathmlBuilder(e,t){var n=new Oe.MathNode("mrow",[mn(e.label,t)]);return n=new Oe.MathNode("mpadded",[n]),n.setAttribute("width","0"),e.side==="left"&&n.setAttribute("lspace","-1width"),n.setAttribute("voffset","0.7em"),n=new Oe.MathNode("mstyle",[n]),n.setAttribute("displaystyle","false"),n.setAttribute("scriptlevel","1"),n}});$e({type:"cdlabelparent",names:["\\\\cdparent"],props:{numArgs:1},handler(e,t){var{parser:n}=e;return{type:"cdlabelparent",mode:n.mode,fragment:t[0]}},htmlBuilder(e,t){var n=se.wrapFragment($t(e.fragment,t),t);return n.classes.push("cd-vert-arrow"),n},mathmlBuilder(e,t){return new Oe.MathNode("mrow",[mn(e.fragment,t)])}});$e({type:"textord",names:["\\@char"],props:{numArgs:1,allowedInText:!0},handler(e,t){for(var{parser:n}=e,r=wt(t[0],"ordgroup"),i=r.body,s="",o=0;o<i.length;o++){var c=wt(i[o],"textord");s+=c.text}var d=parseInt(s),f;if(isNaN(d))throw new Ie("\\@char has non-numeric argument "+s);if(d<0||d>=1114111)throw new Ie("\\@char with invalid code point "+s);return d<=65535?f=String.fromCharCode(d):(d-=65536,f=String.fromCharCode((d>>10)+55296,(d&1023)+56320)),{type:"textord",mode:n.mode,text:f}}});var Dx=(e,t)=>{var n=ur(e.body,t.withColor(e.color),!1);return se.makeFragment(n)},Lx=(e,t)=>{var n=li(e.body,t.withColor(e.color)),r=new Oe.MathNode("mstyle",n);return r.setAttribute("mathcolor",e.color),r};$e({type:"color",names:["\\textcolor"],props:{numArgs:2,allowedInText:!0,argTypes:["color","original"]},handler(e,t){var{parser:n}=e,r=wt(t[0],"color-token").color,i=t[1];return{type:"color",mode:n.mode,color:r,body:Wn(i)}},htmlBuilder:Dx,mathmlBuilder:Lx});$e({type:"color",names:["\\color"],props:{numArgs:1,allowedInText:!0,argTypes:["color"]},handler(e,t){var{parser:n,breakOnTokenText:r}=e,i=wt(t[0],"color-token").color;n.gullet.macros.set("\\current@color",i);var s=n.parseExpression(!0,r);return{type:"color",mode:n.mode,color:i,body:s}},htmlBuilder:Dx,mathmlBuilder:Lx});$e({type:"cr",names:["\\\\"],props:{numArgs:0,numOptionalArgs:0,allowedInText:!0},handler(e,t,n){var{parser:r}=e,i=r.gullet.future().text==="["?r.parseSizeGroup(!0):null,s=!r.settings.displayMode||!r.settings.useStrictBehavior("newLineInDisplayMode","In LaTeX, \\\\ or \\newline does nothing in display mode");return{type:"cr",mode:r.mode,newLine:s,size:i&&wt(i,"size").value}},htmlBuilder(e,t){var n=se.makeSpan(["mspace"],[],t);return e.newLine&&(n.classes.push("newline"),e.size&&(n.style.marginTop=Be(Bn(e.size,t)))),n},mathmlBuilder(e,t){var n=new Oe.MathNode("mspace");return e.newLine&&(n.setAttribute("linebreak","newline"),e.size&&n.setAttribute("height",Be(Bn(e.size,t)))),n}});var Eb={"\\global":"\\global","\\long":"\\\\globallong","\\\\globallong":"\\\\globallong","\\def":"\\gdef","\\gdef":"\\gdef","\\edef":"\\xdef","\\xdef":"\\xdef","\\let":"\\\\globallet","\\futurelet":"\\\\globalfuture"},Px=e=>{var t=e.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(t))throw new Ie("Expected a control sequence",e);return t},Wq=e=>{var t=e.gullet.popToken();return t.text==="="&&(t=e.gullet.popToken(),t.text===" "&&(t=e.gullet.popToken())),t},Bx=(e,t,n,r)=>{var i=e.gullet.macros.get(n.text);i==null&&(n.noexpand=!0,i={tokens:[n],numArgs:0,unexpandable:!e.gullet.isExpandable(n.text)}),e.gullet.macros.set(t,i,r)};$e({type:"internal",names:["\\global","\\long","\\\\globallong"],props:{numArgs:0,allowedInText:!0},handler(e){var{parser:t,funcName:n}=e;t.consumeSpaces();var r=t.fetch();if(Eb[r.text])return(n==="\\global"||n==="\\\\globallong")&&(r.text=Eb[r.text]),wt(t.parseFunction(),"internal");throw new Ie("Invalid token after macro prefix",r)}});$e({type:"internal",names:["\\def","\\gdef","\\edef","\\xdef"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,r=t.gullet.popToken(),i=r.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(i))throw new Ie("Expected a control sequence",r);for(var s=0,o,c=[[]];t.gullet.future().text!=="{";)if(r=t.gullet.popToken(),r.text==="#"){if(t.gullet.future().text==="{"){o=t.gullet.future(),c[s].push("{");break}if(r=t.gullet.popToken(),!/^[1-9]$/.test(r.text))throw new Ie('Invalid argument number "'+r.text+'"');if(parseInt(r.text)!==s+1)throw new Ie('Argument number "'+r.text+'" out of order');s++,c.push([])}else{if(r.text==="EOF")throw new Ie("Expected a macro definition");c[s].push(r.text)}var{tokens:d}=t.gullet.consumeArg();return o&&d.unshift(o),(n==="\\edef"||n==="\\xdef")&&(d=t.gullet.expandTokens(d),d.reverse()),t.gullet.macros.set(i,{tokens:d,numArgs:s,delimiters:c},n===Eb[n]),{type:"internal",mode:t.mode}}});$e({type:"internal",names:["\\let","\\\\globallet"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,r=Px(t.gullet.popToken());t.gullet.consumeSpaces();var i=Wq(t);return Bx(t,r,i,n==="\\\\globallet"),{type:"internal",mode:t.mode}}});$e({type:"internal",names:["\\futurelet","\\\\globalfuture"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,r=Px(t.gullet.popToken()),i=t.gullet.popToken(),s=t.gullet.popToken();return Bx(t,r,s,n==="\\\\globalfuture"),t.gullet.pushToken(s),t.gullet.pushToken(i),{type:"internal",mode:t.mode}}});var Uc=function(t,n,r){var i=yn.math[t]&&yn.math[t].replace,s=B2(i||t,n,r);if(!s)throw new Error("Unsupported symbol "+t+" and font size "+n+".");return s},$2=function(t,n,r,i){var s=r.havingBaseStyle(n),o=se.makeSpan(i.concat(s.sizingClasses(r)),[t],r),c=s.sizeMultiplier/r.sizeMultiplier;return o.height*=c,o.depth*=c,o.maxFontSize=s.sizeMultiplier,o},Ux=function(t,n,r){var i=n.havingBaseStyle(r),s=(1-n.sizeMultiplier/i.sizeMultiplier)*n.fontMetrics().axisHeight;t.classes.push("delimcenter"),t.style.top=Be(s),t.height-=s,t.depth+=s},Xq=function(t,n,r,i,s,o){var c=se.makeSymbol(t,"Main-Regular",s,i),d=$2(c,n,i,o);return r&&Ux(d,i,n),d},Qq=function(t,n,r,i){return se.makeSymbol(t,"Size"+n+"-Regular",r,i)},zx=function(t,n,r,i,s,o){var c=Qq(t,n,s,i),d=$2(se.makeSpan(["delimsizing","size"+n],[c],i),lt.TEXT,i,o);return r&&Ux(d,i,lt.TEXT),d},og=function(t,n,r){var i;n==="Size1-Regular"?i="delim-size1":i="delim-size4";var s=se.makeSpan(["delimsizinginner",i],[se.makeSpan([],[se.makeSymbol(t,n,r)])]);return{type:"elem",elem:s}},ug=function(t,n,r){var i=da["Size4-Regular"][t.charCodeAt(0)]?da["Size4-Regular"][t.charCodeAt(0)][4]:da["Size1-Regular"][t.charCodeAt(0)][4],s=new sl("inner",nq(t,Math.round(1e3*n))),o=new as([s],{width:Be(i),height:Be(n),style:"width:"+Be(i),viewBox:"0 0 "+1e3*i+" "+Math.round(1e3*n),preserveAspectRatio:"xMinYMin"}),c=se.makeSvgSpan([],[o],r);return c.height=n,c.style.height=Be(n),c.style.width=Be(i),{type:"elem",elem:c}},Tb=.008,Ah={type:"kern",size:-1*Tb},Zq=["|","\\lvert","\\rvert","\\vert"],Jq=["\\|","\\lVert","\\rVert","\\Vert"],Fx=function(t,n,r,i,s,o){var c,d,f,m,p="",v=0;c=f=m=t,d=null;var _="Size1-Regular";t==="\\uparrow"?f=m="⏐":t==="\\Uparrow"?f=m="‖":t==="\\downarrow"?c=f="⏐":t==="\\Downarrow"?c=f="‖":t==="\\updownarrow"?(c="\\uparrow",f="⏐",m="\\downarrow"):t==="\\Updownarrow"?(c="\\Uparrow",f="‖",m="\\Downarrow"):Zq.includes(t)?(f="∣",p="vert",v=333):Jq.includes(t)?(f="∥",p="doublevert",v=556):t==="["||t==="\\lbrack"?(c="⎡",f="⎢",m="⎣",_="Size4-Regular",p="lbrack",v=667):t==="]"||t==="\\rbrack"?(c="⎤",f="⎥",m="⎦",_="Size4-Regular",p="rbrack",v=667):t==="\\lfloor"||t==="⌊"?(f=c="⎢",m="⎣",_="Size4-Regular",p="lfloor",v=667):t==="\\lceil"||t==="⌈"?(c="⎡",f=m="⎢",_="Size4-Regular",p="lceil",v=667):t==="\\rfloor"||t==="⌋"?(f=c="⎥",m="⎦",_="Size4-Regular",p="rfloor",v=667):t==="\\rceil"||t==="⌉"?(c="⎤",f=m="⎥",_="Size4-Regular",p="rceil",v=667):t==="("||t==="\\lparen"?(c="⎛",f="⎜",m="⎝",_="Size4-Regular",p="lparen",v=875):t===")"||t==="\\rparen"?(c="⎞",f="⎟",m="⎠",_="Size4-Regular",p="rparen",v=875):t==="\\{"||t==="\\lbrace"?(c="⎧",d="⎨",m="⎩",f="⎪",_="Size4-Regular"):t==="\\}"||t==="\\rbrace"?(c="⎫",d="⎬",m="⎭",f="⎪",_="Size4-Regular"):t==="\\lgroup"||t==="⟮"?(c="⎧",m="⎩",f="⎪",_="Size4-Regular"):t==="\\rgroup"||t==="⟯"?(c="⎫",m="⎭",f="⎪",_="Size4-Regular"):t==="\\lmoustache"||t==="⎰"?(c="⎧",m="⎭",f="⎪",_="Size4-Regular"):(t==="\\rmoustache"||t==="⎱")&&(c="⎫",m="⎩",f="⎪",_="Size4-Regular");var T=Uc(c,_,s),x=T.height+T.depth,k=Uc(f,_,s),A=k.height+k.depth,O=Uc(m,_,s),I=O.height+O.depth,$=0,V=1;if(d!==null){var B=Uc(d,_,s);$=B.height+B.depth,V=2}var Z=x+I+$,ee=Math.max(0,Math.ceil((n-Z)/(V*A))),te=Z+ee*V*A,Y=i.fontMetrics().axisHeight;r&&(Y*=i.sizeMultiplier);var oe=te/2-Y,he=[];if(p.length>0){var Se=te-x-I,fe=Math.round(te*1e3),de=rq(p,Math.round(Se*1e3)),H=new sl(p,de),ie=(v/1e3).toFixed(3)+"em",ve=(fe/1e3).toFixed(3)+"em",xe=new as([H],{width:ie,height:ve,viewBox:"0 0 "+v+" "+fe}),P=se.makeSvgSpan([],[xe],i);P.height=fe/1e3,P.style.width=ie,P.style.height=ve,he.push({type:"elem",elem:P})}else{if(he.push(og(m,_,s)),he.push(Ah),d===null){var z=te-x-I+2*Tb;he.push(ug(f,z,i))}else{var J=(te-x-I-$)/2+2*Tb;he.push(ug(f,J,i)),he.push(Ah),he.push(og(d,_,s)),he.push(Ah),he.push(ug(f,J,i))}he.push(Ah),he.push(og(c,_,s))}var D=i.havingBaseStyle(lt.TEXT),Ae=se.makeVList({positionType:"bottom",positionData:oe,children:he},D);return $2(se.makeSpan(["delimsizing","mult"],[Ae],D),lt.TEXT,i,o)},cg=80,dg=.08,hg=function(t,n,r,i,s){var o=tq(t,i,r),c=new sl(t,o),d=new as([c],{width:"400em",height:Be(n),viewBox:"0 0 400000 "+r,preserveAspectRatio:"xMinYMin slice"});return se.makeSvgSpan(["hide-tail"],[d],s)},e$=function(t,n){var r=n.havingBaseSizing(),i=$x("\\surd",t*r.sizeMultiplier,qx,r),s=r.sizeMultiplier,o=Math.max(0,n.minRuleThickness-n.fontMetrics().sqrtRuleThickness),c,d=0,f=0,m=0,p;return i.type==="small"?(m=1e3+1e3*o+cg,t<1?s=1:t<1.4&&(s=.7),d=(1+o+dg)/s,f=(1+o)/s,c=hg("sqrtMain",d,m,o,n),c.style.minWidth="0.853em",p=.833/s):i.type==="large"?(m=(1e3+cg)*r0[i.size],f=(r0[i.size]+o)/s,d=(r0[i.size]+o+dg)/s,c=hg("sqrtSize"+i.size,d,m,o,n),c.style.minWidth="1.02em",p=1/s):(d=t+o+dg,f=t+o,m=Math.floor(1e3*t+o)+cg,c=hg("sqrtTall",d,m,o,n),c.style.minWidth="0.742em",p=1.056),c.height=f,c.style.height=Be(d),{span:c,advanceWidth:p,ruleWidth:(n.fontMetrics().sqrtRuleThickness+o)*s}},Hx=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","\\surd"],t$=["\\uparrow","\\downarrow","\\updownarrow","\\Uparrow","\\Downarrow","\\Updownarrow","|","\\|","\\vert","\\Vert","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱"],jx=["<",">","\\langle","\\rangle","/","\\backslash","\\lt","\\gt"],r0=[0,1.2,1.8,2.4,3],n$=function(t,n,r,i,s){if(t==="<"||t==="\\lt"||t==="⟨"?t="\\langle":(t===">"||t==="\\gt"||t==="⟩")&&(t="\\rangle"),Hx.includes(t)||jx.includes(t))return zx(t,n,!1,r,i,s);if(t$.includes(t))return Fx(t,r0[n],!1,r,i,s);throw new Ie("Illegal delimiter: '"+t+"'")},r$=[{type:"small",style:lt.SCRIPTSCRIPT},{type:"small",style:lt.SCRIPT},{type:"small",style:lt.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4}],i$=[{type:"small",style:lt.SCRIPTSCRIPT},{type:"small",style:lt.SCRIPT},{type:"small",style:lt.TEXT},{type:"stack"}],qx=[{type:"small",style:lt.SCRIPTSCRIPT},{type:"small",style:lt.SCRIPT},{type:"small",style:lt.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4},{type:"stack"}],a$=function(t){if(t.type==="small")return"Main-Regular";if(t.type==="large")return"Size"+t.size+"-Regular";if(t.type==="stack")return"Size4-Regular";throw new Error("Add support for delim type '"+t.type+"' here.")},$x=function(t,n,r,i){for(var s=Math.min(2,3-i.style.size),o=s;o<r.length&&r[o].type!=="stack";o++){var c=Uc(t,a$(r[o]),"math"),d=c.height+c.depth;if(r[o].type==="small"){var f=i.havingBaseStyle(r[o].style);d*=f.sizeMultiplier}if(d>n)return r[o]}return r[r.length-1]},Gx=function(t,n,r,i,s,o){t==="<"||t==="\\lt"||t==="⟨"?t="\\langle":(t===">"||t==="\\gt"||t==="⟩")&&(t="\\rangle");var c;jx.includes(t)?c=r$:Hx.includes(t)?c=qx:c=i$;var d=$x(t,n,c,i);return d.type==="small"?Xq(t,d.style,r,i,s,o):d.type==="large"?zx(t,d.size,r,i,s,o):Fx(t,n,r,i,s,o)},s$=function(t,n,r,i,s,o){var c=i.fontMetrics().axisHeight*i.sizeMultiplier,d=901,f=5/i.fontMetrics().ptPerEm,m=Math.max(n-c,r+c),p=Math.max(m/500*d,2*m-f);return Gx(t,p,!0,i,s,o)},ts={sqrtImage:e$,sizedDelim:n$,sizeToMaxHeight:r0,customSizedDelim:Gx,leftRightDelim:s$},v6={"\\bigl":{mclass:"mopen",size:1},"\\Bigl":{mclass:"mopen",size:2},"\\biggl":{mclass:"mopen",size:3},"\\Biggl":{mclass:"mopen",size:4},"\\bigr":{mclass:"mclose",size:1},"\\Bigr":{mclass:"mclose",size:2},"\\biggr":{mclass:"mclose",size:3},"\\Biggr":{mclass:"mclose",size:4},"\\bigm":{mclass:"mrel",size:1},"\\Bigm":{mclass:"mrel",size:2},"\\biggm":{mclass:"mrel",size:3},"\\Biggm":{mclass:"mrel",size:4},"\\big":{mclass:"mord",size:1},"\\Big":{mclass:"mord",size:2},"\\bigg":{mclass:"mord",size:3},"\\Bigg":{mclass:"mord",size:4}},l$=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","<",">","\\langle","⟨","\\rangle","⟩","\\lt","\\gt","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱","/","\\backslash","|","\\vert","\\|","\\Vert","\\uparrow","\\Uparrow","\\downarrow","\\Downarrow","\\updownarrow","\\Updownarrow","."];function tm(e,t){var n=Jf(e);if(n&&l$.includes(n.text))return n;throw n?new Ie("Invalid delimiter '"+n.text+"' after '"+t.funcName+"'",e):new Ie("Invalid delimiter type '"+e.type+"'",e)}$e({type:"delimsizing",names:["\\bigl","\\Bigl","\\biggl","\\Biggl","\\bigr","\\Bigr","\\biggr","\\Biggr","\\bigm","\\Bigm","\\biggm","\\Biggm","\\big","\\Big","\\bigg","\\Bigg"],props:{numArgs:1,argTypes:["primitive"]},handler:(e,t)=>{var n=tm(t[0],e);return{type:"delimsizing",mode:e.parser.mode,size:v6[e.funcName].size,mclass:v6[e.funcName].mclass,delim:n.text}},htmlBuilder:(e,t)=>e.delim==="."?se.makeSpan([e.mclass]):ts.sizedDelim(e.delim,e.size,t,e.mode,[e.mclass]),mathmlBuilder:e=>{var t=[];e.delim!=="."&&t.push(ji(e.delim,e.mode));var n=new Oe.MathNode("mo",t);e.mclass==="mopen"||e.mclass==="mclose"?n.setAttribute("fence","true"):n.setAttribute("fence","false"),n.setAttribute("stretchy","true");var r=Be(ts.sizeToMaxHeight[e.size]);return n.setAttribute("minsize",r),n.setAttribute("maxsize",r),n}});function _6(e){if(!e.body)throw new Error("Bug: The leftright ParseNode wasn't fully parsed.")}$e({type:"leftright-right",names:["\\right"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=e.parser.gullet.macros.get("\\current@color");if(n&&typeof n!="string")throw new Ie("\\current@color set to non-string in \\right");return{type:"leftright-right",mode:e.parser.mode,delim:tm(t[0],e).text,color:n}}});$e({type:"leftright",names:["\\left"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=tm(t[0],e),r=e.parser;++r.leftrightDepth;var i=r.parseExpression(!1);--r.leftrightDepth,r.expect("\\right",!1);var s=wt(r.parseFunction(),"leftright-right");return{type:"leftright",mode:r.mode,body:i,left:n.text,right:s.delim,rightColor:s.color}},htmlBuilder:(e,t)=>{_6(e);for(var n=ur(e.body,t,!0,["mopen","mclose"]),r=0,i=0,s=!1,o=0;o<n.length;o++)n[o].isMiddle?s=!0:(r=Math.max(n[o].height,r),i=Math.max(n[o].depth,i));r*=t.sizeMultiplier,i*=t.sizeMultiplier;var c;if(e.left==="."?c=f0(t,["mopen"]):c=ts.leftRightDelim(e.left,r,i,t,e.mode,["mopen"]),n.unshift(c),s)for(var d=1;d<n.length;d++){var f=n[d],m=f.isMiddle;m&&(n[d]=ts.leftRightDelim(m.delim,r,i,m.options,e.mode,[]))}var p;if(e.right===".")p=f0(t,["mclose"]);else{var v=e.rightColor?t.withColor(e.rightColor):t;p=ts.leftRightDelim(e.right,r,i,v,e.mode,["mclose"])}return n.push(p),se.makeSpan(["minner"],n,t)},mathmlBuilder:(e,t)=>{_6(e);var n=li(e.body,t);if(e.left!=="."){var r=new Oe.MathNode("mo",[ji(e.left,e.mode)]);r.setAttribute("fence","true"),n.unshift(r)}if(e.right!=="."){var i=new Oe.MathNode("mo",[ji(e.right,e.mode)]);i.setAttribute("fence","true"),e.rightColor&&i.setAttribute("mathcolor",e.rightColor),n.push(i)}return F2(n)}});$e({type:"middle",names:["\\middle"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=tm(t[0],e);if(!e.parser.leftrightDepth)throw new Ie("\\middle without preceding \\left",n);return{type:"middle",mode:e.parser.mode,delim:n.text}},htmlBuilder:(e,t)=>{var n;if(e.delim===".")n=f0(t,[]);else{n=ts.sizedDelim(e.delim,1,t,e.mode,[]);var r={delim:e.delim,options:t};n.isMiddle=r}return n},mathmlBuilder:(e,t)=>{var n=e.delim==="\\vert"||e.delim==="|"?ji("|","text"):ji(e.delim,e.mode),r=new Oe.MathNode("mo",[n]);return r.setAttribute("fence","true"),r.setAttribute("lspace","0.05em"),r.setAttribute("rspace","0.05em"),r}});var G2=(e,t)=>{var n=se.wrapFragment($t(e.body,t),t),r=e.label.slice(1),i=t.sizeMultiplier,s,o=0,c=Vt.isCharacterBox(e.body);if(r==="sout")s=se.makeSpan(["stretchy","sout"]),s.height=t.fontMetrics().defaultRuleThickness/i,o=-.5*t.fontMetrics().xHeight;else if(r==="phase"){var d=Bn({number:.6,unit:"pt"},t),f=Bn({number:.35,unit:"ex"},t),m=t.havingBaseSizing();i=i/m.sizeMultiplier;var p=n.height+n.depth+d+f;n.style.paddingLeft=Be(p/2+d);var v=Math.floor(1e3*p*i),_=Jj(v),T=new as([new sl("phase",_)],{width:"400em",height:Be(v/1e3),viewBox:"0 0 400000 "+v,preserveAspectRatio:"xMinYMin slice"});s=se.makeSvgSpan(["hide-tail"],[T],t),s.style.height=Be(p),o=n.depth+d+f}else{/cancel/.test(r)?c||n.classes.push("cancel-pad"):r==="angl"?n.classes.push("anglpad"):n.classes.push("boxpad");var x=0,k=0,A=0;/box/.test(r)?(A=Math.max(t.fontMetrics().fboxrule,t.minRuleThickness),x=t.fontMetrics().fboxsep+(r==="colorbox"?0:A),k=x):r==="angl"?(A=Math.max(t.fontMetrics().defaultRuleThickness,t.minRuleThickness),x=4*A,k=Math.max(0,.25-n.depth)):(x=c?.2:0,k=x),s=ls.encloseSpan(n,r,x,k,t),/fbox|boxed|fcolorbox/.test(r)?(s.style.borderStyle="solid",s.style.borderWidth=Be(A)):r==="angl"&&A!==.049&&(s.style.borderTopWidth=Be(A),s.style.borderRightWidth=Be(A)),o=n.depth+k,e.backgroundColor&&(s.style.backgroundColor=e.backgroundColor,e.borderColor&&(s.style.borderColor=e.borderColor))}var O;if(e.backgroundColor)O=se.makeVList({positionType:"individualShift",children:[{type:"elem",elem:s,shift:o},{type:"elem",elem:n,shift:0}]},t);else{var I=/cancel|phase/.test(r)?["svg-align"]:[];O=se.makeVList({positionType:"individualShift",children:[{type:"elem",elem:n,shift:0},{type:"elem",elem:s,shift:o,wrapperClasses:I}]},t)}return/cancel/.test(r)&&(O.height=n.height,O.depth=n.depth),/cancel/.test(r)&&!c?se.makeSpan(["mord","cancel-lap"],[O],t):se.makeSpan(["mord"],[O],t)},Y2=(e,t)=>{var n=0,r=new Oe.MathNode(e.label.indexOf("colorbox")>-1?"mpadded":"menclose",[mn(e.body,t)]);switch(e.label){case"\\cancel":r.setAttribute("notation","updiagonalstrike");break;case"\\bcancel":r.setAttribute("notation","downdiagonalstrike");break;case"\\phase":r.setAttribute("notation","phasorangle");break;case"\\sout":r.setAttribute("notation","horizontalstrike");break;case"\\fbox":r.setAttribute("notation","box");break;case"\\angl":r.setAttribute("notation","actuarial");break;case"\\fcolorbox":case"\\colorbox":if(n=t.fontMetrics().fboxsep*t.fontMetrics().ptPerEm,r.setAttribute("width","+"+2*n+"pt"),r.setAttribute("height","+"+2*n+"pt"),r.setAttribute("lspace",n+"pt"),r.setAttribute("voffset",n+"pt"),e.label==="\\fcolorbox"){var i=Math.max(t.fontMetrics().fboxrule,t.minRuleThickness);r.setAttribute("style","border: "+i+"em solid "+String(e.borderColor))}break;case"\\xcancel":r.setAttribute("notation","updiagonalstrike downdiagonalstrike");break}return e.backgroundColor&&r.setAttribute("mathbackground",e.backgroundColor),r};$e({type:"enclose",names:["\\colorbox"],props:{numArgs:2,allowedInText:!0,argTypes:["color","text"]},handler(e,t,n){var{parser:r,funcName:i}=e,s=wt(t[0],"color-token").color,o=t[1];return{type:"enclose",mode:r.mode,label:i,backgroundColor:s,body:o}},htmlBuilder:G2,mathmlBuilder:Y2});$e({type:"enclose",names:["\\fcolorbox"],props:{numArgs:3,allowedInText:!0,argTypes:["color","color","text"]},handler(e,t,n){var{parser:r,funcName:i}=e,s=wt(t[0],"color-token").color,o=wt(t[1],"color-token").color,c=t[2];return{type:"enclose",mode:r.mode,label:i,backgroundColor:o,borderColor:s,body:c}},htmlBuilder:G2,mathmlBuilder:Y2});$e({type:"enclose",names:["\\fbox"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"enclose",mode:n.mode,label:"\\fbox",body:t[0]}}});$e({type:"enclose",names:["\\cancel","\\bcancel","\\xcancel","\\sout","\\phase"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:r}=e,i=t[0];return{type:"enclose",mode:n.mode,label:r,body:i}},htmlBuilder:G2,mathmlBuilder:Y2});$e({type:"enclose",names:["\\angl"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!1},handler(e,t){var{parser:n}=e;return{type:"enclose",mode:n.mode,label:"\\angl",body:t[0]}}});var Yx={};function ba(e){for(var{type:t,names:n,props:r,handler:i,htmlBuilder:s,mathmlBuilder:o}=e,c={type:t,numArgs:r.numArgs||0,allowedInText:!1,numOptionalArgs:0,handler:i},d=0;d<n.length;++d)Yx[n[d]]=c;s&&(cf[t]=s),o&&(df[t]=o)}var Vx={};function M(e,t){Vx[e]=t}function y6(e){var t=[];e.consumeSpaces();var n=e.fetch().text;for(n==="\\relax"&&(e.consume(),e.consumeSpaces(),n=e.fetch().text);n==="\\hline"||n==="\\hdashline";)e.consume(),t.push(n==="\\hdashline"),e.consumeSpaces(),n=e.fetch().text;return t}var nm=e=>{var t=e.parser.settings;if(!t.displayMode)throw new Ie("{"+e.envName+"} can be used only in display mode.")};function V2(e){if(e.indexOf("ed")===-1)return e.indexOf("*")===-1}function cl(e,t,n){var{hskipBeforeAndAfter:r,addJot:i,cols:s,arraystretch:o,colSeparationType:c,autoTag:d,singleRow:f,emptySingleRow:m,maxNumCols:p,leqno:v}=t;if(e.gullet.beginGroup(),f||e.gullet.macros.set("\\cr","\\\\\\relax"),!o){var _=e.gullet.expandMacroAsText("\\arraystretch");if(_==null)o=1;else if(o=parseFloat(_),!o||o<0)throw new Ie("Invalid \\arraystretch: "+_)}e.gullet.beginGroup();var T=[],x=[T],k=[],A=[],O=d!=null?[]:void 0;function I(){d&&e.gullet.macros.set("\\@eqnsw","1",!0)}function $(){O&&(e.gullet.macros.get("\\df@tag")?(O.push(e.subparse([new Ti("\\df@tag")])),e.gullet.macros.set("\\df@tag",void 0,!0)):O.push(!!d&&e.gullet.macros.get("\\@eqnsw")==="1"))}for(I(),A.push(y6(e));;){var V=e.parseExpression(!1,f?"\\end":"\\\\");e.gullet.endGroup(),e.gullet.beginGroup(),V={type:"ordgroup",mode:e.mode,body:V},n&&(V={type:"styling",mode:e.mode,style:n,body:[V]}),T.push(V);var B=e.fetch().text;if(B==="&"){if(p&&T.length===p){if(f||c)throw new Ie("Too many tab characters: &",e.nextToken);e.settings.reportNonstrict("textEnv","Too few columns specified in the {array} column argument.")}e.consume()}else if(B==="\\end"){$(),T.length===1&&V.type==="styling"&&V.body[0].body.length===0&&(x.length>1||!m)&&x.pop(),A.length<x.length+1&&A.push([]);break}else if(B==="\\\\"){e.consume();var Z=void 0;e.gullet.future().text!==" "&&(Z=e.parseSizeGroup(!0)),k.push(Z?Z.value:null),$(),A.push(y6(e)),T=[],x.push(T),I()}else throw new Ie("Expected & or \\\\ or \\cr or \\end",e.nextToken)}return e.gullet.endGroup(),e.gullet.endGroup(),{type:"array",mode:e.mode,addJot:i,arraystretch:o,body:x,cols:s,rowGaps:k,hskipBeforeAndAfter:r,hLinesBeforeRow:A,colSeparationType:c,tags:O,leqno:v}}function K2(e){return e.slice(0,1)==="d"?"display":"text"}var va=function(t,n){var r,i,s=t.body.length,o=t.hLinesBeforeRow,c=0,d=new Array(s),f=[],m=Math.max(n.fontMetrics().arrayRuleWidth,n.minRuleThickness),p=1/n.fontMetrics().ptPerEm,v=5*p;if(t.colSeparationType&&t.colSeparationType==="small"){var _=n.havingStyle(lt.SCRIPT).sizeMultiplier;v=.2778*(_/n.sizeMultiplier)}var T=t.colSeparationType==="CD"?Bn({number:3,unit:"ex"},n):12*p,x=3*p,k=t.arraystretch*T,A=.7*k,O=.3*k,I=0;function $(pn){for(var Pt=0;Pt<pn.length;++Pt)Pt>0&&(I+=.25),f.push({pos:I,isDashed:pn[Pt]})}for($(o[0]),r=0;r<t.body.length;++r){var V=t.body[r],B=A,Z=O;c<V.length&&(c=V.length);var ee=new Array(V.length);for(i=0;i<V.length;++i){var te=$t(V[i],n);Z<te.depth&&(Z=te.depth),B<te.height&&(B=te.height),ee[i]=te}var Y=t.rowGaps[r],oe=0;Y&&(oe=Bn(Y,n),oe>0&&(oe+=O,Z<oe&&(Z=oe),oe=0)),t.addJot&&(Z+=x),ee.height=B,ee.depth=Z,I+=B,ee.pos=I,I+=Z+oe,d[r]=ee,$(o[r+1])}var he=I/2+n.fontMetrics().axisHeight,Se=t.cols||[],fe=[],de,H,ie=[];if(t.tags&&t.tags.some(pn=>pn))for(r=0;r<s;++r){var ve=d[r],xe=ve.pos-he,P=t.tags[r],z=void 0;P===!0?z=se.makeSpan(["eqn-num"],[],n):P===!1?z=se.makeSpan([],[],n):z=se.makeSpan([],ur(P,n,!0),n),z.depth=ve.depth,z.height=ve.height,ie.push({type:"elem",elem:z,shift:xe})}for(i=0,H=0;i<c||H<Se.length;++i,++H){for(var J=Se[H]||{},D=!0;J.type==="separator";){if(D||(de=se.makeSpan(["arraycolsep"],[]),de.style.width=Be(n.fontMetrics().doubleRuleSep),fe.push(de)),J.separator==="|"||J.separator===":"){var Ae=J.separator==="|"?"solid":"dashed",Le=se.makeSpan(["vertical-separator"],[],n);Le.style.height=Be(I),Le.style.borderRightWidth=Be(m),Le.style.borderRightStyle=Ae,Le.style.margin="0 "+Be(-m/2);var ze=I-he;ze&&(Le.style.verticalAlign=Be(-ze)),fe.push(Le)}else throw new Ie("Invalid separator type: "+J.separator);H++,J=Se[H]||{},D=!1}if(!(i>=c)){var at=void 0;(i>0||t.hskipBeforeAndAfter)&&(at=Vt.deflt(J.pregap,v),at!==0&&(de=se.makeSpan(["arraycolsep"],[]),de.style.width=Be(at),fe.push(de)));var _t=[];for(r=0;r<s;++r){var pt=d[r],Tt=pt[i];if(Tt){var kn=pt.pos-he;Tt.depth=pt.depth,Tt.height=pt.height,_t.push({type:"elem",elem:Tt,shift:kn})}}_t=se.makeVList({positionType:"individualShift",children:_t},n),_t=se.makeSpan(["col-align-"+(J.align||"c")],[_t]),fe.push(_t),(i<c-1||t.hskipBeforeAndAfter)&&(at=Vt.deflt(J.postgap,v),at!==0&&(de=se.makeSpan(["arraycolsep"],[]),de.style.width=Be(at),fe.push(de)))}}if(d=se.makeSpan(["mtable"],fe),f.length>0){for(var pr=se.makeLineSpan("hline",n,m),yt=se.makeLineSpan("hdashline",n,m),ct=[{type:"elem",elem:d,shift:0}];f.length>0;){var Ft=f.pop(),Xe=Ft.pos-he;Ft.isDashed?ct.push({type:"elem",elem:yt,shift:Xe}):ct.push({type:"elem",elem:pr,shift:Xe})}d=se.makeVList({positionType:"individualShift",children:ct},n)}if(ie.length===0)return se.makeSpan(["mord"],[d],n);var jt=se.makeVList({positionType:"individualShift",children:ie},n);return jt=se.makeSpan(["tag"],[jt],n),se.makeFragment([d,jt])},o$={c:"center ",l:"left ",r:"right "},_a=function(t,n){for(var r=[],i=new Oe.MathNode("mtd",[],["mtr-glue"]),s=new Oe.MathNode("mtd",[],["mml-eqn-num"]),o=0;o<t.body.length;o++){for(var c=t.body[o],d=[],f=0;f<c.length;f++)d.push(new Oe.MathNode("mtd",[mn(c[f],n)]));t.tags&&t.tags[o]&&(d.unshift(i),d.push(i),t.leqno?d.unshift(s):d.push(s)),r.push(new Oe.MathNode("mtr",d))}var m=new Oe.MathNode("mtable",r),p=t.arraystretch===.5?.1:.16+t.arraystretch-1+(t.addJot?.09:0);m.setAttribute("rowspacing",Be(p));var v="",_="";if(t.cols&&t.cols.length>0){var T=t.cols,x="",k=!1,A=0,O=T.length;T[0].type==="separator"&&(v+="top ",A=1),T[T.length-1].type==="separator"&&(v+="bottom ",O-=1);for(var I=A;I<O;I++)T[I].type==="align"?(_+=o$[T[I].align],k&&(x+="none "),k=!0):T[I].type==="separator"&&k&&(x+=T[I].separator==="|"?"solid ":"dashed ",k=!1);m.setAttribute("columnalign",_.trim()),/[sd]/.test(x)&&m.setAttribute("columnlines",x.trim())}if(t.colSeparationType==="align"){for(var $=t.cols||[],V="",B=1;B<$.length;B++)V+=B%2?"0em ":"1em ";m.setAttribute("columnspacing",V.trim())}else t.colSeparationType==="alignat"||t.colSeparationType==="gather"?m.setAttribute("columnspacing","0em"):t.colSeparationType==="small"?m.setAttribute("columnspacing","0.2778em"):t.colSeparationType==="CD"?m.setAttribute("columnspacing","0.5em"):m.setAttribute("columnspacing","1em");var Z="",ee=t.hLinesBeforeRow;v+=ee[0].length>0?"left ":"",v+=ee[ee.length-1].length>0?"right ":"";for(var te=1;te<ee.length-1;te++)Z+=ee[te].length===0?"none ":ee[te][0]?"dashed ":"solid ";return/[sd]/.test(Z)&&m.setAttribute("rowlines",Z.trim()),v!==""&&(m=new Oe.MathNode("menclose",[m]),m.setAttribute("notation",v.trim())),t.arraystretch&&t.arraystretch<1&&(m=new Oe.MathNode("mstyle",[m]),m.setAttribute("scriptlevel","1")),m},Kx=function(t,n){t.envName.indexOf("ed")===-1&&nm(t);var r=[],i=t.envName.indexOf("at")>-1?"alignat":"align",s=t.envName==="split",o=cl(t.parser,{cols:r,addJot:!0,autoTag:s?void 0:V2(t.envName),emptySingleRow:!0,colSeparationType:i,maxNumCols:s?2:void 0,leqno:t.parser.settings.leqno},"display"),c,d=0,f={type:"ordgroup",mode:t.mode,body:[]};if(n[0]&&n[0].type==="ordgroup"){for(var m="",p=0;p<n[0].body.length;p++){var v=wt(n[0].body[p],"textord");m+=v.text}c=Number(m),d=c*2}var _=!d;o.body.forEach(function(A){for(var O=1;O<A.length;O+=2){var I=wt(A[O],"styling"),$=wt(I.body[0],"ordgroup");$.body.unshift(f)}if(_)d<A.length&&(d=A.length);else{var V=A.length/2;if(c<V)throw new Ie("Too many math in a row: "+("expected "+c+", but got "+V),A[0])}});for(var T=0;T<d;++T){var x="r",k=0;T%2===1?x="l":T>0&&_&&(k=1),r[T]={type:"align",align:x,pregap:k,postgap:0}}return o.colSeparationType=_?"align":"alignat",o};ba({type:"array",names:["array","darray"],props:{numArgs:1},handler(e,t){var n=Jf(t[0]),r=n?[t[0]]:wt(t[0],"ordgroup").body,i=r.map(function(o){var c=j2(o),d=c.text;if("lcr".indexOf(d)!==-1)return{type:"align",align:d};if(d==="|")return{type:"separator",separator:"|"};if(d===":")return{type:"separator",separator:":"};throw new Ie("Unknown column alignment: "+d,o)}),s={cols:i,hskipBeforeAndAfter:!0,maxNumCols:i.length};return cl(e.parser,s,K2(e.envName))},htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["matrix","pmatrix","bmatrix","Bmatrix","vmatrix","Vmatrix","matrix*","pmatrix*","bmatrix*","Bmatrix*","vmatrix*","Vmatrix*"],props:{numArgs:0},handler(e){var t={matrix:null,pmatrix:["(",")"],bmatrix:["[","]"],Bmatrix:["\\{","\\}"],vmatrix:["|","|"],Vmatrix:["\\Vert","\\Vert"]}[e.envName.replace("*","")],n="c",r={hskipBeforeAndAfter:!1,cols:[{type:"align",align:n}]};if(e.envName.charAt(e.envName.length-1)==="*"){var i=e.parser;if(i.consumeSpaces(),i.fetch().text==="["){if(i.consume(),i.consumeSpaces(),n=i.fetch().text,"lcr".indexOf(n)===-1)throw new Ie("Expected l or c or r",i.nextToken);i.consume(),i.consumeSpaces(),i.expect("]"),i.consume(),r.cols=[{type:"align",align:n}]}}var s=cl(e.parser,r,K2(e.envName)),o=Math.max(0,...s.body.map(c=>c.length));return s.cols=new Array(o).fill({type:"align",align:n}),t?{type:"leftright",mode:e.mode,body:[s],left:t[0],right:t[1],rightColor:void 0}:s},htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["smallmatrix"],props:{numArgs:0},handler(e){var t={arraystretch:.5},n=cl(e.parser,t,"script");return n.colSeparationType="small",n},htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["subarray"],props:{numArgs:1},handler(e,t){var n=Jf(t[0]),r=n?[t[0]]:wt(t[0],"ordgroup").body,i=r.map(function(o){var c=j2(o),d=c.text;if("lc".indexOf(d)!==-1)return{type:"align",align:d};throw new Ie("Unknown column alignment: "+d,o)});if(i.length>1)throw new Ie("{subarray} can contain only one column");var s={cols:i,hskipBeforeAndAfter:!1,arraystretch:.5};if(s=cl(e.parser,s,"script"),s.body.length>0&&s.body[0].length>1)throw new Ie("{subarray} can contain only one column");return s},htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["cases","dcases","rcases","drcases"],props:{numArgs:0},handler(e){var t={arraystretch:1.2,cols:[{type:"align",align:"l",pregap:0,postgap:1},{type:"align",align:"l",pregap:0,postgap:0}]},n=cl(e.parser,t,K2(e.envName));return{type:"leftright",mode:e.mode,body:[n],left:e.envName.indexOf("r")>-1?".":"\\{",right:e.envName.indexOf("r")>-1?"\\}":".",rightColor:void 0}},htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["align","align*","aligned","split"],props:{numArgs:0},handler:Kx,htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["gathered","gather","gather*"],props:{numArgs:0},handler(e){["gather","gather*"].includes(e.envName)&&nm(e);var t={cols:[{type:"align",align:"c"}],addJot:!0,colSeparationType:"gather",autoTag:V2(e.envName),emptySingleRow:!0,leqno:e.parser.settings.leqno};return cl(e.parser,t,"display")},htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["alignat","alignat*","alignedat"],props:{numArgs:1},handler:Kx,htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["equation","equation*"],props:{numArgs:0},handler(e){nm(e);var t={autoTag:V2(e.envName),emptySingleRow:!0,singleRow:!0,maxNumCols:1,leqno:e.parser.settings.leqno};return cl(e.parser,t,"display")},htmlBuilder:va,mathmlBuilder:_a});ba({type:"array",names:["CD"],props:{numArgs:0},handler(e){return nm(e),Kq(e.parser)},htmlBuilder:va,mathmlBuilder:_a});M("\\nonumber","\\gdef\\@eqnsw{0}");M("\\notag","\\nonumber");$e({type:"text",names:["\\hline","\\hdashline"],props:{numArgs:0,allowedInText:!0,allowedInMath:!0},handler(e,t){throw new Ie(e.funcName+" valid only within array environment")}});var E6=Yx;$e({type:"environment",names:["\\begin","\\end"],props:{numArgs:1,argTypes:["text"]},handler(e,t){var{parser:n,funcName:r}=e,i=t[0];if(i.type!=="ordgroup")throw new Ie("Invalid environment name",i);for(var s="",o=0;o<i.body.length;++o)s+=wt(i.body[o],"textord").text;if(r==="\\begin"){if(!E6.hasOwnProperty(s))throw new Ie("No such environment: "+s,i);var c=E6[s],{args:d,optArgs:f}=n.parseArguments("\\begin{"+s+"}",c),m={mode:n.mode,envName:s,parser:n},p=c.handler(m,d,f);n.expect("\\end",!1);var v=n.nextToken,_=wt(n.parseFunction(),"environment");if(_.name!==s)throw new Ie("Mismatch: \\begin{"+s+"} matched by \\end{"+_.name+"}",v);return p}return{type:"environment",mode:n.mode,name:s,nameGroup:i}}});var Wx=(e,t)=>{var n=e.font,r=t.withFont(n);return $t(e.body,r)},Xx=(e,t)=>{var n=e.font,r=t.withFont(n);return mn(e.body,r)},T6={"\\Bbb":"\\mathbb","\\bold":"\\mathbf","\\frak":"\\mathfrak","\\bm":"\\boldsymbol"};$e({type:"font",names:["\\mathrm","\\mathit","\\mathbf","\\mathnormal","\\mathsfit","\\mathbb","\\mathcal","\\mathfrak","\\mathscr","\\mathsf","\\mathtt","\\Bbb","\\bold","\\frak"],props:{numArgs:1,allowedInArgument:!0},handler:(e,t)=>{var{parser:n,funcName:r}=e,i=hf(t[0]),s=r;return s in T6&&(s=T6[s]),{type:"font",mode:n.mode,font:s.slice(1),body:i}},htmlBuilder:Wx,mathmlBuilder:Xx});$e({type:"mclass",names:["\\boldsymbol","\\bm"],props:{numArgs:1},handler:(e,t)=>{var{parser:n}=e,r=t[0],i=Vt.isCharacterBox(r);return{type:"mclass",mode:n.mode,mclass:em(r),body:[{type:"font",mode:n.mode,font:"boldsymbol",body:r}],isCharacterBox:i}}});$e({type:"font",names:["\\rm","\\sf","\\tt","\\bf","\\it","\\cal"],props:{numArgs:0,allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:r,breakOnTokenText:i}=e,{mode:s}=n,o=n.parseExpression(!0,i),c="math"+r.slice(1);return{type:"font",mode:s,font:c,body:{type:"ordgroup",mode:n.mode,body:o}}},htmlBuilder:Wx,mathmlBuilder:Xx});var Qx=(e,t)=>{var n=t;return e==="display"?n=n.id>=lt.SCRIPT.id?n.text():lt.DISPLAY:e==="text"&&n.size===lt.DISPLAY.size?n=lt.TEXT:e==="script"?n=lt.SCRIPT:e==="scriptscript"&&(n=lt.SCRIPTSCRIPT),n},W2=(e,t)=>{var n=Qx(e.size,t.style),r=n.fracNum(),i=n.fracDen(),s;s=t.havingStyle(r);var o=$t(e.numer,s,t);if(e.continued){var c=8.5/t.fontMetrics().ptPerEm,d=3.5/t.fontMetrics().ptPerEm;o.height=o.height<c?c:o.height,o.depth=o.depth<d?d:o.depth}s=t.havingStyle(i);var f=$t(e.denom,s,t),m,p,v;e.hasBarLine?(e.barSize?(p=Bn(e.barSize,t),m=se.makeLineSpan("frac-line",t,p)):m=se.makeLineSpan("frac-line",t),p=m.height,v=m.height):(m=null,p=0,v=t.fontMetrics().defaultRuleThickness);var _,T,x;n.size===lt.DISPLAY.size||e.size==="display"?(_=t.fontMetrics().num1,p>0?T=3*v:T=7*v,x=t.fontMetrics().denom1):(p>0?(_=t.fontMetrics().num2,T=v):(_=t.fontMetrics().num3,T=3*v),x=t.fontMetrics().denom2);var k;if(m){var O=t.fontMetrics().axisHeight;_-o.depth-(O+.5*p)<T&&(_+=T-(_-o.depth-(O+.5*p))),O-.5*p-(f.height-x)<T&&(x+=T-(O-.5*p-(f.height-x)));var I=-(O-.5*p);k=se.makeVList({positionType:"individualShift",children:[{type:"elem",elem:f,shift:x},{type:"elem",elem:m,shift:I},{type:"elem",elem:o,shift:-_}]},t)}else{var A=_-o.depth-(f.height-x);A<T&&(_+=.5*(T-A),x+=.5*(T-A)),k=se.makeVList({positionType:"individualShift",children:[{type:"elem",elem:f,shift:x},{type:"elem",elem:o,shift:-_}]},t)}s=t.havingStyle(n),k.height*=s.sizeMultiplier/t.sizeMultiplier,k.depth*=s.sizeMultiplier/t.sizeMultiplier;var $;n.size===lt.DISPLAY.size?$=t.fontMetrics().delim1:n.size===lt.SCRIPTSCRIPT.size?$=t.havingStyle(lt.SCRIPT).fontMetrics().delim2:$=t.fontMetrics().delim2;var V,B;return e.leftDelim==null?V=f0(t,["mopen"]):V=ts.customSizedDelim(e.leftDelim,$,!0,t.havingStyle(n),e.mode,["mopen"]),e.continued?B=se.makeSpan([]):e.rightDelim==null?B=f0(t,["mclose"]):B=ts.customSizedDelim(e.rightDelim,$,!0,t.havingStyle(n),e.mode,["mclose"]),se.makeSpan(["mord"].concat(s.sizingClasses(t)),[V,se.makeSpan(["mfrac"],[k]),B],t)},X2=(e,t)=>{var n=new Oe.MathNode("mfrac",[mn(e.numer,t),mn(e.denom,t)]);if(!e.hasBarLine)n.setAttribute("linethickness","0px");else if(e.barSize){var r=Bn(e.barSize,t);n.setAttribute("linethickness",Be(r))}var i=Qx(e.size,t.style);if(i.size!==t.style.size){n=new Oe.MathNode("mstyle",[n]);var s=i.size===lt.DISPLAY.size?"true":"false";n.setAttribute("displaystyle",s),n.setAttribute("scriptlevel","0")}if(e.leftDelim!=null||e.rightDelim!=null){var o=[];if(e.leftDelim!=null){var c=new Oe.MathNode("mo",[new Oe.TextNode(e.leftDelim.replace("\\",""))]);c.setAttribute("fence","true"),o.push(c)}if(o.push(n),e.rightDelim!=null){var d=new Oe.MathNode("mo",[new Oe.TextNode(e.rightDelim.replace("\\",""))]);d.setAttribute("fence","true"),o.push(d)}return F2(o)}return n};$e({type:"genfrac",names:["\\dfrac","\\frac","\\tfrac","\\dbinom","\\binom","\\tbinom","\\\\atopfrac","\\\\bracefrac","\\\\brackfrac"],props:{numArgs:2,allowedInArgument:!0},handler:(e,t)=>{var{parser:n,funcName:r}=e,i=t[0],s=t[1],o,c=null,d=null,f="auto";switch(r){case"\\dfrac":case"\\frac":case"\\tfrac":o=!0;break;case"\\\\atopfrac":o=!1;break;case"\\dbinom":case"\\binom":case"\\tbinom":o=!1,c="(",d=")";break;case"\\\\bracefrac":o=!1,c="\\{",d="\\}";break;case"\\\\brackfrac":o=!1,c="[",d="]";break;default:throw new Error("Unrecognized genfrac command")}switch(r){case"\\dfrac":case"\\dbinom":f="display";break;case"\\tfrac":case"\\tbinom":f="text";break}return{type:"genfrac",mode:n.mode,continued:!1,numer:i,denom:s,hasBarLine:o,leftDelim:c,rightDelim:d,size:f,barSize:null}},htmlBuilder:W2,mathmlBuilder:X2});$e({type:"genfrac",names:["\\cfrac"],props:{numArgs:2},handler:(e,t)=>{var{parser:n,funcName:r}=e,i=t[0],s=t[1];return{type:"genfrac",mode:n.mode,continued:!0,numer:i,denom:s,hasBarLine:!0,leftDelim:null,rightDelim:null,size:"display",barSize:null}}});$e({type:"infix",names:["\\over","\\choose","\\atop","\\brace","\\brack"],props:{numArgs:0,infix:!0},handler(e){var{parser:t,funcName:n,token:r}=e,i;switch(n){case"\\over":i="\\frac";break;case"\\choose":i="\\binom";break;case"\\atop":i="\\\\atopfrac";break;case"\\brace":i="\\\\bracefrac";break;case"\\brack":i="\\\\brackfrac";break;default:throw new Error("Unrecognized infix genfrac command")}return{type:"infix",mode:t.mode,replaceWith:i,token:r}}});var x6=["display","text","script","scriptscript"],S6=function(t){var n=null;return t.length>0&&(n=t,n=n==="."?null:n),n};$e({type:"genfrac",names:["\\genfrac"],props:{numArgs:6,allowedInArgument:!0,argTypes:["math","math","size","text","math","math"]},handler(e,t){var{parser:n}=e,r=t[4],i=t[5],s=hf(t[0]),o=s.type==="atom"&&s.family==="open"?S6(s.text):null,c=hf(t[1]),d=c.type==="atom"&&c.family==="close"?S6(c.text):null,f=wt(t[2],"size"),m,p=null;f.isBlank?m=!0:(p=f.value,m=p.number>0);var v="auto",_=t[3];if(_.type==="ordgroup"){if(_.body.length>0){var T=wt(_.body[0],"textord");v=x6[Number(T.text)]}}else _=wt(_,"textord"),v=x6[Number(_.text)];return{type:"genfrac",mode:n.mode,numer:r,denom:i,continued:!1,hasBarLine:m,barSize:p,leftDelim:o,rightDelim:d,size:v}},htmlBuilder:W2,mathmlBuilder:X2});$e({type:"infix",names:["\\above"],props:{numArgs:1,argTypes:["size"],infix:!0},handler(e,t){var{parser:n,funcName:r,token:i}=e;return{type:"infix",mode:n.mode,replaceWith:"\\\\abovefrac",size:wt(t[0],"size").value,token:i}}});$e({type:"genfrac",names:["\\\\abovefrac"],props:{numArgs:3,argTypes:["math","size","math"]},handler:(e,t)=>{var{parser:n,funcName:r}=e,i=t[0],s=Uj(wt(t[1],"infix").size),o=t[2],c=s.number>0;return{type:"genfrac",mode:n.mode,numer:i,denom:o,continued:!1,hasBarLine:c,barSize:s,leftDelim:null,rightDelim:null,size:"auto"}},htmlBuilder:W2,mathmlBuilder:X2});var Zx=(e,t)=>{var n=t.style,r,i;e.type==="supsub"?(r=e.sup?$t(e.sup,t.havingStyle(n.sup()),t):$t(e.sub,t.havingStyle(n.sub()),t),i=wt(e.base,"horizBrace")):i=wt(e,"horizBrace");var s=$t(i.base,t.havingBaseStyle(lt.DISPLAY)),o=ls.svgSpan(i,t),c;if(i.isOver?(c=se.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:s},{type:"kern",size:.1},{type:"elem",elem:o}]},t),c.children[0].children[0].children[1].classes.push("svg-align")):(c=se.makeVList({positionType:"bottom",positionData:s.depth+.1+o.height,children:[{type:"elem",elem:o},{type:"kern",size:.1},{type:"elem",elem:s}]},t),c.children[0].children[0].children[0].classes.push("svg-align")),r){var d=se.makeSpan(["mord",i.isOver?"mover":"munder"],[c],t);i.isOver?c=se.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:d},{type:"kern",size:.2},{type:"elem",elem:r}]},t):c=se.makeVList({positionType:"bottom",positionData:d.depth+.2+r.height+r.depth,children:[{type:"elem",elem:r},{type:"kern",size:.2},{type:"elem",elem:d}]},t)}return se.makeSpan(["mord",i.isOver?"mover":"munder"],[c],t)},u$=(e,t)=>{var n=ls.mathMLnode(e.label);return new Oe.MathNode(e.isOver?"mover":"munder",[mn(e.base,t),n])};$e({type:"horizBrace",names:["\\overbrace","\\underbrace"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:r}=e;return{type:"horizBrace",mode:n.mode,label:r,isOver:/^\\over/.test(r),base:t[0]}},htmlBuilder:Zx,mathmlBuilder:u$});$e({type:"href",names:["\\href"],props:{numArgs:2,argTypes:["url","original"],allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=t[1],i=wt(t[0],"url").url;return n.settings.isTrusted({command:"\\href",url:i})?{type:"href",mode:n.mode,href:i,body:Wn(r)}:n.formatUnsupportedCmd("\\href")},htmlBuilder:(e,t)=>{var n=ur(e.body,t,!1);return se.makeAnchor(e.href,[],n,t)},mathmlBuilder:(e,t)=>{var n=ll(e.body,t);return n instanceof _i||(n=new _i("mrow",[n])),n.setAttribute("href",e.href),n}});$e({type:"href",names:["\\url"],props:{numArgs:1,argTypes:["url"],allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=wt(t[0],"url").url;if(!n.settings.isTrusted({command:"\\url",url:r}))return n.formatUnsupportedCmd("\\url");for(var i=[],s=0;s<r.length;s++){var o=r[s];o==="~"&&(o="\\textasciitilde"),i.push({type:"textord",mode:"text",text:o})}var c={type:"text",mode:n.mode,font:"\\texttt",body:i};return{type:"href",mode:n.mode,href:r,body:Wn(c)}}});$e({type:"hbox",names:["\\hbox"],props:{numArgs:1,argTypes:["text"],allowedInText:!0,primitive:!0},handler(e,t){var{parser:n}=e;return{type:"hbox",mode:n.mode,body:Wn(t[0])}},htmlBuilder(e,t){var n=ur(e.body,t,!1);return se.makeFragment(n)},mathmlBuilder(e,t){return new Oe.MathNode("mrow",li(e.body,t))}});$e({type:"html",names:["\\htmlClass","\\htmlId","\\htmlStyle","\\htmlData"],props:{numArgs:2,argTypes:["raw","original"],allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:r,token:i}=e,s=wt(t[0],"raw").string,o=t[1];n.settings.strict&&n.settings.reportNonstrict("htmlExtension","HTML extension is disabled on strict mode");var c,d={};switch(r){case"\\htmlClass":d.class=s,c={command:"\\htmlClass",class:s};break;case"\\htmlId":d.id=s,c={command:"\\htmlId",id:s};break;case"\\htmlStyle":d.style=s,c={command:"\\htmlStyle",style:s};break;case"\\htmlData":{for(var f=s.split(","),m=0;m<f.length;m++){var p=f[m],v=p.indexOf("=");if(v<0)throw new Ie("\\htmlData key/value '"+p+"' missing equals sign");var _=p.slice(0,v),T=p.slice(v+1);d["data-"+_.trim()]=T}c={command:"\\htmlData",attributes:d};break}default:throw new Error("Unrecognized html command")}return n.settings.isTrusted(c)?{type:"html",mode:n.mode,attributes:d,body:Wn(o)}:n.formatUnsupportedCmd(r)},htmlBuilder:(e,t)=>{var n=ur(e.body,t,!1),r=["enclosing"];e.attributes.class&&r.push(...e.attributes.class.trim().split(/\s+/));var i=se.makeSpan(r,n,t);for(var s in e.attributes)s!=="class"&&e.attributes.hasOwnProperty(s)&&i.setAttribute(s,e.attributes[s]);return i},mathmlBuilder:(e,t)=>ll(e.body,t)});$e({type:"htmlmathml",names:["\\html@mathml"],props:{numArgs:2,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e;return{type:"htmlmathml",mode:n.mode,html:Wn(t[0]),mathml:Wn(t[1])}},htmlBuilder:(e,t)=>{var n=ur(e.html,t,!1);return se.makeFragment(n)},mathmlBuilder:(e,t)=>ll(e.mathml,t)});var fg=function(t){if(/^[-+]? *(\d+(\.\d*)?|\.\d+)$/.test(t))return{number:+t,unit:"bp"};var n=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(t);if(!n)throw new Ie("Invalid size: '"+t+"' in \\includegraphics");var r={number:+(n[1]+n[2]),unit:n[3]};if(!bx(r))throw new Ie("Invalid unit: '"+r.unit+"' in \\includegraphics.");return r};$e({type:"includegraphics",names:["\\includegraphics"],props:{numArgs:1,numOptionalArgs:1,argTypes:["raw","url"],allowedInText:!1},handler:(e,t,n)=>{var{parser:r}=e,i={number:0,unit:"em"},s={number:.9,unit:"em"},o={number:0,unit:"em"},c="";if(n[0])for(var d=wt(n[0],"raw").string,f=d.split(","),m=0;m<f.length;m++){var p=f[m].split("=");if(p.length===2){var v=p[1].trim();switch(p[0].trim()){case"alt":c=v;break;case"width":i=fg(v);break;case"height":s=fg(v);break;case"totalheight":o=fg(v);break;default:throw new Ie("Invalid key: '"+p[0]+"' in \\includegraphics.")}}}var _=wt(t[0],"url").url;return c===""&&(c=_,c=c.replace(/^.*[\\/]/,""),c=c.substring(0,c.lastIndexOf("."))),r.settings.isTrusted({command:"\\includegraphics",url:_})?{type:"includegraphics",mode:r.mode,alt:c,width:i,height:s,totalheight:o,src:_}:r.formatUnsupportedCmd("\\includegraphics")},htmlBuilder:(e,t)=>{var n=Bn(e.height,t),r=0;e.totalheight.number>0&&(r=Bn(e.totalheight,t)-n);var i=0;e.width.number>0&&(i=Bn(e.width,t));var s={height:Be(n+r)};i>0&&(s.width=Be(i)),r>0&&(s.verticalAlign=Be(-r));var o=new uq(e.src,e.alt,s);return o.height=n,o.depth=r,o},mathmlBuilder:(e,t)=>{var n=new Oe.MathNode("mglyph",[]);n.setAttribute("alt",e.alt);var r=Bn(e.height,t),i=0;if(e.totalheight.number>0&&(i=Bn(e.totalheight,t)-r,n.setAttribute("valign",Be(-i))),n.setAttribute("height",Be(r+i)),e.width.number>0){var s=Bn(e.width,t);n.setAttribute("width",Be(s))}return n.setAttribute("src",e.src),n}});$e({type:"kern",names:["\\kern","\\mkern","\\hskip","\\mskip"],props:{numArgs:1,argTypes:["size"],primitive:!0,allowedInText:!0},handler(e,t){var{parser:n,funcName:r}=e,i=wt(t[0],"size");if(n.settings.strict){var s=r[1]==="m",o=i.value.unit==="mu";s?(o||n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+r+" supports only mu units, "+("not "+i.value.unit+" units")),n.mode!=="math"&&n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+r+" works only in math mode")):o&&n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+r+" doesn't support mu units")}return{type:"kern",mode:n.mode,dimension:i.value}},htmlBuilder(e,t){return se.makeGlue(e.dimension,t)},mathmlBuilder(e,t){var n=Bn(e.dimension,t);return new Oe.SpaceNode(n)}});$e({type:"lap",names:["\\mathllap","\\mathrlap","\\mathclap"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:r}=e,i=t[0];return{type:"lap",mode:n.mode,alignment:r.slice(5),body:i}},htmlBuilder:(e,t)=>{var n;e.alignment==="clap"?(n=se.makeSpan([],[$t(e.body,t)]),n=se.makeSpan(["inner"],[n],t)):n=se.makeSpan(["inner"],[$t(e.body,t)]);var r=se.makeSpan(["fix"],[]),i=se.makeSpan([e.alignment],[n,r],t),s=se.makeSpan(["strut"]);return s.style.height=Be(i.height+i.depth),i.depth&&(s.style.verticalAlign=Be(-i.depth)),i.children.unshift(s),i=se.makeSpan(["thinbox"],[i],t),se.makeSpan(["mord","vbox"],[i],t)},mathmlBuilder:(e,t)=>{var n=new Oe.MathNode("mpadded",[mn(e.body,t)]);if(e.alignment!=="rlap"){var r=e.alignment==="llap"?"-1":"-0.5";n.setAttribute("lspace",r+"width")}return n.setAttribute("width","0px"),n}});$e({type:"styling",names:["\\(","$"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(e,t){var{funcName:n,parser:r}=e,i=r.mode;r.switchMode("math");var s=n==="\\("?"\\)":"$",o=r.parseExpression(!1,s);return r.expect(s),r.switchMode(i),{type:"styling",mode:r.mode,style:"text",body:o}}});$e({type:"text",names:["\\)","\\]"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(e,t){throw new Ie("Mismatched "+e.funcName)}});var w6=(e,t)=>{switch(t.style.size){case lt.DISPLAY.size:return e.display;case lt.TEXT.size:return e.text;case lt.SCRIPT.size:return e.script;case lt.SCRIPTSCRIPT.size:return e.scriptscript;default:return e.text}};$e({type:"mathchoice",names:["\\mathchoice"],props:{numArgs:4,primitive:!0},handler:(e,t)=>{var{parser:n}=e;return{type:"mathchoice",mode:n.mode,display:Wn(t[0]),text:Wn(t[1]),script:Wn(t[2]),scriptscript:Wn(t[3])}},htmlBuilder:(e,t)=>{var n=w6(e,t),r=ur(n,t,!1);return se.makeFragment(r)},mathmlBuilder:(e,t)=>{var n=w6(e,t);return ll(n,t)}});var Jx=(e,t,n,r,i,s,o)=>{e=se.makeSpan([],[e]);var c=n&&Vt.isCharacterBox(n),d,f;if(t){var m=$t(t,r.havingStyle(i.sup()),r);f={elem:m,kern:Math.max(r.fontMetrics().bigOpSpacing1,r.fontMetrics().bigOpSpacing3-m.depth)}}if(n){var p=$t(n,r.havingStyle(i.sub()),r);d={elem:p,kern:Math.max(r.fontMetrics().bigOpSpacing2,r.fontMetrics().bigOpSpacing4-p.height)}}var v;if(f&&d){var _=r.fontMetrics().bigOpSpacing5+d.elem.height+d.elem.depth+d.kern+e.depth+o;v=se.makeVList({positionType:"bottom",positionData:_,children:[{type:"kern",size:r.fontMetrics().bigOpSpacing5},{type:"elem",elem:d.elem,marginLeft:Be(-s)},{type:"kern",size:d.kern},{type:"elem",elem:e},{type:"kern",size:f.kern},{type:"elem",elem:f.elem,marginLeft:Be(s)},{type:"kern",size:r.fontMetrics().bigOpSpacing5}]},r)}else if(d){var T=e.height-o;v=se.makeVList({positionType:"top",positionData:T,children:[{type:"kern",size:r.fontMetrics().bigOpSpacing5},{type:"elem",elem:d.elem,marginLeft:Be(-s)},{type:"kern",size:d.kern},{type:"elem",elem:e}]},r)}else if(f){var x=e.depth+o;v=se.makeVList({positionType:"bottom",positionData:x,children:[{type:"elem",elem:e},{type:"kern",size:f.kern},{type:"elem",elem:f.elem,marginLeft:Be(s)},{type:"kern",size:r.fontMetrics().bigOpSpacing5}]},r)}else return e;var k=[v];if(d&&s!==0&&!c){var A=se.makeSpan(["mspace"],[],r);A.style.marginRight=Be(s),k.unshift(A)}return se.makeSpan(["mop","op-limits"],k,r)},eS=["\\smallint"],Eu=(e,t)=>{var n,r,i=!1,s;e.type==="supsub"?(n=e.sup,r=e.sub,s=wt(e.base,"op"),i=!0):s=wt(e,"op");var o=t.style,c=!1;o.size===lt.DISPLAY.size&&s.symbol&&!eS.includes(s.name)&&(c=!0);var d;if(s.symbol){var f=c?"Size2-Regular":"Size1-Regular",m="";if((s.name==="\\oiint"||s.name==="\\oiiint")&&(m=s.name.slice(1),s.name=m==="oiint"?"\\iint":"\\iiint"),d=se.makeSymbol(s.name,f,"math",t,["mop","op-symbol",c?"large-op":"small-op"]),m.length>0){var p=d.italic,v=se.staticSvg(m+"Size"+(c?"2":"1"),t);d=se.makeVList({positionType:"individualShift",children:[{type:"elem",elem:d,shift:0},{type:"elem",elem:v,shift:c?.08:0}]},t),s.name="\\"+m,d.classes.unshift("mop"),d.italic=p}}else if(s.body){var _=ur(s.body,t,!0);_.length===1&&_[0]instanceof Hi?(d=_[0],d.classes[0]="mop"):d=se.makeSpan(["mop"],_,t)}else{for(var T=[],x=1;x<s.name.length;x++)T.push(se.mathsym(s.name[x],s.mode,t));d=se.makeSpan(["mop"],T,t)}var k=0,A=0;return(d instanceof Hi||s.name==="\\oiint"||s.name==="\\oiiint")&&!s.suppressBaseShift&&(k=(d.height-d.depth)/2-t.fontMetrics().axisHeight,A=d.italic),i?Jx(d,n,r,t,o,A,k):(k&&(d.style.position="relative",d.style.top=Be(k)),d)},P0=(e,t)=>{var n;if(e.symbol)n=new _i("mo",[ji(e.name,e.mode)]),eS.includes(e.name)&&n.setAttribute("largeop","false");else if(e.body)n=new _i("mo",li(e.body,t));else{n=new _i("mi",[new ha(e.name.slice(1))]);var r=new _i("mo",[ji("⁡","text")]);e.parentIsSupSub?n=new _i("mrow",[n,r]):n=Cx([n,r])}return n},c$={"∏":"\\prod","∐":"\\coprod","∑":"\\sum","⋀":"\\bigwedge","⋁":"\\bigvee","⋂":"\\bigcap","⋃":"\\bigcup","⨀":"\\bigodot","⨁":"\\bigoplus","⨂":"\\bigotimes","⨄":"\\biguplus","⨆":"\\bigsqcup"};$e({type:"op",names:["\\coprod","\\bigvee","\\bigwedge","\\biguplus","\\bigcap","\\bigcup","\\intop","\\prod","\\sum","\\bigotimes","\\bigoplus","\\bigodot","\\bigsqcup","\\smallint","∏","∐","∑","⋀","⋁","⋂","⋃","⨀","⨁","⨂","⨄","⨆"],props:{numArgs:0},handler:(e,t)=>{var{parser:n,funcName:r}=e,i=r;return i.length===1&&(i=c$[i]),{type:"op",mode:n.mode,limits:!0,parentIsSupSub:!1,symbol:!0,name:i}},htmlBuilder:Eu,mathmlBuilder:P0});$e({type:"op",names:["\\mathop"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var{parser:n}=e,r=t[0];return{type:"op",mode:n.mode,limits:!1,parentIsSupSub:!1,symbol:!1,body:Wn(r)}},htmlBuilder:Eu,mathmlBuilder:P0});var d$={"∫":"\\int","∬":"\\iint","∭":"\\iiint","∮":"\\oint","∯":"\\oiint","∰":"\\oiiint"};$e({type:"op",names:["\\arcsin","\\arccos","\\arctan","\\arctg","\\arcctg","\\arg","\\ch","\\cos","\\cosec","\\cosh","\\cot","\\cotg","\\coth","\\csc","\\ctg","\\cth","\\deg","\\dim","\\exp","\\hom","\\ker","\\lg","\\ln","\\log","\\sec","\\sin","\\sinh","\\sh","\\tan","\\tanh","\\tg","\\th"],props:{numArgs:0},handler(e){var{parser:t,funcName:n}=e;return{type:"op",mode:t.mode,limits:!1,parentIsSupSub:!1,symbol:!1,name:n}},htmlBuilder:Eu,mathmlBuilder:P0});$e({type:"op",names:["\\det","\\gcd","\\inf","\\lim","\\max","\\min","\\Pr","\\sup"],props:{numArgs:0},handler(e){var{parser:t,funcName:n}=e;return{type:"op",mode:t.mode,limits:!0,parentIsSupSub:!1,symbol:!1,name:n}},htmlBuilder:Eu,mathmlBuilder:P0});$e({type:"op",names:["\\int","\\iint","\\iiint","\\oint","\\oiint","\\oiiint","∫","∬","∭","∮","∯","∰"],props:{numArgs:0,allowedInArgument:!0},handler(e){var{parser:t,funcName:n}=e,r=n;return r.length===1&&(r=d$[r]),{type:"op",mode:t.mode,limits:!1,parentIsSupSub:!1,symbol:!0,name:r}},htmlBuilder:Eu,mathmlBuilder:P0});var tS=(e,t)=>{var n,r,i=!1,s;e.type==="supsub"?(n=e.sup,r=e.sub,s=wt(e.base,"operatorname"),i=!0):s=wt(e,"operatorname");var o;if(s.body.length>0){for(var c=s.body.map(p=>{var v=p.text;return typeof v=="string"?{type:"textord",mode:p.mode,text:v}:p}),d=ur(c,t.withFont("mathrm"),!0),f=0;f<d.length;f++){var m=d[f];m instanceof Hi&&(m.text=m.text.replace(/\u2212/,"-").replace(/\u2217/,"*"))}o=se.makeSpan(["mop"],d,t)}else o=se.makeSpan(["mop"],[],t);return i?Jx(o,n,r,t,t.style,0,0):o},h$=(e,t)=>{for(var n=li(e.body,t.withFont("mathrm")),r=!0,i=0;i<n.length;i++){var s=n[i];if(!(s instanceof Oe.SpaceNode))if(s instanceof Oe.MathNode)switch(s.type){case"mi":case"mn":case"ms":case"mspace":case"mtext":break;case"mo":{var o=s.children[0];s.children.length===1&&o instanceof Oe.TextNode?o.text=o.text.replace(/\u2212/,"-").replace(/\u2217/,"*"):r=!1;break}default:r=!1}else r=!1}if(r){var c=n.map(m=>m.toText()).join("");n=[new Oe.TextNode(c)]}var d=new Oe.MathNode("mi",n);d.setAttribute("mathvariant","normal");var f=new Oe.MathNode("mo",[ji("⁡","text")]);return e.parentIsSupSub?new Oe.MathNode("mrow",[d,f]):Oe.newDocumentFragment([d,f])};$e({type:"operatorname",names:["\\operatorname@","\\operatornamewithlimits"],props:{numArgs:1},handler:(e,t)=>{var{parser:n,funcName:r}=e,i=t[0];return{type:"operatorname",mode:n.mode,body:Wn(i),alwaysHandleSupSub:r==="\\operatornamewithlimits",limits:!1,parentIsSupSub:!1}},htmlBuilder:tS,mathmlBuilder:h$});M("\\operatorname","\\@ifstar\\operatornamewithlimits\\operatorname@");Jl({type:"ordgroup",htmlBuilder(e,t){return e.semisimple?se.makeFragment(ur(e.body,t,!1)):se.makeSpan(["mord"],ur(e.body,t,!0),t)},mathmlBuilder(e,t){return ll(e.body,t,!0)}});$e({type:"overline",names:["\\overline"],props:{numArgs:1},handler(e,t){var{parser:n}=e,r=t[0];return{type:"overline",mode:n.mode,body:r}},htmlBuilder(e,t){var n=$t(e.body,t.havingCrampedStyle()),r=se.makeLineSpan("overline-line",t),i=t.fontMetrics().defaultRuleThickness,s=se.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n},{type:"kern",size:3*i},{type:"elem",elem:r},{type:"kern",size:i}]},t);return se.makeSpan(["mord","overline"],[s],t)},mathmlBuilder(e,t){var n=new Oe.MathNode("mo",[new Oe.TextNode("‾")]);n.setAttribute("stretchy","true");var r=new Oe.MathNode("mover",[mn(e.body,t),n]);return r.setAttribute("accent","true"),r}});$e({type:"phantom",names:["\\phantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=t[0];return{type:"phantom",mode:n.mode,body:Wn(r)}},htmlBuilder:(e,t)=>{var n=ur(e.body,t.withPhantom(),!1);return se.makeFragment(n)},mathmlBuilder:(e,t)=>{var n=li(e.body,t);return new Oe.MathNode("mphantom",n)}});$e({type:"hphantom",names:["\\hphantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=t[0];return{type:"hphantom",mode:n.mode,body:r}},htmlBuilder:(e,t)=>{var n=se.makeSpan([],[$t(e.body,t.withPhantom())]);if(n.height=0,n.depth=0,n.children)for(var r=0;r<n.children.length;r++)n.children[r].height=0,n.children[r].depth=0;return n=se.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n}]},t),se.makeSpan(["mord"],[n],t)},mathmlBuilder:(e,t)=>{var n=li(Wn(e.body),t),r=new Oe.MathNode("mphantom",n),i=new Oe.MathNode("mpadded",[r]);return i.setAttribute("height","0px"),i.setAttribute("depth","0px"),i}});$e({type:"vphantom",names:["\\vphantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=t[0];return{type:"vphantom",mode:n.mode,body:r}},htmlBuilder:(e,t)=>{var n=se.makeSpan(["inner"],[$t(e.body,t.withPhantom())]),r=se.makeSpan(["fix"],[]);return se.makeSpan(["mord","rlap"],[n,r],t)},mathmlBuilder:(e,t)=>{var n=li(Wn(e.body),t),r=new Oe.MathNode("mphantom",n),i=new Oe.MathNode("mpadded",[r]);return i.setAttribute("width","0px"),i}});$e({type:"raisebox",names:["\\raisebox"],props:{numArgs:2,argTypes:["size","hbox"],allowedInText:!0},handler(e,t){var{parser:n}=e,r=wt(t[0],"size").value,i=t[1];return{type:"raisebox",mode:n.mode,dy:r,body:i}},htmlBuilder(e,t){var n=$t(e.body,t),r=Bn(e.dy,t);return se.makeVList({positionType:"shift",positionData:-r,children:[{type:"elem",elem:n}]},t)},mathmlBuilder(e,t){var n=new Oe.MathNode("mpadded",[mn(e.body,t)]),r=e.dy.number+e.dy.unit;return n.setAttribute("voffset",r),n}});$e({type:"internal",names:["\\relax"],props:{numArgs:0,allowedInText:!0,allowedInArgument:!0},handler(e){var{parser:t}=e;return{type:"internal",mode:t.mode}}});$e({type:"rule",names:["\\rule"],props:{numArgs:2,numOptionalArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["size","size","size"]},handler(e,t,n){var{parser:r}=e,i=n[0],s=wt(t[0],"size"),o=wt(t[1],"size");return{type:"rule",mode:r.mode,shift:i&&wt(i,"size").value,width:s.value,height:o.value}},htmlBuilder(e,t){var n=se.makeSpan(["mord","rule"],[],t),r=Bn(e.width,t),i=Bn(e.height,t),s=e.shift?Bn(e.shift,t):0;return n.style.borderRightWidth=Be(r),n.style.borderTopWidth=Be(i),n.style.bottom=Be(s),n.width=r,n.height=i+s,n.depth=-s,n.maxFontSize=i*1.125*t.sizeMultiplier,n},mathmlBuilder(e,t){var n=Bn(e.width,t),r=Bn(e.height,t),i=e.shift?Bn(e.shift,t):0,s=t.color&&t.getColor()||"black",o=new Oe.MathNode("mspace");o.setAttribute("mathbackground",s),o.setAttribute("width",Be(n)),o.setAttribute("height",Be(r));var c=new Oe.MathNode("mpadded",[o]);return i>=0?c.setAttribute("height",Be(i)):(c.setAttribute("height",Be(i)),c.setAttribute("depth",Be(-i))),c.setAttribute("voffset",Be(i)),c}});function nS(e,t,n){for(var r=ur(e,t,!1),i=t.sizeMultiplier/n.sizeMultiplier,s=0;s<r.length;s++){var o=r[s].classes.indexOf("sizing");o<0?Array.prototype.push.apply(r[s].classes,t.sizingClasses(n)):r[s].classes[o+1]==="reset-size"+t.size&&(r[s].classes[o+1]="reset-size"+n.size),r[s].height*=i,r[s].depth*=i}return se.makeFragment(r)}var A6=["\\tiny","\\sixptsize","\\scriptsize","\\footnotesize","\\small","\\normalsize","\\large","\\Large","\\LARGE","\\huge","\\Huge"],f$=(e,t)=>{var n=t.havingSize(e.size);return nS(e.body,n,t)};$e({type:"sizing",names:A6,props:{numArgs:0,allowedInText:!0},handler:(e,t)=>{var{breakOnTokenText:n,funcName:r,parser:i}=e,s=i.parseExpression(!1,n);return{type:"sizing",mode:i.mode,size:A6.indexOf(r)+1,body:s}},htmlBuilder:f$,mathmlBuilder:(e,t)=>{var n=t.havingSize(e.size),r=li(e.body,n),i=new Oe.MathNode("mstyle",r);return i.setAttribute("mathsize",Be(n.sizeMultiplier)),i}});$e({type:"smash",names:["\\smash"],props:{numArgs:1,numOptionalArgs:1,allowedInText:!0},handler:(e,t,n)=>{var{parser:r}=e,i=!1,s=!1,o=n[0]&&wt(n[0],"ordgroup");if(o)for(var c="",d=0;d<o.body.length;++d){var f=o.body[d];if(c=f.text,c==="t")i=!0;else if(c==="b")s=!0;else{i=!1,s=!1;break}}else i=!0,s=!0;var m=t[0];return{type:"smash",mode:r.mode,body:m,smashHeight:i,smashDepth:s}},htmlBuilder:(e,t)=>{var n=se.makeSpan([],[$t(e.body,t)]);if(!e.smashHeight&&!e.smashDepth)return n;if(e.smashHeight&&(n.height=0,n.children))for(var r=0;r<n.children.length;r++)n.children[r].height=0;if(e.smashDepth&&(n.depth=0,n.children))for(var i=0;i<n.children.length;i++)n.children[i].depth=0;var s=se.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n}]},t);return se.makeSpan(["mord"],[s],t)},mathmlBuilder:(e,t)=>{var n=new Oe.MathNode("mpadded",[mn(e.body,t)]);return e.smashHeight&&n.setAttribute("height","0px"),e.smashDepth&&n.setAttribute("depth","0px"),n}});$e({type:"sqrt",names:["\\sqrt"],props:{numArgs:1,numOptionalArgs:1},handler(e,t,n){var{parser:r}=e,i=n[0],s=t[0];return{type:"sqrt",mode:r.mode,body:s,index:i}},htmlBuilder(e,t){var n=$t(e.body,t.havingCrampedStyle());n.height===0&&(n.height=t.fontMetrics().xHeight),n=se.wrapFragment(n,t);var r=t.fontMetrics(),i=r.defaultRuleThickness,s=i;t.style.id<lt.TEXT.id&&(s=t.fontMetrics().xHeight);var o=i+s/4,c=n.height+n.depth+o+i,{span:d,ruleWidth:f,advanceWidth:m}=ts.sqrtImage(c,t),p=d.height-f;p>n.height+n.depth+o&&(o=(o+p-n.height-n.depth)/2);var v=d.height-n.height-o-f;n.style.paddingLeft=Be(m);var _=se.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n,wrapperClasses:["svg-align"]},{type:"kern",size:-(n.height+v)},{type:"elem",elem:d},{type:"kern",size:f}]},t);if(e.index){var T=t.havingStyle(lt.SCRIPTSCRIPT),x=$t(e.index,T,t),k=.6*(_.height-_.depth),A=se.makeVList({positionType:"shift",positionData:-k,children:[{type:"elem",elem:x}]},t),O=se.makeSpan(["root"],[A]);return se.makeSpan(["mord","sqrt"],[O,_],t)}else return se.makeSpan(["mord","sqrt"],[_],t)},mathmlBuilder(e,t){var{body:n,index:r}=e;return r?new Oe.MathNode("mroot",[mn(n,t),mn(r,t)]):new Oe.MathNode("msqrt",[mn(n,t)])}});var k6={display:lt.DISPLAY,text:lt.TEXT,script:lt.SCRIPT,scriptscript:lt.SCRIPTSCRIPT};$e({type:"styling",names:["\\displaystyle","\\textstyle","\\scriptstyle","\\scriptscriptstyle"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e,t){var{breakOnTokenText:n,funcName:r,parser:i}=e,s=i.parseExpression(!0,n),o=r.slice(1,r.length-5);return{type:"styling",mode:i.mode,style:o,body:s}},htmlBuilder(e,t){var n=k6[e.style],r=t.havingStyle(n).withFont("");return nS(e.body,r,t)},mathmlBuilder(e,t){var n=k6[e.style],r=t.havingStyle(n),i=li(e.body,r),s=new Oe.MathNode("mstyle",i),o={display:["0","true"],text:["0","false"],script:["1","false"],scriptscript:["2","false"]},c=o[e.style];return s.setAttribute("scriptlevel",c[0]),s.setAttribute("displaystyle",c[1]),s}});var m$=function(t,n){var r=t.base;if(r)if(r.type==="op"){var i=r.limits&&(n.style.size===lt.DISPLAY.size||r.alwaysHandleSupSub);return i?Eu:null}else if(r.type==="operatorname"){var s=r.alwaysHandleSupSub&&(n.style.size===lt.DISPLAY.size||r.limits);return s?tS:null}else{if(r.type==="accent")return Vt.isCharacterBox(r.base)?q2:null;if(r.type==="horizBrace"){var o=!t.sub;return o===r.isOver?Zx:null}else return null}else return null};Jl({type:"supsub",htmlBuilder(e,t){var n=m$(e,t);if(n)return n(e,t);var{base:r,sup:i,sub:s}=e,o=$t(r,t),c,d,f=t.fontMetrics(),m=0,p=0,v=r&&Vt.isCharacterBox(r);if(i){var _=t.havingStyle(t.style.sup());c=$t(i,_,t),v||(m=o.height-_.fontMetrics().supDrop*_.sizeMultiplier/t.sizeMultiplier)}if(s){var T=t.havingStyle(t.style.sub());d=$t(s,T,t),v||(p=o.depth+T.fontMetrics().subDrop*T.sizeMultiplier/t.sizeMultiplier)}var x;t.style===lt.DISPLAY?x=f.sup1:t.style.cramped?x=f.sup3:x=f.sup2;var k=t.sizeMultiplier,A=Be(.5/f.ptPerEm/k),O=null;if(d){var I=e.base&&e.base.type==="op"&&e.base.name&&(e.base.name==="\\oiint"||e.base.name==="\\oiiint");(o instanceof Hi||I)&&(O=Be(-o.italic))}var $;if(c&&d){m=Math.max(m,x,c.depth+.25*f.xHeight),p=Math.max(p,f.sub2);var V=f.defaultRuleThickness,B=4*V;if(m-c.depth-(d.height-p)<B){p=B-(m-c.depth)+d.height;var Z=.8*f.xHeight-(m-c.depth);Z>0&&(m+=Z,p-=Z)}var ee=[{type:"elem",elem:d,shift:p,marginRight:A,marginLeft:O},{type:"elem",elem:c,shift:-m,marginRight:A}];$=se.makeVList({positionType:"individualShift",children:ee},t)}else if(d){p=Math.max(p,f.sub1,d.height-.8*f.xHeight);var te=[{type:"elem",elem:d,marginLeft:O,marginRight:A}];$=se.makeVList({positionType:"shift",positionData:p,children:te},t)}else if(c)m=Math.max(m,x,c.depth+.25*f.xHeight),$=se.makeVList({positionType:"shift",positionData:-m,children:[{type:"elem",elem:c,marginRight:A}]},t);else throw new Error("supsub must have either sup or sub.");var Y=_b(o,"right")||"mord";return se.makeSpan([Y],[o,se.makeSpan(["msupsub"],[$])],t)},mathmlBuilder(e,t){var n=!1,r,i;e.base&&e.base.type==="horizBrace"&&(i=!!e.sup,i===e.base.isOver&&(n=!0,r=e.base.isOver)),e.base&&(e.base.type==="op"||e.base.type==="operatorname")&&(e.base.parentIsSupSub=!0);var s=[mn(e.base,t)];e.sub&&s.push(mn(e.sub,t)),e.sup&&s.push(mn(e.sup,t));var o;if(n)o=r?"mover":"munder";else if(e.sub)if(e.sup){var f=e.base;f&&f.type==="op"&&f.limits&&t.style===lt.DISPLAY||f&&f.type==="operatorname"&&f.alwaysHandleSupSub&&(t.style===lt.DISPLAY||f.limits)?o="munderover":o="msubsup"}else{var d=e.base;d&&d.type==="op"&&d.limits&&(t.style===lt.DISPLAY||d.alwaysHandleSupSub)||d&&d.type==="operatorname"&&d.alwaysHandleSupSub&&(d.limits||t.style===lt.DISPLAY)?o="munder":o="msub"}else{var c=e.base;c&&c.type==="op"&&c.limits&&(t.style===lt.DISPLAY||c.alwaysHandleSupSub)||c&&c.type==="operatorname"&&c.alwaysHandleSupSub&&(c.limits||t.style===lt.DISPLAY)?o="mover":o="msup"}return new Oe.MathNode(o,s)}});Jl({type:"atom",htmlBuilder(e,t){return se.mathsym(e.text,e.mode,t,["m"+e.family])},mathmlBuilder(e,t){var n=new Oe.MathNode("mo",[ji(e.text,e.mode)]);if(e.family==="bin"){var r=H2(e,t);r==="bold-italic"&&n.setAttribute("mathvariant",r)}else e.family==="punct"?n.setAttribute("separator","true"):(e.family==="open"||e.family==="close")&&n.setAttribute("stretchy","false");return n}});var rS={mi:"italic",mn:"normal",mtext:"normal"};Jl({type:"mathord",htmlBuilder(e,t){return se.makeOrd(e,t,"mathord")},mathmlBuilder(e,t){var n=new Oe.MathNode("mi",[ji(e.text,e.mode,t)]),r=H2(e,t)||"italic";return r!==rS[n.type]&&n.setAttribute("mathvariant",r),n}});Jl({type:"textord",htmlBuilder(e,t){return se.makeOrd(e,t,"textord")},mathmlBuilder(e,t){var n=ji(e.text,e.mode,t),r=H2(e,t)||"normal",i;return e.mode==="text"?i=new Oe.MathNode("mtext",[n]):/[0-9]/.test(e.text)?i=new Oe.MathNode("mn",[n]):e.text==="\\prime"?i=new Oe.MathNode("mo",[n]):i=new Oe.MathNode("mi",[n]),r!==rS[i.type]&&i.setAttribute("mathvariant",r),i}});var mg={"\\nobreak":"nobreak","\\allowbreak":"allowbreak"},pg={" ":{},"\\ ":{},"~":{className:"nobreak"},"\\space":{},"\\nobreakspace":{className:"nobreak"}};Jl({type:"spacing",htmlBuilder(e,t){if(pg.hasOwnProperty(e.text)){var n=pg[e.text].className||"";if(e.mode==="text"){var r=se.makeOrd(e,t,"textord");return r.classes.push(n),r}else return se.makeSpan(["mspace",n],[se.mathsym(e.text,e.mode,t)],t)}else{if(mg.hasOwnProperty(e.text))return se.makeSpan(["mspace",mg[e.text]],[],t);throw new Ie('Unknown type of space "'+e.text+'"')}},mathmlBuilder(e,t){var n;if(pg.hasOwnProperty(e.text))n=new Oe.MathNode("mtext",[new Oe.TextNode(" ")]);else{if(mg.hasOwnProperty(e.text))return new Oe.MathNode("mspace");throw new Ie('Unknown type of space "'+e.text+'"')}return n}});var C6=()=>{var e=new Oe.MathNode("mtd",[]);return e.setAttribute("width","50%"),e};Jl({type:"tag",mathmlBuilder(e,t){var n=new Oe.MathNode("mtable",[new Oe.MathNode("mtr",[C6(),new Oe.MathNode("mtd",[ll(e.body,t)]),C6(),new Oe.MathNode("mtd",[ll(e.tag,t)])])]);return n.setAttribute("width","100%"),n}});var N6={"\\text":void 0,"\\textrm":"textrm","\\textsf":"textsf","\\texttt":"texttt","\\textnormal":"textrm"},O6={"\\textbf":"textbf","\\textmd":"textmd"},p$={"\\textit":"textit","\\textup":"textup"},R6=(e,t)=>{var n=e.font;if(n){if(N6[n])return t.withTextFontFamily(N6[n]);if(O6[n])return t.withTextFontWeight(O6[n]);if(n==="\\emph")return t.fontShape==="textit"?t.withTextFontShape("textup"):t.withTextFontShape("textit")}else return t;return t.withTextFontShape(p$[n])};$e({type:"text",names:["\\text","\\textrm","\\textsf","\\texttt","\\textnormal","\\textbf","\\textmd","\\textit","\\textup","\\emph"],props:{numArgs:1,argTypes:["text"],allowedInArgument:!0,allowedInText:!0},handler(e,t){var{parser:n,funcName:r}=e,i=t[0];return{type:"text",mode:n.mode,body:Wn(i),font:r}},htmlBuilder(e,t){var n=R6(e,t),r=ur(e.body,n,!0);return se.makeSpan(["mord","text"],r,n)},mathmlBuilder(e,t){var n=R6(e,t);return ll(e.body,n)}});$e({type:"underline",names:["\\underline"],props:{numArgs:1,allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"underline",mode:n.mode,body:t[0]}},htmlBuilder(e,t){var n=$t(e.body,t),r=se.makeLineSpan("underline-line",t),i=t.fontMetrics().defaultRuleThickness,s=se.makeVList({positionType:"top",positionData:n.height,children:[{type:"kern",size:i},{type:"elem",elem:r},{type:"kern",size:3*i},{type:"elem",elem:n}]},t);return se.makeSpan(["mord","underline"],[s],t)},mathmlBuilder(e,t){var n=new Oe.MathNode("mo",[new Oe.TextNode("‾")]);n.setAttribute("stretchy","true");var r=new Oe.MathNode("munder",[mn(e.body,t),n]);return r.setAttribute("accentunder","true"),r}});$e({type:"vcenter",names:["\\vcenter"],props:{numArgs:1,argTypes:["original"],allowedInText:!1},handler(e,t){var{parser:n}=e;return{type:"vcenter",mode:n.mode,body:t[0]}},htmlBuilder(e,t){var n=$t(e.body,t),r=t.fontMetrics().axisHeight,i=.5*(n.height-r-(n.depth+r));return se.makeVList({positionType:"shift",positionData:i,children:[{type:"elem",elem:n}]},t)},mathmlBuilder(e,t){return new Oe.MathNode("mpadded",[mn(e.body,t)],["vcenter"])}});$e({type:"verb",names:["\\verb"],props:{numArgs:0,allowedInText:!0},handler(e,t,n){throw new Ie("\\verb ended by end of line instead of matching delimiter")},htmlBuilder(e,t){for(var n=M6(e),r=[],i=t.havingStyle(t.style.text()),s=0;s<n.length;s++){var o=n[s];o==="~"&&(o="\\textasciitilde"),r.push(se.makeSymbol(o,"Typewriter-Regular",e.mode,i,["mord","texttt"]))}return se.makeSpan(["mord","text"].concat(i.sizingClasses(t)),se.tryCombineChars(r),i)},mathmlBuilder(e,t){var n=new Oe.TextNode(M6(e)),r=new Oe.MathNode("mtext",[n]);return r.setAttribute("mathvariant","monospace"),r}});var M6=e=>e.body.replace(/ /g,e.star?"␣":" "),el=Ax,iS=`[ \r
	]`,g$="\\\\[a-zA-Z@]+",b$="\\\\[^\uD800-\uDFFF]",v$="("+g$+")"+iS+"*",_$=`\\\\(
|[ \r	]+
?)[ \r	]*`,xb="[̀-ͯ]",y$=new RegExp(xb+"+$"),E$="("+iS+"+)|"+(_$+"|")+"([!-\\[\\]-‧‪-퟿豈-]"+(xb+"*")+"|[\uD800-\uDBFF][\uDC00-\uDFFF]"+(xb+"*")+"|\\\\verb\\*([^]).*?\\4|\\\\verb([^*a-zA-Z]).*?\\5"+("|"+v$)+("|"+b$+")");class I6{constructor(t,n){this.input=void 0,this.settings=void 0,this.tokenRegex=void 0,this.catcodes=void 0,this.input=t,this.settings=n,this.tokenRegex=new RegExp(E$,"g"),this.catcodes={"%":14,"~":13}}setCatcode(t,n){this.catcodes[t]=n}lex(){var t=this.input,n=this.tokenRegex.lastIndex;if(n===t.length)return new Ti("EOF",new ri(this,n,n));var r=this.tokenRegex.exec(t);if(r===null||r.index!==n)throw new Ie("Unexpected character: '"+t[n]+"'",new Ti(t[n],new ri(this,n,n+1)));var i=r[6]||r[3]||(r[2]?"\\ ":" ");if(this.catcodes[i]===14){var s=t.indexOf(`
`,this.tokenRegex.lastIndex);return s===-1?(this.tokenRegex.lastIndex=t.length,this.settings.reportNonstrict("commentAtEnd","% comment has no terminating newline; LaTeX would fail because of commenting the end of math mode (e.g. $)")):this.tokenRegex.lastIndex=s+1,this.lex()}return new Ti(i,new ri(this,n,this.tokenRegex.lastIndex))}}class T${constructor(t,n){t===void 0&&(t={}),n===void 0&&(n={}),this.current=void 0,this.builtins=void 0,this.undefStack=void 0,this.current=n,this.builtins=t,this.undefStack=[]}beginGroup(){this.undefStack.push({})}endGroup(){if(this.undefStack.length===0)throw new Ie("Unbalanced namespace destruction: attempt to pop global namespace; please report this as a bug");var t=this.undefStack.pop();for(var n in t)t.hasOwnProperty(n)&&(t[n]==null?delete this.current[n]:this.current[n]=t[n])}endGroups(){for(;this.undefStack.length>0;)this.endGroup()}has(t){return this.current.hasOwnProperty(t)||this.builtins.hasOwnProperty(t)}get(t){return this.current.hasOwnProperty(t)?this.current[t]:this.builtins[t]}set(t,n,r){if(r===void 0&&(r=!1),r){for(var i=0;i<this.undefStack.length;i++)delete this.undefStack[i][t];this.undefStack.length>0&&(this.undefStack[this.undefStack.length-1][t]=n)}else{var s=this.undefStack[this.undefStack.length-1];s&&!s.hasOwnProperty(t)&&(s[t]=this.current[t])}n==null?delete this.current[t]:this.current[t]=n}}var x$=Vx;M("\\noexpand",function(e){var t=e.popToken();return e.isExpandable(t.text)&&(t.noexpand=!0,t.treatAsRelax=!0),{tokens:[t],numArgs:0}});M("\\expandafter",function(e){var t=e.popToken();return e.expandOnce(!0),{tokens:[t],numArgs:0}});M("\\@firstoftwo",function(e){var t=e.consumeArgs(2);return{tokens:t[0],numArgs:0}});M("\\@secondoftwo",function(e){var t=e.consumeArgs(2);return{tokens:t[1],numArgs:0}});M("\\@ifnextchar",function(e){var t=e.consumeArgs(3);e.consumeSpaces();var n=e.future();return t[0].length===1&&t[0][0].text===n.text?{tokens:t[1],numArgs:0}:{tokens:t[2],numArgs:0}});M("\\@ifstar","\\@ifnextchar *{\\@firstoftwo{#1}}");M("\\TextOrMath",function(e){var t=e.consumeArgs(2);return e.mode==="text"?{tokens:t[0],numArgs:0}:{tokens:t[1],numArgs:0}});var D6={0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9,a:10,A:10,b:11,B:11,c:12,C:12,d:13,D:13,e:14,E:14,f:15,F:15};M("\\char",function(e){var t=e.popToken(),n,r="";if(t.text==="'")n=8,t=e.popToken();else if(t.text==='"')n=16,t=e.popToken();else if(t.text==="`")if(t=e.popToken(),t.text[0]==="\\")r=t.text.charCodeAt(1);else{if(t.text==="EOF")throw new Ie("\\char` missing argument");r=t.text.charCodeAt(0)}else n=10;if(n){if(r=D6[t.text],r==null||r>=n)throw new Ie("Invalid base-"+n+" digit "+t.text);for(var i;(i=D6[e.future().text])!=null&&i<n;)r*=n,r+=i,e.popToken()}return"\\@char{"+r+"}"});var Q2=(e,t,n,r)=>{var i=e.consumeArg().tokens;if(i.length!==1)throw new Ie("\\newcommand's first argument must be a macro name");var s=i[0].text,o=e.isDefined(s);if(o&&!t)throw new Ie("\\newcommand{"+s+"} attempting to redefine "+(s+"; use \\renewcommand"));if(!o&&!n)throw new Ie("\\renewcommand{"+s+"} when command "+s+" does not yet exist; use \\newcommand");var c=0;if(i=e.consumeArg().tokens,i.length===1&&i[0].text==="["){for(var d="",f=e.expandNextToken();f.text!=="]"&&f.text!=="EOF";)d+=f.text,f=e.expandNextToken();if(!d.match(/^\s*[0-9]+\s*$/))throw new Ie("Invalid number of arguments: "+d);c=parseInt(d),i=e.consumeArg().tokens}return o&&r||e.macros.set(s,{tokens:i,numArgs:c}),""};M("\\newcommand",e=>Q2(e,!1,!0,!1));M("\\renewcommand",e=>Q2(e,!0,!1,!1));M("\\providecommand",e=>Q2(e,!0,!0,!0));M("\\message",e=>{var t=e.consumeArgs(1)[0];return console.log(t.reverse().map(n=>n.text).join("")),""});M("\\errmessage",e=>{var t=e.consumeArgs(1)[0];return console.error(t.reverse().map(n=>n.text).join("")),""});M("\\show",e=>{var t=e.popToken(),n=t.text;return console.log(t,e.macros.get(n),el[n],yn.math[n],yn.text[n]),""});M("\\bgroup","{");M("\\egroup","}");M("~","\\nobreakspace");M("\\lq","`");M("\\rq","'");M("\\aa","\\r a");M("\\AA","\\r A");M("\\textcopyright","\\html@mathml{\\textcircled{c}}{\\char`©}");M("\\copyright","\\TextOrMath{\\textcopyright}{\\text{\\textcopyright}}");M("\\textregistered","\\html@mathml{\\textcircled{\\scriptsize R}}{\\char`®}");M("ℬ","\\mathscr{B}");M("ℰ","\\mathscr{E}");M("ℱ","\\mathscr{F}");M("ℋ","\\mathscr{H}");M("ℐ","\\mathscr{I}");M("ℒ","\\mathscr{L}");M("ℳ","\\mathscr{M}");M("ℛ","\\mathscr{R}");M("ℭ","\\mathfrak{C}");M("ℌ","\\mathfrak{H}");M("ℨ","\\mathfrak{Z}");M("\\Bbbk","\\Bbb{k}");M("·","\\cdotp");M("\\llap","\\mathllap{\\textrm{#1}}");M("\\rlap","\\mathrlap{\\textrm{#1}}");M("\\clap","\\mathclap{\\textrm{#1}}");M("\\mathstrut","\\vphantom{(}");M("\\underbar","\\underline{\\text{#1}}");M("\\not",'\\html@mathml{\\mathrel{\\mathrlap\\@not}}{\\char"338}');M("\\neq","\\html@mathml{\\mathrel{\\not=}}{\\mathrel{\\char`≠}}");M("\\ne","\\neq");M("≠","\\neq");M("\\notin","\\html@mathml{\\mathrel{{\\in}\\mathllap{/\\mskip1mu}}}{\\mathrel{\\char`∉}}");M("∉","\\notin");M("≘","\\html@mathml{\\mathrel{=\\kern{-1em}\\raisebox{0.4em}{$\\scriptsize\\frown$}}}{\\mathrel{\\char`≘}}");M("≙","\\html@mathml{\\stackrel{\\tiny\\wedge}{=}}{\\mathrel{\\char`≘}}");M("≚","\\html@mathml{\\stackrel{\\tiny\\vee}{=}}{\\mathrel{\\char`≚}}");M("≛","\\html@mathml{\\stackrel{\\scriptsize\\star}{=}}{\\mathrel{\\char`≛}}");M("≝","\\html@mathml{\\stackrel{\\tiny\\mathrm{def}}{=}}{\\mathrel{\\char`≝}}");M("≞","\\html@mathml{\\stackrel{\\tiny\\mathrm{m}}{=}}{\\mathrel{\\char`≞}}");M("≟","\\html@mathml{\\stackrel{\\tiny?}{=}}{\\mathrel{\\char`≟}}");M("⟂","\\perp");M("‼","\\mathclose{!\\mkern-0.8mu!}");M("∌","\\notni");M("⌜","\\ulcorner");M("⌝","\\urcorner");M("⌞","\\llcorner");M("⌟","\\lrcorner");M("©","\\copyright");M("®","\\textregistered");M("️","\\textregistered");M("\\ulcorner",'\\html@mathml{\\@ulcorner}{\\mathop{\\char"231c}}');M("\\urcorner",'\\html@mathml{\\@urcorner}{\\mathop{\\char"231d}}');M("\\llcorner",'\\html@mathml{\\@llcorner}{\\mathop{\\char"231e}}');M("\\lrcorner",'\\html@mathml{\\@lrcorner}{\\mathop{\\char"231f}}');M("\\vdots","{\\varvdots\\rule{0pt}{15pt}}");M("⋮","\\vdots");M("\\varGamma","\\mathit{\\Gamma}");M("\\varDelta","\\mathit{\\Delta}");M("\\varTheta","\\mathit{\\Theta}");M("\\varLambda","\\mathit{\\Lambda}");M("\\varXi","\\mathit{\\Xi}");M("\\varPi","\\mathit{\\Pi}");M("\\varSigma","\\mathit{\\Sigma}");M("\\varUpsilon","\\mathit{\\Upsilon}");M("\\varPhi","\\mathit{\\Phi}");M("\\varPsi","\\mathit{\\Psi}");M("\\varOmega","\\mathit{\\Omega}");M("\\substack","\\begin{subarray}{c}#1\\end{subarray}");M("\\colon","\\nobreak\\mskip2mu\\mathpunct{}\\mathchoice{\\mkern-3mu}{\\mkern-3mu}{}{}{:}\\mskip6mu\\relax");M("\\boxed","\\fbox{$\\displaystyle{#1}$}");M("\\iff","\\DOTSB\\;\\Longleftrightarrow\\;");M("\\implies","\\DOTSB\\;\\Longrightarrow\\;");M("\\impliedby","\\DOTSB\\;\\Longleftarrow\\;");M("\\dddot","{\\overset{\\raisebox{-0.1ex}{\\normalsize ...}}{#1}}");M("\\ddddot","{\\overset{\\raisebox{-0.1ex}{\\normalsize ....}}{#1}}");var L6={",":"\\dotsc","\\not":"\\dotsb","+":"\\dotsb","=":"\\dotsb","<":"\\dotsb",">":"\\dotsb","-":"\\dotsb","*":"\\dotsb",":":"\\dotsb","\\DOTSB":"\\dotsb","\\coprod":"\\dotsb","\\bigvee":"\\dotsb","\\bigwedge":"\\dotsb","\\biguplus":"\\dotsb","\\bigcap":"\\dotsb","\\bigcup":"\\dotsb","\\prod":"\\dotsb","\\sum":"\\dotsb","\\bigotimes":"\\dotsb","\\bigoplus":"\\dotsb","\\bigodot":"\\dotsb","\\bigsqcup":"\\dotsb","\\And":"\\dotsb","\\longrightarrow":"\\dotsb","\\Longrightarrow":"\\dotsb","\\longleftarrow":"\\dotsb","\\Longleftarrow":"\\dotsb","\\longleftrightarrow":"\\dotsb","\\Longleftrightarrow":"\\dotsb","\\mapsto":"\\dotsb","\\longmapsto":"\\dotsb","\\hookrightarrow":"\\dotsb","\\doteq":"\\dotsb","\\mathbin":"\\dotsb","\\mathrel":"\\dotsb","\\relbar":"\\dotsb","\\Relbar":"\\dotsb","\\xrightarrow":"\\dotsb","\\xleftarrow":"\\dotsb","\\DOTSI":"\\dotsi","\\int":"\\dotsi","\\oint":"\\dotsi","\\iint":"\\dotsi","\\iiint":"\\dotsi","\\iiiint":"\\dotsi","\\idotsint":"\\dotsi","\\DOTSX":"\\dotsx"};M("\\dots",function(e){var t="\\dotso",n=e.expandAfterFuture().text;return n in L6?t=L6[n]:(n.slice(0,4)==="\\not"||n in yn.math&&["bin","rel"].includes(yn.math[n].group))&&(t="\\dotsb"),t});var Z2={")":!0,"]":!0,"\\rbrack":!0,"\\}":!0,"\\rbrace":!0,"\\rangle":!0,"\\rceil":!0,"\\rfloor":!0,"\\rgroup":!0,"\\rmoustache":!0,"\\right":!0,"\\bigr":!0,"\\biggr":!0,"\\Bigr":!0,"\\Biggr":!0,$:!0,";":!0,".":!0,",":!0};M("\\dotso",function(e){var t=e.future().text;return t in Z2?"\\ldots\\,":"\\ldots"});M("\\dotsc",function(e){var t=e.future().text;return t in Z2&&t!==","?"\\ldots\\,":"\\ldots"});M("\\cdots",function(e){var t=e.future().text;return t in Z2?"\\@cdots\\,":"\\@cdots"});M("\\dotsb","\\cdots");M("\\dotsm","\\cdots");M("\\dotsi","\\!\\cdots");M("\\dotsx","\\ldots\\,");M("\\DOTSI","\\relax");M("\\DOTSB","\\relax");M("\\DOTSX","\\relax");M("\\tmspace","\\TextOrMath{\\kern#1#3}{\\mskip#1#2}\\relax");M("\\,","\\tmspace+{3mu}{.1667em}");M("\\thinspace","\\,");M("\\>","\\mskip{4mu}");M("\\:","\\tmspace+{4mu}{.2222em}");M("\\medspace","\\:");M("\\;","\\tmspace+{5mu}{.2777em}");M("\\thickspace","\\;");M("\\!","\\tmspace-{3mu}{.1667em}");M("\\negthinspace","\\!");M("\\negmedspace","\\tmspace-{4mu}{.2222em}");M("\\negthickspace","\\tmspace-{5mu}{.277em}");M("\\enspace","\\kern.5em ");M("\\enskip","\\hskip.5em\\relax");M("\\quad","\\hskip1em\\relax");M("\\qquad","\\hskip2em\\relax");M("\\tag","\\@ifstar\\tag@literal\\tag@paren");M("\\tag@paren","\\tag@literal{({#1})}");M("\\tag@literal",e=>{if(e.macros.get("\\df@tag"))throw new Ie("Multiple \\tag");return"\\gdef\\df@tag{\\text{#1}}"});M("\\bmod","\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}\\mathbin{\\rm mod}\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}");M("\\pod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern8mu}{\\mkern8mu}{\\mkern8mu}(#1)");M("\\pmod","\\pod{{\\rm mod}\\mkern6mu#1}");M("\\mod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern12mu}{\\mkern12mu}{\\mkern12mu}{\\rm mod}\\,\\,#1");M("\\newline","\\\\\\relax");M("\\TeX","\\textrm{\\html@mathml{T\\kern-.1667em\\raisebox{-.5ex}{E}\\kern-.125emX}{TeX}}");var aS=Be(da["Main-Regular"][84][1]-.7*da["Main-Regular"][65][1]);M("\\LaTeX","\\textrm{\\html@mathml{"+("L\\kern-.36em\\raisebox{"+aS+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{LaTeX}}");M("\\KaTeX","\\textrm{\\html@mathml{"+("K\\kern-.17em\\raisebox{"+aS+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{KaTeX}}");M("\\hspace","\\@ifstar\\@hspacer\\@hspace");M("\\@hspace","\\hskip #1\\relax");M("\\@hspacer","\\rule{0pt}{0pt}\\hskip #1\\relax");M("\\ordinarycolon",":");M("\\vcentcolon","\\mathrel{\\mathop\\ordinarycolon}");M("\\dblcolon",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-.9mu}\\vcentcolon}}{\\mathop{\\char"2237}}');M("\\coloneqq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2254}}');M("\\Coloneqq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2237\\char"3d}}');M("\\coloneq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"3a\\char"2212}}');M("\\Coloneq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"2237\\char"2212}}');M("\\eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2255}}');M("\\Eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"3d\\char"2237}}');M("\\eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2239}}');M("\\Eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"2212\\char"2237}}');M("\\colonapprox",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"3a\\char"2248}}');M("\\Colonapprox",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"2237\\char"2248}}');M("\\colonsim",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"3a\\char"223c}}');M("\\Colonsim",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"2237\\char"223c}}');M("∷","\\dblcolon");M("∹","\\eqcolon");M("≔","\\coloneqq");M("≕","\\eqqcolon");M("⩴","\\Coloneqq");M("\\ratio","\\vcentcolon");M("\\coloncolon","\\dblcolon");M("\\colonequals","\\coloneqq");M("\\coloncolonequals","\\Coloneqq");M("\\equalscolon","\\eqqcolon");M("\\equalscoloncolon","\\Eqqcolon");M("\\colonminus","\\coloneq");M("\\coloncolonminus","\\Coloneq");M("\\minuscolon","\\eqcolon");M("\\minuscoloncolon","\\Eqcolon");M("\\coloncolonapprox","\\Colonapprox");M("\\coloncolonsim","\\Colonsim");M("\\simcolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\vcentcolon}");M("\\simcoloncolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\dblcolon}");M("\\approxcolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\vcentcolon}");M("\\approxcoloncolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\dblcolon}");M("\\notni","\\html@mathml{\\not\\ni}{\\mathrel{\\char`∌}}");M("\\limsup","\\DOTSB\\operatorname*{lim\\,sup}");M("\\liminf","\\DOTSB\\operatorname*{lim\\,inf}");M("\\injlim","\\DOTSB\\operatorname*{inj\\,lim}");M("\\projlim","\\DOTSB\\operatorname*{proj\\,lim}");M("\\varlimsup","\\DOTSB\\operatorname*{\\overline{lim}}");M("\\varliminf","\\DOTSB\\operatorname*{\\underline{lim}}");M("\\varinjlim","\\DOTSB\\operatorname*{\\underrightarrow{lim}}");M("\\varprojlim","\\DOTSB\\operatorname*{\\underleftarrow{lim}}");M("\\gvertneqq","\\html@mathml{\\@gvertneqq}{≩}");M("\\lvertneqq","\\html@mathml{\\@lvertneqq}{≨}");M("\\ngeqq","\\html@mathml{\\@ngeqq}{≱}");M("\\ngeqslant","\\html@mathml{\\@ngeqslant}{≱}");M("\\nleqq","\\html@mathml{\\@nleqq}{≰}");M("\\nleqslant","\\html@mathml{\\@nleqslant}{≰}");M("\\nshortmid","\\html@mathml{\\@nshortmid}{∤}");M("\\nshortparallel","\\html@mathml{\\@nshortparallel}{∦}");M("\\nsubseteqq","\\html@mathml{\\@nsubseteqq}{⊈}");M("\\nsupseteqq","\\html@mathml{\\@nsupseteqq}{⊉}");M("\\varsubsetneq","\\html@mathml{\\@varsubsetneq}{⊊}");M("\\varsubsetneqq","\\html@mathml{\\@varsubsetneqq}{⫋}");M("\\varsupsetneq","\\html@mathml{\\@varsupsetneq}{⊋}");M("\\varsupsetneqq","\\html@mathml{\\@varsupsetneqq}{⫌}");M("\\imath","\\html@mathml{\\@imath}{ı}");M("\\jmath","\\html@mathml{\\@jmath}{ȷ}");M("\\llbracket","\\html@mathml{\\mathopen{[\\mkern-3.2mu[}}{\\mathopen{\\char`⟦}}");M("\\rrbracket","\\html@mathml{\\mathclose{]\\mkern-3.2mu]}}{\\mathclose{\\char`⟧}}");M("⟦","\\llbracket");M("⟧","\\rrbracket");M("\\lBrace","\\html@mathml{\\mathopen{\\{\\mkern-3.2mu[}}{\\mathopen{\\char`⦃}}");M("\\rBrace","\\html@mathml{\\mathclose{]\\mkern-3.2mu\\}}}{\\mathclose{\\char`⦄}}");M("⦃","\\lBrace");M("⦄","\\rBrace");M("\\minuso","\\mathbin{\\html@mathml{{\\mathrlap{\\mathchoice{\\kern{0.145em}}{\\kern{0.145em}}{\\kern{0.1015em}}{\\kern{0.0725em}}\\circ}{-}}}{\\char`⦵}}");M("⦵","\\minuso");M("\\darr","\\downarrow");M("\\dArr","\\Downarrow");M("\\Darr","\\Downarrow");M("\\lang","\\langle");M("\\rang","\\rangle");M("\\uarr","\\uparrow");M("\\uArr","\\Uparrow");M("\\Uarr","\\Uparrow");M("\\N","\\mathbb{N}");M("\\R","\\mathbb{R}");M("\\Z","\\mathbb{Z}");M("\\alef","\\aleph");M("\\alefsym","\\aleph");M("\\Alpha","\\mathrm{A}");M("\\Beta","\\mathrm{B}");M("\\bull","\\bullet");M("\\Chi","\\mathrm{X}");M("\\clubs","\\clubsuit");M("\\cnums","\\mathbb{C}");M("\\Complex","\\mathbb{C}");M("\\Dagger","\\ddagger");M("\\diamonds","\\diamondsuit");M("\\empty","\\emptyset");M("\\Epsilon","\\mathrm{E}");M("\\Eta","\\mathrm{H}");M("\\exist","\\exists");M("\\harr","\\leftrightarrow");M("\\hArr","\\Leftrightarrow");M("\\Harr","\\Leftrightarrow");M("\\hearts","\\heartsuit");M("\\image","\\Im");M("\\infin","\\infty");M("\\Iota","\\mathrm{I}");M("\\isin","\\in");M("\\Kappa","\\mathrm{K}");M("\\larr","\\leftarrow");M("\\lArr","\\Leftarrow");M("\\Larr","\\Leftarrow");M("\\lrarr","\\leftrightarrow");M("\\lrArr","\\Leftrightarrow");M("\\Lrarr","\\Leftrightarrow");M("\\Mu","\\mathrm{M}");M("\\natnums","\\mathbb{N}");M("\\Nu","\\mathrm{N}");M("\\Omicron","\\mathrm{O}");M("\\plusmn","\\pm");M("\\rarr","\\rightarrow");M("\\rArr","\\Rightarrow");M("\\Rarr","\\Rightarrow");M("\\real","\\Re");M("\\reals","\\mathbb{R}");M("\\Reals","\\mathbb{R}");M("\\Rho","\\mathrm{P}");M("\\sdot","\\cdot");M("\\sect","\\S");M("\\spades","\\spadesuit");M("\\sub","\\subset");M("\\sube","\\subseteq");M("\\supe","\\supseteq");M("\\Tau","\\mathrm{T}");M("\\thetasym","\\vartheta");M("\\weierp","\\wp");M("\\Zeta","\\mathrm{Z}");M("\\argmin","\\DOTSB\\operatorname*{arg\\,min}");M("\\argmax","\\DOTSB\\operatorname*{arg\\,max}");M("\\plim","\\DOTSB\\mathop{\\operatorname{plim}}\\limits");M("\\bra","\\mathinner{\\langle{#1}|}");M("\\ket","\\mathinner{|{#1}\\rangle}");M("\\braket","\\mathinner{\\langle{#1}\\rangle}");M("\\Bra","\\left\\langle#1\\right|");M("\\Ket","\\left|#1\\right\\rangle");var sS=e=>t=>{var n=t.consumeArg().tokens,r=t.consumeArg().tokens,i=t.consumeArg().tokens,s=t.consumeArg().tokens,o=t.macros.get("|"),c=t.macros.get("\\|");t.macros.beginGroup();var d=p=>v=>{e&&(v.macros.set("|",o),i.length&&v.macros.set("\\|",c));var _=p;if(!p&&i.length){var T=v.future();T.text==="|"&&(v.popToken(),_=!0)}return{tokens:_?i:r,numArgs:0}};t.macros.set("|",d(!1)),i.length&&t.macros.set("\\|",d(!0));var f=t.consumeArg().tokens,m=t.expandTokens([...s,...f,...n]);return t.macros.endGroup(),{tokens:m.reverse(),numArgs:0}};M("\\bra@ket",sS(!1));M("\\bra@set",sS(!0));M("\\Braket","\\bra@ket{\\left\\langle}{\\,\\middle\\vert\\,}{\\,\\middle\\vert\\,}{\\right\\rangle}");M("\\Set","\\bra@set{\\left\\{\\:}{\\;\\middle\\vert\\;}{\\;\\middle\\Vert\\;}{\\:\\right\\}}");M("\\set","\\bra@set{\\{\\,}{\\mid}{}{\\,\\}}");M("\\angln","{\\angl n}");M("\\blue","\\textcolor{##6495ed}{#1}");M("\\orange","\\textcolor{##ffa500}{#1}");M("\\pink","\\textcolor{##ff00af}{#1}");M("\\red","\\textcolor{##df0030}{#1}");M("\\green","\\textcolor{##28ae7b}{#1}");M("\\gray","\\textcolor{gray}{#1}");M("\\purple","\\textcolor{##9d38bd}{#1}");M("\\blueA","\\textcolor{##ccfaff}{#1}");M("\\blueB","\\textcolor{##80f6ff}{#1}");M("\\blueC","\\textcolor{##63d9ea}{#1}");M("\\blueD","\\textcolor{##11accd}{#1}");M("\\blueE","\\textcolor{##0c7f99}{#1}");M("\\tealA","\\textcolor{##94fff5}{#1}");M("\\tealB","\\textcolor{##26edd5}{#1}");M("\\tealC","\\textcolor{##01d1c1}{#1}");M("\\tealD","\\textcolor{##01a995}{#1}");M("\\tealE","\\textcolor{##208170}{#1}");M("\\greenA","\\textcolor{##b6ffb0}{#1}");M("\\greenB","\\textcolor{##8af281}{#1}");M("\\greenC","\\textcolor{##74cf70}{#1}");M("\\greenD","\\textcolor{##1fab54}{#1}");M("\\greenE","\\textcolor{##0d923f}{#1}");M("\\goldA","\\textcolor{##ffd0a9}{#1}");M("\\goldB","\\textcolor{##ffbb71}{#1}");M("\\goldC","\\textcolor{##ff9c39}{#1}");M("\\goldD","\\textcolor{##e07d10}{#1}");M("\\goldE","\\textcolor{##a75a05}{#1}");M("\\redA","\\textcolor{##fca9a9}{#1}");M("\\redB","\\textcolor{##ff8482}{#1}");M("\\redC","\\textcolor{##f9685d}{#1}");M("\\redD","\\textcolor{##e84d39}{#1}");M("\\redE","\\textcolor{##bc2612}{#1}");M("\\maroonA","\\textcolor{##ffbde0}{#1}");M("\\maroonB","\\textcolor{##ff92c6}{#1}");M("\\maroonC","\\textcolor{##ed5fa6}{#1}");M("\\maroonD","\\textcolor{##ca337c}{#1}");M("\\maroonE","\\textcolor{##9e034e}{#1}");M("\\purpleA","\\textcolor{##ddd7ff}{#1}");M("\\purpleB","\\textcolor{##c6b9fc}{#1}");M("\\purpleC","\\textcolor{##aa87ff}{#1}");M("\\purpleD","\\textcolor{##7854ab}{#1}");M("\\purpleE","\\textcolor{##543b78}{#1}");M("\\mintA","\\textcolor{##f5f9e8}{#1}");M("\\mintB","\\textcolor{##edf2df}{#1}");M("\\mintC","\\textcolor{##e0e5cc}{#1}");M("\\grayA","\\textcolor{##f6f7f7}{#1}");M("\\grayB","\\textcolor{##f0f1f2}{#1}");M("\\grayC","\\textcolor{##e3e5e6}{#1}");M("\\grayD","\\textcolor{##d6d8da}{#1}");M("\\grayE","\\textcolor{##babec2}{#1}");M("\\grayF","\\textcolor{##888d93}{#1}");M("\\grayG","\\textcolor{##626569}{#1}");M("\\grayH","\\textcolor{##3b3e40}{#1}");M("\\grayI","\\textcolor{##21242c}{#1}");M("\\kaBlue","\\textcolor{##314453}{#1}");M("\\kaGreen","\\textcolor{##71B307}{#1}");var lS={"^":!0,_:!0,"\\limits":!0,"\\nolimits":!0};class S${constructor(t,n,r){this.settings=void 0,this.expansionCount=void 0,this.lexer=void 0,this.macros=void 0,this.stack=void 0,this.mode=void 0,this.settings=n,this.expansionCount=0,this.feed(t),this.macros=new T$(x$,n.macros),this.mode=r,this.stack=[]}feed(t){this.lexer=new I6(t,this.settings)}switchMode(t){this.mode=t}beginGroup(){this.macros.beginGroup()}endGroup(){this.macros.endGroup()}endGroups(){this.macros.endGroups()}future(){return this.stack.length===0&&this.pushToken(this.lexer.lex()),this.stack[this.stack.length-1]}popToken(){return this.future(),this.stack.pop()}pushToken(t){this.stack.push(t)}pushTokens(t){this.stack.push(...t)}scanArgument(t){var n,r,i;if(t){if(this.consumeSpaces(),this.future().text!=="[")return null;n=this.popToken(),{tokens:i,end:r}=this.consumeArg(["]"])}else({tokens:i,start:n,end:r}=this.consumeArg());return this.pushToken(new Ti("EOF",r.loc)),this.pushTokens(i),new Ti("",ri.range(n,r))}consumeSpaces(){for(;;){var t=this.future();if(t.text===" ")this.stack.pop();else break}}consumeArg(t){var n=[],r=t&&t.length>0;r||this.consumeSpaces();var i=this.future(),s,o=0,c=0;do{if(s=this.popToken(),n.push(s),s.text==="{")++o;else if(s.text==="}"){if(--o,o===-1)throw new Ie("Extra }",s)}else if(s.text==="EOF")throw new Ie("Unexpected end of input in a macro argument, expected '"+(t&&r?t[c]:"}")+"'",s);if(t&&r)if((o===0||o===1&&t[c]==="{")&&s.text===t[c]){if(++c,c===t.length){n.splice(-c,c);break}}else c=0}while(o!==0||r);return i.text==="{"&&n[n.length-1].text==="}"&&(n.pop(),n.shift()),n.reverse(),{tokens:n,start:i,end:s}}consumeArgs(t,n){if(n){if(n.length!==t+1)throw new Ie("The length of delimiters doesn't match the number of args!");for(var r=n[0],i=0;i<r.length;i++){var s=this.popToken();if(r[i]!==s.text)throw new Ie("Use of the macro doesn't match its definition",s)}}for(var o=[],c=0;c<t;c++)o.push(this.consumeArg(n&&n[c+1]).tokens);return o}countExpansion(t){if(this.expansionCount+=t,this.expansionCount>this.settings.maxExpand)throw new Ie("Too many expansions: infinite loop or need to increase maxExpand setting")}expandOnce(t){var n=this.popToken(),r=n.text,i=n.noexpand?null:this._getExpansion(r);if(i==null||t&&i.unexpandable){if(t&&i==null&&r[0]==="\\"&&!this.isDefined(r))throw new Ie("Undefined control sequence: "+r);return this.pushToken(n),!1}this.countExpansion(1);var s=i.tokens,o=this.consumeArgs(i.numArgs,i.delimiters);if(i.numArgs){s=s.slice();for(var c=s.length-1;c>=0;--c){var d=s[c];if(d.text==="#"){if(c===0)throw new Ie("Incomplete placeholder at end of macro body",d);if(d=s[--c],d.text==="#")s.splice(c+1,1);else if(/^[1-9]$/.test(d.text))s.splice(c,2,...o[+d.text-1]);else throw new Ie("Not a valid argument number",d)}}}return this.pushTokens(s),s.length}expandAfterFuture(){return this.expandOnce(),this.future()}expandNextToken(){for(;;)if(this.expandOnce()===!1){var t=this.stack.pop();return t.treatAsRelax&&(t.text="\\relax"),t}throw new Error}expandMacro(t){return this.macros.has(t)?this.expandTokens([new Ti(t)]):void 0}expandTokens(t){var n=[],r=this.stack.length;for(this.pushTokens(t);this.stack.length>r;)if(this.expandOnce(!0)===!1){var i=this.stack.pop();i.treatAsRelax&&(i.noexpand=!1,i.treatAsRelax=!1),n.push(i)}return this.countExpansion(n.length),n}expandMacroAsText(t){var n=this.expandMacro(t);return n&&n.map(r=>r.text).join("")}_getExpansion(t){var n=this.macros.get(t);if(n==null)return n;if(t.length===1){var r=this.lexer.catcodes[t];if(r!=null&&r!==13)return}var i=typeof n=="function"?n(this):n;if(typeof i=="string"){var s=0;if(i.indexOf("#")!==-1)for(var o=i.replace(/##/g,"");o.indexOf("#"+(s+1))!==-1;)++s;for(var c=new I6(i,this.settings),d=[],f=c.lex();f.text!=="EOF";)d.push(f),f=c.lex();d.reverse();var m={tokens:d,numArgs:s};return m}return i}isDefined(t){return this.macros.has(t)||el.hasOwnProperty(t)||yn.math.hasOwnProperty(t)||yn.text.hasOwnProperty(t)||lS.hasOwnProperty(t)}isExpandable(t){var n=this.macros.get(t);return n!=null?typeof n=="string"||typeof n=="function"||!n.unexpandable:el.hasOwnProperty(t)&&!el[t].primitive}}var P6=/^[₊₋₌₍₎₀₁₂₃₄₅₆₇₈₉ₐₑₕᵢⱼₖₗₘₙₒₚᵣₛₜᵤᵥₓᵦᵧᵨᵩᵪ]/,kh=Object.freeze({"₊":"+","₋":"-","₌":"=","₍":"(","₎":")","₀":"0","₁":"1","₂":"2","₃":"3","₄":"4","₅":"5","₆":"6","₇":"7","₈":"8","₉":"9","ₐ":"a","ₑ":"e","ₕ":"h","ᵢ":"i","ⱼ":"j","ₖ":"k","ₗ":"l","ₘ":"m","ₙ":"n","ₒ":"o","ₚ":"p","ᵣ":"r","ₛ":"s","ₜ":"t","ᵤ":"u","ᵥ":"v","ₓ":"x","ᵦ":"β","ᵧ":"γ","ᵨ":"ρ","ᵩ":"ϕ","ᵪ":"χ","⁺":"+","⁻":"-","⁼":"=","⁽":"(","⁾":")","⁰":"0","¹":"1","²":"2","³":"3","⁴":"4","⁵":"5","⁶":"6","⁷":"7","⁸":"8","⁹":"9","ᴬ":"A","ᴮ":"B","ᴰ":"D","ᴱ":"E","ᴳ":"G","ᴴ":"H","ᴵ":"I","ᴶ":"J","ᴷ":"K","ᴸ":"L","ᴹ":"M","ᴺ":"N","ᴼ":"O","ᴾ":"P","ᴿ":"R","ᵀ":"T","ᵁ":"U","ⱽ":"V","ᵂ":"W","ᵃ":"a","ᵇ":"b","ᶜ":"c","ᵈ":"d","ᵉ":"e","ᶠ":"f","ᵍ":"g",ʰ:"h","ⁱ":"i",ʲ:"j","ᵏ":"k",ˡ:"l","ᵐ":"m",ⁿ:"n","ᵒ":"o","ᵖ":"p",ʳ:"r",ˢ:"s","ᵗ":"t","ᵘ":"u","ᵛ":"v",ʷ:"w",ˣ:"x",ʸ:"y","ᶻ":"z","ᵝ":"β","ᵞ":"γ","ᵟ":"δ","ᵠ":"ϕ","ᵡ":"χ","ᶿ":"θ"}),gg={"́":{text:"\\'",math:"\\acute"},"̀":{text:"\\`",math:"\\grave"},"̈":{text:'\\"',math:"\\ddot"},"̃":{text:"\\~",math:"\\tilde"},"̄":{text:"\\=",math:"\\bar"},"̆":{text:"\\u",math:"\\breve"},"̌":{text:"\\v",math:"\\check"},"̂":{text:"\\^",math:"\\hat"},"̇":{text:"\\.",math:"\\dot"},"̊":{text:"\\r",math:"\\mathring"},"̋":{text:"\\H"},"̧":{text:"\\c"}},B6={á:"á",à:"à",ä:"ä",ǟ:"ǟ",ã:"ã",ā:"ā",ă:"ă",ắ:"ắ",ằ:"ằ",ẵ:"ẵ",ǎ:"ǎ",â:"â",ấ:"ấ",ầ:"ầ",ẫ:"ẫ",ȧ:"ȧ",ǡ:"ǡ",å:"å",ǻ:"ǻ",ḃ:"ḃ",ć:"ć",ḉ:"ḉ",č:"č",ĉ:"ĉ",ċ:"ċ",ç:"ç",ď:"ď",ḋ:"ḋ",ḑ:"ḑ",é:"é",è:"è",ë:"ë",ẽ:"ẽ",ē:"ē",ḗ:"ḗ",ḕ:"ḕ",ĕ:"ĕ",ḝ:"ḝ",ě:"ě",ê:"ê",ế:"ế",ề:"ề",ễ:"ễ",ė:"ė",ȩ:"ȩ",ḟ:"ḟ",ǵ:"ǵ",ḡ:"ḡ",ğ:"ğ",ǧ:"ǧ",ĝ:"ĝ",ġ:"ġ",ģ:"ģ",ḧ:"ḧ",ȟ:"ȟ",ĥ:"ĥ",ḣ:"ḣ",ḩ:"ḩ",í:"í",ì:"ì",ï:"ï",ḯ:"ḯ",ĩ:"ĩ",ī:"ī",ĭ:"ĭ",ǐ:"ǐ",î:"î",ǰ:"ǰ",ĵ:"ĵ",ḱ:"ḱ",ǩ:"ǩ",ķ:"ķ",ĺ:"ĺ",ľ:"ľ",ļ:"ļ",ḿ:"ḿ",ṁ:"ṁ",ń:"ń",ǹ:"ǹ",ñ:"ñ",ň:"ň",ṅ:"ṅ",ņ:"ņ",ó:"ó",ò:"ò",ö:"ö",ȫ:"ȫ",õ:"õ",ṍ:"ṍ",ṏ:"ṏ",ȭ:"ȭ",ō:"ō",ṓ:"ṓ",ṑ:"ṑ",ŏ:"ŏ",ǒ:"ǒ",ô:"ô",ố:"ố",ồ:"ồ",ỗ:"ỗ",ȯ:"ȯ",ȱ:"ȱ",ő:"ő",ṕ:"ṕ",ṗ:"ṗ",ŕ:"ŕ",ř:"ř",ṙ:"ṙ",ŗ:"ŗ",ś:"ś",ṥ:"ṥ",š:"š",ṧ:"ṧ",ŝ:"ŝ",ṡ:"ṡ",ş:"ş",ẗ:"ẗ",ť:"ť",ṫ:"ṫ",ţ:"ţ",ú:"ú",ù:"ù",ü:"ü",ǘ:"ǘ",ǜ:"ǜ",ǖ:"ǖ",ǚ:"ǚ",ũ:"ũ",ṹ:"ṹ",ū:"ū",ṻ:"ṻ",ŭ:"ŭ",ǔ:"ǔ",û:"û",ů:"ů",ű:"ű",ṽ:"ṽ",ẃ:"ẃ",ẁ:"ẁ",ẅ:"ẅ",ŵ:"ŵ",ẇ:"ẇ",ẘ:"ẘ",ẍ:"ẍ",ẋ:"ẋ",ý:"ý",ỳ:"ỳ",ÿ:"ÿ",ỹ:"ỹ",ȳ:"ȳ",ŷ:"ŷ",ẏ:"ẏ",ẙ:"ẙ",ź:"ź",ž:"ž",ẑ:"ẑ",ż:"ż",Á:"Á",À:"À",Ä:"Ä",Ǟ:"Ǟ",Ã:"Ã",Ā:"Ā",Ă:"Ă",Ắ:"Ắ",Ằ:"Ằ",Ẵ:"Ẵ",Ǎ:"Ǎ",Â:"Â",Ấ:"Ấ",Ầ:"Ầ",Ẫ:"Ẫ",Ȧ:"Ȧ",Ǡ:"Ǡ",Å:"Å",Ǻ:"Ǻ",Ḃ:"Ḃ",Ć:"Ć",Ḉ:"Ḉ",Č:"Č",Ĉ:"Ĉ",Ċ:"Ċ",Ç:"Ç",Ď:"Ď",Ḋ:"Ḋ",Ḑ:"Ḑ",É:"É",È:"È",Ë:"Ë",Ẽ:"Ẽ",Ē:"Ē",Ḗ:"Ḗ",Ḕ:"Ḕ",Ĕ:"Ĕ",Ḝ:"Ḝ",Ě:"Ě",Ê:"Ê",Ế:"Ế",Ề:"Ề",Ễ:"Ễ",Ė:"Ė",Ȩ:"Ȩ",Ḟ:"Ḟ",Ǵ:"Ǵ",Ḡ:"Ḡ",Ğ:"Ğ",Ǧ:"Ǧ",Ĝ:"Ĝ",Ġ:"Ġ",Ģ:"Ģ",Ḧ:"Ḧ",Ȟ:"Ȟ",Ĥ:"Ĥ",Ḣ:"Ḣ",Ḩ:"Ḩ",Í:"Í",Ì:"Ì",Ï:"Ï",Ḯ:"Ḯ",Ĩ:"Ĩ",Ī:"Ī",Ĭ:"Ĭ",Ǐ:"Ǐ",Î:"Î",İ:"İ",Ĵ:"Ĵ",Ḱ:"Ḱ",Ǩ:"Ǩ",Ķ:"Ķ",Ĺ:"Ĺ",Ľ:"Ľ",Ļ:"Ļ",Ḿ:"Ḿ",Ṁ:"Ṁ",Ń:"Ń",Ǹ:"Ǹ",Ñ:"Ñ",Ň:"Ň",Ṅ:"Ṅ",Ņ:"Ņ",Ó:"Ó",Ò:"Ò",Ö:"Ö",Ȫ:"Ȫ",Õ:"Õ",Ṍ:"Ṍ",Ṏ:"Ṏ",Ȭ:"Ȭ",Ō:"Ō",Ṓ:"Ṓ",Ṑ:"Ṑ",Ŏ:"Ŏ",Ǒ:"Ǒ",Ô:"Ô",Ố:"Ố",Ồ:"Ồ",Ỗ:"Ỗ",Ȯ:"Ȯ",Ȱ:"Ȱ",Ő:"Ő",Ṕ:"Ṕ",Ṗ:"Ṗ",Ŕ:"Ŕ",Ř:"Ř",Ṙ:"Ṙ",Ŗ:"Ŗ",Ś:"Ś",Ṥ:"Ṥ",Š:"Š",Ṧ:"Ṧ",Ŝ:"Ŝ",Ṡ:"Ṡ",Ş:"Ş",Ť:"Ť",Ṫ:"Ṫ",Ţ:"Ţ",Ú:"Ú",Ù:"Ù",Ü:"Ü",Ǘ:"Ǘ",Ǜ:"Ǜ",Ǖ:"Ǖ",Ǚ:"Ǚ",Ũ:"Ũ",Ṹ:"Ṹ",Ū:"Ū",Ṻ:"Ṻ",Ŭ:"Ŭ",Ǔ:"Ǔ",Û:"Û",Ů:"Ů",Ű:"Ű",Ṽ:"Ṽ",Ẃ:"Ẃ",Ẁ:"Ẁ",Ẅ:"Ẅ",Ŵ:"Ŵ",Ẇ:"Ẇ",Ẍ:"Ẍ",Ẋ:"Ẋ",Ý:"Ý",Ỳ:"Ỳ",Ÿ:"Ÿ",Ỹ:"Ỹ",Ȳ:"Ȳ",Ŷ:"Ŷ",Ẏ:"Ẏ",Ź:"Ź",Ž:"Ž",Ẑ:"Ẑ",Ż:"Ż",ά:"ά",ὰ:"ὰ",ᾱ:"ᾱ",ᾰ:"ᾰ",έ:"έ",ὲ:"ὲ",ή:"ή",ὴ:"ὴ",ί:"ί",ὶ:"ὶ",ϊ:"ϊ",ΐ:"ΐ",ῒ:"ῒ",ῑ:"ῑ",ῐ:"ῐ",ό:"ό",ὸ:"ὸ",ύ:"ύ",ὺ:"ὺ",ϋ:"ϋ",ΰ:"ΰ",ῢ:"ῢ",ῡ:"ῡ",ῠ:"ῠ",ώ:"ώ",ὼ:"ὼ",Ύ:"Ύ",Ὺ:"Ὺ",Ϋ:"Ϋ",Ῡ:"Ῡ",Ῠ:"Ῠ",Ώ:"Ώ",Ὼ:"Ὼ"};class rm{constructor(t,n){this.mode=void 0,this.gullet=void 0,this.settings=void 0,this.leftrightDepth=void 0,this.nextToken=void 0,this.mode="math",this.gullet=new S$(t,n,this.mode),this.settings=n,this.leftrightDepth=0}expect(t,n){if(n===void 0&&(n=!0),this.fetch().text!==t)throw new Ie("Expected '"+t+"', got '"+this.fetch().text+"'",this.fetch());n&&this.consume()}consume(){this.nextToken=null}fetch(){return this.nextToken==null&&(this.nextToken=this.gullet.expandNextToken()),this.nextToken}switchMode(t){this.mode=t,this.gullet.switchMode(t)}parse(){this.settings.globalGroup||this.gullet.beginGroup(),this.settings.colorIsTextColor&&this.gullet.macros.set("\\color","\\textcolor");try{var t=this.parseExpression(!1);return this.expect("EOF"),this.settings.globalGroup||this.gullet.endGroup(),t}finally{this.gullet.endGroups()}}subparse(t){var n=this.nextToken;this.consume(),this.gullet.pushToken(new Ti("}")),this.gullet.pushTokens(t);var r=this.parseExpression(!1);return this.expect("}"),this.nextToken=n,r}parseExpression(t,n){for(var r=[];;){this.mode==="math"&&this.consumeSpaces();var i=this.fetch();if(rm.endOfExpression.indexOf(i.text)!==-1||n&&i.text===n||t&&el[i.text]&&el[i.text].infix)break;var s=this.parseAtom(n);if(s){if(s.type==="internal")continue}else break;r.push(s)}return this.mode==="text"&&this.formLigatures(r),this.handleInfixNodes(r)}handleInfixNodes(t){for(var n=-1,r,i=0;i<t.length;i++)if(t[i].type==="infix"){if(n!==-1)throw new Ie("only one infix operator per group",t[i].token);n=i,r=t[i].replaceWith}if(n!==-1&&r){var s,o,c=t.slice(0,n),d=t.slice(n+1);c.length===1&&c[0].type==="ordgroup"?s=c[0]:s={type:"ordgroup",mode:this.mode,body:c},d.length===1&&d[0].type==="ordgroup"?o=d[0]:o={type:"ordgroup",mode:this.mode,body:d};var f;return r==="\\\\abovefrac"?f=this.callFunction(r,[s,t[n],o],[]):f=this.callFunction(r,[s,o],[]),[f]}else return t}handleSupSubscript(t){var n=this.fetch(),r=n.text;this.consume(),this.consumeSpaces();var i;do{var s;i=this.parseGroup(t)}while(((s=i)==null?void 0:s.type)==="internal");if(!i)throw new Ie("Expected group after '"+r+"'",n);return i}formatUnsupportedCmd(t){for(var n=[],r=0;r<t.length;r++)n.push({type:"textord",mode:"text",text:t[r]});var i={type:"text",mode:this.mode,body:n},s={type:"color",mode:this.mode,color:this.settings.errorColor,body:[i]};return s}parseAtom(t){var n=this.parseGroup("atom",t);if((n==null?void 0:n.type)==="internal"||this.mode==="text")return n;for(var r,i;;){this.consumeSpaces();var s=this.fetch();if(s.text==="\\limits"||s.text==="\\nolimits"){if(n&&n.type==="op"){var o=s.text==="\\limits";n.limits=o,n.alwaysHandleSupSub=!0}else if(n&&n.type==="operatorname")n.alwaysHandleSupSub&&(n.limits=s.text==="\\limits");else throw new Ie("Limit controls must follow a math operator",s);this.consume()}else if(s.text==="^"){if(r)throw new Ie("Double superscript",s);r=this.handleSupSubscript("superscript")}else if(s.text==="_"){if(i)throw new Ie("Double subscript",s);i=this.handleSupSubscript("subscript")}else if(s.text==="'"){if(r)throw new Ie("Double superscript",s);var c={type:"textord",mode:this.mode,text:"\\prime"},d=[c];for(this.consume();this.fetch().text==="'";)d.push(c),this.consume();this.fetch().text==="^"&&d.push(this.handleSupSubscript("superscript")),r={type:"ordgroup",mode:this.mode,body:d}}else if(kh[s.text]){var f=P6.test(s.text),m=[];for(m.push(new Ti(kh[s.text])),this.consume();;){var p=this.fetch().text;if(!kh[p]||P6.test(p)!==f)break;m.unshift(new Ti(kh[p])),this.consume()}var v=this.subparse(m);f?i={type:"ordgroup",mode:"math",body:v}:r={type:"ordgroup",mode:"math",body:v}}else break}return r||i?{type:"supsub",mode:this.mode,base:n,sup:r,sub:i}:n}parseFunction(t,n){var r=this.fetch(),i=r.text,s=el[i];if(!s)return null;if(this.consume(),n&&n!=="atom"&&!s.allowedInArgument)throw new Ie("Got function '"+i+"' with no arguments"+(n?" as "+n:""),r);if(this.mode==="text"&&!s.allowedInText)throw new Ie("Can't use function '"+i+"' in text mode",r);if(this.mode==="math"&&s.allowedInMath===!1)throw new Ie("Can't use function '"+i+"' in math mode",r);var{args:o,optArgs:c}=this.parseArguments(i,s);return this.callFunction(i,o,c,r,t)}callFunction(t,n,r,i,s){var o={funcName:t,parser:this,token:i,breakOnTokenText:s},c=el[t];if(c&&c.handler)return c.handler(o,n,r);throw new Ie("No function handler for "+t)}parseArguments(t,n){var r=n.numArgs+n.numOptionalArgs;if(r===0)return{args:[],optArgs:[]};for(var i=[],s=[],o=0;o<r;o++){var c=n.argTypes&&n.argTypes[o],d=o<n.numOptionalArgs;(n.primitive&&c==null||n.type==="sqrt"&&o===1&&s[0]==null)&&(c="primitive");var f=this.parseGroupOfType("argument to '"+t+"'",c,d);if(d)s.push(f);else if(f!=null)i.push(f);else throw new Ie("Null argument, please report this as a bug")}return{args:i,optArgs:s}}parseGroupOfType(t,n,r){switch(n){case"color":return this.parseColorGroup(r);case"size":return this.parseSizeGroup(r);case"url":return this.parseUrlGroup(r);case"math":case"text":return this.parseArgumentGroup(r,n);case"hbox":{var i=this.parseArgumentGroup(r,"text");return i!=null?{type:"styling",mode:i.mode,body:[i],style:"text"}:null}case"raw":{var s=this.parseStringGroup("raw",r);return s!=null?{type:"raw",mode:"text",string:s.text}:null}case"primitive":{if(r)throw new Ie("A primitive argument cannot be optional");var o=this.parseGroup(t);if(o==null)throw new Ie("Expected group as "+t,this.fetch());return o}case"original":case null:case void 0:return this.parseArgumentGroup(r);default:throw new Ie("Unknown group type as "+t,this.fetch())}}consumeSpaces(){for(;this.fetch().text===" ";)this.consume()}parseStringGroup(t,n){var r=this.gullet.scanArgument(n);if(r==null)return null;for(var i="",s;(s=this.fetch()).text!=="EOF";)i+=s.text,this.consume();return this.consume(),r.text=i,r}parseRegexGroup(t,n){for(var r=this.fetch(),i=r,s="",o;(o=this.fetch()).text!=="EOF"&&t.test(s+o.text);)i=o,s+=i.text,this.consume();if(s==="")throw new Ie("Invalid "+n+": '"+r.text+"'",r);return r.range(i,s)}parseColorGroup(t){var n=this.parseStringGroup("color",t);if(n==null)return null;var r=/^(#[a-f0-9]{3,4}|#[a-f0-9]{6}|#[a-f0-9]{8}|[a-f0-9]{6}|[a-z]+)$/i.exec(n.text);if(!r)throw new Ie("Invalid color: '"+n.text+"'",n);var i=r[0];return/^[0-9a-f]{6}$/i.test(i)&&(i="#"+i),{type:"color-token",mode:this.mode,color:i}}parseSizeGroup(t){var n,r=!1;if(this.gullet.consumeSpaces(),!t&&this.gullet.future().text!=="{"?n=this.parseRegexGroup(/^[-+]? *(?:$|\d+|\d+\.\d*|\.\d*) *[a-z]{0,2} *$/,"size"):n=this.parseStringGroup("size",t),!n)return null;!t&&n.text.length===0&&(n.text="0pt",r=!0);var i=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(n.text);if(!i)throw new Ie("Invalid size: '"+n.text+"'",n);var s={number:+(i[1]+i[2]),unit:i[3]};if(!bx(s))throw new Ie("Invalid unit: '"+s.unit+"'",n);return{type:"size",mode:this.mode,value:s,isBlank:r}}parseUrlGroup(t){this.gullet.lexer.setCatcode("%",13),this.gullet.lexer.setCatcode("~",12);var n=this.parseStringGroup("url",t);if(this.gullet.lexer.setCatcode("%",14),this.gullet.lexer.setCatcode("~",13),n==null)return null;var r=n.text.replace(/\\([#$%&~_^{}])/g,"$1");return{type:"url",mode:this.mode,url:r}}parseArgumentGroup(t,n){var r=this.gullet.scanArgument(t);if(r==null)return null;var i=this.mode;n&&this.switchMode(n),this.gullet.beginGroup();var s=this.parseExpression(!1,"EOF");this.expect("EOF"),this.gullet.endGroup();var o={type:"ordgroup",mode:this.mode,loc:r.loc,body:s};return n&&this.switchMode(i),o}parseGroup(t,n){var r=this.fetch(),i=r.text,s;if(i==="{"||i==="\\begingroup"){this.consume();var o=i==="{"?"}":"\\endgroup";this.gullet.beginGroup();var c=this.parseExpression(!1,o),d=this.fetch();this.expect(o),this.gullet.endGroup(),s={type:"ordgroup",mode:this.mode,loc:ri.range(r,d),body:c,semisimple:i==="\\begingroup"||void 0}}else if(s=this.parseFunction(n,t)||this.parseSymbol(),s==null&&i[0]==="\\"&&!lS.hasOwnProperty(i)){if(this.settings.throwOnError)throw new Ie("Undefined control sequence: "+i,r);s=this.formatUnsupportedCmd(i),this.consume()}return s}formLigatures(t){for(var n=t.length-1,r=0;r<n;++r){var i=t[r],s=i.text;s==="-"&&t[r+1].text==="-"&&(r+1<n&&t[r+2].text==="-"?(t.splice(r,3,{type:"textord",mode:"text",loc:ri.range(i,t[r+2]),text:"---"}),n-=2):(t.splice(r,2,{type:"textord",mode:"text",loc:ri.range(i,t[r+1]),text:"--"}),n-=1)),(s==="'"||s==="`")&&t[r+1].text===s&&(t.splice(r,2,{type:"textord",mode:"text",loc:ri.range(i,t[r+1]),text:s+s}),n-=1)}}parseSymbol(){var t=this.fetch(),n=t.text;if(/^\\verb[^a-zA-Z]/.test(n)){this.consume();var r=n.slice(5),i=r.charAt(0)==="*";if(i&&(r=r.slice(1)),r.length<2||r.charAt(0)!==r.slice(-1))throw new Ie(`\\verb assertion failed --
                    please report what input caused this bug`);return r=r.slice(1,-1),{type:"verb",mode:"text",body:r,star:i}}B6.hasOwnProperty(n[0])&&!yn[this.mode][n[0]]&&(this.settings.strict&&this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Accented Unicode text character "'+n[0]+'" used in math mode',t),n=B6[n[0]]+n.slice(1));var s=y$.exec(n);s&&(n=n.substring(0,s.index),n==="i"?n="ı":n==="j"&&(n="ȷ"));var o;if(yn[this.mode][n]){this.settings.strict&&this.mode==="math"&&vb.indexOf(n)>=0&&this.settings.reportNonstrict("unicodeTextInMathMode",'Latin-1/Unicode text character "'+n[0]+'" used in math mode',t);var c=yn[this.mode][n].group,d=ri.range(t),f;if(hq.hasOwnProperty(c)){var m=c;f={type:"atom",mode:this.mode,family:m,loc:d,text:n}}else f={type:c,mode:this.mode,loc:d,text:n};o=f}else if(n.charCodeAt(0)>=128)this.settings.strict&&(gx(n.charCodeAt(0))?this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Unicode text character "'+n[0]+'" used in math mode',t):this.settings.reportNonstrict("unknownSymbol",'Unrecognized Unicode character "'+n[0]+'"'+(" ("+n.charCodeAt(0)+")"),t)),o={type:"textord",mode:"text",loc:ri.range(t),text:n};else return null;if(this.consume(),s)for(var p=0;p<s[0].length;p++){var v=s[0][p];if(!gg[v])throw new Ie("Unknown accent ' "+v+"'",t);var _=gg[v][this.mode]||gg[v].text;if(!_)throw new Ie("Accent "+v+" unsupported in "+this.mode+" mode",t);o={type:"accent",mode:this.mode,loc:ri.range(t),label:_,isStretchy:!1,isShifty:!0,base:o}}return o}}rm.endOfExpression=["}","\\endgroup","\\end","\\right","&"];var J2=function(t,n){if(!(typeof t=="string"||t instanceof String))throw new TypeError("KaTeX can only parse string typed expression");var r=new rm(t,n);delete r.gullet.macros.current["\\df@tag"];var i=r.parse();if(delete r.gullet.macros.current["\\current@color"],delete r.gullet.macros.current["\\color"],r.gullet.macros.get("\\df@tag")){if(!n.displayMode)throw new Ie("\\tag works only in display equations");i=[{type:"tag",mode:"text",body:i,tag:r.subparse([new Ti("\\df@tag")])}]}return i},oS=function(t,n,r){n.textContent="";var i=ev(t,r).toNode();n.appendChild(i)};typeof document<"u"&&document.compatMode!=="CSS1Compat"&&(typeof console<"u"&&console.warn("Warning: KaTeX doesn't work in quirks mode. Make sure your website has a suitable doctype."),oS=function(){throw new Ie("KaTeX doesn't work in quirks mode.")});var w$=function(t,n){var r=ev(t,n).toMarkup();return r},A$=function(t,n){var r=new L2(n);return J2(t,r)},uS=function(t,n,r){if(r.throwOnError||!(t instanceof Ie))throw t;var i=se.makeSpan(["katex-error"],[new Hi(n)]);return i.setAttribute("title",t.toString()),i.setAttribute("style","color:"+r.errorColor),i},ev=function(t,n){var r=new L2(n);try{var i=J2(t,r);return Lq(i,t,r)}catch(s){return uS(s,t,r)}},k$=function(t,n){var r=new L2(n);try{var i=J2(t,r);return Pq(i,t,r)}catch(s){return uS(s,t,r)}},C$="0.16.27",N$={Span:L0,Anchor:U2,SymbolNode:Hi,SvgNode:as,PathNode:sl,LineNode:bb},U6={version:C$,render:oS,renderToString:w$,ParseError:Ie,SETTINGS_SCHEMA:$h,__parse:A$,__renderToDomTree:ev,__renderToHTMLTree:k$,__setFontMetrics:iq,__defineSymbol:E,__defineFunction:$e,__defineMacro:M,__domTree:N$};const O$={},R$=[];function M$(e){const t=e||O$;return function(n,r){T2(n,"element",function(i,s){const o=Array.isArray(i.properties.className)?i.properties.className:R$,c=o.includes("language-math"),d=o.includes("math-display"),f=o.includes("math-inline");let m=d;if(!c&&!d&&!f)return;let p=s[s.length-1],v=i;if(i.tagName==="code"&&c&&p&&p.type==="element"&&p.tagName==="pre"&&(v=p,p=s[s.length-2],m=!0),!p)return;const _=YT(v,{whitespace:"pre"});let T;try{T=U6.renderToString(_,{...t,displayMode:m,throwOnError:!0})}catch(k){const A=k,O=A.name.toLowerCase();r.message("Could not render math with KaTeX",{ancestors:[...s,i],cause:A,place:i.position,ruleId:O,source:"rehype-katex"});try{T=U6.renderToString(_,{...t,displayMode:m,strict:"ignore",throwOnError:!1})}catch{T=[{type:"element",tagName:"span",properties:{className:["katex-error"],style:"color:"+(t.errorColor||"#cc0000"),title:String(k)},children:[{type:"text",value:_}]}]}}typeof T=="string"&&(T=Nj(T).children);const x=p.children.indexOf(v);return p.children.splice(x,1,...T),L7})}}function I$(){return{enter:{mathFlow:e,mathFlowFenceMeta:t,mathText:s},exit:{mathFlow:i,mathFlowFence:r,mathFlowFenceMeta:n,mathFlowValue:c,mathText:o,mathTextData:c}};function e(d){const f={type:"element",tagName:"code",properties:{className:["language-math","math-display"]},children:[]};this.enter({type:"math",meta:null,value:"",data:{hName:"pre",hChildren:[f]}},d)}function t(){this.buffer()}function n(){const d=this.resume(),f=this.stack[this.stack.length-1];f.type,f.meta=d}function r(){this.data.mathFlowInside||(this.buffer(),this.data.mathFlowInside=!0)}function i(d){const f=this.resume().replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),m=this.stack[this.stack.length-1];m.type,this.exit(d),m.value=f;const p=m.data.hChildren[0];p.type,p.tagName,p.children.push({type:"text",value:f}),this.data.mathFlowInside=void 0}function s(d){this.enter({type:"inlineMath",value:"",data:{hName:"code",hProperties:{className:["language-math","math-inline"]},hChildren:[]}},d),this.buffer()}function o(d){const f=this.resume(),m=this.stack[this.stack.length-1];m.type,this.exit(d),m.value=f,m.data.hChildren.push({type:"text",value:f})}function c(d){this.config.enter.data.call(this,d),this.config.exit.data.call(this,d)}}function D$(e){let t=(e||{}).singleDollarTextMath;return t==null&&(t=!0),r.peek=i,{unsafe:[{character:"\r",inConstruct:"mathFlowMeta"},{character:`
`,inConstruct:"mathFlowMeta"},{character:"$",after:t?void 0:"\\$",inConstruct:"phrasing"},{character:"$",inConstruct:"mathFlowMeta"},{atBreak:!0,character:"$",after:"\\$"}],handlers:{math:n,inlineMath:r}};function n(s,o,c,d){const f=s.value||"",m=c.createTracker(d),p="$".repeat(Math.max(j7(f,"$")+1,2)),v=c.enter("mathFlow");let _=m.move(p);if(s.meta){const T=c.enter("mathFlowMeta");_+=m.move(c.safe(s.meta,{after:`
`,before:_,encode:["$"],...m.current()})),T()}return _+=m.move(`
`),f&&(_+=m.move(f+`
`)),_+=m.move(p),v(),_}function r(s,o,c){let d=s.value||"",f=1;for(t||f++;new RegExp("(^|[^$])"+"\\$".repeat(f)+"([^$]|$)").test(d);)f++;const m="$".repeat(f);/[^ \r\n]/.test(d)&&(/^[ \r\n]/.test(d)&&/[ \r\n]$/.test(d)||/^\$|\$$/.test(d))&&(d=" "+d+" ");let p=-1;for(;++p<c.unsafe.length;){const v=c.unsafe[p];if(!v.atBreak)continue;const _=c.compilePattern(v);let T;for(;T=_.exec(d);){let x=T.index;d.codePointAt(x)===10&&d.codePointAt(x-1)===13&&x--,d=d.slice(0,x)+" "+d.slice(T.index+1)}}return m+d+m}function i(){return"$"}}const L$={tokenize:P$,concrete:!0,name:"mathFlow"},z6={tokenize:B$,partial:!0};function P$(e,t,n){const r=this,i=r.events[r.events.length-1],s=i&&i[1].type==="linePrefix"?i[2].sliceSerialize(i[1],!0).length:0;let o=0;return c;function c(O){return e.enter("mathFlow"),e.enter("mathFlowFence"),e.enter("mathFlowFenceSequence"),d(O)}function d(O){return O===36?(e.consume(O),o++,d):o<2?n(O):(e.exit("mathFlowFenceSequence"),Ot(e,f,"whitespace")(O))}function f(O){return O===null||tt(O)?p(O):(e.enter("mathFlowFenceMeta"),e.enter("chunkString",{contentType:"string"}),m(O))}function m(O){return O===null||tt(O)?(e.exit("chunkString"),e.exit("mathFlowFenceMeta"),p(O)):O===36?n(O):(e.consume(O),m)}function p(O){return e.exit("mathFlowFence"),r.interrupt?t(O):e.attempt(z6,v,k)(O)}function v(O){return e.attempt({tokenize:A,partial:!0},k,_)(O)}function _(O){return(s?Ot(e,T,"linePrefix",s+1):T)(O)}function T(O){return O===null?k(O):tt(O)?e.attempt(z6,v,k)(O):(e.enter("mathFlowValue"),x(O))}function x(O){return O===null||tt(O)?(e.exit("mathFlowValue"),T(O)):(e.consume(O),x)}function k(O){return e.exit("mathFlow"),t(O)}function A(O,I,$){let V=0;return Ot(O,B,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4);function B(te){return O.enter("mathFlowFence"),O.enter("mathFlowFenceSequence"),Z(te)}function Z(te){return te===36?(V++,O.consume(te),Z):V<o?$(te):(O.exit("mathFlowFenceSequence"),Ot(O,ee,"whitespace")(te))}function ee(te){return te===null||tt(te)?(O.exit("mathFlowFence"),I(te)):$(te)}}}function B$(e,t,n){const r=this;return i;function i(o){return o===null?t(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),s)}function s(o){return r.parser.lazy[r.now().line]?n(o):t(o)}}function U$(e){let n=(e||{}).singleDollarTextMath;return n==null&&(n=!0),{tokenize:r,resolve:z$,previous:F$,name:"mathText"};function r(i,s,o){let c=0,d,f;return m;function m(x){return i.enter("mathText"),i.enter("mathTextSequence"),p(x)}function p(x){return x===36?(i.consume(x),c++,p):c<2&&!n?o(x):(i.exit("mathTextSequence"),v(x))}function v(x){return x===null?o(x):x===36?(f=i.enter("mathTextSequence"),d=0,T(x)):x===32?(i.enter("space"),i.consume(x),i.exit("space"),v):tt(x)?(i.enter("lineEnding"),i.consume(x),i.exit("lineEnding"),v):(i.enter("mathTextData"),_(x))}function _(x){return x===null||x===32||x===36||tt(x)?(i.exit("mathTextData"),v(x)):(i.consume(x),_)}function T(x){return x===36?(i.consume(x),d++,T):d===c?(i.exit("mathTextSequence"),i.exit("mathText"),s(x)):(f.type="mathTextData",_(x))}}}function z$(e){let t=e.length-4,n=3,r,i;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="mathTextData"){e[t][1].type="mathTextPadding",e[n][1].type="mathTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)i===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(i=r):(r===t||e[r][1].type==="lineEnding")&&(e[i][1].type="mathTextData",r!==i+2&&(e[i][1].end=e[r-1][1].end,e.splice(i+2,r-i-2),t-=r-i-2,r=i+2),i=void 0);return e}function F$(e){return e!==36||this.events[this.events.length-1][1].type==="characterEscape"}function H$(e){return{flow:{36:L$},text:{36:U$(e)}}}const j$={};function q$(e){const t=this,n=e||j$,r=t.data(),i=r.micromarkExtensions||(r.micromarkExtensions=[]),s=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),o=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);i.push(H$(n)),s.push(I$()),o.push(D$(n))}const $$=({children:e,className:t,node:n,inline:r,...i})=>{const[s,o]=F.useState(!1),c=F.useRef(null),d=async()=>{var v;try{const _=((v=c.current)==null?void 0:v.textContent)||"";await navigator.clipboard.writeText(_),o(!0),setTimeout(()=>o(!1),2e3)}catch(_){console.error("Failed to copy code:",_)}},f=v=>{var _;return typeof v=="string"?v:Array.isArray(v)?v.map(f).join(""):(_=v==null?void 0:v.props)!=null&&_.children?f(v.props.children):""},m=f(e);return r||!m.includes(`
`)?C.jsx("code",{className:t,...i,children:e}):C.jsxs("div",{className:"relative group",children:[C.jsx("button",{onClick:d,className:"absolute top-1 right-1 opacity-0 group-hover:opacity-100 transition-opacity inline-flex items-center gap-1.5 px-2.5 py-1.5 text-xs font-medium text-gray-600 hover:text-gray-900 bg-white hover:bg-gray-50 border border-gray-200 rounded-md shadow-sm z-10",title:"Copy code",children:s?C.jsxs(C.Fragment,{children:[C.jsx("svg",{width:"13",height:"13",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:C.jsx("polyline",{points:"20 6 9 17 4 12"})}),C.jsx("span",{children:"Copied!"})]}):C.jsx(C.Fragment,{children:C.jsxs("svg",{width:"13",height:"13",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("rect",{x:"9",y:"9",width:"13",height:"13",rx:"2",ry:"2"}),C.jsx("path",{d:"M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1"})]})})}),C.jsx("code",{ref:c,className:t,...i,children:e})]})},G$=({children:e})=>C.jsx("div",{className:"not-prose",children:e}),Y$=({src:e,alt:t,...n})=>{const[r,i]=F.useState(!1),s=F.useCallback(async()=>{try{const c=await(await fetch(e)).blob(),d=window.URL.createObjectURL(c),f=document.createElement("a");f.href=d,f.download=t||"image",document.body.appendChild(f),f.click(),document.body.removeChild(f),window.URL.revokeObjectURL(d)}catch(o){console.error("Failed to download image:",o)}},[e,t]);return C.jsxs("div",{className:"relative inline-block group",onMouseEnter:()=>i(!0),onMouseLeave:()=>i(!1),children:[C.jsx("img",{src:e,alt:t,...n}),r&&C.jsx("button",{onClick:s,className:"absolute top-8 right-2 p-2 rounded-lg transition-all duration-200",style:{backgroundColor:"var(--bg-primary)",border:"1px solid var(--border-primary)",color:"var(--text-primary)",boxShadow:"var(--shadow-md)"},title:"Download image","aria-label":"Download image",children:C.jsxs("svg",{xmlns:"http://www.w3.org/2000/svg",width:"18",height:"18",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"}),C.jsx("polyline",{points:"7 10 12 15 17 10"}),C.jsx("line",{x1:"12",y1:"15",x2:"12",y2:"3"})]})})]})},V$=({href:e,onSend:t,...n})=>{const r=F.useCallback(i=>{t(decodeURIComponent(e.slice(23))),i.preventDefault()},[e,t]);return e.startsWith("https://cycls.com/send/")?C.jsx("a",{...n,className:n.className||"underline decoration-[var(--text-tertiary)]/40 decoration-2 hover:decoration-[var(--text-tertiary)]/60",href:"#",onClick:r}):C.jsx("a",{...n,href:e,target:"_blank",rel:"noreferrer"})},K$=({children:e,...t})=>{const n=F.useRef(null),[r,i]=F.useState(!1),s=F.useCallback(()=>{try{if(!n.current)return;const c=[],d=n.current,f=Array.from(d.querySelectorAll("thead th")).map(k=>{var A;return((A=k.textContent)==null?void 0:A.trim())||""});f.length>0&&c.push(f),Array.from(d.querySelectorAll("tbody tr")).forEach(k=>{const A=Array.from(k.querySelectorAll("td")).map(O=>{var I;return((I=O.textContent)==null?void 0:I.trim())||""});A.length>0&&c.push(A)});const p=c.map(k=>k.map(A=>{const O=String(A);return O.includes(",")||O.includes('"')||O.includes(`
`)?`"${O.replace(/"/g,'""')}"`:O}).join(",")).join(`
`),v="\uFEFF",_=new Blob([v+p],{type:"text/csv;charset=utf-8;"}),T=window.URL.createObjectURL(_),x=document.createElement("a");x.href=T,x.download=`table-export-${Date.now()}.csv`,document.body.appendChild(x),x.click(),document.body.removeChild(x),window.URL.revokeObjectURL(T)}catch(c){console.error("Failed to export table as CSV:",c)}},[]),o=F.useCallback(async()=>{try{if(!n.current)return;const c=[],d=n.current,f=Array.from(d.querySelectorAll("thead th")).map(p=>{var v;return((v=p.textContent)==null?void 0:v.trim())||""});f.length>0&&c.push(f.join("	")),Array.from(d.querySelectorAll("tbody tr")).forEach(p=>{const v=Array.from(p.querySelectorAll("td")).map(_=>{var T;return((T=_.textContent)==null?void 0:T.trim())||""});v.length>0&&c.push(v.join("	"))}),await navigator.clipboard.writeText(c.join(`
`)),i(!0),setTimeout(()=>i(!1),2e3)}catch(c){console.error("Failed to copy table:",c)}},[]);return C.jsxs("div",{className:"table-wrapper",children:[C.jsx("table",{ref:n,...t,children:e}),C.jsxs("div",{className:"!-mt-2",style:{display:"flex",alignItems:"center",justifyContent:"space-between",padding:"12px 16px",marginTop:"8px",borderRadius:"8px",backgroundColor:"var(--bg-secondary)",border:"1px solid var(--border-primary)"},children:[C.jsxs("button",{onClick:s,style:{display:"flex",alignItems:"center",gap:"8px",fontSize:"14px",color:"var(--text-secondary)",background:"none",border:"none",cursor:"pointer",padding:"0"},"aria-label":"Export table as CSV",children:[C.jsxs("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("rect",{x:"3",y:"3",width:"18",height:"18",rx:"2",ry:"2"}),C.jsx("line",{x1:"3",y1:"9",x2:"21",y2:"9"}),C.jsx("line",{x1:"3",y1:"15",x2:"21",y2:"15"}),C.jsx("line",{x1:"9",y1:"3",x2:"9",y2:"21"}),C.jsx("line",{x1:"15",y1:"3",x2:"15",y2:"21"})]}),C.jsx("span",{children:"Export as CSV"})]}),C.jsx("button",{onClick:o,style:{display:"flex",alignItems:"center",gap:"6px",padding:"6px",borderRadius:"4px",background:"none",border:"none",cursor:"pointer",color:r?"var(--text-success, #22c55e)":"var(--text-tertiary)"},title:r?"Copied!":"Copy table","aria-label":"Copy table",children:r?C.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:C.jsx("polyline",{points:"20 6 9 17 4 12"})}):C.jsxs("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("rect",{x:"9",y:"9",width:"13",height:"13",rx:"2",ry:"2"}),C.jsx("path",{d:"M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1"})]})})]})]})},$l=ue.memo(({markdown:e,onSend:t})=>{const n=F.useMemo(()=>({raw:G$,a:r=>C.jsx(V$,{...r,onSend:t}),code:$$,img:Y$,table:K$}),[t]);return C.jsx("div",{dir:"auto",children:C.jsx(hL,{components:n,remarkPlugins:[SB,q$],rehypePlugins:[DF,M$,[Ej,{ignoreMissing:!0,detect:!0}]],children:e})})});$l.displayName="MarkdownRenderer";const Qa={MAX_FILE_BYTES:10*1024*1024,ALLOWED_MIME:new Set(["image/jpeg","image/png","image/webp","application/pdf","text/plain","text/markdown","text/csv","video/mp4","video/webm","video/ogg","video/quicktime"]),MAX_CHATS:15};function m0(e){const t=/<!--\s*cycls:attachments\s*([\s\S]*?)\s*cycls:attachments\s*-->/m,n=e.match(t);if(!n)return{clean:e,attachments:[]};let r=[];try{r=JSON.parse(n[1])}catch{r=[]}return{clean:e.replace(t,"").trimEnd(),attachments:r}}function W$(e){return e?e.startsWith("image/")?"image":e.startsWith("video/")?"video":e==="application/pdf"?"pdf":e==="text/csv"?"csv":e==="text/markdown"?"md":e==="text/plain"?"txt":"file":"file"}async function X$(e,t="anon",n="anon"){if(e.size>Qa.MAX_FILE_BYTES)throw new Error("File too large (max 10MB)");if(!Qa.ALLOWED_MIME.has(e.type))throw new Error(`Type not allowed: ${e.type}`);const r=new FormData;r.append("file",e),r.append("orgId",t),r.append("userId",n);const i=await fetch("https://cfywthfcvbajcekvwajz.supabase.co/functions/v1/upload",{method:"POST",body:r});if(!i.ok)throw new Error(`Upload failed (${i.status})`);return await i.json()}const ff=e=>e<1024?`${e}B`:e<1024*1024?`${(e/1024).toFixed(2)}kB`:`${(e/(1024*1024)).toFixed(2)}MB`,Q$=e=>{if(e.size>Qa.MAX_FILE_BYTES)return{valid:!1,error:`File "${e.name}" is too large (${ff(e.size)}). Maximum size is ${ff(Qa.MAX_FILE_BYTES)}.`};if(!Qa.ALLOWED_MIME.has(e.type)){const t=Array.from(Qa.ALLOWED_MIME).map(n=>n.split("/")[1]).join(", ");return{valid:!1,error:`File type "${e.type}" is not supported. Allowed types: ${t}`}}return{valid:!0}},Z$=({attachments:e=[]})=>e.length?C.jsx("div",{className:"mt-3 flex flex-wrap gap-2",children:e.map((t,n)=>{const r=W$(t.mime);if(r==="image")return C.jsx("a",{href:t.url,target:"_blank",rel:"noopener noreferrer",className:"group relative overflow-hidden rounded-lg shadow-sm transition-all duration-200 theme-transition",style:{border:"1px solid var(--border-primary)"},children:C.jsx("img",{src:t.url,alt:"",loading:"lazy",className:"mb-1 w-40 rounded-md"})},n);const i={pdf:"📄",csv:"📊",md:"📝",txt:"📝"}[r]||"📎";return C.jsxs("a",{href:t.url,target:"_blank",rel:"noopener noreferrer",className:"inline-flex items-center gap-2.5 rounded-xl backdrop-blur-sm px-4 py-2.5 text-sm transition-all shadow-sm hover:bg-[var(--bg-hover)] theme-transition",style:{border:"1px solid var(--border-primary)",backgroundColor:"var(--bg-primary)"},children:[C.jsx("span",{className:"text-xl",children:i}),C.jsx("span",{className:"text-xs uppercase font-semibold tracking-wide",style:{color:"var(--text-tertiary)"},children:r||"file"})]},n)})}):null,J$=({error:e,onRetry:t,isRetrying:n})=>{const r=i=>i?i.type==="network"?"Network error. Please check your connection and try again.":i.type==="timeout"?"Request timed out. The server took too long to respond.":i.type==="rate_limit"?i.message||"Too many requests. Please wait a moment and try again.":i.type==="server"?`Server error (${i.status||"unknown"}). Please try again later.`:i.type==="abort"?"Request was cancelled.":i.message||"An error occurred while processing your request.":"An unexpected error occurred";return C.jsx("div",{className:"rounded-lg p-4 my-2 theme-transition",style:{backgroundColor:"rgba(239, 68, 68, 0.1)",border:"1px solid rgba(239, 68, 68, 0.3)"},children:C.jsxs("div",{className:"flex items-start gap-3",children:[C.jsx("div",{className:"flex-shrink-0 mt-0.5",children:C.jsxs("svg",{className:"h-5 w-5 text-red-500",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",children:[C.jsx("circle",{cx:"12",cy:"12",r:"10"}),C.jsx("line",{x1:"12",y1:"8",x2:"12",y2:"12"}),C.jsx("line",{x1:"12",y1:"16",x2:"12.01",y2:"16"})]})}),C.jsxs("div",{className:"flex-1 min-w-0",children:[C.jsx("p",{className:"text-sm font-medium text-red-500",children:"Error"}),C.jsx("p",{className:"text-sm mt-1",style:{color:"var(--text-secondary)"},children:r(e)}),t&&e.type!=="abort"&&C.jsx("button",{onClick:t,disabled:n,className:"mt-3 inline-flex items-center gap-1.5 px-3 py-1.5 text-sm font-medium text-red-500 hover:text-red-400 border border-red-500/30 hover:border-red-500/50 rounded-lg transition-colors disabled:opacity-50 disabled:cursor-not-allowed theme-transition",style:{backgroundColor:"var(--bg-primary)"},children:n?C.jsxs(C.Fragment,{children:[C.jsxs("svg",{className:"animate-spin h-4 w-4",xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",children:[C.jsx("circle",{className:"opacity-25",cx:"12",cy:"12",r:"10",stroke:"currentColor",strokeWidth:"4"}),C.jsx("path",{className:"opacity-75",fill:"currentColor",d:"M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"})]}),C.jsx("span",{children:"Retrying..."})]}):C.jsxs(C.Fragment,{children:[C.jsxs("svg",{width:"14",height:"14",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("polyline",{points:"23 4 23 10 17 10"}),C.jsx("polyline",{points:"1 20 1 14 7 14"}),C.jsx("path",{d:"M3.51 9a9 9 0 0 1 14.85-3.36L23 10M1 14l4.64 4.36A9 9 0 0 0 20.49 15"})]}),C.jsx("span",{children:"Retry"})]})})]})]})})},eG=({message:e,onCopy:t,onRegenerate:n,isLastAssistant:r})=>{const[i,s]=F.useState(!1),o=async()=>{try{const{clean:c}=m0(e.content);await navigator.clipboard.writeText(c),s(!0),setTimeout(()=>s(!1),2e3)}catch(c){console.error("Failed to copy:",c)}};return C.jsxs("div",{className:"flex items-center gap-1 opacity-0 group-hover:opacity-100 transition-opacity duration-200",children:[C.jsx("button",{onClick:o,className:"inline-flex items-center gap-1.5 px-2.5 py-1.5 text-xs font-medium rounded-lg transition-colors hover:bg-[var(--bg-hover)] theme-transition",style:{color:"var(--text-tertiary)"},title:"Copy message",children:i?C.jsxs(C.Fragment,{children:[C.jsx("svg",{width:"14",height:"14",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:C.jsx("polyline",{points:"20 6 9 17 4 12"})}),C.jsx("span",{children:"Copied!"})]}):C.jsxs(C.Fragment,{children:[C.jsxs("svg",{width:"14",height:"14",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("rect",{x:"9",y:"9",width:"13",height:"13",rx:"2",ry:"2"}),C.jsx("path",{d:"M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1"})]}),C.jsx("span",{children:"Copy"})]})}),r&&C.jsxs("button",{onClick:n,className:"inline-flex items-center gap-1.5 px-2.5 py-1.5 text-xs font-medium rounded-lg transition-colors hover:bg-[var(--bg-hover)] theme-transition",style:{color:"var(--text-tertiary)"},title:"Regenerate response",children:[C.jsxs("svg",{width:"14",height:"14",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("polyline",{points:"23 4 23 10 17 10"}),C.jsx("polyline",{points:"1 20 1 14 7 14"}),C.jsx("path",{d:"M3.51 9a9 9 0 0 1 14.85-3.36L23 10M1 14l4.64 4.36A9 9 0 0 0 20.49 15"})]}),C.jsx("span",{children:"Regenerate"})]})]})},tv=(...e)=>e.filter(Boolean).join(" ");function Sb({isOpen:e}){return C.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round",className:tv("transition-transform duration-200",e?"rotate-180":"rotate-0"),children:C.jsx("path",{d:"M6 9l6 6 6-6"})})}function tG(){return C.jsxs("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round",style:{color:"var(--text-tertiary)"},children:[C.jsx("circle",{cx:"12",cy:"12",r:"10"}),C.jsx("path",{d:"M2 12h20"}),C.jsx("path",{d:"M12 2a15.3 15.3 0 0 1 4 10 15.3 15.3 0 0 1-4 10 15.3 15.3 0 0 1-4-10 15.3 15.3 0 0 1 4-10z"})]})}function nG(){return C.jsx("div",{className:"w-1.5 h-1.5 rounded-full",style:{backgroundColor:"var(--text-tertiary)"}})}function rG(e){if(e<60)return`${e}s`;const t=Math.floor(e/60),n=e%60;return`${t}m ${n}s`}function iG({thinking:e,onSend:t,isActive:n,startTime:r,duration:i}){const[s,o]=ue.useState(!1),[c,d]=ue.useState(()=>i??(r&&!n?Math.round((Date.now()-r)/1e3):0));return ue.useEffect(()=>{if(i!=null){d(i);return}if(!n)return;r&&d(Math.round((Date.now()-r)/1e3));const f=setInterval(()=>{r&&d(Math.round((Date.now()-r)/1e3))},1e3);return()=>clearInterval(f)},[n,r,i]),C.jsxs("div",{className:"my-3 rounded-lg border",style:{borderColor:"var(--border-primary)"},children:[C.jsxs("button",{type:"button",onClick:()=>o(f=>!f),className:"w-full flex items-center justify-between gap-3 px-4 py-3 text-left rounded-2xl transition-colors",style:{color:"var(--text-secondary)"},children:[C.jsx("span",{className:"text-sm",style:{color:"var(--text-secondary)"},children:"Thinking"}),C.jsxs("div",{className:"flex items-center gap-2 flex-shrink-0",children:[(c>0||n)&&C.jsx("span",{className:"text-xs",style:{color:"var(--text-tertiary)"},children:rG(c)}),C.jsx("span",{style:{color:"var(--text-tertiary)"},children:C.jsx(Sb,{isOpen:s})})]})]}),s&&C.jsx("div",{className:"px-4 pb-0",style:{borderTop:"1px solid var(--border-primary)"},children:C.jsx("div",{className:"mt-3 prose prose-sm max-w-none",style:{color:"var(--text-tertiary)"},children:C.jsx($l,{markdown:e,onSend:t})})})]})}function aG({steps:e,onSend:t}){const[n,r]=ue.useState(!1),[i,s]=ue.useState({});if(!e||e.length===0)return null;const o=2,c=n?0:Math.max(0,e.length-o),d=n?e:e.slice(-o),f=p=>{s(v=>({...v,[p]:!v[p]}))},m=p=>p.result||p.type==="search"||p.step&&(p.step.toLowerCase().includes("search")||p.step.toLowerCase().includes("fetch"));return C.jsxs("div",{className:"my-3 rounded-lg border",style:{borderColor:"var(--border-primary)"},children:[C.jsxs("button",{type:"button",onClick:()=>r(p=>!p),className:"w-full flex items-center gap-2 px-4 py-3 text-left rounded-2xl transition-colors",style:{color:"var(--text-secondary)"},children:[C.jsx("span",{className:"flex-shrink-0",style:{color:"var(--text-tertiary)"},children:C.jsx(Sb,{isOpen:n})}),C.jsxs("span",{className:"text-sm",style:{color:"var(--text-secondary)"},children:[e.length," step",e.length!==1?"s":""]})]}),C.jsxs("div",{className:"px-4 pb-4",children:[c>0&&C.jsxs("button",{type:"button",onClick:()=>r(!0),className:"w-full text-left py-2 pl-5 text-sm transition-opacity hover:opacity-70",style:{color:"var(--text-tertiary)"},children:["+",c," more step",c!==1?"s":""]}),C.jsx("div",{className:"relative",children:d.map((p,v)=>{const _=n?v:e.length-o+v,T=p.data!=null,x=i[_],k=v===d.length-1,A=m(p);return C.jsxs("div",{className:"relative",children:[!k&&C.jsx("div",{className:"absolute left-[7px] top-5 w-px -mt-0.5",style:{backgroundColor:"var(--border-primary)",height:"calc(100% + 1px)"}}),C.jsxs("div",{className:"flex items-start gap-3 py-1.5",children:[C.jsx("div",{className:"flex-shrink-0 mt-0.5 flex items-center justify-center w-4 h-4",children:A?C.jsx(tG,{}):C.jsx(nG,{})}),C.jsxs("div",{className:"flex-1 min-w-0 flex items-start justify-between gap-2",children:[C.jsx("button",{type:"button",onClick:T?()=>f(_):void 0,disabled:!T,className:tv("flex-1 text-left text-sm leading-relaxed",T&&"cursor-pointer hover:opacity-80"),style:{color:"var(--text-secondary)"},children:p.step}),C.jsxs("div",{className:"flex items-center gap-2 flex-shrink-0",children:[p.result&&C.jsx("span",{className:"text-sm",style:{color:"var(--text-tertiary)"},children:p.result}),T&&C.jsx("button",{type:"button",onClick:()=>f(_),className:"p-1 -m-1 hover:opacity-70",style:{color:"var(--text-tertiary)"},children:C.jsx(Sb,{isOpen:x})})]})]})]}),T&&x&&C.jsx("div",{className:"ml-7 mt-1 mb-2",children:C.jsx("div",{className:"rounded-lg border px-2 prose prose-sm max-w-none overflow-x-auto",style:{borderColor:"var(--border-primary)",color:"var(--text-tertiary)"},children:C.jsx($l,{markdown:typeof p.data=="string"?p.data:"```json\n"+JSON.stringify(p.data,null,2)+"\n```",onSend:t})})})]},_)})})]})]})}const sG=ue.memo(function({part:t,onSend:n,isGenerating:r}){if(!t||!t.type)return null;if(t.type==="thinking")return C.jsx(iG,{thinking:t.thinking||"",onSend:n,isActive:r&&!t._complete,startTime:t._startTime,duration:t._duration});if(t.type==="steps")return C.jsx(aG,{steps:t.steps||[],onSend:n});let i="";switch(t.type){case"text":i=t.text||"";break;case"code":i="```"+(t.language||"")+`
`+(t.code||"")+"\n```";break;case"table":t.headers&&t.headers.length>0&&(i+="| "+t.headers.join(" | ")+` |
`,i+="| "+t.headers.map(()=>"---").join(" | ")+` |
`),t.rows&&t.rows.length>0&&t.rows.forEach(c=>{i+="| "+c.join(" | ")+` |
`});break;case"callout":i=`> ${{info:"ℹ️",success:"✅",warning:"⚠️",error:"❌"}[t.style||"info"]||"ℹ️"} **${t.title||t.style||"Info"}**
>
> ${t.callout||""}`;break;case"image":i=`![${t.alt||""}](${t.src})`,t.caption&&(i+=`

*${t.caption}*`);break;default:return console.warn("Unknown part type:",t.type),null}return C.jsx("div",{className:tv("prose prose-sm max-w-none","prose-headings:scroll-mt-24","prose-pre:p-0","theme-transition"),style:{color:"var(--text-primary)"},children:C.jsx($l,{markdown:i,onSend:n})})}),cS=ue.memo(({messages:e,onSend:t,onRegenerate:n,isGenerating:r,onRetry:i,retryingIndex:s})=>{const o=F.useMemo(()=>e.map((c,d)=>{if(c.type==="request"||c.role==="user"){const x=c.content||"",{clean:k,attachments:A}=m0(x),O=/[\u0591-\u07FF\uFB1D-\uFDFD\uFE70-\uFEFC]/.test(k);return C.jsx("div",{className:`flex mb-4 ${O?"justify-start":"justify-end"}`,children:C.jsxs("div",{className:"max-w-[85%] md:max-w-[75%]",children:[A.length>0&&C.jsx("div",{className:"mb-1",children:C.jsx(Z$,{attachments:A})}),k&&C.jsx("div",{className:"px-4 py-2 rounded-3xl shadow-sm theme-transition",style:{backgroundColor:"var(--msg-user-bg)",color:"var(--text-primary)"},children:C.jsx("div",{dir:"auto",className:"text-[15px] leading-relaxed whitespace-pre-wrap",children:k})})]})},d)}const m=(c.type==="response"||c.role==="assistant")&&d===e.length-1,p=m&&r,v=c.parts&&Array.isArray(c.parts),_=!v&&(c.content||c.content===""),T=v&&c.parts.length>0&&c.parts.some(x=>x.type==="text"&&x.text||x.type==="code"&&x.code||x.type==="table"&&x.headers)||_&&c.content&&c.content!=="";return C.jsx("div",{className:"flex mb-4 justify-start group",children:C.jsx("div",{className:"w-full",children:c.error?C.jsx(J$,{error:c.error,onRetry:()=>i(d),isRetrying:s===d}):C.jsxs(C.Fragment,{children:[v&&C.jsxs("div",{className:"space-y-2",children:[c.parts.map((x,k)=>C.jsx(sG,{part:x,onSend:t,isGenerating:p},k)),c.parts.length===0&&p&&C.jsx("div",{className:"h-4 w-32 rounded animate-pulse",style:{backgroundColor:"var(--bg-tertiary)"}})]}),_&&C.jsxs("div",{className:"prose prose-sm max-w-none",children:[C.jsx($l,{markdown:c.content,onSend:t}),c.content===""&&p&&C.jsx("div",{className:"h-4 w-32 rounded animate-pulse",style:{backgroundColor:"var(--bg-tertiary)"}})]}),T&&!p&&C.jsx(eG,{message:c,onRegenerate:()=>n(d),isLastAssistant:m&&!r})]})})},d)}),[e,t,n,r,i,s]);return C.jsx("div",{className:"space-y-1",children:o})});cS.displayName="MessageList";const lG=({file:e,onRemove:t})=>{const[n,r]=F.useState(null),i=e.type.startsWith("image/");return F.useEffect(()=>{if(!i)return;const s=new FileReader;s.onloadend=()=>r(String(s.result)),s.readAsDataURL(e)},[e,i]),C.jsxs("div",{className:"group inline-flex items-start gap-2 rounded-xl shadow-sm px-2.5 py-1 theme-transition",style:{backgroundColor:"var(--bg-primary)",border:"1px solid var(--border-primary)"},title:e.name,children:[C.jsx("div",{className:"w-10 h-10 rounded-md overflow-hidden flex items-center justify-center",style:{backgroundColor:"var(--bg-tertiary)"},children:i&&n?C.jsx("img",{src:n,alt:e.name,className:"w-full h-full object-cover"}):C.jsx("span",{className:"text-xs",children:"📄"})}),C.jsxs("div",{className:"min-w-0 leading-tight",children:[C.jsx("div",{className:"text-xs font-medium truncate max-w-[100px]",style:{color:"var(--text-primary)"},children:e.name}),C.jsx("div",{className:"text-xs text-left",style:{color:"var(--text-tertiary)"},children:ff(e.size)})]}),C.jsx("button",{onClick:t,className:"ml-1 h-5 w-5 rounded-full grid place-items-center hover:bg-[var(--bg-hover)] theme-transition",style:{backgroundColor:"var(--bg-tertiary)",color:"var(--text-secondary)"},"aria-label":"Remove attachment",children:C.jsx("svg",{width:"12",height:"12",viewBox:"0 0 12 12",fill:"none",children:C.jsx("path",{d:"M9 3L3 9M3 3L9 9",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round"})})})]})},oG=({error:e,onDismiss:t})=>(F.useEffect(()=>{const n=setTimeout(t,5e3);return()=>clearTimeout(n)},[t]),C.jsx("div",{className:"fixed bottom-40 left-1/2 transform -translate-x-1/2 bg-red-50 border border-red-200 rounded-xl shadow-lg px-4 py-3 min-w-[320px] max-w-[90vw] z-50 animate-in slide-in-from-bottom-2 duration-300",children:C.jsxs("div",{className:"flex items-start gap-3",children:[C.jsx("div",{className:"flex-shrink-0 mt-0.5",children:C.jsxs("svg",{className:"h-5 w-5 text-red-600",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",children:[C.jsx("circle",{cx:"12",cy:"12",r:"10"}),C.jsx("line",{x1:"12",y1:"8",x2:"12",y2:"12"}),C.jsx("line",{x1:"12",y1:"16",x2:"12.01",y2:"16"})]})}),C.jsxs("div",{className:"flex-1 min-w-0",children:[C.jsx("p",{className:"text-sm font-medium text-red-900",children:"Upload Error"}),C.jsx("p",{className:"text-sm text-red-700 mt-1",children:e})]}),C.jsx("button",{onClick:t,className:"flex-shrink-0 text-red-400 hover:text-red-600 transition-colors","aria-label":"Dismiss",children:C.jsx("svg",{width:"20",height:"20",viewBox:"0 0 20 20",fill:"currentColor",children:C.jsx("path",{fillRule:"evenodd",d:"M4.293 4.293a1 1 0 011.414 0L10 8.586l4.293-4.293a1 1 0 111.414 1.414L11.414 10l4.293 4.293a1 1 0 01-1.414 1.414L10 11.414l-4.293 4.293a1 1 0 01-1.414-1.414L8.586 10 4.293 5.707a1 1 0 010-1.414z",clipRule:"evenodd"})})})]})})),uG=({onSend:e,isLoading:t=!1,onStop:n,disabled:r=!1,onUpgradeClick:i,sidebarWidth:s=0})=>{const[o,c]=F.useState(""),[d,f]=F.useState([]),[m,p]=F.useState(!1),[v,_]=F.useState(null),[T,x]=F.useState(!1),k=F.useRef(null),A=F.useRef(null),O=F.useRef(0);F.useEffect(()=>{const te=()=>p(window.innerWidth<=768);return te(),window.addEventListener("resize",te),()=>window.removeEventListener("resize",te)},[]);const I=F.useCallback(te=>{if(r)return;const Y=[];for(const oe of te){const he=Q$(oe);if(he.valid)Y.push(oe);else{_(he.error);break}}Y.length>0&&f(oe=>[...oe,...Y])},[r]);F.useEffect(()=>{const te=Se=>{Se.preventDefault(),Se.stopPropagation(),!r&&(O.current++,Se.dataTransfer.types.includes("Files")&&x(!0))},Y=Se=>{Se.preventDefault(),Se.stopPropagation(),O.current--,O.current===0&&x(!1)},oe=Se=>{Se.preventDefault(),Se.stopPropagation()},he=Se=>{if(Se.preventDefault(),Se.stopPropagation(),x(!1),O.current=0,r)return;const fe=Array.from(Se.dataTransfer.files||[]);fe.length>0&&I(fe)};return document.addEventListener("dragenter",te),document.addEventListener("dragleave",Y),document.addEventListener("dragover",oe),document.addEventListener("drop",he),()=>{document.removeEventListener("dragenter",te),document.removeEventListener("dragleave",Y),document.removeEventListener("dragover",oe),document.removeEventListener("drop",he)}},[I,r]),F.useEffect(()=>{const te=Y=>{var fe;if(r||!(document.activeElement===A.current))return;const Se=Array.from(((fe=Y.clipboardData)==null?void 0:fe.items)||[]).filter(de=>de.type.startsWith("image/"));if(Se.length>0){Y.preventDefault();const de=Se.map(H=>H.getAsFile()).filter(H=>H!==null);de.length>0&&I(de)}};return document.addEventListener("paste",te),()=>document.removeEventListener("paste",te)},[I,r]);const $=()=>{var te;r||(te=k.current)==null||te.click()},V=te=>{if(r)return;const Y=Array.from(te.target.files||[]);I(Y),te.target.value=""},B=te=>f(Y=>Y.filter((oe,he)=>he!==te)),Z=async()=>{t||r||(e({text:o,files:d}),c(""),f([]))},ee=te=>{te.key==="Enter"&&!te.shiftKey&&!m&&!t&&!r&&(te.preventDefault(),Z())};return C.jsxs(C.Fragment,{children:[v&&C.jsx(oG,{error:v,onDismiss:()=>_(null)}),T&&!r&&C.jsx("div",{className:"fixed inset-0 z-50 backdrop-blur-sm flex items-center justify-center pointer-events-none",style:{backgroundColor:"var(--bg-overlay)"},children:C.jsx("div",{className:"rounded-2xl shadow-2xl p-8 max-w-md mx-4 border-2 border-dashed theme-transition",style:{backgroundColor:"var(--bg-primary)",borderColor:"var(--text-primary)"},children:C.jsxs("div",{className:"text-center",children:[C.jsx("div",{className:"mx-auto w-16 h-16 rounded-full flex items-center justify-center mb-4",style:{backgroundColor:"var(--bg-tertiary)"},children:C.jsx("svg",{className:"w-8 h-8",style:{color:"var(--text-primary)"},fill:"none",viewBox:"0 0 24 24",stroke:"currentColor",children:C.jsx("path",{strokeLinecap:"round",strokeLinejoin:"round",strokeWidth:2,d:"M7 16a4 4 0 01-.88-7.903A5 5 0 1115.9 6L16 6a5 5 0 011 9.9M15 13l-3-3m0 0l-3 3m3-3v12"})})}),C.jsx("h3",{className:"text-lg font-semibold mb-2",style:{color:"var(--text-primary)"},children:"Drop files to upload"}),C.jsx("p",{className:"text-sm",style:{color:"var(--text-secondary)"},children:"Images, PDFs, and text files supported"}),C.jsxs("p",{className:"text-xs mt-2",style:{color:"var(--text-tertiary)"},children:["Max ",ff(Qa.MAX_FILE_BYTES)," per file"]})]})})}),C.jsx("div",{className:"fixed right-0 z-40 transition-all duration-300 ease-in-out bottom-[max(0.75rem,env(safe-area-inset-bottom))] md:bottom-[max(1rem,env(safe-area-inset-bottom))]",style:{left:m?"0px":`${s}px`},children:C.jsxs("div",{className:"mx-auto max-w-3xl px-3 md:px-4",children:[C.jsxs("div",{className:`cursor-text rounded-3xl relative p-0 pt-1 backdrop-blur-xl w-full theme-transition ${r?"opacity-75":""}`,style:{backgroundColor:"var(--input-bg)",border:"1px solid var(--border-primary)"},children:[d.length>0&&C.jsx("div",{className:"px-3 pt-3",children:C.jsx("div",{className:"flex flex-wrap gap-2",children:d.map((te,Y)=>C.jsx(lG,{file:te,onRemove:()=>B(Y)},Y))})}),C.jsxs("div",{className:"px-3 pb-3 pt-2",children:[C.jsx("textarea",{ref:A,className:`w-full resize-none border-0 bg-transparent focus:ring-0 focus:outline-none text-base leading-6 max-h-40 mb-2 disabled:opacity-50 disabled:cursor-not-allowed ${r?"cursor-not-allowed":""}`,style:{color:"var(--text-primary)",caretColor:"var(--accent-primary)"},dir:"auto",autoFocus:!r,tabIndex:0,rows:Math.max(1,Math.min(6,o.split(`
`).length)),placeholder:r?"Upgrade to continue chatting...":t?"Waiting for response...":"What's on your mind?",onChange:te=>c(te.target.value),onKeyDown:ee,value:o,disabled:t||r}),C.jsxs("div",{className:"flex items-center gap-2",children:[C.jsx("button",{onClick:$,disabled:r,className:`rounded-full w-8 h-8 inline-flex items-center justify-center p-1 theme-transition ${r?"opacity-50 cursor-not-allowed":"hover:bg-[var(--bg-hover)] active:scale-[0.98]"}`,style:{backgroundColor:"var(--bg-primary)",border:"1px solid var(--border-primary)",color:"var(--text-primary)"},"aria-label":"Attach file",title:r?"Upgrade to attach files":"Attach files",children:C.jsx("svg",{xmlns:"http://www.w3.org/2000/svg",width:"20",height:"20",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round",children:C.jsx("path",{d:"m16 6-8.414 8.586a2 2 0 0 0 2.829 2.829l8.414-8.586a4 4 0 1 0-5.657-5.657l-8.379 8.551a6 6 0 1 0 8.485 8.485l8.379-8.551"})})}),C.jsx("input",{ref:k,type:"file",multiple:!0,className:"hidden",onChange:V,accept:".jpg,.jpeg,.png,.webp,.pdf,.txt,.md,.csv",disabled:r}),C.jsx("div",{className:"flex-1"}),t&&!r&&C.jsx("button",{onClick:n,className:"rounded-full hover:bg-[var(--bg-hover)] active:scale-95 transition-all inline-flex items-center justify-center w-8 h-8 flex-shrink-0 theme-transition",style:{backgroundColor:"var(--bg-primary)",border:"1px solid var(--border-primary)",color:"var(--text-primary)",boxShadow:"var(--shadow-sm)"},"aria-label":"Stop generating",title:"Stop",children:C.jsx("svg",{width:"18",height:"18",viewBox:"0 0 24 24",fill:"currentColor",children:C.jsx("rect",{x:"6",y:"6",width:"12",height:"12",rx:"2"})})}),r&&C.jsxs("button",{onClick:i,className:"rounded-full bg-gradient-to-r from-blue-600 to-indigo-600 text-white hover:from-blue-700 hover:to-indigo-700 active:scale-[0.98] transition-all inline-flex items-center justify-center gap-1.5 px-4 h-9 flex-shrink-0 shadow-md font-medium text-sm","aria-label":"Upgrade to continue",title:"Upgrade",children:[C.jsx("svg",{className:"w-4 h-4",fill:"currentColor",viewBox:"0 0 20 20",children:C.jsx("path",{fillRule:"evenodd",d:"M11.3 1.046A1 1 0 0112 2v5h4a1 1 0 01.82 1.573l-7 10A1 1 0 018 18v-5H4a1 1 0 01-.82-1.573l7-10a1 1 0 011.12-.38z",clipRule:"evenodd"})}),"Upgrade"]}),!t&&!r&&C.jsx("button",{onClick:Z,disabled:t,className:"rounded-full hover:opacity-90 active:scale-[0.98] inline-flex items-center justify-center w-9 h-9 flex-shrink-0 disabled:opacity-50 disabled:cursor-not-allowed disabled:active:scale-100 theme-transition",style:{backgroundColor:"var(--btn-primary-bg)",color:"var(--btn-primary-text)"},"aria-label":"Send message",title:"Send",children:C.jsx("svg",{width:"20",height:"20",viewBox:"0 0 20 20",fill:"currentColor",xmlns:"http://www.w3.org/2000/svg",children:C.jsx("path",{d:"M8.99992 16V6.41407L5.70696 9.70704C5.31643 10.0976 4.68342 10.0976 4.29289 9.70704C3.90237 9.31652 3.90237 8.6835 4.29289 8.29298L9.29289 3.29298L9.36907 3.22462C9.76184 2.90427 10.3408 2.92686 10.707 3.29298L15.707 8.29298L15.7753 8.36915C16.0957 8.76192 16.0731 9.34092 15.707 9.70704C15.3408 10.0732 14.7618 10.0958 14.3691 9.7754L14.2929 9.70704L10.9999 6.41407V16C10.9999 16.5523 10.5522 17 9.99992 17C9.44764 17 8.99992 16.5523 8.99992 16Z"})})})]})]})]}),r&&C.jsx("p",{className:"text-xs text-center mt-2",style:{color:"var(--text-tertiary)"},children:"You've reached your free message limit"})]})}),C.jsx("style",{children:`
        textarea::placeholder {
          color: var(--text-muted);
        }
      `})]})},cG=({fileName:e,progress:t})=>C.jsx("div",{className:"fixed bottom-40 left-1/2 transform -translate-x-1/2 rounded-xl shadow-lg px-4 py-3 min-w-[280px] theme-transition",style:{backgroundColor:"var(--bg-primary)",border:"1px solid var(--border-primary)",boxShadow:"var(--shadow-lg)"},children:C.jsxs("div",{className:"flex items-center gap-3",children:[C.jsx("div",{className:"flex-shrink-0",children:C.jsxs("svg",{className:"animate-spin h-5 w-5",style:{color:"var(--text-secondary)"},xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",children:[C.jsx("circle",{className:"opacity-25",cx:"12",cy:"12",r:"10",stroke:"currentColor",strokeWidth:"4"}),C.jsx("path",{className:"opacity-75",fill:"currentColor",d:"M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"})]})}),C.jsxs("div",{className:"flex-1 min-w-0",children:[C.jsx("p",{className:"text-sm font-medium truncate",style:{color:"var(--text-primary)"},children:e}),C.jsx("div",{className:"mt-1 w-full rounded-full h-1.5",style:{backgroundColor:"var(--bg-tertiary)"},children:C.jsx("div",{className:"h-1.5 rounded-full transition-all duration-300",style:{width:`${t}%`,backgroundColor:"var(--text-primary)"}})})]})]})}),mf={collapsed:56,expanded:275},hr=(...e)=>e.filter(Boolean).join(" "),F6=({children:e})=>C.jsx("span",{className:"grid place-items-center w-5 h-5",children:e}),H6=e=>C.jsxs("svg",{"aria-hidden":"true",viewBox:"0 0 24 24",className:hr("w-5 h-5",e==null?void 0:e.className),fill:"none",stroke:"currentColor",strokeWidth:"1.7",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("path",{d:"M12 3a9 9 0 1 1-6.22 15.5"}),C.jsx("path",{d:"M12 8v8"}),C.jsx("path",{d:"M16 12H8"})]}),j6=e=>C.jsxs("svg",{"aria-hidden":"true",viewBox:"0 0 24 24",className:hr("w-[18px] h-[18px]",e==null?void 0:e.className),fill:"none",stroke:"currentColor",strokeWidth:"1.7",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("rect",{x:"3",y:"3",width:"18",height:"18",rx:"2"}),C.jsx("path",{d:"M9 3v18"})]}),dG=e=>C.jsx("svg",{"aria-hidden":"true",viewBox:"0 0 24 24",className:hr("w-5 h-5",e==null?void 0:e.className),fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round",children:C.jsx("path",{d:"M10 7l5 5-5 5"})}),hG=e=>C.jsxs("svg",{"aria-hidden":"true",viewBox:"0 0 24 24",className:hr("w-4 h-4",e==null?void 0:e.className),fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("path",{d:"M3 6h18"}),C.jsx("path",{d:"M8 6V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2"}),C.jsx("path",{d:"M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6"}),C.jsx("path",{d:"M10 11v6"}),C.jsx("path",{d:"M14 11v6"})]}),fG=e=>C.jsxs("svg",{xmlns:"http://www.w3.org/2000/svg",width:"20",height:"20",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round",className:hr("lucide lucide-ellipsis-icon lucide-ellipsis",e==null?void 0:e.className),children:[C.jsx("circle",{cx:"12",cy:"12",r:"1"}),C.jsx("circle",{cx:"19",cy:"12",r:"1"}),C.jsx("circle",{cx:"5",cy:"12",r:"1"})]});function mG(e,t,n=!0){F.useEffect(()=>{if(!n)return;const r=i=>{(Array.isArray(e)?e:[e]).some(c=>(c==null?void 0:c.current)&&c.current.contains(i.target))||t(i)};return document.addEventListener("mousedown",r),document.addEventListener("touchstart",r,{passive:!0}),()=>{document.removeEventListener("mousedown",r),document.removeEventListener("touchstart",r)}},[e,t,n])}const pG=({icon:e,children:t,isCollapsed:n,...r})=>C.jsxs("button",{...r,className:hr("group w-full flex items-center gap-3 rounded-xl px-2.5 py-2 text-left","hover:bg-[var(--bg-hover)] active:bg-[var(--bg-active)]","focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20","theme-transition",n&&"justify-center px-2"),style:{color:"var(--text-primary)"},children:[C.jsx("span",{className:"shrink-0",style:{color:"var(--text-primary)"},children:e}),!n&&C.jsx("span",{className:"text-sm font-medium leading-5",children:t})]}),gG=({children:e})=>C.jsx("div",{className:"px-2.5 py-1.5 text-[11px] font-semibold tracking-wide uppercase",style:{color:"var(--text-tertiary)"},children:e}),bG=({chat:e,isActive:t,onSelect:n,onDelete:r})=>{const[i,s]=F.useState(!1),o=F.useRef(null),c=F.useRef(null),d=F.useId();return mG([o,c],()=>s(!1),i),C.jsxs("div",{className:"relative",children:[C.jsxs("button",{onClick:()=>n(e.id),className:hr("group w-full flex items-center gap-2 rounded-xl px-2.5 py-2 text-left","hover:bg-[var(--bg-hover)] active:bg-[var(--bg-active)]","focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20","theme-transition"),style:{backgroundColor:t?"var(--bg-active)":"transparent"},"aria-current":t?"page":void 0,children:[C.jsx("span",{className:"min-w-0 flex-1 truncate text-sm",style:{color:"var(--text-primary)"},children:e.title||"Untitled"}),C.jsx("button",{ref:c,type:"button",onClick:f=>{f.stopPropagation(),s(m=>!m)},className:hr("shrink-0 rounded-lg p-1.5","hover:bg-[var(--bg-hover)] active:bg-[var(--bg-active)]","opacity-0 group-hover:opacity-100 focus:opacity-100","focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20","theme-transition"),style:{color:"var(--text-tertiary)"},"aria-label":"Chat options","aria-haspopup":"menu","aria-expanded":i,"aria-controls":d,children:C.jsx(fG,{})})]}),i&&C.jsx("div",{id:d,ref:o,role:"menu",className:hr("absolute right-2 top-[calc(100%+6px)] z-50 min-w-[170px]","rounded-xl shadow-lg","overflow-hidden dropdown-menu"),style:{backgroundColor:"var(--bg-primary)",border:"1px solid var(--border-primary)"},children:C.jsxs("button",{role:"menuitem",onClick:f=>{f.stopPropagation(),r(e.id),s(!1)},className:hr("w-full flex items-center gap-2 px-3 py-2.5 text-sm","text-red-500 hover:bg-red-500/10 focus:bg-red-500/10","focus:outline-none theme-transition"),children:[C.jsx(hG,{}),"Delete"]})})]})},vG=({user:e,isOnPaidPlan:t,tierName:n,UserButtonComponent:r})=>{var o,c;const i=(e==null?void 0:e.fullName)||(e==null?void 0:e.firstName)||((c=(o=e==null?void 0:e.emailAddresses)==null?void 0:o[0])==null?void 0:c.emailAddress)||"User",s=t?n||"Pro":"Free plan";return C.jsxs("div",{className:"flex items-center gap-3 rounded-xl p-2 hover:bg-[var(--bg-hover)] transition-colors theme-transition",children:[C.jsx("div",{className:"shrink-0",children:r}),C.jsxs("div",{className:"min-w-0 flex-1",children:[C.jsx("div",{className:"truncate text-sm font-semibold",style:{color:"var(--text-primary)"},children:i}),C.jsx("div",{className:"truncate text-xs",style:{color:"var(--text-tertiary)"},children:s})]})]})},_G=({UserButtonComponent:e})=>C.jsx("div",{className:"grid place-items-center p-1",children:e}),yG=({isOpen:e,onClose:t,onToggle:n,chats:r,activeChat:i,onSelectChat:s,onNewChat:o,onDeleteChat:c,user:d,isOnPaidPlan:f,tierName:m,UserButtonComponent:p,isAuthenticated:v})=>{const _=F.useMemo(()=>[...r||[]].sort((k,A)=>new Date(A.updatedAt)-new Date(k.updatedAt)),[r]),T=F.useMemo(()=>{const k={today:[],yesterday:[],previous7Days:[],previous30Days:[],older:[]},A=new Date,O=new Date(A.getFullYear(),A.getMonth(),A.getDate()),I=new Date(O);I.setDate(I.getDate()-1);const $=new Date(O);$.setDate($.getDate()-7);const V=new Date(O);return V.setDate(V.getDate()-30),_.forEach(B=>{const Z=new Date(B.updatedAt);Z>=O?k.today.push(B):Z>=I?k.yesterday.push(B):Z>=$?k.previous7Days.push(B):Z>=V?k.previous30Days.push(B):k.older.push(B)}),k},[_]),x=(k,A)=>A!=null&&A.length?C.jsxs("div",{className:"mb-4",children:[C.jsx(gG,{children:k}),C.jsx("div",{className:"space-y-1",children:A.map(O=>C.jsx(bG,{chat:O,isActive:i===O.id,onSelect:s,onDelete:c},O.id))})]}):null;return C.jsxs(C.Fragment,{children:[C.jsx("div",{className:hr("fixed inset-0 z-40 md:hidden transition-opacity duration-300 ease-in-out",e?"opacity-100":"opacity-0 pointer-events-none"),style:{backgroundColor:"var(--bg-overlay)"},onClick:t,"aria-hidden":"true"}),C.jsxs("aside",{className:hr("fixed left-0 top-0 z-50 h-full","backdrop-blur supports-[backdrop-filter]:backdrop-blur-xl","transition-all duration-300 ease-in-out","flex flex-col",e?"translate-x-0":"-translate-x-full md:translate-x-0"),style:{width:`${e?mf.expanded:mf.collapsed}px`,backgroundColor:"var(--bg-sidebar)",borderRight:"1px solid var(--border-primary)"},children:[C.jsxs("div",{className:hr("flex h-full w-full flex-col","transition-opacity duration-200",e?"opacity-100":"opacity-0 pointer-events-none absolute inset-0"),children:[C.jsxs("div",{className:"flex h-14 items-center justify-between px-2",children:[C.jsxs("button",{onClick:o,className:hr("inline-flex items-center gap-2 rounded-xl px-2.5 py-2","hover:bg-[var(--bg-hover)] active:bg-[var(--bg-active)]","focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20","theme-transition"),style:{color:"var(--text-primary)"},"aria-label":"New chat",title:"New chat",children:[C.jsx(F6,{children:C.jsx(H6,{})}),C.jsx("span",{className:"text-sm font-semibold",children:"New"})]}),C.jsx("button",{onClick:n,className:hr("rounded-xl p-2 hover:bg-[var(--bg-hover)] active:bg-[var(--bg-active)]","focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20","theme-transition"),style:{color:"var(--text-primary)"},"aria-label":"Collapse sidebar",title:"Collapse",children:C.jsx(j6,{})})]}),C.jsx("div",{className:"mx-3",style:{borderTop:"1px solid var(--border-primary)"}}),C.jsx("div",{className:"flex-1 overflow-y-auto px-2 py-3 scrollbar-thin",children:_.length===0?C.jsx("div",{className:"px-2 py-10 text-center text-sm",style:{color:"var(--text-tertiary)"},children:"No chats yet"}):C.jsxs(C.Fragment,{children:[x("Today",T.today),x("Yesterday",T.yesterday),x("Previous 7 days",T.previous7Days),x("Previous 30 days",T.previous30Days),x("Older",T.older)]})}),C.jsx("div",{className:"p-2",style:{borderTop:"1px solid var(--border-primary)"},children:v&&d?C.jsx(vG,{user:d,isOnPaidPlan:f,tierName:m,UserButtonComponent:p}):C.jsxs("div",{className:"px-2 py-2 text-center text-xs",style:{color:"var(--text-tertiary)"},children:[r.length," / ",Qa.MAX_CHATS," chats"]})})]}),C.jsxs("div",{className:hr("hidden md:flex h-full w-full flex-col","transition-opacity duration-200",e?"opacity-0 pointer-events-none absolute inset-0":"opacity-100"),children:[C.jsx("div",{className:"flex h-14 items-center justify-center",children:C.jsx("button",{onClick:n,className:hr("rounded-xl p-2 hover:bg-[var(--bg-hover)] active:bg-[var(--bg-active)]","focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20","theme-transition"),style:{color:"var(--text-primary)"},"aria-label":"Expand sidebar",title:"Expand",children:C.jsx(j6,{})})}),C.jsx("div",{className:"px-1 py-2",children:C.jsx(pG,{onClick:o,icon:C.jsx(F6,{children:C.jsx(H6,{})}),isCollapsed:!0,"aria-label":"New chat",title:"New chat"})}),C.jsx("div",{className:"flex-1"}),v&&p&&C.jsx("div",{className:"p-2",style:{borderTop:"1px solid var(--border-primary)"},children:C.jsx(_G,{UserButtonComponent:p})})]})]}),C.jsx("button",{onClick:n,className:hr("fixed left-3 top-3 z-30 md:hidden","rounded-xl backdrop-blur","p-2 hover:bg-[var(--bg-hover)] active:bg-[var(--bg-active)]","focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20","theme-transition transition-opacity duration-300 ease-in-out",e?"opacity-0 pointer-events-none":"opacity-100"),style:{backgroundColor:"var(--bg-sidebar)",border:"1px solid var(--border-primary)",color:"var(--text-primary)"},"aria-label":"Open sidebar",title:"Open",children:C.jsx(dG,{})})]})},EG=({open:e,onClose:t,tier:n})=>e?C.jsx("div",{className:"fixed inset-0 z-50 flex items-center justify-center backdrop-blur-md px-4",style:{backgroundColor:"var(--bg-overlay)"},children:C.jsxs("div",{className:"relative w-full max-w-xl rounded-3xl shadow-2xl overflow-hidden theme-transition",style:{background:"linear-gradient(to bottom, var(--bg-primary), var(--bg-secondary))",border:"1px solid var(--border-primary)"},children:[C.jsx("div",{className:"absolute top-0 left-0 right-0 h-32 pointer-events-none opacity-50",style:{background:"linear-gradient(to bottom right, rgba(59, 130, 246, 0.1), rgba(99, 102, 241, 0.05), transparent)"}}),C.jsx("button",{type:"button",onClick:t,className:"absolute right-4 top-4 z-10 inline-flex h-9 w-9 items-center justify-center rounded-full backdrop-blur-sm transition-all duration-200 shadow-sm theme-transition",style:{backgroundColor:"var(--bg-primary)",border:"1px solid var(--border-primary)",color:"var(--text-tertiary)"},"aria-label":"Close",children:C.jsx("span",{className:"text-xl leading-none",children:"×"})}),C.jsxs("div",{className:"relative p-8 md:p-10",children:[C.jsxs("div",{className:"space-y-3 pr-8 mb-6",children:[C.jsxs("div",{className:"inline-flex items-center gap-2 px-3 py-1 rounded-full bg-blue-500/10 text-blue-500 border border-blue-500/20",children:[C.jsx("svg",{className:"w-3.5 h-3.5",fill:"currentColor",viewBox:"0 0 20 20",children:C.jsx("path",{fillRule:"evenodd",d:"M11.3 1.046A1 1 0 0112 2v5h4a1 1 0 01.82 1.573l-7 10A1 1 0 018 18v-5H4a1 1 0 01-.82-1.573l7-10a1 1 0 011.12-.38z",clipRule:"evenodd"})}),C.jsx("span",{className:"text-xs font-semibold uppercase tracking-wide",children:"Upgrade Available"})]}),C.jsxs("h2",{className:"text-2xl md:text-3xl font-bold leading-tight",style:{color:"var(--text-primary)"},children:["Unlock"," ",C.jsx("span",{className:"bg-gradient-to-r from-blue-600 to-indigo-600 bg-clip-text text-transparent",children:"Cycls Pass"})," ","features"]}),C.jsxs("p",{className:"text-base leading-relaxed",style:{color:"var(--text-secondary)"},children:["You've reached your free message limit. Upgrade to access the full"," ",C.jsx("span",{className:"font-semibold",style:{color:"var(--text-primary)"},children:"Cycls Pass"})," ","experience, priority AI, and unlimited messages."]})]}),C.jsx("div",{className:"relative -mx-2 mb-6",children:C.jsx("div",{className:"max-h-[420px] overflow-y-auto rounded-2xl backdrop-blur-sm shadow-inner scrollbar-thin",style:{backgroundColor:"var(--bg-tertiary)",border:"1px solid var(--border-primary)"},children:C.jsx(AO,{})})}),C.jsx("div",{className:"flex justify-end",children:C.jsx("button",{type:"button",onClick:t,className:"inline-flex items-center gap-2 rounded-xl px-5 py-2.5 text-sm font-medium transition-all duration-200 hover:bg-[var(--bg-hover)] theme-transition",style:{color:"var(--text-secondary)"},children:"Maybe later"})})]})]})}):null,dS=({isAuthenticated:e,isPublic:t=!1,meta:n={}})=>{const[r,i]=F.useState(window.location.pathname);return F.useEffect(()=>{const s=()=>i(window.location.pathname);window.addEventListener("popstate",s);const o=setInterval(s,100);return()=>{window.removeEventListener("popstate",s),clearInterval(o)}},[]),F.useEffect(()=>{const o=r==="/auth"||r.startsWith("/sign-in")||r.startsWith("/sign-up")||r.includes("clerk")||e&&!t;let c=document.querySelector('meta[name="robots"]');c||(c=document.createElement("meta"),c.setAttribute("name","robots"),document.head.appendChild(c)),o?c.setAttribute("content","noindex, nofollow"):c.setAttribute("content","index, follow");let d=document.querySelector('meta[name="googlebot"]');if(d||(d=document.createElement("meta"),d.setAttribute("name","googlebot"),document.head.appendChild(d)),o?d.setAttribute("content","noindex, nofollow"):d.setAttribute("content","index, follow"),n.title&&(document.title=n.title),n.description){let p=document.querySelector('meta[name="description"]');p||(p=document.createElement("meta"),p.setAttribute("name","description"),document.head.appendChild(p)),p.setAttribute("content",n.description)}let f=document.querySelector('link[rel="canonical"]');f||(f=document.createElement("link"),f.setAttribute("rel","canonical"),document.head.appendChild(f));const m=n.canonical||window.location.origin+r;return f.setAttribute("href",m),()=>{}},[r,e,t,n]),null},TG=({afterUrl:e})=>{const t=us(),{resolvedTheme:n}=W5(),r=t.hash==="#sign-up/"||t.hash==="#sign-up"?"sign-up":"sign-in",i={elements:{card:"shadow-none border-none",footer:"hidden",formButtonPrimary:"py-2.5 rounded-lg transition-colors",formFieldInput:"border-gray-300 focus:border-blue-500 focus:ring-blue-500 rounded-lg",formFieldLabel:"text-gray-700 font-medium text-sm",dividerLine:"bg-gray-200",dividerText:"text-gray-500 text-sm"}};return C.jsxs("div",{className:"min-h-screen flex items-center justify-center px-4 theme-transition",style:{backgroundColor:"var(--bg-secondary)"},children:[C.jsx(dS,{isAuthenticated:!1,isPublic:!1,meta:{title:"Sign In",description:"Authentication page"}}),C.jsx("div",{className:"fixed top-4 right-4",children:C.jsx(X5,{})}),C.jsx("div",{className:"w-full max-w-md",children:r==="sign-in"?C.jsxs("div",{className:"space-y-4",children:[C.jsx(bO,{routing:"virtual",fallbackRedirectUrl:e,signUpUrl:"#sign-up",appearance:i}),C.jsx("div",{style:{marginLeft:"-30px"},className:"text-center",children:C.jsxs("p",{className:"text-sm",style:{color:"var(--text-secondary)"},children:["Don't have an account?"," ",C.jsx("a",{href:"#sign-up/",className:"font-medium hover:underline transition-colors",style:{color:"var(--accent-primary)"},children:"Sign up"})]})})]}):C.jsxs("div",{className:"space-y-4",children:[C.jsx(vO,{routing:"virtual",fallbackRedirectUrl:e,signInUrl:"#sign-in",appearance:i}),C.jsx("div",{style:{marginLeft:"-40px"},className:"text-center",children:C.jsxs("p",{className:"text-sm",style:{color:"var(--text-secondary)"},children:["Already have an account?"," ",C.jsx("a",{href:"#sign-in/",className:"font-medium hover:underline transition-colors",style:{color:"var(--accent-primary)"},children:"Sign in"})]})})]})})]})},xG=({children:e})=>C.jsxs(C.Fragment,{children:[C.jsx(lO,{children:e}),C.jsx(oO,{children:C.jsx(h8,{to:"/auth",replace:!0})})]});rn(({clerk:e,children:t,...n})=>{const{planId:r,planPeriod:i,for:s,onSubscriptionComplete:o,newSubscriptionRedirectUrl:c,checkoutProps:d,...f}=n,{userId:m,orgId:p}=x0();if(m===null)throw new Error("Clerk: Ensure that `<CheckoutButton />` is rendered inside a `<SignedIn />` component.");if(p===null&&s==="organization")throw new Error('Clerk: Wrap `<CheckoutButton for="organization" />` with a check for an active organization. Retrieve `orgId` from `useAuth()` and confirm it is defined. For SSR, see: https://clerk.com/docs/reference/backend/types/auth-object#how-to-access-the-auth-object');t=Kl(t,"Checkout");const v=Vl(t)("CheckoutButton"),_=()=>{if(e)return e.__internal_openCheckout({planId:r,planPeriod:i,for:s,onSubscriptionComplete:o,newSubscriptionRedirectUrl:c,...d})},x={...f,onClick:async k=>(v&&typeof v=="object"&&"props"in v&&await Wl(v.props.onClick)(k),_())};return ue.cloneElement(v,x)},{component:"CheckoutButton",renderWhileLoading:!0});rn(({clerk:e,children:t,...n})=>{const{plan:r,planId:i,initialPlanPeriod:s,planDetailsProps:o,...c}=n;t=Kl(t,"Plan details");const d=Vl(t)("PlanDetailsButton"),f=()=>{if(e)return e.__internal_openPlanDetails({plan:r,planId:i,initialPlanPeriod:s,...o})},p={...c,onClick:async v=>(d&&typeof d=="object"&&"props"in d&&await Wl(d.props.onClick)(v),f())};return ue.cloneElement(d,p)},{component:"PlanDetailsButton",renderWhileLoading:!0});rn(({clerk:e,children:t,...n})=>{const{for:r,subscriptionDetailsProps:i,onSubscriptionCancel:s,...o}=n;t=Kl(t,"Subscription details");const c=Vl(t)("SubscriptionDetailsButton"),{userId:d,orgId:f}=x0();if(d===null)throw new Error("Clerk: Ensure that `<SubscriptionDetailsButton />` is rendered inside a `<SignedIn />` component.");if(f===null&&r==="organization")throw new Error('Clerk: Wrap `<SubscriptionDetailsButton for="organization" />` with a check for an active organization. Retrieve `orgId` from `useAuth()` and confirm it is defined. For SSR, see: https://clerk.com/docs/reference/backend/types/auth-object#how-to-access-the-auth-object');const m=()=>{if(e)return e.__internal_openSubscriptionDetails({for:r,onSubscriptionCancel:s,...i})},v={...o,onClick:async _=>(c&&typeof c=="object"&&"props"in c&&await Wl(c.props.onClick)(_),m())};return ue.cloneElement(c,v)},{component:"SubscriptionDetailsButton",renderWhileLoading:!0});const hS=F.createContext({subscription:null,isLoading:!1,error:null,revalidate:()=>{}}),SG=()=>F.useContext(hS),wG=({tier:e,children:t})=>{const{data:n,isLoading:r,error:i,revalidate:s}=CN({enabled:e==="cycls_pass"}),o=F.useMemo(()=>({subscription:n,isLoading:r,error:i,revalidate:s}),[n,r,i,s]);return C.jsx(hS.Provider,{value:o,children:t})};async function AG(e,t,{signal:n}={}){const r=e.body.getReader(),i=new TextDecoder;let s="";for(;;){if(n!=null&&n.aborted)throw new DOMException("Aborted","AbortError");const{value:o,done:c}=await r.read();if(c)break;if(o){const d=i.decode(o,{stream:!0});s+=d;let f;for(;(f=s.indexOf(`
`))!==-1;){const m=s.slice(0,f).trim();if(s=s.slice(f+1),!m||!m.startsWith("data: "))continue;const p=m.slice(6);if(p==="[DONE]")return;try{const v=JSON.parse(p);t(v)}catch(v){console.error("Failed to parse SSE payload:",v,p)}}}}}async function kG(e){const t=await fetch("/config",{method:"GET",credentials:"include",signal:e});if(!t.ok)throw new Error("Metadata request failed: "+t.status);return t.json()}async function wb({messages:e,auth:t,getToken:n,setActive:r,org:i,onPart:s,signal:o}){const c=e.map(({role:m,content:p,parts:v})=>{if(m){if(v){const $=v.map(V=>V.type==="text"?V.text:V.type==="thinking"?`<thinking>${V.thinking}</thinking>`:V.type==="code"?"```"+(V.language||"")+`
`+V.code+"\n```":"").join(`

`);return{role:m,content:$}}const{clean:A,attachments:O}=m0(p);if(O.length===0)return{role:m,content:A};const I=[];A.trim()&&I.push({type:"text",text:A});for(const $ of O)$.mime&&$.mime.startsWith("image/")?I.push({type:"image_url",image_url:{url:$.url}}):I.push({type:"file",text:"[File attached: "+$.name+`]
File URL: `+$.url+`
File type: `+($.mime||"unknown")});return{role:m,content:I}}const _=m||(e.type==="request"?"user":"assistant"),{clean:T,attachments:x}=m0(p);if(x.length===0)return{role:_,content:T};const k=[];T.trim()&&k.push({type:"text",text:T});for(const A of x)A.mime&&A.mime.startsWith("image/")?k.push({type:"image_url",image_url:{url:A.url}}):k.push({type:"file",text:"[File attached: "+A.name+`]
File URL: `+A.url+`
File type: `+(A.mime||"unknown")});return{role:_,content:k}}),d={"Content-Type":"application/json"};if(t&&n)try{const m=await n({template:"template"});if(m&&(d.Authorization="Bearer "+m),r&&i)try{await r({organization:i})}catch{}}catch{}const f=await fetch("/chat/cycls",{method:"POST",headers:d,body:JSON.stringify({messages:c}),signal:o});if(!f.ok){let m="server",p="Server returned "+f.status;if(f.status===429){m="rate_limit";const v=f.headers.get("Retry-After");p=v?"Too many requests. Please try again in "+v+" seconds.":"Too many requests. Please wait a moment and try again."}else f.status>=500?p="Server error. Please try again later.":(f.status===401||f.status===403)&&(p="Authentication error. Please refresh and try again.");throw{type:m,status:f.status,message:p}}await AG(f,s,{signal:o})}const bg="cycls_chat_history",Ch="cycls_active_chat",nv="cycls_message_count";function fS(){try{const e=localStorage.getItem(nv);return e?parseInt(e,10):0}catch{return 0}}function CG(){try{const e=fS();return localStorage.setItem(nv,String(e+1)),e+1}catch{return 0}}function NG(){try{localStorage.removeItem(nv)}catch{}}class lr{static getAllChats(){try{const t=localStorage.getItem(bg);return t?JSON.parse(t):[]}catch(t){return console.error("Error loading chat history:",t),[]}}static saveAllChats(t){try{localStorage.setItem(bg,JSON.stringify(t))}catch(n){console.error("Error saving chat history:",n)}}static getActiveChat(){try{return localStorage.getItem(Ch)}catch{return null}}static setActiveChat(t){try{localStorage.setItem(Ch,t)}catch(n){console.error("Error saving active chat:",n)}}static createChat(t=[]){const n=this.getAllChats(),r={id:Date.now().toString(),title:this.generateTitle(t),messages:t,createdAt:new Date().toISOString(),updatedAt:new Date().toISOString()};return n.length>=Qa.MAX_CHATS&&(n.sort((i,s)=>new Date(i.createdAt)-new Date(s.createdAt)),n.shift()),n.push(r),this.saveAllChats(n),this.setActiveChat(r.id),r}static updateChat(t,n){const r=this.getAllChats(),i=r.findIndex(s=>s.id===t);i!==-1&&(r[i].messages=n,r[i].updatedAt=new Date().toISOString(),r[i].title=this.generateTitle(n),this.saveAllChats(r))}static deleteChat(t){const r=this.getAllChats().filter(i=>i.id!==t);this.saveAllChats(r),this.getActiveChat()===t&&localStorage.removeItem(Ch)}static getChat(t){return this.getAllChats().find(r=>r.id===t)}static generateTitle(t){if(!t||t.length===0)return"New Chat";const n=t.find(s=>s.type==="request"||s.role==="user");if(!n)return"New Chat";const{clean:r}=m0(n.content);return r.trim().slice(0,50)||"New Chat"}static clearAll(){try{localStorage.removeItem(bg),localStorage.removeItem(Ch)}catch(t){console.error("Error clearing chat history:",t)}}}var ge=typeof window<"u"?window:void 0,Tr=typeof globalThis<"u"?globalThis:ge;typeof self>"u"&&(Tr.self=Tr),typeof File>"u"&&(Tr.File=function(){});var mS=Array.prototype,q6=mS.forEach,$6=mS.indexOf,yi=Tr==null?void 0:Tr.navigator,qe=Tr==null?void 0:Tr.document,ii=Tr==null?void 0:Tr.location,Ab=Tr==null?void 0:Tr.fetch,kb=Tr!=null&&Tr.XMLHttpRequest&&"withCredentials"in new Tr.XMLHttpRequest?Tr.XMLHttpRequest:void 0,G6=Tr==null?void 0:Tr.AbortController,ni=yi==null?void 0:yi.userAgent,it=ge??{},$a={DEBUG:!1,LIB_VERSION:"1.333.0"};function Y6(e,t,n,r,i,s,o){try{var c=e[s](o),d=c.value}catch(f){return void n(f)}c.done?t(d):Promise.resolve(d).then(r,i)}function Qo(e){return function(){var t=this,n=arguments;return new Promise((function(r,i){var s=e.apply(t,n);function o(d){Y6(s,r,i,o,c,"next",d)}function c(d){Y6(s,r,i,o,c,"throw",d)}o(void 0)}))}}function Ve(){return Ve=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Ve.apply(null,arguments)}function pS(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}var OG=["amazonbot","amazonproductbot","app.hypefactors.com","applebot","archive.org_bot","awariobot","backlinksextendedbot","baiduspider","bingbot","bingpreview","chrome-lighthouse","dataforseobot","deepscan","duckduckbot","facebookexternal","facebookcatalog","http://yandex.com/bots","hubspot","ia_archiver","leikibot","linkedinbot","meta-externalagent","mj12bot","msnbot","nessus","petalbot","pinterest","prerender","rogerbot","screaming frog","sebot-wa","sitebulb","slackbot","slurp","trendictionbot","turnitin","twitterbot","vercel-screenshot","vercelbot","yahoo! slurp","yandexbot","zoombot","bot.htm","bot.php","(bot;","bot/","crawler","ahrefsbot","ahrefssiteaudit","semrushbot","siteauditbot","splitsignalbot","gptbot","oai-searchbot","chatgpt-user","perplexitybot","better uptime bot","sentryuptimebot","uptimerobot","headlesschrome","cypress","google-hoteladsverifier","adsbot-google","apis-google","duplexweb-google","feedfetcher-google","google favicon","google web preview","google-read-aloud","googlebot","googleother","google-cloudvertexbot","googleweblight","mediapartners-google","storebot-google","google-inspectiontool","bytespider"],V6=function(e,t){if(t===void 0&&(t=[]),!e)return!1;var n=e.toLowerCase();return OG.concat(t).some((r=>{var i=r.toLowerCase();return n.indexOf(i)!==-1}))},RG=["$snapshot","$pageview","$pageleave","$set","survey dismissed","survey sent","survey shown","$identify","$groupidentify","$create_alias","$$client_ingestion_warning","$web_experiment_applied","$feature_enrollment_update","$feature_flag_called"];function Dt(e,t){return e.indexOf(t)!==-1}var im=function(e){return e.trim()},Cb=function(e){return e.replace(/^\$/,"")},MG=Array.isArray,gS=Object.prototype,bS=gS.hasOwnProperty,am=gS.toString,Qt=MG||function(e){return am.call(e)==="[object Array]"},nl=e=>typeof e=="function",fr=e=>e===Object(e)&&!Qt(e),Zo=e=>{if(fr(e)){for(var t in e)if(bS.call(e,t))return!1;return!0}return!1},He=e=>e===void 0,or=e=>am.call(e)=="[object String]",Nb=e=>or(e)&&e.trim().length===0,Qi=e=>e===null,Wt=e=>He(e)||Qi(e),os=e=>am.call(e)=="[object Number]"&&e==e,Ko=e=>os(e)&&e>0,ns=e=>am.call(e)==="[object Boolean]",IG=e=>e instanceof FormData,DG=e=>Dt(RG,e);function Ob(e){return e===null||typeof e!="object"}function pf(e,t){return Object.prototype.toString.call(e)==="[object "+t+"]"}function vS(e){return!He(Event)&&(function(t,n){try{return t instanceof n}catch{return!1}})(e,Event)}var LG=[!0,"true",1,"1","yes"],vg=e=>Dt(LG,e),PG=[!1,"false",0,"0","no"];function fa(e,t,n,r,i){return t>n&&(r.warn("min cannot be greater than max."),t=n),os(e)?e>n?(r.warn(" cannot be  greater than max: "+n+". Using max value instead."),n):e<t?(r.warn(" cannot be less than min: "+t+". Using min value instead."),t):e:(r.warn(" must be a number. using max or fallback. max: "+n+", fallback: "+i),fa(i||n,t,n,r))}class BG{constructor(t){this.t={},this.i=t.i,this.o=fa(t.bucketSize,0,100,t.h),this.m=fa(t.refillRate,0,this.o,t.h),this.$=fa(t.refillInterval,0,864e5,t.h)}S(t,n){var r=n-t.lastAccess,i=Math.floor(r/this.$);if(i>0){var s=i*this.m;t.tokens=Math.min(t.tokens+s,this.o),t.lastAccess=t.lastAccess+i*this.$}}consumeRateLimit(t){var n,r=Date.now(),i=String(t),s=this.t[i];return s?this.S(s,r):(s={tokens:this.o,lastAccess:r},this.t[i]=s),s.tokens===0||(s.tokens--,s.tokens===0&&((n=this.i)==null||n.call(this,t)),s.tokens===0)}stop(){this.t={}}}var Ui="Mobile",gf="iOS",Za="Android",p0="Tablet",_S=Za+" "+p0,yS="iPad",ES="Apple",TS=ES+" Watch",g0="Safari",ou="BlackBerry",xS="Samsung",SS=xS+"Browser",wS=xS+" Internet",Gl="Chrome",UG=Gl+" OS",AS=Gl+" "+gf,rv="Internet Explorer",kS=rv+" "+Ui,iv="Opera",zG=iv+" Mini",av="Edge",CS="Microsoft "+av,nu="Firefox",NS=nu+" "+gf,b0="Nintendo",v0="PlayStation",ru="Xbox",OS=Za+" "+Ui,RS=Ui+" "+g0,zc="Windows",Rb=zc+" Phone",K6="Nokia",Mb="Ouya",MS="Generic",FG=MS+" "+Ui.toLowerCase(),IS=MS+" "+p0.toLowerCase(),Ib="Konqueror",Pr="(\\d+(\\.\\d+)?)",_g=new RegExp("Version/"+Pr),HG=new RegExp(ru,"i"),jG=new RegExp(v0+" \\w+","i"),qG=new RegExp(b0+" \\w+","i"),sv=new RegExp(ou+"|PlayBook|BB10","i"),$G={"NT3.51":"NT 3.11","NT4.0":"NT 4.0","5.0":"2000",5.1:"XP",5.2:"XP","6.0":"Vista",6.1:"7",6.2:"8",6.3:"8.1",6.4:"10","10.0":"10"},Nh,W6,yg,GG=(e,t)=>t&&Dt(t,ES)||(function(n){return Dt(n,g0)&&!Dt(n,Gl)&&!Dt(n,Za)})(e),DS=function(e,t){return t=t||"",Dt(e," OPR/")&&Dt(e,"Mini")?zG:Dt(e," OPR/")?iv:sv.test(e)?ou:Dt(e,"IE"+Ui)||Dt(e,"WPDesktop")?kS:Dt(e,SS)?wS:Dt(e,av)||Dt(e,"Edg/")?CS:Dt(e,"FBIOS")?"Facebook "+Ui:Dt(e,"UCWEB")||Dt(e,"UCBrowser")?"UC Browser":Dt(e,"CriOS")?AS:Dt(e,"CrMo")||Dt(e,Gl)?Gl:Dt(e,Za)&&Dt(e,g0)?OS:Dt(e,"FxiOS")?NS:Dt(e.toLowerCase(),Ib.toLowerCase())?Ib:GG(e,t)?Dt(e,Ui)?RS:g0:Dt(e,nu)?nu:Dt(e,"MSIE")||Dt(e,"Trident/")?rv:Dt(e,"Gecko")?nu:""},YG={[kS]:[new RegExp("rv:"+Pr)],[CS]:[new RegExp(av+"?\\/"+Pr)],[Gl]:[new RegExp("("+Gl+"|CrMo)\\/"+Pr)],[AS]:[new RegExp("CriOS\\/"+Pr)],"UC Browser":[new RegExp("(UCBrowser|UCWEB)\\/"+Pr)],[g0]:[_g],[RS]:[_g],[iv]:[new RegExp("(Opera|OPR)\\/"+Pr)],[nu]:[new RegExp(nu+"\\/"+Pr)],[NS]:[new RegExp("FxiOS\\/"+Pr)],[Ib]:[new RegExp("Konqueror[:/]?"+Pr,"i")],[ou]:[new RegExp(ou+" "+Pr),_g],[OS]:[new RegExp("android\\s"+Pr,"i")],[wS]:[new RegExp(SS+"\\/"+Pr)],[rv]:[new RegExp("(rv:|MSIE )"+Pr)],Mozilla:[new RegExp("rv:"+Pr)]},VG=function(e,t){var n=DS(e,t),r=YG[n];if(He(r))return null;for(var i=0;i<r.length;i++){var s=r[i],o=e.match(s);if(o)return parseFloat(o[o.length-2])}return null},X6=[[new RegExp(ru+"; "+ru+" (.*?)[);]","i"),e=>[ru,e&&e[1]||""]],[new RegExp(b0,"i"),[b0,""]],[new RegExp(v0,"i"),[v0,""]],[sv,[ou,""]],[new RegExp(zc,"i"),(e,t)=>{if(/Phone/.test(t)||/WPDesktop/.test(t))return[Rb,""];if(new RegExp(Ui).test(t)&&!/IEMobile\b/.test(t))return[zc+" "+Ui,""];var n=/Windows NT ([0-9.]+)/i.exec(t);if(n&&n[1]){var r=n[1],i=$G[r]||"";return/arm/i.test(t)&&(i="RT"),[zc,i]}return[zc,""]}],[/((iPhone|iPad|iPod).*?OS (\d+)_(\d+)_?(\d+)?|iPhone)/,e=>{if(e&&e[3]){var t=[e[3],e[4],e[5]||"0"];return[gf,t.join(".")]}return[gf,""]}],[/(watch.*\/(\d+\.\d+\.\d+)|watch os,(\d+\.\d+),)/i,e=>{var t="";return e&&e.length>=3&&(t=He(e[2])?e[3]:e[2]),["watchOS",t]}],[new RegExp("("+Za+" (\\d+)\\.(\\d+)\\.?(\\d+)?|"+Za+")","i"),e=>{if(e&&e[2]){var t=[e[2],e[3],e[4]||"0"];return[Za,t.join(".")]}return[Za,""]}],[/Mac OS X (\d+)[_.](\d+)[_.]?(\d+)?/i,e=>{var t=["Mac OS X",""];if(e&&e[1]){var n=[e[1],e[2],e[3]||"0"];t[1]=n.join(".")}return t}],[/Mac/i,["Mac OS X",""]],[/CrOS/,[UG,""]],[/Linux|debian/i,["Linux",""]]],Q6=function(e){return qG.test(e)?b0:jG.test(e)?v0:HG.test(e)?ru:new RegExp(Mb,"i").test(e)?Mb:new RegExp("("+Rb+"|WPDesktop)","i").test(e)?Rb:/iPad/.test(e)?yS:/iPod/.test(e)?"iPod Touch":/iPhone/.test(e)?"iPhone":/(watch)(?: ?os[,/]|\d,\d\/)[\d.]+/i.test(e)?TS:sv.test(e)?ou:/(kobo)\s(ereader|touch)/i.test(e)?"Kobo":new RegExp(K6,"i").test(e)?K6:/(kf[a-z]{2}wi|aeo[c-r]{2})( bui|\))/i.test(e)||/(kf[a-z]+)( bui|\)).+silk\//i.test(e)?"Kindle Fire":/(Android|ZTE)/i.test(e)?new RegExp(Ui).test(e)&&!/(9138B|TB782B|Nexus [97]|pixel c|HUAWEISHT|BTV|noble nook|smart ultra 6)/i.test(e)||/pixel[\daxl ]{1,6}/i.test(e)&&!/pixel c/i.test(e)||/(huaweimed-al00|tah-|APA|SM-G92|i980|zte|U304AA)/i.test(e)||/lmy47v/i.test(e)&&!/QTAQZ3/i.test(e)?Za:_S:new RegExp("(pda|"+Ui+")","i").test(e)?FG:new RegExp(p0,"i").test(e)&&!new RegExp(p0+" pc","i").test(e)?IS:""},KG=e=>e instanceof Error;function WG(e){var t=globalThis._posthogChunkIds;if(t){var n=Object.keys(t);return yg&&n.length===W6||(W6=n.length,yg=n.reduce(((r,i)=>{Nh||(Nh={});var s=Nh[i];if(s)r[s[0]]=s[1];else for(var o=e(i),c=o.length-1;c>=0;c--){var d=o[c],f=d==null?void 0:d.filename,m=t[i];if(f&&m){r[f]=m,Nh[i]=[f,m];break}}return r}),{})),yg}}class XG{constructor(t,n,r){r===void 0&&(r=[]),this.coercers=t,this.stackParser=n,this.modifiers=r}buildFromUnknown(t,n){n===void 0&&(n={});var r=n&&n.mechanism||{handled:!0,type:"generic"},i=this.buildCoercingContext(r,n,0).apply(t),s=this.buildParsingContext(),o=this.parseStacktrace(i,s);return{$exception_list:this.convertToExceptionList(o,r),$exception_level:"error"}}modifyFrames(t){var n=this;return Qo((function*(){for(var r of t)r.stacktrace&&r.stacktrace.frames&&Qt(r.stacktrace.frames)&&(r.stacktrace.frames=yield n.applyModifiers(r.stacktrace.frames));return t}))()}coerceFallback(t){var n;return{type:"Error",value:"Unknown error",stack:(n=t.syntheticException)==null?void 0:n.stack,synthetic:!0}}parseStacktrace(t,n){var r,i;return t.cause!=null&&(r=this.parseStacktrace(t.cause,n)),t.stack!=""&&t.stack!=null&&(i=this.applyChunkIds(this.stackParser(t.stack,t.synthetic?1:0),n.chunkIdMap)),Ve({},t,{cause:r,stack:i})}applyChunkIds(t,n){return t.map((r=>(r.filename&&n&&(r.chunk_id=n[r.filename]),r)))}applyCoercers(t,n){for(var r of this.coercers)if(r.match(t))return r.coerce(t,n);return this.coerceFallback(n)}applyModifiers(t){var n=this;return Qo((function*(){var r=t;for(var i of n.modifiers)r=yield i(r);return r}))()}convertToExceptionList(t,n){var r,i,s,o={type:t.type,value:t.value,mechanism:{type:(r=n.type)!==null&&r!==void 0?r:"generic",handled:(i=n.handled)===null||i===void 0||i,synthetic:(s=t.synthetic)!==null&&s!==void 0&&s}};t.stack&&(o.stacktrace={type:"raw",frames:t.stack});var c=[o];return t.cause!=null&&c.push(...this.convertToExceptionList(t.cause,Ve({},n,{handled:!0}))),c}buildParsingContext(){return{chunkIdMap:WG(this.stackParser)}}buildCoercingContext(t,n,r){r===void 0&&(r=0);var i=(s,o)=>{if(o<=4){var c=this.buildCoercingContext(t,n,o);return this.applyCoercers(s,c)}};return Ve({},n,{syntheticException:r==0?n.syntheticException:void 0,mechanism:t,apply:s=>i(s,r),next:s=>i(s,r+1)})}}var uu="?";function Db(e,t,n,r,i){var s={platform:e,filename:t,function:n==="<anonymous>"?uu:n,in_app:!0};return He(r)||(s.lineno=r),He(i)||(s.colno=i),s}var LS=(e,t)=>{var n=e.indexOf("safari-extension")!==-1,r=e.indexOf("safari-web-extension")!==-1;return n||r?[e.indexOf("@")!==-1?e.split("@")[0]:uu,n?"safari-extension:"+t:"safari-web-extension:"+t]:[e,t]},QG=/^\s*at (\S+?)(?::(\d+))(?::(\d+))\s*$/i,ZG=/^\s*at (?:(.+?\)(?: \[.+\])?|.*?) ?\((?:address at )?)?(?:async )?((?:<anonymous>|[-a-z]+:|.*bundle|\/)?.*?)(?::(\d+))?(?::(\d+))?\)?\s*$/i,JG=/\((\S*)(?::(\d+))(?::(\d+))\)/,eY=(e,t)=>{var n=QG.exec(e);if(n){var[,r,i,s]=n;return Db(t,r,uu,+i,+s)}var o=ZG.exec(e);if(o){if(o[2]&&o[2].indexOf("eval")===0){var c=JG.exec(o[2]);c&&(o[2]=c[1],o[3]=c[2],o[4]=c[3])}var[d,f]=LS(o[1]||uu,o[2]);return Db(t,f,d,o[3]?+o[3]:void 0,o[4]?+o[4]:void 0)}},tY=/^\s*(.*?)(?:\((.*?)\))?(?:^|@)?((?:[-a-z]+)?:\/.*?|\[native code\]|[^@]*(?:bundle|\d+\.js)|\/[\w\-. /=]+)(?::(\d+))?(?::(\d+))?\s*$/i,nY=/(\S+) line (\d+)(?: > eval line \d+)* > eval/i,rY=(e,t)=>{var n=tY.exec(e);if(n){if(n[3]&&n[3].indexOf(" > eval")>-1){var r=nY.exec(n[3]);r&&(n[1]=n[1]||"eval",n[3]=r[1],n[4]=r[2],n[5]="")}var i=n[3],s=n[1]||uu;return[s,i]=LS(s,i),Db(t,i,s,n[4]?+n[4]:void 0,n[5]?+n[5]:void 0)}},Z6=/\(error: (.*)\)/,J6=50;function iY(){return(function(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];return function(i,s){s===void 0&&(s=0);for(var o=[],c=i.split(`
`),d=s;d<c.length;d++){var f=c[d];if(!(f.length>1024)){var m=Z6.test(f)?f.replace(Z6,"$1"):f;if(!m.match(/\S*Error: /)){for(var p of n){var v=p(m,e);if(v){o.push(v);break}}if(o.length>=J6)break}}}return(function(_){if(!_.length)return[];var T=Array.from(_);return T.reverse(),T.slice(0,J6).map((x=>{return Ve({},x,{filename:x.filename||(k=T,k[k.length-1]||{}).filename,function:x.function||uu});var k}))})(o)}})("web:javascript",eY,rY)}class aY{match(t){return this.isDOMException(t)||this.isDOMError(t)}coerce(t,n){var r=or(t.stack);return{type:this.getType(t),value:this.getValue(t),stack:r?t.stack:void 0,cause:t.cause?n.next(t.cause):void 0,synthetic:!1}}getType(t){return this.isDOMError(t)?"DOMError":"DOMException"}getValue(t){var n=t.name||(this.isDOMError(t)?"DOMError":"DOMException");return t.message?n+": "+t.message:n}isDOMException(t){return pf(t,"DOMException")}isDOMError(t){return pf(t,"DOMError")}}class sY{match(t){return(n=>n instanceof Error)(t)}coerce(t,n){return{type:this.getType(t),value:this.getMessage(t,n),stack:this.getStack(t),cause:t.cause?n.next(t.cause):void 0,synthetic:!1}}getType(t){return t.name||t.constructor.name}getMessage(t,n){var r=t.message;return r.error&&typeof r.error.message=="string"?String(r.error.message):String(r)}getStack(t){return t.stacktrace||t.stack||void 0}}class lY{constructor(){}match(t){return pf(t,"ErrorEvent")&&t.error!=null}coerce(t,n){var r,i=n.apply(t.error);return i||{type:"ErrorEvent",value:t.message,stack:(r=n.syntheticException)==null?void 0:r.stack,synthetic:!0}}}var oY=/^(?:[Uu]ncaught (?:exception: )?)?(?:((?:Eval|Internal|Range|Reference|Syntax|Type|URI|)Error): )?(.*)$/i;class uY{match(t){return typeof t=="string"}coerce(t,n){var r,[i,s]=this.getInfos(t);return{type:i??"Error",value:s??t,stack:(r=n.syntheticException)==null?void 0:r.stack,synthetic:!0}}getInfos(t){var n="Error",r=t,i=t.match(oY);return i&&(n=i[1],r=i[2]),[n,r]}}var cY=["fatal","error","warning","log","info","debug"];function PS(e,t){t===void 0&&(t=40);var n=Object.keys(e);if(n.sort(),!n.length)return"[object has no keys]";for(var r=n.length;r>0;r--){var i=n.slice(0,r).join(", ");if(!(i.length>t))return r===n.length||i.length<=t?i:i.slice(0,t)+"..."}return""}class dY{match(t){return typeof t=="object"&&t!==null}coerce(t,n){var r,i=this.getErrorPropertyFromObject(t);return i?n.apply(i):{type:this.getType(t),value:this.getValue(t),stack:(r=n.syntheticException)==null?void 0:r.stack,level:this.isSeverityLevel(t.level)?t.level:"error",synthetic:!0}}getType(t){return vS(t)?t.constructor.name:"Error"}getValue(t){if("name"in t&&typeof t.name=="string"){var n="'"+t.name+"' captured as exception";return"message"in t&&typeof t.message=="string"&&(n+=" with message: '"+t.message+"'"),n}if("message"in t&&typeof t.message=="string")return t.message;var r=this.getObjectClassName(t);return(r&&r!=="Object"?"'"+r+"'":"Object")+" captured as exception with keys: "+PS(t)}isSeverityLevel(t){return or(t)&&!Nb(t)&&cY.indexOf(t)>=0}getErrorPropertyFromObject(t){for(var n in t)if(Object.prototype.hasOwnProperty.call(t,n)){var r=t[n];if(KG(r))return r}}getObjectClassName(t){try{var n=Object.getPrototypeOf(t);return n?n.constructor.name:void 0}catch{return}}}class hY{match(t){return vS(t)}coerce(t,n){var r,i=t.constructor.name;return{type:i,value:i+" captured as exception with keys: "+PS(t),stack:(r=n.syntheticException)==null?void 0:r.stack,synthetic:!0}}}class fY{match(t){return Ob(t)}coerce(t,n){var r;return{type:"Error",value:"Primitive value captured as exception: "+String(t),stack:(r=n.syntheticException)==null?void 0:r.stack,synthetic:!0}}}class mY{match(t){return pf(t,"PromiseRejectionEvent")}coerce(t,n){var r,i=this.getUnhandledRejectionReason(t);return Ob(i)?{type:"UnhandledRejection",value:"Non-Error promise rejection captured with value: "+String(i),stack:(r=n.syntheticException)==null?void 0:r.stack,synthetic:!0}:n.apply(i)}getUnhandledRejectionReason(t){if(Ob(t))return t;try{if("reason"in t)return t.reason;if("detail"in t&&"reason"in t.detail)return t.detail.reason}catch{}return t}}var BS=function(e,t){var{debugEnabled:n}=t===void 0?{}:t,r={k:function(i){if(ge&&($a.DEBUG||it.POSTHOG_DEBUG||n)&&!He(ge.console)&&ge.console){for(var s=("__rrweb_original__"in ge.console[i])?ge.console[i].__rrweb_original__:ge.console[i],o=arguments.length,c=new Array(o>1?o-1:0),d=1;d<o;d++)c[d-1]=arguments[d];s(e,...c)}},info:function(){for(var i=arguments.length,s=new Array(i),o=0;o<i;o++)s[o]=arguments[o];r.k("log",...s)},warn:function(){for(var i=arguments.length,s=new Array(i),o=0;o<i;o++)s[o]=arguments[o];r.k("warn",...s)},error:function(){for(var i=arguments.length,s=new Array(i),o=0;o<i;o++)s[o]=arguments[o];r.k("error",...s)},critical:function(){for(var i=arguments.length,s=new Array(i),o=0;o<i;o++)s[o]=arguments[o];console.error(e,...s)},uninitializedWarning:i=>{r.error("You must initialize PostHog before calling "+i)},createLogger:(i,s)=>BS(e+" "+i,s)};return r},je=BS("[PostHog.js]"),Hn=je.createLogger,pY=Hn("[ExternalScriptsLoader]"),e5=(e,t,n)=>{if(e.config.disable_external_dependency_loading)return pY.warn(t+" was requested but loading of external scripts is disabled."),n("Loading of external scripts is disabled");var r=qe==null?void 0:qe.querySelectorAll("script");if(r){for(var i,s=function(){if(r[o].src===t){var d=r[o];return d.__posthog_loading_callback_fired?{v:n()}:(d.addEventListener("load",(f=>{d.__posthog_loading_callback_fired=!0,n(void 0,f)})),d.onerror=f=>n(f),{v:void 0})}},o=0;o<r.length;o++)if(i=s())return i.v}var c=()=>{if(!qe)return n("document not found");var d=qe.createElement("script");if(d.type="text/javascript",d.crossOrigin="anonymous",d.src=t,d.onload=p=>{d.__posthog_loading_callback_fired=!0,n(void 0,p)},d.onerror=p=>n(p),e.config.prepare_external_dependency_script&&(d=e.config.prepare_external_dependency_script(d)),!d)return n("prepare_external_dependency_script returned null");var f,m=qe.querySelectorAll("body > script");m.length>0?(f=m[0].parentNode)==null||f.insertBefore(d,m[0]):qe.body.appendChild(d)};qe!=null&&qe.body?c():qe==null||qe.addEventListener("DOMContentLoaded",c)};it.__PosthogExtensions__=it.__PosthogExtensions__||{},it.__PosthogExtensions__.loadExternalDependency=(e,t,n)=>{var r="/static/"+t+".js?v="+e.version;if(t==="remote-config"&&(r="/array/"+e.config.token+"/config.js"),t==="toolbar"){var i=3e5;r=r+"&t="+Math.floor(Date.now()/i)*i}var s=e.requestRouter.endpointFor("assets",r);e5(e,s,n)},it.__PosthogExtensions__.loadSiteApp=(e,t,n)=>{var r=e.requestRouter.endpointFor("api",t);e5(e,r,n)};var bf={};function rl(e,t,n){if(Qt(e)){if(q6&&e.forEach===q6)e.forEach(t,n);else if("length"in e&&e.length===+e.length){for(var r=0,i=e.length;r<i;r++)if(r in e&&t.call(n,e[r],r)===bf)return}}}function _n(e,t,n){if(!Wt(e)){if(Qt(e))return rl(e,t,n);if(IG(e)){for(var r of e.entries())if(t.call(n,r[1],r[0])===bf)return}else for(var i in e)if(bS.call(e,i)&&t.call(n,e[i],i)===bf)return}}var Vn=function(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];return rl(n,(function(i){for(var s in i)i[s]!==void 0&&(e[s]=i[s])})),e},Tu=function(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];return rl(n,(function(i){rl(i,(function(s){e.push(s)}))})),e};function Yh(e){for(var t=Object.keys(e),n=t.length,r=new Array(n);n--;)r[n]=[t[n],e[t[n]]];return r}var t5=function(e){try{return e()}catch{return}},gY=function(e){return function(){try{for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return e.apply(this,n)}catch(i){je.critical("Implementation error. Please turn on debug mode and open a ticket on https://app.posthog.com/home#panel=support%3Asupport%3A."),je.critical(i)}}},lv=function(e){var t={};return _n(e,(function(n,r){(or(n)&&n.length>0||os(n))&&(t[r]=n)})),t};function bY(e,t){return n=e,r=s=>or(s)&&!Qi(t)?s.slice(0,t):s,i=new Set,(function s(o,c){return o!==Object(o)?r?r(o,c):o:i.has(o)?void 0:(i.add(o),Qt(o)?(d=[],rl(o,(f=>{d.push(s(f))}))):(d={},_n(o,((f,m)=>{i.has(f)||(d[m]=s(f,m))}))),d);var d})(n);var n,r,i}var vY=["herokuapp.com","vercel.app","netlify.app"];function _Y(e){var t=e==null?void 0:e.hostname;if(!or(t))return!1;var n=t.split(".").slice(-2).join(".");for(var r of vY)if(n===r)return!1;return!0}function US(e,t){for(var n=0;n<e.length;n++)if(t(e[n]))return e[n]}function rr(e,t,n,r){var{capture:i=!1,passive:s=!0}=r??{};e==null||e.addEventListener(t,n,{capture:i,passive:s})}var zS="$people_distinct_id",Fc="__alias",Hc="__timers",n5="$autocapture_disabled_server_side",Lb="$heatmaps_enabled_server_side",r5="$exception_capture_enabled_server_side",Pb="$error_tracking_suppression_rules",i5="$error_tracking_capture_extension_exceptions",a5="$web_vitals_enabled_server_side",FS="$dead_clicks_enabled_server_side",s5="$product_tours_enabled_server_side",l5="$web_vitals_allowed_metrics",Eg="$session_recording_remote_config",vf="$sesid",HS="$session_is_sampled",Jo="$enabled_feature_flags",jc="$early_access_features",Bb="$feature_flag_details",qc="$stored_person_properties",zl="$stored_group_properties",Ub="$surveys",_f="$flag_call_reported",Ga="$user_state",zb="$client_session_props",Fb="$capture_rate_limit",Hb="$initial_campaign_params",jb="$initial_referrer_info",yf="$initial_person_info",Ef="$epp",jS="__POSTHOG_TOOLBAR__",kc="$posthog_cookieless",yY=[zS,Fc,"__cmpns",Hc,"$session_recording_enabled_server_side",Lb,vf,Jo,Pb,Ga,jc,Bb,zl,qc,Ub,_f,zb,Fb,Hb,jb,Ef,yf,"$conversations_widget_session_id","$conversations_ticket_id","$conversations_widget_state","$conversations_user_traits"];function o5(e){return e instanceof Element&&(e.id===jS||!(e.closest==null||!e.closest(".toolbar-global-fade-container")))}function sm(e){return!!e&&e.nodeType===1}function il(e,t){return!!e&&!!e.tagName&&e.tagName.toLowerCase()===t.toLowerCase()}function qS(e){return!!e&&e.nodeType===3}function $S(e){return!!e&&e.nodeType===11}function ov(e){return e?im(e).split(/\s+/):[]}function u5(e){var t=ge==null?void 0:ge.location.href;return!!(t&&e&&e.some((n=>t.match(n))))}function Tf(e){var t="";switch(typeof e.className){case"string":t=e.className;break;case"object":t=(e.className&&"baseVal"in e.className?e.className.baseVal:null)||e.getAttribute("class")||"";break;default:t=""}return ov(t)}function GS(e){return Wt(e)?null:im(e).split(/(\s+)/).filter((t=>_0(t))).join("").replace(/[\r\n]/g," ").replace(/[ ]+/g," ").substring(0,255)}function B0(e){var t="";return qb(e)&&!XS(e)&&e.childNodes&&e.childNodes.length&&_n(e.childNodes,(function(n){var r;qS(n)&&n.textContent&&(t+=(r=GS(n.textContent))!==null&&r!==void 0?r:"")})),im(t)}function YS(e){return He(e.target)?e.srcElement||null:(t=e.target)!=null&&t.shadowRoot?e.composedPath()[0]||null:e.target||null;var t}var uv=["a","button","form","input","select","textarea","label"];function VS(e,t){if(He(t))return!0;var n,r=function(s){if(t.some((o=>s.matches(o))))return{v:!0}};for(var i of e)if(n=r(i))return n.v;return!1}function KS(e){var t=e.parentNode;return!(!t||!sm(t))&&t}var EY=["next","previous","prev",">","<"],c5=10,d5=[".ph-no-rageclick",".ph-no-capture"];function TY(e,t){if(!ge||cv(e))return!1;var n,r,i;if(ns(t)?(n=!!t&&d5,r=void 0):(n=(i=t==null?void 0:t.css_selector_ignorelist)!==null&&i!==void 0?i:d5,r=t==null?void 0:t.content_ignorelist),n===!1)return!1;var{targetElementList:s}=WS(e,!1);return!(function(o,c){if(o===!1||He(o))return!1;var d;if(o===!0)d=EY;else{if(!Qt(o))return!1;if(o.length>c5)return je.error("[PostHog] content_ignorelist array cannot exceed "+c5+" items. Use css_selector_ignorelist for more complex matching."),!1;d=o.map((f=>f.toLowerCase()))}return c.some((f=>{var{safeText:m,ariaLabel:p}=f;return d.some((v=>m.includes(v)||p.includes(v)))}))})(r,s.map((o=>{var c;return{safeText:B0(o).toLowerCase(),ariaLabel:((c=o.getAttribute("aria-label"))==null?void 0:c.toLowerCase().trim())||""}})))&&!VS(s,n)}var cv=e=>!e||il(e,"html")||!sm(e),WS=(e,t)=>{if(!ge||cv(e))return{parentIsUsefulElement:!1,targetElementList:[]};for(var n=!1,r=[e],i=e;i.parentNode&&!il(i,"body");)if($S(i.parentNode))r.push(i.parentNode.host),i=i.parentNode.host;else{var s=KS(i);if(!s)break;if(t||uv.indexOf(s.tagName.toLowerCase())>-1)n=!0;else{var o=ge.getComputedStyle(s);o&&o.getPropertyValue("cursor")==="pointer"&&(n=!0)}r.push(s),i=s}return{parentIsUsefulElement:n,targetElementList:r}};function xY(e,t,n,r,i){var s,o,c,d;if(n===void 0&&(n=void 0),!ge||cv(e)||(s=n)!=null&&s.url_allowlist&&!u5(n.url_allowlist)||(o=n)!=null&&o.url_ignorelist&&u5(n.url_ignorelist))return!1;if((c=n)!=null&&c.dom_event_allowlist){var f=n.dom_event_allowlist;if(f&&!f.some((T=>t.type===T)))return!1}var{parentIsUsefulElement:m,targetElementList:p}=WS(e,r);if(!(function(T,x){var k=x==null?void 0:x.element_allowlist;if(He(k))return!0;var A,O=function($){if(k.some((V=>$.tagName.toLowerCase()===V)))return{v:!0}};for(var I of T)if(A=O(I))return A.v;return!1})(p,n)||!VS(p,(d=n)==null?void 0:d.css_selector_allowlist))return!1;var v=ge.getComputedStyle(e);if(v&&v.getPropertyValue("cursor")==="pointer"&&t.type==="click")return!0;var _=e.tagName.toLowerCase();switch(_){case"html":return!1;case"form":return(i||["submit"]).indexOf(t.type)>=0;case"input":case"select":case"textarea":return(i||["change","click"]).indexOf(t.type)>=0;default:return m?(i||["click"]).indexOf(t.type)>=0:(i||["click"]).indexOf(t.type)>=0&&(uv.indexOf(_)>-1||e.getAttribute("contenteditable")==="true")}}function qb(e){for(var t=e;t.parentNode&&!il(t,"body");t=t.parentNode){var n=Tf(t);if(Dt(n,"ph-sensitive")||Dt(n,"ph-no-capture"))return!1}if(Dt(Tf(e),"ph-include"))return!0;var r=e.type||"";if(or(r))switch(r.toLowerCase()){case"hidden":case"password":return!1}var i=e.name||e.id||"";return!(or(i)&&/^cc|cardnum|ccnum|creditcard|csc|cvc|cvv|exp|pass|pwd|routing|seccode|securitycode|securitynum|socialsec|socsec|ssn/i.test(i.replace(/[^a-zA-Z0-9]/g,"")))}function XS(e){return!!(il(e,"input")&&!["button","checkbox","submit","reset"].includes(e.type)||il(e,"select")||il(e,"textarea")||e.getAttribute("contenteditable")==="true")}var QS="(4[0-9]{12}(?:[0-9]{3})?)|(5[1-5][0-9]{14})|(6(?:011|5[0-9]{2})[0-9]{12})|(3[47][0-9]{13})|(3(?:0[0-5]|[68][0-9])[0-9]{11})|((?:2131|1800|35[0-9]{3})[0-9]{11})",SY=new RegExp("^(?:"+QS+")$"),wY=new RegExp(QS),ZS="\\d{3}-?\\d{2}-?\\d{4}",AY=new RegExp("^("+ZS+")$"),kY=new RegExp("("+ZS+")");function _0(e,t){return t===void 0&&(t=!0),!(Wt(e)||or(e)&&(e=im(e),(t?SY:wY).test((e||"").replace(/[- ]/g,""))||(t?AY:kY).test(e)))}function JS(e){var t=B0(e);return _0(t=(t+" "+e9(e)).trim())?t:""}function e9(e){var t="";return e&&e.childNodes&&e.childNodes.length&&_n(e.childNodes,(function(n){var r;if(n&&((r=n.tagName)==null?void 0:r.toLowerCase())==="span")try{var i=B0(n);t=(t+" "+i).trim(),n.childNodes&&n.childNodes.length&&(t=(t+" "+e9(n)).trim())}catch(s){je.error("[AutoCapture]",s)}})),t}function CY(e){return(function(t){var n=t.map((r=>{var i,s,o="";if(r.tag_name&&(o+=r.tag_name),r.attr_class)for(var c of(r.attr_class.sort(),r.attr_class))o+="."+c.replace(/"/g,"");var d=Ve({},r.text?{text:r.text}:{},{"nth-child":(i=r.nth_child)!==null&&i!==void 0?i:0,"nth-of-type":(s=r.nth_of_type)!==null&&s!==void 0?s:0},r.href?{href:r.href}:{},r.attr_id?{attr_id:r.attr_id}:{},r.attributes),f={};return Yh(d).sort(((m,p)=>{var[v]=m,[_]=p;return v.localeCompare(_)})).forEach((m=>{var[p,v]=m;return f[h5(p.toString())]=h5(v.toString())})),o+=":",o+=Yh(f).map((m=>{var[p,v]=m;return p+'="'+v+'"'})).join("")}));return n.join(";")})((function(t){return t.map((n=>{var r,i,s={text:(r=n.$el_text)==null?void 0:r.slice(0,400),tag_name:n.tag_name,href:(i=n.attr__href)==null?void 0:i.slice(0,2048),attr_class:NY(n),attr_id:n.attr__id,nth_child:n.nth_child,nth_of_type:n.nth_of_type,attributes:{}};return Yh(n).filter((o=>{var[c]=o;return c.indexOf("attr__")===0})).forEach((o=>{var[c,d]=o;return s.attributes[c]=d})),s}))})(e))}function h5(e){return e.replace(/"|\\"/g,'\\"')}function NY(e){var t=e.attr__class;return t?Qt(t)?t:ov(t):void 0}class t9{constructor(t){this.disabled=t===!1;var n=fr(t)?t:{};this.thresholdPx=n.threshold_px||30,this.timeoutMs=n.timeout_ms||1e3,this.clickCount=n.click_count||3,this.clicks=[]}isRageClick(t,n,r){if(this.disabled)return!1;var i=this.clicks[this.clicks.length-1];if(i&&Math.abs(t-i.x)+Math.abs(n-i.y)<this.thresholdPx&&r-i.timestamp<this.timeoutMs){if(this.clicks.push({x:t,y:n,timestamp:r}),this.clicks.length===this.clickCount)return!0}else this.clicks=[{x:t,y:n,timestamp:r}];return!1}}var xf=e=>{var t=qe==null?void 0:qe.createElement("a");return He(t)?null:(t.href=e,t)},OY=function(e,t){var n,r;t===void 0&&(t="&");var i=[];return _n(e,(function(s,o){He(s)||He(o)||o==="undefined"||(n=encodeURIComponent((c=>c instanceof File)(s)?s.name:s.toString()),r=encodeURIComponent(o),i[i.length]=r+"="+n)})),i.join(t)},Sf=function(e,t){for(var n,r=((e.split("#")[0]||"").split(/\?(.*)/)[1]||"").replace(/^\?+/g,"").split("&"),i=0;i<r.length;i++){var s=r[i].split("=");if(s[0]===t){n=s;break}}if(!Qt(n)||n.length<2)return"";var o=n[1];try{o=decodeURIComponent(o)}catch{je.error("Skipping decoding for malformed query param: "+o)}return o.replace(/\+/g," ")},U0=function(e,t,n){if(!e||!t||!t.length)return e;for(var r=e.split("#"),i=r[0]||"",s=r[1],o=i.split("?"),c=o[1],d=o[0],f=(c||"").split("&"),m=[],p=0;p<f.length;p++){var v=f[p].split("=");Qt(v)&&(t.includes(v[0])?m.push(v[0]+"="+n):m.push(f[p]))}var _=d;return c!=null&&(_+="?"+m.join("&")),s!=null&&(_+="#"+s),_},wf=function(e,t){var n=e.match(new RegExp(t+"=([^&]*)"));return n?n[1]:null},Tg="$copy_autocapture",f5=Hn("[AutoCapture]");function xg(e,t){return t.length>e?t.slice(0,e)+"...":t}function RY(e){if(e.previousElementSibling)return e.previousElementSibling;var t=e;do t=t.previousSibling;while(t&&!sm(t));return t}function MY(e,t,n,r){var i=e.tagName.toLowerCase(),s={tag_name:i};uv.indexOf(i)>-1&&!n&&(i.toLowerCase()==="a"||i.toLowerCase()==="button"?s.$el_text=xg(1024,JS(e)):s.$el_text=xg(1024,B0(e)));var o=Tf(e);o.length>0&&(s.classes=o.filter((function(m){return m!==""}))),_n(e.attributes,(function(m){var p;if((!XS(e)||["name","id","class","aria-label"].indexOf(m.name)!==-1)&&(r==null||!r.includes(m.name))&&!t&&_0(m.value)&&(p=m.name,!or(p)||p.substring(0,10)!=="_ngcontent"&&p.substring(0,7)!=="_nghost")){var v=m.value;m.name==="class"&&(v=ov(v).join(" ")),s["attr__"+m.name]=xg(1024,v)}}));for(var c=1,d=1,f=e;f=RY(f);)c++,f.tagName===e.tagName&&d++;return s.nth_child=c,s.nth_of_type=d,s}function IY(e,t){for(var n,r,{e:i,maskAllElementAttributes:s,maskAllText:o,elementAttributeIgnoreList:c,elementsChainAsString:d}=t,f=[e],m=e;m.parentNode&&!il(m,"body");)$S(m.parentNode)?(f.push(m.parentNode.host),m=m.parentNode.host):(f.push(m.parentNode),m=m.parentNode);var p,v=[],_={},T=!1,x=!1;if(_n(f,($=>{var V=qb($);$.tagName.toLowerCase()==="a"&&(T=$.getAttribute("href"),T=V&&T&&_0(T)&&T),Dt(Tf($),"ph-no-capture")&&(x=!0),v.push(MY($,s,o,c));var B=(function(Z){if(!qb(Z))return{};var ee={};return _n(Z.attributes,(function(te){if(te.name&&te.name.indexOf("data-ph-capture-attribute")===0){var Y=te.name.replace("data-ph-capture-attribute-",""),oe=te.value;Y&&oe&&_0(oe)&&(ee[Y]=oe)}})),ee})($);Vn(_,B)})),x)return{props:{},explicitNoCapture:x};if(o||(e.tagName.toLowerCase()==="a"||e.tagName.toLowerCase()==="button"?v[0].$el_text=JS(e):v[0].$el_text=B0(e)),T){var k,A;v[0].attr__href=T;var O=(k=xf(T))==null?void 0:k.host,I=ge==null||(A=ge.location)==null?void 0:A.host;O&&I&&O!==I&&(p=T)}return{props:Vn({$event_type:i.type,$ce_version:1},d?{}:{$elements:v},{$elements_chain:CY(v)},(n=v[0])!=null&&n.$el_text?{$el_text:(r=v[0])==null?void 0:r.$el_text}:{},p&&i.type==="click"?{$external_click_url:p}:{},_)}}class DY{constructor(t){this.P=!1,this.T=null,this.I=!1,this.instance=t,this.rageclicks=new t9(t.config.rageclick),this.C=null}get R(){var t,n,r=fr(this.instance.config.autocapture)?this.instance.config.autocapture:{};return r.url_allowlist=(t=r.url_allowlist)==null?void 0:t.map((i=>new RegExp(i))),r.url_ignorelist=(n=r.url_ignorelist)==null?void 0:n.map((i=>new RegExp(i))),r}F(){if(this.isBrowserSupported()){if(ge&&qe){var t=r=>{r=r||(ge==null?void 0:ge.event);try{this.M(r)}catch(i){f5.error("Failed to capture event",i)}};if(rr(qe,"submit",t,{capture:!0}),rr(qe,"change",t,{capture:!0}),rr(qe,"click",t,{capture:!0}),this.R.capture_copied_text){var n=r=>{r=r||(ge==null?void 0:ge.event),this.M(r,Tg)};rr(qe,"copy",n,{capture:!0}),rr(qe,"cut",n,{capture:!0})}}}else f5.info("Disabling Automatic Event Collection because this browser is not supported")}startIfEnabled(){this.isEnabled&&!this.P&&(this.F(),this.P=!0)}onRemoteConfig(t){t.elementsChainAsString&&(this.I=t.elementsChainAsString),this.instance.persistence&&this.instance.persistence.register({[n5]:!!t.autocapture_opt_out}),this.T=!!t.autocapture_opt_out,this.startIfEnabled()}setElementSelectors(t){this.C=t}getElementSelectors(t){var n,r=[];return(n=this.C)==null||n.forEach((i=>{var s=qe==null?void 0:qe.querySelectorAll(i);s==null||s.forEach((o=>{t===o&&r.push(i)}))})),r}get isEnabled(){var t,n,r=(t=this.instance.persistence)==null?void 0:t.props[n5],i=this.T;if(Qi(i)&&!ns(r)&&!this.instance.O())return!1;var s=(n=this.T)!==null&&n!==void 0?n:!!r;return!!this.instance.config.autocapture&&!s}M(t,n){if(n===void 0&&(n="$autocapture"),this.isEnabled){var r,i=YS(t);qS(i)&&(i=i.parentNode||null),n==="$autocapture"&&t.type==="click"&&t instanceof MouseEvent&&this.instance.config.rageclick&&(r=this.rageclicks)!=null&&r.isRageClick(t.clientX,t.clientY,t.timeStamp||new Date().getTime())&&TY(i,this.instance.config.rageclick)&&this.M(t,"$rageclick");var s=n===Tg;if(i&&xY(i,t,this.R,s,s?["copy","cut"]:void 0)){var{props:o,explicitNoCapture:c}=IY(i,{e:t,maskAllElementAttributes:this.instance.config.mask_all_element_attributes,maskAllText:this.instance.config.mask_all_text,elementAttributeIgnoreList:this.R.element_attribute_ignorelist,elementsChainAsString:this.I});if(c)return!1;var d=this.getElementSelectors(i);if(d&&d.length>0&&(o.$element_selectors=d),n===Tg){var f,m=GS(ge==null||(f=ge.getSelection())==null?void 0:f.toString()),p=t.type||"clipboard";if(!m)return!1;o.$selected_content=m,o.$copy_type=p}return this.instance.capture(n,o),!0}}}isBrowserSupported(){return nl(qe==null?void 0:qe.querySelectorAll)}}Math.trunc||(Math.trunc=function(e){return e<0?Math.ceil(e):Math.floor(e)}),Number.isInteger||(Number.isInteger=function(e){return os(e)&&isFinite(e)&&Math.floor(e)===e});var m5="0123456789abcdef";class Af{constructor(t){if(this.bytes=t,t.length!==16)throw new TypeError("not 128-bit length")}static fromFieldsV7(t,n,r,i){if(!Number.isInteger(t)||!Number.isInteger(n)||!Number.isInteger(r)||!Number.isInteger(i)||t<0||n<0||r<0||i<0||t>0xffffffffffff||n>4095||r>1073741823||i>4294967295)throw new RangeError("invalid field value");var s=new Uint8Array(16);return s[0]=t/Math.pow(2,40),s[1]=t/Math.pow(2,32),s[2]=t/Math.pow(2,24),s[3]=t/Math.pow(2,16),s[4]=t/Math.pow(2,8),s[5]=t,s[6]=112|n>>>8,s[7]=n,s[8]=128|r>>>24,s[9]=r>>>16,s[10]=r>>>8,s[11]=r,s[12]=i>>>24,s[13]=i>>>16,s[14]=i>>>8,s[15]=i,new Af(s)}toString(){for(var t="",n=0;n<this.bytes.length;n++)t=t+m5.charAt(this.bytes[n]>>>4)+m5.charAt(15&this.bytes[n]),n!==3&&n!==5&&n!==7&&n!==9||(t+="-");if(t.length!==36)throw new Error("Invalid UUIDv7 was generated");return t}clone(){return new Af(this.bytes.slice(0))}equals(t){return this.compareTo(t)===0}compareTo(t){for(var n=0;n<16;n++){var r=this.bytes[n]-t.bytes[n];if(r!==0)return Math.sign(r)}return 0}}class LY{constructor(){this.A=0,this.D=0,this.j=new PY}generate(){var t=this.generateOrAbort();if(He(t)){this.A=0;var n=this.generateOrAbort();if(He(n))throw new Error("Could not generate UUID after timestamp reset");return n}return t}generateOrAbort(){var t=Date.now();if(t>this.A)this.A=t,this.L();else{if(!(t+1e4>this.A))return;this.D++,this.D>4398046511103&&(this.A++,this.L())}return Af.fromFieldsV7(this.A,Math.trunc(this.D/Math.pow(2,30)),this.D&Math.pow(2,30)-1,this.j.nextUint32())}L(){this.D=1024*this.j.nextUint32()+(1023&this.j.nextUint32())}}var p5,n9=e=>{if(typeof UUIDV7_DENY_WEAK_RNG<"u"&&UUIDV7_DENY_WEAK_RNG)throw new Error("no cryptographically strong RNG available");for(var t=0;t<e.length;t++)e[t]=65536*Math.trunc(65536*Math.random())+Math.trunc(65536*Math.random());return e};ge&&!He(ge.crypto)&&crypto.getRandomValues&&(n9=e=>crypto.getRandomValues(e));class PY{constructor(){this.N=new Uint32Array(8),this.U=1/0}nextUint32(){return this.U>=this.N.length&&(n9(this.N),this.U=0),this.N[this.U++]}}var tl=()=>BY().toString(),BY=()=>(p5||(p5=new LY)).generate(),Cc="",UY=/[a-z0-9][a-z0-9-]+\.[a-z]{2,}$/i;function zY(e,t){if(t){var n=(function(i,s){if(s===void 0&&(s=qe),Cc)return Cc;if(!s||["localhost","127.0.0.1"].includes(i))return"";for(var o=i.split("."),c=Math.min(o.length,8),d="dmn_chk_"+tl();!Cc&&c--;){var f=o.slice(c).join("."),m=d+"=1;domain=."+f+";path=/";s.cookie=m+";max-age=3",s.cookie.includes(d)&&(s.cookie=m+";max-age=0",Cc=f)}return Cc})(e);if(!n){var r=(i=>{var s=i.match(UY);return s?s[0]:""})(e);r!==n&&je.info("Warning: cookie subdomain discovery mismatch",r,n),n=r}return n?"; domain=."+n:""}return""}var ua={H:()=>!!qe,B:function(e){je.error("cookieStore error: "+e)},q:function(e){if(qe){try{for(var t=e+"=",n=qe.cookie.split(";").filter((s=>s.length)),r=0;r<n.length;r++){for(var i=n[r];i.charAt(0)==" ";)i=i.substring(1,i.length);if(i.indexOf(t)===0)return decodeURIComponent(i.substring(t.length,i.length))}}catch{}return null}},W:function(e){var t;try{t=JSON.parse(ua.q(e))||{}}catch{}return t},G:function(e,t,n,r,i){if(qe)try{var s="",o="",c=zY(qe.location.hostname,r);if(n){var d=new Date;d.setTime(d.getTime()+24*n*60*60*1e3),s="; expires="+d.toUTCString()}i&&(o="; secure");var f=e+"="+encodeURIComponent(JSON.stringify(t))+s+"; SameSite=Lax; path=/"+c+o;return f.length>3686.4&&je.warn("cookieStore warning: large cookie, len="+f.length),qe.cookie=f,f}catch{return}},V:function(e,t){if(qe!=null&&qe.cookie)try{ua.G(e,"",-1,t)}catch{return}}},Sg=null,Pn={H:function(){if(!Qi(Sg))return Sg;var e=!0;if(He(ge))e=!1;else try{var t="__mplssupport__";Pn.G(t,"xyz"),Pn.q(t)!=='"xyz"'&&(e=!1),Pn.V(t)}catch{e=!1}return e||je.error("localStorage unsupported; falling back to cookie store"),Sg=e,e},B:function(e){je.error("localStorage error: "+e)},q:function(e){try{return ge==null?void 0:ge.localStorage.getItem(e)}catch(t){Pn.B(t)}return null},W:function(e){try{return JSON.parse(Pn.q(e))||{}}catch{}return null},G:function(e,t){try{ge==null||ge.localStorage.setItem(e,JSON.stringify(t))}catch(n){Pn.B(n)}},V:function(e){try{ge==null||ge.localStorage.removeItem(e)}catch(t){Pn.B(t)}}},FY=["$device_id","distinct_id",vf,HS,Ef,yf],Oh={},HY={H:function(){return!0},B:function(e){je.error("memoryStorage error: "+e)},q:function(e){return Oh[e]||null},W:function(e){return Oh[e]||null},G:function(e,t){Oh[e]=t},V:function(e){delete Oh[e]}},Pl=null,Er={H:function(){if(!Qi(Pl))return Pl;if(Pl=!0,He(ge))Pl=!1;else try{var e="__support__";Er.G(e,"xyz"),Er.q(e)!=='"xyz"'&&(Pl=!1),Er.V(e)}catch{Pl=!1}return Pl},B:function(e){je.error("sessionStorage error: ",e)},q:function(e){try{return ge==null?void 0:ge.sessionStorage.getItem(e)}catch(t){Er.B(t)}return null},W:function(e){try{return JSON.parse(Er.q(e))||null}catch{}return null},G:function(e,t){try{ge==null||ge.sessionStorage.setItem(e,JSON.stringify(t))}catch(n){Er.B(n)}},V:function(e){try{ge==null||ge.sessionStorage.removeItem(e)}catch(t){Er.B(t)}}},Ya=(function(e){return e[e.PENDING=-1]="PENDING",e[e.DENIED=0]="DENIED",e[e.GRANTED=1]="GRANTED",e})({});class jY{constructor(t){this._instance=t}get R(){return this._instance.config}get consent(){return this.J()?Ya.DENIED:this.K}isOptedOut(){return this.R.cookieless_mode==="always"||this.consent===Ya.DENIED||this.consent===Ya.PENDING&&(this.R.opt_out_capturing_by_default||this.R.cookieless_mode==="on_reject")}isOptedIn(){return!this.isOptedOut()}isExplicitlyOptedOut(){return this.consent===Ya.DENIED}optInOut(t){this.Y.G(this.X,t?1:0,this.R.cookie_expiration,this.R.cross_subdomain_cookie,this.R.secure_cookie)}reset(){this.Y.V(this.X,this.R.cross_subdomain_cookie)}get X(){var{token:t,opt_out_capturing_cookie_prefix:n,consent_persistence_name:r}=this._instance.config;return r||(n?n+t:"__ph_opt_in_out_"+t)}get K(){var t=this.Y.q(this.X);return vg(t)?Ya.GRANTED:Dt(PG,t)?Ya.DENIED:Ya.PENDING}get Y(){if(!this.Z){var t=this.R.opt_out_capturing_persistence_type;this.Z=t==="localStorage"?Pn:ua;var n=t==="localStorage"?ua:Pn;n.q(this.X)&&(this.Z.q(this.X)||this.optInOut(vg(n.q(this.X))),n.V(this.X,this.R.cross_subdomain_cookie))}return this.Z}J(){return!!this.R.respect_dnt&&!!US([yi==null?void 0:yi.doNotTrack,yi==null?void 0:yi.msDoNotTrack,it.doNotTrack],(t=>vg(t)))}}var Rh=Hn("[Dead Clicks]"),qY=()=>!0,$Y=e=>{var t,n=!((t=e.instance.persistence)==null||!t.get_property(FS)),r=e.instance.config.capture_dead_clicks;return ns(r)?r:!!fr(r)||n};class r9{get lazyLoadedDeadClicksAutocapture(){return this.tt}constructor(t,n,r){this.instance=t,this.isEnabled=n,this.onCapture=r,this.startIfEnabled()}onRemoteConfig(t){this.instance.persistence&&this.instance.persistence.register({[FS]:t==null?void 0:t.captureDeadClicks}),this.startIfEnabled()}startIfEnabled(){this.isEnabled(this)&&this.it((()=>{this.et()}))}it(t){var n,r;(n=it.__PosthogExtensions__)!=null&&n.initDeadClicksAutocapture&&t(),(r=it.__PosthogExtensions__)==null||r.loadExternalDependency==null||r.loadExternalDependency(this.instance,"dead-clicks-autocapture",(i=>{i?Rh.error("failed to load script",i):t()}))}et(){var t;if(qe){if(!this.tt&&(t=it.__PosthogExtensions__)!=null&&t.initDeadClicksAutocapture){var n=fr(this.instance.config.capture_dead_clicks)?this.instance.config.capture_dead_clicks:{};n.__onCapture=this.onCapture,this.tt=it.__PosthogExtensions__.initDeadClicksAutocapture(this.instance,n),this.tt.start(qe),Rh.info("starting...")}}else Rh.error("`document` not found. Cannot start.")}stop(){this.tt&&(this.tt.stop(),this.tt=void 0,Rh.info("stopping..."))}}var Nc=Hn("[ExceptionAutocapture]");class GY{constructor(t){var n,r,i;this.rt=()=>{var s;if(ge&&this.isEnabled&&(s=it.__PosthogExtensions__)!=null&&s.errorWrappingFunctions){var o=it.__PosthogExtensions__.errorWrappingFunctions.wrapOnError,c=it.__PosthogExtensions__.errorWrappingFunctions.wrapUnhandledRejection,d=it.__PosthogExtensions__.errorWrappingFunctions.wrapConsoleError;try{!this.st&&this.R.capture_unhandled_errors&&(this.st=o(this.captureException.bind(this))),!this.nt&&this.R.capture_unhandled_rejections&&(this.nt=c(this.captureException.bind(this))),!this.ot&&this.R.capture_console_errors&&(this.ot=d(this.captureException.bind(this)))}catch(f){Nc.error("failed to start",f),this.ut()}}},this._instance=t,this.ht=!((n=this._instance.persistence)==null||!n.props[r5]),this.dt=new BG({refillRate:(r=this._instance.config.error_tracking.__exceptionRateLimiterRefillRate)!==null&&r!==void 0?r:1,bucketSize:(i=this._instance.config.error_tracking.__exceptionRateLimiterBucketSize)!==null&&i!==void 0?i:10,refillInterval:1e4,h:Nc}),this.R=this.vt(),this.startIfEnabledOrStop()}vt(){var t=this._instance.config.capture_exceptions,n={capture_unhandled_errors:!1,capture_unhandled_rejections:!1,capture_console_errors:!1};return fr(t)?n=Ve({},n,t):(He(t)?this.ht:t)&&(n=Ve({},n,{capture_unhandled_errors:!0,capture_unhandled_rejections:!0})),n}get isEnabled(){return this.R.capture_console_errors||this.R.capture_unhandled_errors||this.R.capture_unhandled_rejections}startIfEnabledOrStop(){this.isEnabled?(Nc.info("enabled"),this.ut(),this.it(this.rt)):this.ut()}it(t){var n,r;(n=it.__PosthogExtensions__)!=null&&n.errorWrappingFunctions&&t(),(r=it.__PosthogExtensions__)==null||r.loadExternalDependency==null||r.loadExternalDependency(this._instance,"exception-autocapture",(i=>{if(i)return Nc.error("failed to load script",i);t()}))}ut(){var t,n,r;(t=this.st)==null||t.call(this),this.st=void 0,(n=this.nt)==null||n.call(this),this.nt=void 0,(r=this.ot)==null||r.call(this),this.ot=void 0}onRemoteConfig(t){var n=t.autocaptureExceptions;this.ht=!!n||!1,this._instance.persistence&&this._instance.persistence.register({[r5]:this.ht}),this.R=this.vt(),this.startIfEnabledOrStop()}onConfigChange(){this.R=this.vt()}captureException(t){var n,r,i=(n=t==null||(r=t.$exception_list)==null||(r=r[0])==null?void 0:r.type)!==null&&n!==void 0?n:"Exception";this.dt.consumeRateLimit(i)?Nc.info("Skipping exception capture because of client rate limiting.",{exception:i}):this._instance.exceptions.sendExceptionEvent(t)}}function g5(e,t,n){try{if(!(t in e))return()=>{};var r=e[t],i=n(r);return nl(i)&&(i.prototype=i.prototype||{},Object.defineProperties(i,{__posthog_wrapped__:{enumerable:!1,value:!0}})),e[t]=i,()=>{e[t]=r}}catch{return()=>{}}}class YY{constructor(t){var n;this._instance=t,this.ct=(ge==null||(n=ge.location)==null?void 0:n.pathname)||""}get isEnabled(){return this._instance.config.capture_pageview==="history_change"}startIfEnabled(){this.isEnabled&&(je.info("History API monitoring enabled, starting..."),this.monitorHistoryChanges())}stop(){this.ft&&this.ft(),this.ft=void 0,je.info("History API monitoring stopped")}monitorHistoryChanges(){var t,n;if(ge&&ge.history){var r=this;(t=ge.history.pushState)!=null&&t.__posthog_wrapped__||g5(ge.history,"pushState",(i=>function(s,o,c){i.call(this,s,o,c),r._t("pushState")})),(n=ge.history.replaceState)!=null&&n.__posthog_wrapped__||g5(ge.history,"replaceState",(i=>function(s,o,c){i.call(this,s,o,c),r._t("replaceState")})),this.yt()}}_t(t){try{var n,r=ge==null||(n=ge.location)==null?void 0:n.pathname;if(!r)return;r!==this.ct&&this.isEnabled&&this._instance.capture("$pageview",{navigation_type:t}),this.ct=r}catch(i){je.error("Error capturing "+t+" pageview",i)}}yt(){if(!this.ft){var t=()=>{this._t("popstate")};rr(ge,"popstate",t),this.ft=()=>{ge&&ge.removeEventListener("popstate",t)}}}}var wg=Hn("[SegmentIntegration]");function VY(e,t){var n=e.config.segment;if(!n)return t();(function(r,i){var s=r.config.segment;if(!s)return i();var o=d=>{var f=()=>d.anonymousId()||tl();r.config.get_device_id=f,d.id()&&(r.register({distinct_id:d.id(),$device_id:f()}),r.persistence.set_property(Ga,"identified")),i()},c=s.user();"then"in c&&nl(c.then)?c.then(o):o(c)})(e,(()=>{n.register((r=>{Promise&&Promise.resolve||wg.warn("This browser does not have Promise support, and can not use the segment integration");var i=(s,o)=>{if(!o)return s;s.event.userId||s.event.anonymousId===r.get_distinct_id()||(wg.info("No userId set, resetting PostHog"),r.reset()),s.event.userId&&s.event.userId!==r.get_distinct_id()&&(wg.info("UserId set, identifying with PostHog"),r.identify(s.event.userId));var c=r.calculateEventProperties(o,s.event.properties);return s.event.properties=Object.assign({},c,s.event.properties),s};return{name:"PostHog JS",type:"enrichment",version:"1.0.0",isLoaded:()=>!0,load:()=>Promise.resolve(),track:s=>i(s,s.event.event),page:s=>i(s,"$pageview"),identify:s=>i(s,"$identify"),screen:s=>i(s,"$screen")}})(e)).then((()=>{t()}))}))}var i9="posthog-js";function a9(e,t){var{organization:n,projectId:r,prefix:i,severityAllowList:s=["error"],sendExceptionsToPostHog:o=!0}=t===void 0?{}:t;return c=>{var d,f,m,p,v;if(!(s==="*"||s.includes(c.level))||!e.__loaded)return c;c.tags||(c.tags={});var _=e.requestRouter.endpointFor("ui","/project/"+e.config.token+"/person/"+e.get_distinct_id());c.tags["PostHog Person URL"]=_,e.sessionRecordingStarted()&&(c.tags["PostHog Recording URL"]=e.get_session_replay_url({withTimestamp:!0}));var T=((d=c.exception)==null?void 0:d.values)||[],x=T.map((A=>Ve({},A,{stacktrace:A.stacktrace?Ve({},A.stacktrace,{type:"raw",frames:(A.stacktrace.frames||[]).map((O=>Ve({},O,{platform:"web:javascript"})))}):void 0}))),k={$exception_message:((f=T[0])==null?void 0:f.value)||c.message,$exception_type:(m=T[0])==null?void 0:m.type,$exception_level:c.level,$exception_list:x,$sentry_event_id:c.event_id,$sentry_exception:c.exception,$sentry_exception_message:((p=T[0])==null?void 0:p.value)||c.message,$sentry_exception_type:(v=T[0])==null?void 0:v.type,$sentry_tags:c.tags};return n&&r&&(k.$sentry_url=(i||"https://sentry.io/organizations/")+n+"/issues/?project="+r+"&query="+c.event_id),o&&e.exceptions.sendExceptionEvent(k),c}}class KY{constructor(t,n,r,i,s,o){this.name=i9,this.setupOnce=function(c){c(a9(t,{organization:n,projectId:r,prefix:i,severityAllowList:s,sendExceptionsToPostHog:o==null||o}))}}}var WY=ge!=null&&ge.location?wf(ge.location.hash,"__posthog")||wf(location.hash,"state"):null,b5="_postHogToolbarParams",v5=Hn("[Toolbar]"),Xs=(function(e){return e[e.UNINITIALIZED=0]="UNINITIALIZED",e[e.LOADING=1]="LOADING",e[e.LOADED=2]="LOADED",e})(Xs||{});class XY{constructor(t){this.instance=t}bt(t){it.ph_toolbar_state=t}wt(){var t;return(t=it.ph_toolbar_state)!==null&&t!==void 0?t:Xs.UNINITIALIZED}maybeLoadToolbar(t,n,r){if(t===void 0&&(t=void 0),n===void 0&&(n=void 0),r===void 0&&(r=void 0),!ge||!qe)return!1;t=t??ge.location,r=r??ge.history;try{if(!n){try{ge.localStorage.setItem("test","test"),ge.localStorage.removeItem("test")}catch{return!1}n=ge==null?void 0:ge.localStorage}var i,s=WY||wf(t.hash,"__posthog")||wf(t.hash,"state"),o=s?t5((()=>JSON.parse(atob(decodeURIComponent(s)))))||t5((()=>JSON.parse(decodeURIComponent(s)))):null;return o&&o.action==="ph_authorize"?((i=o).source="url",i&&Object.keys(i).length>0&&(o.desiredHash?t.hash=o.desiredHash:r?r.replaceState(r.state,"",t.pathname+t.search):t.hash="")):((i=JSON.parse(n.getItem(b5)||"{}")).source="localstorage",delete i.userIntent),!(!i.token||this.instance.config.token!==i.token)&&(this.loadToolbar(i),!0)}catch{return!1}}xt(t){var n=it.ph_load_toolbar||it.ph_load_editor;!Wt(n)&&nl(n)?n(t,this.instance):v5.warn("No toolbar load function found")}loadToolbar(t){var n=!(qe==null||!qe.getElementById(jS));if(!ge||n)return!1;var r=this.instance.requestRouter.region==="custom"&&this.instance.config.advanced_disable_toolbar_metrics,i=Ve({token:this.instance.config.token},t,{apiURL:this.instance.requestRouter.endpointFor("ui")},r?{instrument:!1}:{});if(ge.localStorage.setItem(b5,JSON.stringify(Ve({},i,{source:void 0}))),this.wt()===Xs.LOADED)this.xt(i);else if(this.wt()===Xs.UNINITIALIZED){var s;this.bt(Xs.LOADING),(s=it.__PosthogExtensions__)==null||s.loadExternalDependency==null||s.loadExternalDependency(this.instance,"toolbar",(o=>{if(o)return v5.error("[Toolbar] Failed to load",o),void this.bt(Xs.UNINITIALIZED);this.bt(Xs.LOADED),this.xt(i)})),rr(ge,"turbolinks:load",(()=>{this.bt(Xs.UNINITIALIZED),this.loadToolbar(i)}))}return!0}Et(t){return this.loadToolbar(t)}maybeLoadEditor(t,n,r){return t===void 0&&(t=void 0),n===void 0&&(n=void 0),r===void 0&&(r=void 0),this.maybeLoadToolbar(t,n,r)}}var QY=Hn("[TracingHeaders]");class ZY{constructor(t){this.$t=void 0,this.St=void 0,this.rt=()=>{var n,r;He(this.$t)&&((n=it.__PosthogExtensions__)==null||(n=n.tracingHeadersPatchFns)==null||n._patchXHR(this._instance.config.__add_tracing_headers||[],this._instance.get_distinct_id(),this._instance.sessionManager)),He(this.St)&&((r=it.__PosthogExtensions__)==null||(r=r.tracingHeadersPatchFns)==null||r._patchFetch(this._instance.config.__add_tracing_headers||[],this._instance.get_distinct_id(),this._instance.sessionManager))},this._instance=t}it(t){var n,r;(n=it.__PosthogExtensions__)!=null&&n.tracingHeadersPatchFns&&t(),(r=it.__PosthogExtensions__)==null||r.loadExternalDependency==null||r.loadExternalDependency(this._instance,"tracing-headers",(i=>{if(i)return QY.error("failed to load script",i);t()}))}startIfEnabledOrStop(){var t,n;this._instance.config.__add_tracing_headers?this.it(this.rt):((t=this.$t)==null||t.call(this),(n=this.St)==null||n.call(this),this.$t=void 0,this.St=void 0)}}var Mh="https?://(.*)",xu=["gclid","gclsrc","dclid","gbraid","wbraid","fbclid","msclkid","twclid","li_fat_id","igshid","ttclid","rdt_cid","epik","qclid","sccid","irclid","_kx"],JY=Tu(["utm_source","utm_medium","utm_campaign","utm_content","utm_term","gad_source","mc_cid"],xu),z0="<masked>",eV=["li_fat_id"];function s9(e,t,n){if(!qe)return{};var r,i=t?Tu([],xu,n||[]):[],s=l9(U0(qe.URL,i,z0),e),o=(r={},_n(eV,(function(c){var d=ua.q(c);r[c]=d||null})),r);return Vn(o,s)}function l9(e,t){var n=JY.concat(t||[]),r={};return _n(n,(function(i){var s=Sf(e,i);r[i]=s||null})),r}function o9(e){var t=(function(s){return s?s.search(Mh+"google.([^/?]*)")===0?"google":s.search(Mh+"bing.com")===0?"bing":s.search(Mh+"yahoo.com")===0?"yahoo":s.search(Mh+"duckduckgo.com")===0?"duckduckgo":null:null})(e),n=t!="yahoo"?"q":"p",r={};if(!Qi(t)){r.$search_engine=t;var i=qe?Sf(qe.referrer,n):"";i.length&&(r.ph_keyword=i)}return r}function _5(){return navigator.language||navigator.userLanguage}function u9(){return(qe==null?void 0:qe.referrer)||"$direct"}function c9(e,t){var n=e?Tu([],xu,t||[]):[],r=ii==null?void 0:ii.href.substring(0,1e3);return{r:u9().substring(0,1e3),u:r?U0(r,n,z0):void 0}}function d9(e){var t,{r:n,u:r}=e,i={$referrer:n,$referring_domain:n==null?void 0:n=="$direct"?"$direct":(t=xf(n))==null?void 0:t.host};if(r){i.$current_url=r;var s=xf(r);i.$host=s==null?void 0:s.host,i.$pathname=s==null?void 0:s.pathname;var o=l9(r);Vn(i,o)}if(n){var c=o9(n);Vn(i,c)}return i}function h9(){try{return Intl.DateTimeFormat().resolvedOptions().timeZone}catch{return}}function tV(){try{return new Date().getTimezoneOffset()}catch{return}}function nV(e,t){if(!ni)return{};var n,r,i,s=e?Tu([],xu,t||[]):[],[o,c]=(function(d){for(var f=0;f<X6.length;f++){var[m,p]=X6[f],v=m.exec(d),_=v&&(nl(p)?p(v,d):p);if(_)return _}return["",""]})(ni);return Vn(lv({$os:o,$os_version:c,$browser:DS(ni,navigator.vendor),$device:Q6(ni),$device_type:(r=ni,i=Q6(r),i===yS||i===_S||i==="Kobo"||i==="Kindle Fire"||i===IS?p0:i===b0||i===ru||i===v0||i===Mb?"Console":i===TS?"Wearable":i?Ui:"Desktop"),$timezone:h9(),$timezone_offset:tV()}),{$current_url:U0(ii==null?void 0:ii.href,s,z0),$host:ii==null?void 0:ii.host,$pathname:ii==null?void 0:ii.pathname,$raw_user_agent:ni.length>1e3?ni.substring(0,997)+"...":ni,$browser_version:VG(ni,navigator.vendor),$browser_language:_5(),$browser_language_prefix:(n=_5(),typeof n=="string"?n.split("-")[0]:void 0),$screen_height:ge==null?void 0:ge.screen.height,$screen_width:ge==null?void 0:ge.screen.width,$viewport_height:ge==null?void 0:ge.innerHeight,$viewport_width:ge==null?void 0:ge.innerWidth,$lib:"web",$lib_version:$a.LIB_VERSION,$insert_id:Math.random().toString(36).substring(2,10)+Math.random().toString(36).substring(2,10),$time:Date.now()/1e3})}var $s=Hn("[Web Vitals]"),y5=9e5;class rV{constructor(t){var n;this.kt=!1,this.P=!1,this.N={url:void 0,metrics:[],firstMetricTimestamp:void 0},this.Pt=()=>{clearTimeout(this.Tt),this.N.metrics.length!==0&&(this._instance.capture("$web_vitals",this.N.metrics.reduce(((r,i)=>Ve({},r,{["$web_vitals_"+i.name+"_event"]:Ve({},i),["$web_vitals_"+i.name+"_value"]:i.value})),{})),this.N={url:void 0,metrics:[],firstMetricTimestamp:void 0})},this.It=r=>{var i,s=(i=this._instance.sessionManager)==null?void 0:i.checkAndGetSessionAndWindowId(!0);if(He(s))$s.error("Could not read session ID. Dropping metrics!");else{this.N=this.N||{url:void 0,metrics:[],firstMetricTimestamp:void 0};var o=this.Ct();He(o)||(Wt(r==null?void 0:r.name)||Wt(r==null?void 0:r.value)?$s.error("Invalid metric received",r):this.Rt&&r.value>=this.Rt?$s.error("Ignoring metric with value >= "+this.Rt,r):(this.N.url!==o&&(this.Pt(),this.Tt=setTimeout(this.Pt,this.flushToCaptureTimeoutMs)),He(this.N.url)&&(this.N.url=o),this.N.firstMetricTimestamp=He(this.N.firstMetricTimestamp)?Date.now():this.N.firstMetricTimestamp,r.attribution&&r.attribution.interactionTargetElement&&(r.attribution.interactionTargetElement=void 0),this.N.metrics.push(Ve({},r,{$current_url:o,$session_id:s.sessionId,$window_id:s.windowId,timestamp:Date.now()})),this.N.metrics.length===this.allowedMetrics.length&&this.Pt()))}},this.rt=()=>{var r,i,s,o,c=it.__PosthogExtensions__;He(c)||He(c.postHogWebVitalsCallbacks)||({onLCP:r,onCLS:i,onFCP:s,onINP:o}=c.postHogWebVitalsCallbacks),r&&i&&s&&o?(this.allowedMetrics.indexOf("LCP")>-1&&r(this.It.bind(this)),this.allowedMetrics.indexOf("CLS")>-1&&i(this.It.bind(this)),this.allowedMetrics.indexOf("FCP")>-1&&s(this.It.bind(this)),this.allowedMetrics.indexOf("INP")>-1&&o(this.It.bind(this)),this.P=!0):$s.error("web vitals callbacks not loaded - not starting")},this._instance=t,this.kt=!((n=this._instance.persistence)==null||!n.props[a5]),this.startIfEnabled()}get allowedMetrics(){var t,n,r=fr(this._instance.config.capture_performance)?(t=this._instance.config.capture_performance)==null?void 0:t.web_vitals_allowed_metrics:void 0;return He(r)?((n=this._instance.persistence)==null?void 0:n.props[l5])||["CLS","FCP","INP","LCP"]:r}get flushToCaptureTimeoutMs(){return(fr(this._instance.config.capture_performance)?this._instance.config.capture_performance.web_vitals_delayed_flush_ms:void 0)||5e3}get Rt(){var t=fr(this._instance.config.capture_performance)&&os(this._instance.config.capture_performance.__web_vitals_max_value)?this._instance.config.capture_performance.__web_vitals_max_value:y5;return 0<t&&t<=6e4?y5:t}get isEnabled(){var t=ii==null?void 0:ii.protocol;if(t!=="http:"&&t!=="https:")return $s.info("Web Vitals are disabled on non-http/https protocols"),!1;var n=fr(this._instance.config.capture_performance)?this._instance.config.capture_performance.web_vitals:ns(this._instance.config.capture_performance)?this._instance.config.capture_performance:void 0;return ns(n)?n:this.kt}startIfEnabled(){this.isEnabled&&!this.P&&($s.info("enabled, starting..."),this.it(this.rt))}onRemoteConfig(t){var n=fr(t.capturePerformance)&&!!t.capturePerformance.web_vitals,r=fr(t.capturePerformance)?t.capturePerformance.web_vitals_allowed_metrics:void 0;this._instance.persistence&&(this._instance.persistence.register({[a5]:n}),this._instance.persistence.register({[l5]:r})),this.kt=n,this.startIfEnabled()}it(t){var n,r;(n=it.__PosthogExtensions__)!=null&&n.postHogWebVitalsCallbacks&&t(),(r=it.__PosthogExtensions__)==null||r.loadExternalDependency==null||r.loadExternalDependency(this._instance,"web-vitals",(i=>{i?$s.error("failed to load script",i):t()}))}Ct(){var t=ge?ge.location.href:void 0;if(t){var n=this._instance.config.mask_personal_data_properties,r=this._instance.config.custom_personal_data_properties,i=n?Tu([],xu,r||[]):[];return U0(t,i,z0)}$s.error("Could not determine current URL")}}var iV=Hn("[Heatmaps]");function E5(e){return fr(e)&&"clientX"in e&&"clientY"in e&&os(e.clientX)&&os(e.clientY)}class aV{constructor(t){var n;this.kt=!1,this.P=!1,this.Ft=null,this.instance=t,this.kt=!((n=this.instance.persistence)==null||!n.props[Lb]),this.rageclicks=new t9(t.config.rageclick)}get flushIntervalMilliseconds(){var t=5e3;return fr(this.instance.config.capture_heatmaps)&&this.instance.config.capture_heatmaps.flush_interval_milliseconds&&(t=this.instance.config.capture_heatmaps.flush_interval_milliseconds),t}get isEnabled(){return He(this.instance.config.capture_heatmaps)?He(this.instance.config.enable_heatmaps)?this.kt:this.instance.config.enable_heatmaps:this.instance.config.capture_heatmaps!==!1}startIfEnabled(){if(this.isEnabled){if(this.P)return;iV.info("starting..."),this.Mt(),this.Ot()}else{var t;clearInterval((t=this.Ft)!==null&&t!==void 0?t:void 0),this.At(),this.getAndClearBuffer()}}onRemoteConfig(t){var n=!!t.heatmaps;this.instance.persistence&&this.instance.persistence.register({[Lb]:n}),this.kt=n,this.startIfEnabled()}getAndClearBuffer(){var t=this.N;return this.N=void 0,t}Dt(t){this.jt(t.originalEvent,"deadclick")}Ot(){this.Ft&&clearInterval(this.Ft),this.Ft=(function(t){return(t==null?void 0:t.visibilityState)==="visible"})(qe)?setInterval(this.Lt.bind(this),this.flushIntervalMilliseconds):null}Mt(){ge&&qe&&(this.Nt=this.Lt.bind(this),rr(ge,"beforeunload",this.Nt),this.Ut=t=>this.jt(t||(ge==null?void 0:ge.event)),rr(qe,"click",this.Ut,{capture:!0}),this.zt=t=>this.Ht(t||(ge==null?void 0:ge.event)),rr(qe,"mousemove",this.zt,{capture:!0}),this.Bt=new r9(this.instance,qY,this.Dt.bind(this)),this.Bt.startIfEnabled(),this.qt=this.Ot.bind(this),rr(qe,"visibilitychange",this.qt),this.P=!0)}At(){var t;ge&&qe&&(this.Nt&&ge.removeEventListener("beforeunload",this.Nt),this.Ut&&qe.removeEventListener("click",this.Ut,{capture:!0}),this.zt&&qe.removeEventListener("mousemove",this.zt,{capture:!0}),this.qt&&qe.removeEventListener("visibilitychange",this.qt),clearTimeout(this.Wt),(t=this.Bt)==null||t.stop(),this.P=!1)}Gt(t,n){var r=this.instance.scrollManager.scrollY(),i=this.instance.scrollManager.scrollX(),s=this.instance.scrollManager.scrollElement(),o=(function(c,d,f){for(var m=c;m&&sm(m)&&!il(m,"body");){if(m===f)return!1;if(Dt(d,ge==null?void 0:ge.getComputedStyle(m).position))return!0;m=KS(m)}return!1})(YS(t),["fixed","sticky"],s);return{x:t.clientX+(o?0:i),y:t.clientY+(o?0:r),target_fixed:o,type:n}}jt(t,n){var r;if(n===void 0&&(n="click"),!o5(t.target)&&E5(t)){var i=this.Gt(t,n);(r=this.rageclicks)!=null&&r.isRageClick(t.clientX,t.clientY,new Date().getTime())&&this.Vt(Ve({},i,{type:"rageclick"})),this.Vt(i)}}Ht(t){!o5(t.target)&&E5(t)&&(clearTimeout(this.Wt),this.Wt=setTimeout((()=>{this.Vt(this.Gt(t,"mousemove"))}),500))}Vt(t){if(ge){var n=ge.location.href,r=this.instance.config.mask_personal_data_properties,i=this.instance.config.custom_personal_data_properties,s=r?Tu([],xu,i||[]):[],o=U0(n,s,z0);this.N=this.N||{},this.N[o]||(this.N[o]=[]),this.N[o].push(t)}}Lt(){this.N&&!Zo(this.N)&&this.instance.capture("$$heatmap",{$heatmap_data:this.getAndClearBuffer()})}}class T5{constructor(t){this.Jt=(n,r,i)=>{i&&(i.noSessionId||i.activityTimeout||i.sessionPastMaximumLength)&&(je.info("[PageViewManager] Session rotated, clearing pageview state",{sessionId:n,changeReason:i}),this.Kt=void 0,this._instance.scrollManager.resetContext())},this._instance=t,this.Yt()}Yt(){var t;this.Xt=(t=this._instance.sessionManager)==null?void 0:t.onSessionId(this.Jt)}destroy(){var t;(t=this.Xt)==null||t.call(this),this.Xt=void 0}doPageView(t,n){var r,i=this.Qt(t,n);return this.Kt={pathname:(r=ge==null?void 0:ge.location.pathname)!==null&&r!==void 0?r:"",pageViewId:n,timestamp:t},this._instance.scrollManager.resetContext(),i}doPageLeave(t){var n;return this.Qt(t,(n=this.Kt)==null?void 0:n.pageViewId)}doEvent(){var t;return{$pageview_id:(t=this.Kt)==null?void 0:t.pageViewId}}Qt(t,n){var r=this.Kt;if(!r)return{$pageview_id:n};var i={$pageview_id:n,$prev_pageview_id:r.pageViewId},s=this._instance.scrollManager.getContext();if(s&&!this._instance.config.disable_scroll_properties){var{maxScrollHeight:o,lastScrollY:c,maxScrollY:d,maxContentHeight:f,lastContentY:m,maxContentY:p}=s;if(!(He(o)||He(c)||He(d)||He(f)||He(m)||He(p))){o=Math.ceil(o),c=Math.ceil(c),d=Math.ceil(d),f=Math.ceil(f),m=Math.ceil(m),p=Math.ceil(p);var v=o<=1?1:fa(c/o,0,1,je),_=o<=1?1:fa(d/o,0,1,je),T=f<=1?1:fa(m/f,0,1,je),x=f<=1?1:fa(p/f,0,1,je);i=Vn(i,{$prev_pageview_last_scroll:c,$prev_pageview_last_scroll_percentage:v,$prev_pageview_max_scroll:d,$prev_pageview_max_scroll_percentage:_,$prev_pageview_last_content:m,$prev_pageview_last_content_percentage:T,$prev_pageview_max_content:p,$prev_pageview_max_content_percentage:x})}}return r.pathname&&(i.$prev_pageview_pathname=r.pathname),r.timestamp&&(i.$prev_pageview_duration=(t.getTime()-r.timestamp.getTime())/1e3),i}}var Xa=(function(e){return e.GZipJS="gzip-js",e.Base64="base64",e})({}),zi=Uint8Array,ai=Uint16Array,cu=Uint32Array,dv=new zi([0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0,0,0,0]),hv=new zi([0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,0,0]),x5=new zi([16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15]),f9=function(e,t){for(var n=new ai(31),r=0;r<31;++r)n[r]=t+=1<<e[r-1];var i=new cu(n[30]);for(r=1;r<30;++r)for(var s=n[r];s<n[r+1];++s)i[s]=s-n[r]<<5|r;return[n,i]},m9=f9(dv,2),sV=m9[0],$b=m9[1];sV[28]=258,$b[258]=28;for(var S5=f9(hv,0)[1],p9=new ai(32768),An=0;An<32768;++An){var Bl=(43690&An)>>>1|(21845&An)<<1;Bl=(61680&(Bl=(52428&Bl)>>>2|(13107&Bl)<<2))>>>4|(3855&Bl)<<4,p9[An]=((65280&Bl)>>>8|(255&Bl)<<8)>>>1}var i0=function(e,t,n){for(var r=e.length,i=0,s=new ai(t);i<r;++i)++s[e[i]-1];var o,c=new ai(t);for(i=0;i<t;++i)c[i]=c[i-1]+s[i-1]<<1;for(o=new ai(r),i=0;i<r;++i)o[i]=p9[c[e[i]-1]++]>>>15-e[i];return o},Yl=new zi(288);for(An=0;An<144;++An)Yl[An]=8;for(An=144;An<256;++An)Yl[An]=9;for(An=256;An<280;++An)Yl[An]=7;for(An=280;An<288;++An)Yl[An]=8;var kf=new zi(32);for(An=0;An<32;++An)kf[An]=5;var lV=i0(Yl,9),oV=i0(kf,5),g9=function(e){return(e/8>>0)+(7&e&&1)},b9=function(e,t,n){(n==null||n>e.length)&&(n=e.length);var r=new(e instanceof ai?ai:e instanceof cu?cu:zi)(n-t);return r.set(e.subarray(t,n)),r},ja=function(e,t,n){n<<=7&t;var r=t/8>>0;e[r]|=n,e[r+1]|=n>>>8},Oc=function(e,t,n){n<<=7&t;var r=t/8>>0;e[r]|=n,e[r+1]|=n>>>8,e[r+2]|=n>>>16},Ag=function(e,t){for(var n=[],r=0;r<e.length;++r)e[r]&&n.push({s:r,f:e[r]});var i=n.length,s=n.slice();if(!i)return[new zi(0),0];if(i==1){var o=new zi(n[0].s+1);return o[n[0].s]=1,[o,1]}n.sort((function(V,B){return V.f-B.f})),n.push({s:-1,f:25001});var c=n[0],d=n[1],f=0,m=1,p=2;for(n[0]={s:-1,f:c.f+d.f,l:c,r:d};m!=i-1;)c=n[n[f].f<n[p].f?f++:p++],d=n[f!=m&&n[f].f<n[p].f?f++:p++],n[m++]={s:-1,f:c.f+d.f,l:c,r:d};var v=s[0].s;for(r=1;r<i;++r)s[r].s>v&&(v=s[r].s);var _=new ai(v+1),T=Gb(n[m-1],_,0);if(T>t){r=0;var x=0,k=T-t,A=1<<k;for(s.sort((function(V,B){return _[B.s]-_[V.s]||V.f-B.f}));r<i;++r){var O=s[r].s;if(!(_[O]>t))break;x+=A-(1<<T-_[O]),_[O]=t}for(x>>>=k;x>0;){var I=s[r].s;_[I]<t?x-=1<<t-_[I]++-1:++r}for(;r>=0&&x;--r){var $=s[r].s;_[$]==t&&(--_[$],++x)}T=t}return[new zi(_),T]},Gb=function(e,t,n){return e.s==-1?Math.max(Gb(e.l,t,n+1),Gb(e.r,t,n+1)):t[e.s]=n},w5=function(e){for(var t=e.length;t&&!e[--t];);for(var n=new ai(++t),r=0,i=e[0],s=1,o=function(d){n[r++]=d},c=1;c<=t;++c)if(e[c]==i&&c!=t)++s;else{if(!i&&s>2){for(;s>138;s-=138)o(32754);s>2&&(o(s>10?s-11<<5|28690:s-3<<5|12305),s=0)}else if(s>3){for(o(i),--s;s>6;s-=6)o(8304);s>2&&(o(s-3<<5|8208),s=0)}for(;s--;)o(i);s=1,i=e[c]}return[n.subarray(0,r),t]},Rc=function(e,t){for(var n=0,r=0;r<t.length;++r)n+=e[r]*t[r];return n},Yb=function(e,t,n){var r=n.length,i=g9(t+2);e[i]=255&r,e[i+1]=r>>>8,e[i+2]=255^e[i],e[i+3]=255^e[i+1];for(var s=0;s<r;++s)e[i+s+4]=n[s];return 8*(i+4+r)},A5=function(e,t,n,r,i,s,o,c,d,f,m){ja(t,m++,n),++i[256];for(var p=Ag(i,15),v=p[0],_=p[1],T=Ag(s,15),x=T[0],k=T[1],A=w5(v),O=A[0],I=A[1],$=w5(x),V=$[0],B=$[1],Z=new ai(19),ee=0;ee<O.length;++ee)Z[31&O[ee]]++;for(ee=0;ee<V.length;++ee)Z[31&V[ee]]++;for(var te=Ag(Z,7),Y=te[0],oe=te[1],he=19;he>4&&!Y[x5[he-1]];--he);var Se,fe,de,H,ie=f+5<<3,ve=Rc(i,Yl)+Rc(s,kf)+o,xe=Rc(i,v)+Rc(s,x)+o+14+3*he+Rc(Z,Y)+(2*Z[16]+3*Z[17]+7*Z[18]);if(ie<=ve&&ie<=xe)return Yb(t,m,e.subarray(d,d+f));if(ja(t,m,1+(xe<ve)),m+=2,xe<ve){Se=i0(v,_),fe=v,de=i0(x,k),H=x;var P=i0(Y,oe);for(ja(t,m,I-257),ja(t,m+5,B-1),ja(t,m+10,he-4),m+=14,ee=0;ee<he;++ee)ja(t,m+3*ee,Y[x5[ee]]);m+=3*he;for(var z=[O,V],J=0;J<2;++J){var D=z[J];for(ee=0;ee<D.length;++ee){var Ae=31&D[ee];ja(t,m,P[Ae]),m+=Y[Ae],Ae>15&&(ja(t,m,D[ee]>>>5&127),m+=D[ee]>>>12)}}}else Se=lV,fe=Yl,de=oV,H=kf;for(ee=0;ee<c;++ee)if(r[ee]>255){Ae=r[ee]>>>18&31,Oc(t,m,Se[Ae+257]),m+=fe[Ae+257],Ae>7&&(ja(t,m,r[ee]>>>23&31),m+=dv[Ae]);var Le=31&r[ee];Oc(t,m,de[Le]),m+=H[Le],Le>3&&(Oc(t,m,r[ee]>>>5&8191),m+=hv[Le])}else Oc(t,m,Se[r[ee]]),m+=fe[r[ee]];return Oc(t,m,Se[256]),m+fe[256]},uV=new cu([65540,131080,131088,131104,262176,1048704,1048832,2114560,2117632]),cV=(function(){for(var e=new cu(256),t=0;t<256;++t){for(var n=t,r=9;--r;)n=(1&n&&3988292384)^n>>>1;e[t]=n}return e})(),dV=function(e,t,n,r,i){return(function(s,o,c,d,f,m){var p=s.length,v=new zi(d+p+5*(1+Math.floor(p/7e3))+f),_=v.subarray(d,v.length-f),T=0;if(!o||p<8)for(var x=0;x<=p;x+=65535){var k=x+65535;k<p?T=Yb(_,T,s.subarray(x,k)):(_[x]=m,T=Yb(_,T,s.subarray(x,p)))}else{for(var A=uV[o-1],O=A>>>13,I=8191&A,$=(1<<c)-1,V=new ai(32768),B=new ai($+1),Z=Math.ceil(c/3),ee=2*Z,te=function(jt){return(s[jt]^s[jt+1]<<Z^s[jt+2]<<ee)&$},Y=new cu(25e3),oe=new ai(288),he=new ai(32),Se=0,fe=0,de=(x=0,0),H=0,ie=0;x<p;++x){var ve=te(x),xe=32767&x,P=B[ve];if(V[xe]=P,B[ve]=xe,H<=x){var z=p-x;if((Se>7e3||de>24576)&&z>423){T=A5(s,_,0,Y,oe,he,fe,de,ie,x-ie,T),de=Se=fe=0,ie=x;for(var J=0;J<286;++J)oe[J]=0;for(J=0;J<30;++J)he[J]=0}var D=2,Ae=0,Le=I,ze=xe-P&32767;if(z>2&&ve==te(x-ze))for(var at=Math.min(O,z)-1,_t=Math.min(32767,x),pt=Math.min(258,z);ze<=_t&&--Le&&xe!=P;){if(s[x+D]==s[x+D-ze]){for(var Tt=0;Tt<pt&&s[x+Tt]==s[x+Tt-ze];++Tt);if(Tt>D){if(D=Tt,Ae=ze,Tt>at)break;var kn=Math.min(ze,Tt-2),pr=0;for(J=0;J<kn;++J){var yt=x-ze+J+32768&32767,ct=yt-V[yt]+32768&32767;ct>pr&&(pr=ct,P=yt)}}}ze+=(xe=P)-(P=V[xe])+32768&32767}if(Ae){Y[de++]=268435456|$b[D]<<18|S5[Ae];var Ft=31&$b[D],Xe=31&S5[Ae];fe+=dv[Ft]+hv[Xe],++oe[257+Ft],++he[Xe],H=x+D,++Se}else Y[de++]=s[x],++oe[s[x]]}}T=A5(s,_,m,Y,oe,he,fe,de,ie,x-ie,T)}return b9(v,0,d+g9(T)+f)})(e,t.level==null?6:t.level,t.mem==null?Math.ceil(1.5*Math.max(8,Math.min(13,Math.log(e.length)))):12+t.mem,n,r,!0)},kg=function(e,t,n){for(;n;++t)e[t]=n,n>>>=8};function hV(e,t){t===void 0&&(t={});var n=(function(){var c=4294967295;return{p:function(d){for(var f=c,m=0;m<d.length;++m)f=cV[255&f^d[m]]^f>>>8;c=f},d:function(){return 4294967295^c}}})(),r=e.length;n.p(e);var i,s=dV(e,t,10+((i=t).filename&&i.filename.length+1||0),8),o=s.length;return(function(c,d){var f=d.filename;if(c[0]=31,c[1]=139,c[2]=8,c[8]=d.level<2?4:d.level==9?2:0,c[9]=3,d.mtime!=0&&kg(c,4,Math.floor(new Date(d.mtime||Date.now())/1e3)),f){c[3]=8;for(var m=0;m<=f.length;++m)c[m+10]=f.charCodeAt(m)}})(s,t),kg(s,o-8,n.d()),kg(s,o-4,r),s}var fV=function(e){var t,n,r,i,s="";for(t=n=0,r=(e=(e+"").replace(/\r\n/g,`
`).replace(/\r/g,`
`)).length,i=0;i<r;i++){var o=e.charCodeAt(i),c=null;o<128?n++:c=o>127&&o<2048?String.fromCharCode(o>>6|192,63&o|128):String.fromCharCode(o>>12|224,o>>6&63|128,63&o|128),Qi(c)||(n>t&&(s+=e.substring(t,n)),s+=c,t=n=i+1)}return n>t&&(s+=e.substring(t,e.length)),s},mV=!!kb||!!Ab,k5="text/plain",Cf=function(e,t,n){var r;n===void 0&&(n=!0);var[i,s]=e.split("?"),o=Ve({},t),c=(r=s==null?void 0:s.split("&").map((f=>{var m,[p,v]=f.split("="),_=n&&(m=o[p])!==null&&m!==void 0?m:v;return delete o[p],p+"="+_})))!==null&&r!==void 0?r:[],d=OY(o);return d&&c.push(d),i+"?"+c.join("&")},$c=(e,t)=>JSON.stringify(e,((n,r)=>typeof r=="bigint"?r.toString():r),t),Cg=e=>{var{data:t,compression:n}=e;if(t){if(n===Xa.GZipJS){var r=hV((function(d,f){var m=d.length;if(typeof TextEncoder<"u")return new TextEncoder().encode(d);for(var p=new zi(d.length+(d.length>>>1)),v=0,_=function(A){p[v++]=A},T=0;T<m;++T){if(v+5>p.length){var x=new zi(v+8+(m-T<<1));x.set(p),p=x}var k=d.charCodeAt(T);k<128||f?_(k):k<2048?(_(192|k>>>6),_(128|63&k)):k>55295&&k<57344?(_(240|(k=65536+(1047552&k)|1023&d.charCodeAt(++T))>>>18),_(128|k>>>12&63),_(128|k>>>6&63),_(128|63&k)):(_(224|k>>>12),_(128|k>>>6&63),_(128|63&k))}return b9(p,0,v)})($c(t)),{mtime:0}),i=new Blob([r],{type:k5});return{contentType:k5,body:i,estimatedSize:i.size}}if(n===Xa.Base64){var s=(function(d){var f,m,p,v,_,T="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=",x=0,k=0,A="",O=[];if(!d)return d;d=fV(d);do f=(_=d.charCodeAt(x++)<<16|d.charCodeAt(x++)<<8|d.charCodeAt(x++))>>18&63,m=_>>12&63,p=_>>6&63,v=63&_,O[k++]=T.charAt(f)+T.charAt(m)+T.charAt(p)+T.charAt(v);while(x<d.length);switch(A=O.join(""),d.length%3){case 1:A=A.slice(0,-2)+"==";break;case 2:A=A.slice(0,-1)+"="}return A})($c(t)),o=(d=>"data="+encodeURIComponent(typeof d=="string"?d:$c(d)))(s);return{contentType:"application/x-www-form-urlencoded",body:o,estimatedSize:new Blob([o]).size}}var c=$c(t);return{contentType:"application/json",body:c,estimatedSize:new Blob([c]).size}}},Vh=[];Ab&&Vh.push({transport:"fetch",method:e=>{var t,n,{contentType:r,body:i,estimatedSize:s}=(t=Cg(e))!==null&&t!==void 0?t:{},o=new Headers;_n(e.headers,(function(m,p){o.append(p,m)})),r&&o.append("Content-Type",r);var c=e.url,d=null;if(G6){var f=new G6;d={signal:f.signal,timeout:setTimeout((()=>f.abort()),e.timeout)}}Ab(c,Ve({method:(e==null?void 0:e.method)||"GET",headers:o,keepalive:e.method==="POST"&&(s||0)<52428.8,body:i,signal:(n=d)==null?void 0:n.signal},e.fetchOptions)).then((m=>m.text().then((p=>{var v={statusCode:m.status,text:p};if(m.status===200)try{v.json=JSON.parse(p)}catch(_){je.error(_)}e.callback==null||e.callback(v)})))).catch((m=>{je.error(m),e.callback==null||e.callback({statusCode:0,text:m})})).finally((()=>d?clearTimeout(d.timeout):null))}}),kb&&Vh.push({transport:"XHR",method:e=>{var t,n=new kb;n.open(e.method||"GET",e.url,!0);var{contentType:r,body:i}=(t=Cg(e))!==null&&t!==void 0?t:{};_n(e.headers,(function(s,o){n.setRequestHeader(o,s)})),r&&n.setRequestHeader("Content-Type",r),e.timeout&&(n.timeout=e.timeout),e.disableXHRCredentials||(n.withCredentials=!0),n.onreadystatechange=()=>{if(n.readyState===4){var s={statusCode:n.status,text:n.responseText};if(n.status===200)try{s.json=JSON.parse(n.responseText)}catch{}e.callback==null||e.callback(s)}},n.send(i)}}),yi!=null&&yi.sendBeacon&&Vh.push({transport:"sendBeacon",method:e=>{var t=Cf(e.url,{beacon:"1"});try{var n,{contentType:r,body:i}=(n=Cg(e))!==null&&n!==void 0?n:{},s=typeof i=="string"?new Blob([i],{type:r}):i;yi.sendBeacon(t,s)}catch{}}});var Nf=function(e,t){if(!(function(n){try{new RegExp(n)}catch{return!1}return!0})(t))return!1;try{return new RegExp(t).test(e)}catch{return!1}};function C5(e,t,n){return $c({distinct_id:e,userPropertiesToSet:t,userPropertiesToSetOnce:n})}var v9={exact:(e,t)=>t.some((n=>e.some((r=>n===r)))),is_not:(e,t)=>t.every((n=>e.every((r=>n!==r)))),regex:(e,t)=>t.some((n=>e.some((r=>Nf(n,r))))),not_regex:(e,t)=>t.every((n=>e.every((r=>!Nf(n,r))))),icontains:(e,t)=>t.map(Ih).some((n=>e.map(Ih).some((r=>n.includes(r))))),not_icontains:(e,t)=>t.map(Ih).every((n=>e.map(Ih).every((r=>!n.includes(r))))),gt:(e,t)=>t.some((n=>{var r=parseFloat(n);return!isNaN(r)&&e.some((i=>r>parseFloat(i)))})),lt:(e,t)=>t.some((n=>{var r=parseFloat(n);return!isNaN(r)&&e.some((i=>r<parseFloat(i)))}))},Ih=e=>e.toLowerCase();function _9(e,t){return!e||Object.entries(e).every((n=>{var[r,i]=n,s=t==null?void 0:t[r];if(He(s)||Qi(s))return!1;var o=[String(s)],c=v9[i.operator];return!!c&&c(i.values,o)}))}var Ng=Hn("[Error tracking]");class pV{constructor(t){var n,r;this.Zt=[],this.ti=new XG([new aY,new mY,new lY,new sY,new hY,new dY,new uY,new fY],iY()),this._instance=t,this.Zt=(n=(r=this._instance.persistence)==null?void 0:r.get_property(Pb))!==null&&n!==void 0?n:[]}onRemoteConfig(t){var n,r,i,s=(n=(r=t.errorTracking)==null?void 0:r.suppressionRules)!==null&&n!==void 0?n:[],o=(i=t.errorTracking)==null?void 0:i.captureExtensionExceptions;this.Zt=s,this._instance.persistence&&this._instance.persistence.register({[Pb]:this.Zt,[i5]:o})}get ii(){var t,n=!!this._instance.get_property(i5),r=this._instance.config.error_tracking.captureExtensionExceptions;return(t=r??n)!==null&&t!==void 0&&t}buildProperties(t,n){return this.ti.buildFromUnknown(t,{syntheticException:n==null?void 0:n.syntheticException,mechanism:{handled:n==null?void 0:n.handled}})}sendExceptionEvent(t){var n=t.$exception_list;if(this.ei(n)){if(this.ri(n))return void Ng.info("Skipping exception capture because a suppression rule matched");if(!this.ii&&this.si(n))return void Ng.info("Skipping exception capture because it was thrown by an extension");if(!this._instance.config.error_tracking.__capturePostHogExceptions&&this.ni(n))return void Ng.info("Skipping exception capture because it was thrown by the PostHog SDK")}return this._instance.capture("$exception",t,{_noTruncate:!0,_batchKey:"exceptionEvent"})}ri(t){if(t.length===0)return!1;var n=t.reduce(((r,i)=>{var{type:s,value:o}=i;return or(s)&&s.length>0&&r.$exception_types.push(s),or(o)&&o.length>0&&r.$exception_values.push(o),r}),{$exception_types:[],$exception_values:[]});return this.Zt.some((r=>{var i=r.values.map((s=>{var o,c=v9[s.operator],d=Qt(s.value)?s.value:[s.value],f=(o=n[s.key])!==null&&o!==void 0?o:[];return d.length>0&&c(d,f)}));return r.type==="OR"?i.some(Boolean):i.every(Boolean)}))}si(t){return t.flatMap((n=>{var r,i;return(r=(i=n.stacktrace)==null?void 0:i.frames)!==null&&r!==void 0?r:[]})).some((n=>n.filename&&n.filename.startsWith("chrome-extension://")))}ni(t){if(t.length>0){var n,r,i,s,o=(n=(r=t[0].stacktrace)==null?void 0:r.frames)!==null&&n!==void 0?n:[],c=o[o.length-1];return(i=c==null||(s=c.filename)==null?void 0:s.includes("posthog.com/static"))!==null&&i!==void 0&&i}return!1}ei(t){return!Wt(t)&&Qt(t)}}var Di=Hn("[FeatureFlags]"),Mc=Hn("[FeatureFlags]",{debugEnabled:!0}),Og="$active_feature_flags",Ho="$override_feature_flags",N5="$feature_flag_payloads",Ic="$override_feature_flag_payloads",O5="$feature_flag_request_id",R5="$feature_flag_evaluated_at",M5=e=>{var t={};for(var[n,r]of Yh(e||{}))r&&(t[n]=r);return t},gV=e=>{var t=e.flags;return t?(e.featureFlags=Object.fromEntries(Object.keys(t).map((n=>{var r;return[n,(r=t[n].variant)!==null&&r!==void 0?r:t[n].enabled]}))),e.featureFlagPayloads=Object.fromEntries(Object.keys(t).filter((n=>t[n].enabled)).filter((n=>{var r;return(r=t[n].metadata)==null?void 0:r.payload})).map((n=>{var r;return[n,(r=t[n].metadata)==null?void 0:r.payload]})))):Di.warn("Using an older version of the feature flags endpoint. Please upgrade your PostHog server to the latest version"),e},bV=(function(e){return e.FeatureFlags="feature_flags",e.Recordings="recordings",e})({});class vV{constructor(t){this.oi=!1,this.ai=!1,this.li=!1,this.ui=!1,this.hi=!1,this.di=!1,this.vi=!1,this.ci=!1,this._instance=t,this.featureFlagEventHandlers=[]}fi(){var t,n=(t=this._instance.config.evaluation_contexts)!==null&&t!==void 0?t:this._instance.config.evaluation_environments;return!this._instance.config.evaluation_environments||this._instance.config.evaluation_contexts||this.ci||(Di.warn("evaluation_environments is deprecated. Use evaluation_contexts instead. evaluation_environments will be removed in a future version."),this.ci=!0),n!=null&&n.length?n.filter((r=>{var i=r&&typeof r=="string"&&r.trim().length>0;return i||Di.error("Invalid evaluation context found:",r,"Expected non-empty string"),i})):[]}pi(){return this.fi().length>0}flags(){if(this._instance.config.__preview_remote_config)this.di=!0;else{var t=!this.gi&&(this._instance.config.advanced_disable_feature_flags||this._instance.config.advanced_disable_feature_flags_on_first_load);this.mi({disableFlags:t})}}get hasLoadedFlags(){return this.ai}getFlags(){return Object.keys(this.getFlagVariants())}getFlagsWithDetails(){var t=this._instance.get_property(Bb),n=this._instance.get_property(Ho),r=this._instance.get_property(Ic);if(!r&&!n)return t||{};var i=Vn({},t||{}),s=[...new Set([...Object.keys(r||{}),...Object.keys(n||{})])];for(var o of s){var c,d,f=i[o],m=n==null?void 0:n[o],p=He(m)?(c=f==null?void 0:f.enabled)!==null&&c!==void 0&&c:!!m,v=He(m)?f.variant:typeof m=="string"?m:void 0,_=r==null?void 0:r[o],T=Ve({},f,{enabled:p,variant:p?v??(f==null?void 0:f.variant):void 0});p!==(f==null?void 0:f.enabled)&&(T.original_enabled=f==null?void 0:f.enabled),v!==(f==null?void 0:f.variant)&&(T.original_variant=f==null?void 0:f.variant),_&&(T.metadata=Ve({},f==null?void 0:f.metadata,{payload:_,original_payload:f==null||(d=f.metadata)==null?void 0:d.payload})),i[o]=T}return this.oi||(Di.warn(" Overriding feature flag details!",{flagDetails:t,overriddenPayloads:r,finalDetails:i}),this.oi=!0),i}getFlagVariants(){var t=this._instance.get_property(Jo),n=this._instance.get_property(Ho);if(!n)return t||{};for(var r=Vn({},t),i=Object.keys(n),s=0;s<i.length;s++)r[i[s]]=n[i[s]];return this.oi||(Di.warn(" Overriding feature flags!",{enabledFlags:t,overriddenFlags:n,finalFlags:r}),this.oi=!0),r}getFlagPayloads(){var t=this._instance.get_property(N5),n=this._instance.get_property(Ic);if(!n)return t||{};for(var r=Vn({},t||{}),i=Object.keys(n),s=0;s<i.length;s++)r[i[s]]=n[i[s]];return this.oi||(Di.warn(" Overriding feature flag payloads!",{flagPayloads:t,overriddenPayloads:n,finalPayloads:r}),this.oi=!0),r}reloadFeatureFlags(){this.ui||this._instance.config.advanced_disable_feature_flags||this.gi||(this.gi=setTimeout((()=>{this.mi()}),5))}yi(){clearTimeout(this.gi),this.gi=void 0}ensureFlagsLoaded(){this.ai||this.li||this.gi||this.reloadFeatureFlags()}setAnonymousDistinctId(t){this.$anon_distinct_id=t}setReloadingPaused(t){this.ui=t}mi(t){var n;if(this.yi(),!this._instance.O())if(this.li)this.hi=!0;else{var r=this._instance.config.token,i=this._instance.get_property("$device_id"),s={token:r,distinct_id:this._instance.get_distinct_id(),groups:this._instance.getGroups(),$anon_distinct_id:this.$anon_distinct_id,person_properties:Ve({},((n=this._instance.persistence)==null?void 0:n.get_initial_props())||{},this._instance.get_property(qc)||{}),group_properties:this._instance.get_property(zl)};Qi(i)||He(i)||(s.$device_id=i),(t!=null&&t.disableFlags||this._instance.config.advanced_disable_feature_flags)&&(s.disable_flags=!0),this.pi()&&(s.evaluation_contexts=this.fi());var o=this._instance.config.__preview_remote_config,c=o?"/flags/?v=2":"/flags/?v=2&config=true",d=this._instance.config.advanced_only_evaluate_survey_feature_flags?"&only_evaluate_survey_feature_flags=true":"",f=this._instance.requestRouter.endpointFor("flags",c+d);o&&(s.timezone=h9()),this.li=!0,this._instance._send_request({method:"POST",url:f,data:s,compression:this._instance.config.disable_compression?void 0:Xa.Base64,timeout:this._instance.config.feature_flag_request_timeout_ms,callback:m=>{var p,v,_=!0;if(m.statusCode===200&&(this.hi||(this.$anon_distinct_id=void 0),_=!1),this.li=!1,this.di||(this.di=!0,this._instance.bi((v=m.json)!==null&&v!==void 0?v:{})),!s.disable_flags||this.hi)if(this.vi=!_,m.json&&(p=m.json.quotaLimited)!=null&&p.includes(bV.FeatureFlags))Di.warn("You have hit your feature flags quota limit, and will not be able to load feature flags until the quota is reset.  Please visit https://posthog.com/docs/billing/limits-alerts to learn more.");else{var T;s.disable_flags||this.receivedFeatureFlags((T=m.json)!==null&&T!==void 0?T:{},_),this.hi&&(this.hi=!1,this.mi())}}})}}getFeatureFlag(t,n){if(n===void 0&&(n={}),this.ai||this.getFlags()&&this.getFlags().length>0){var r=this.getFlagVariants()[t],i=""+r,s=this._instance.get_property(O5)||void 0,o=this._instance.get_property(R5)||void 0,c=this._instance.get_property(_f)||{};if((n.send_event||!("send_event"in n))&&(!(t in c)||!c[t].includes(i))){var d,f,m,p,v,_,T,x,k;Qt(c[t])?c[t].push(i):c[t]=[i],(d=this._instance.persistence)==null||d.register({[_f]:c});var A=this.getFeatureFlagDetails(t),O={$feature_flag:t,$feature_flag_response:r,$feature_flag_payload:this.getFeatureFlagPayload(t)||null,$feature_flag_request_id:s,$feature_flag_evaluated_at:o,$feature_flag_bootstrapped_response:((f=this._instance.config.bootstrap)==null||(f=f.featureFlags)==null?void 0:f[t])||null,$feature_flag_bootstrapped_payload:((m=this._instance.config.bootstrap)==null||(m=m.featureFlagPayloads)==null?void 0:m[t])||null,$used_bootstrap_value:!this.vi};He(A==null||(p=A.metadata)==null?void 0:p.version)||(O.$feature_flag_version=A.metadata.version);var I,$=(v=A==null||(_=A.reason)==null?void 0:_.description)!==null&&v!==void 0?v:A==null||(T=A.reason)==null?void 0:T.code;$&&(O.$feature_flag_reason=$),A!=null&&(x=A.metadata)!=null&&x.id&&(O.$feature_flag_id=A.metadata.id),He(A==null?void 0:A.original_variant)&&He(A==null?void 0:A.original_enabled)||(O.$feature_flag_original_response=He(A.original_variant)?A.original_enabled:A.original_variant),A!=null&&(k=A.metadata)!=null&&k.original_payload&&(O.$feature_flag_original_payload=A==null||(I=A.metadata)==null?void 0:I.original_payload),this._instance.capture("$feature_flag_called",O)}return r}Di.warn('getFeatureFlag for key "'+t+`" failed. Feature flags didn't load in time.`)}getFeatureFlagDetails(t){return this.getFlagsWithDetails()[t]}getFeatureFlagPayload(t){return this.getFlagPayloads()[t]}getRemoteConfigPayload(t,n){var r=this._instance.config.token,i={distinct_id:this._instance.get_distinct_id(),token:r};this.pi()&&(i.evaluation_contexts=this.fi()),this._instance._send_request({method:"POST",url:this._instance.requestRouter.endpointFor("flags","/flags/?v=2&config=true"),data:i,compression:this._instance.config.disable_compression?void 0:Xa.Base64,timeout:this._instance.config.feature_flag_request_timeout_ms,callback:s=>{var o,c=(o=s.json)==null?void 0:o.featureFlagPayloads;n((c==null?void 0:c[t])||void 0)}})}isFeatureEnabled(t,n){if(n===void 0&&(n={}),this.ai||this.getFlags()&&this.getFlags().length>0){var r=this.getFeatureFlag(t,n);return He(r)?void 0:!!r}Di.warn('isFeatureEnabled for key "'+t+`" failed. Feature flags didn't load in time.`)}addFeatureFlagsHandler(t){this.featureFlagEventHandlers.push(t)}removeFeatureFlagsHandler(t){this.featureFlagEventHandlers=this.featureFlagEventHandlers.filter((n=>n!==t))}receivedFeatureFlags(t,n){if(this._instance.persistence){this.ai=!0;var r=this.getFlagVariants(),i=this.getFlagPayloads(),s=this.getFlagsWithDetails();(function(o,c,d,f,m){d===void 0&&(d={}),f===void 0&&(f={}),m===void 0&&(m={});var p=gV(o),v=p.flags,_=p.featureFlags,T=p.featureFlagPayloads;if(_){var x=o.requestId,k=o.evaluatedAt;if(Qt(_)){Di.warn("v1 of the feature flags endpoint is deprecated. Please use the latest version.");var A={};if(_)for(var O=0;O<_.length;O++)A[_[O]]=!0;c&&c.register({[Og]:_,[Jo]:A})}else{var I=_,$=T,V=v;o.errorsWhileComputingFlags&&(I=Ve({},d,I),$=Ve({},f,$),V=Ve({},m,V)),c&&c.register(Ve({[Og]:Object.keys(M5(I)),[Jo]:I||{},[N5]:$||{},[Bb]:V||{}},x?{[O5]:x}:{},k?{[R5]:k}:{}))}}})(t,this._instance.persistence,r,i,s),this.wi(n)}}override(t,n){n===void 0&&(n=!1),Di.warn("override is deprecated. Please use overrideFeatureFlags instead."),this.overrideFeatureFlags({flags:t,suppressWarning:n})}overrideFeatureFlags(t){if(!this._instance.__loaded||!this._instance.persistence)return Di.uninitializedWarning("posthog.featureFlags.overrideFeatureFlags");if(t===!1)return this._instance.persistence.unregister(Ho),this._instance.persistence.unregister(Ic),this.wi(),Mc.info("All overrides cleared");if(t&&typeof t=="object"&&("flags"in t||"payloads"in t)){var n,r=t;if(this.oi=!!((n=r.suppressWarning)!==null&&n!==void 0&&n),"flags"in r){if(r.flags===!1)this._instance.persistence.unregister(Ho),Mc.info("Flag overrides cleared");else if(r.flags){if(Qt(r.flags)){for(var i={},s=0;s<r.flags.length;s++)i[r.flags[s]]=!0;this._instance.persistence.register({[Ho]:i})}else this._instance.persistence.register({[Ho]:r.flags});Mc.info("Flag overrides set",{flags:r.flags})}}return"payloads"in r&&(r.payloads===!1?(this._instance.persistence.unregister(Ic),Mc.info("Payload overrides cleared")):r.payloads&&(this._instance.persistence.register({[Ic]:r.payloads}),Mc.info("Payload overrides set",{payloads:r.payloads}))),void this.wi()}this.wi()}onFeatureFlags(t){if(this.addFeatureFlagsHandler(t),this.ai){var{flags:n,flagVariants:r}=this.xi();t(n,r)}return()=>this.removeFeatureFlagsHandler(t)}updateEarlyAccessFeatureEnrollment(t,n,r){var i,s=(this._instance.get_property(jc)||[]).find((f=>f.flagKey===t)),o={["$feature_enrollment/"+t]:n},c={$feature_flag:t,$feature_enrollment:n,$set:o};s&&(c.$early_access_feature_name=s.name),r&&(c.$feature_enrollment_stage=r),this._instance.capture("$feature_enrollment_update",c),this.setPersonPropertiesForFlags(o,!1);var d=Ve({},this.getFlagVariants(),{[t]:n});(i=this._instance.persistence)==null||i.register({[Og]:Object.keys(M5(d)),[Jo]:d}),this.wi()}getEarlyAccessFeatures(t,n,r){n===void 0&&(n=!1);var i=this._instance.get_property(jc),s=r?"&"+r.map((o=>"stage="+o)).join("&"):"";if(i&&!n)return t(i);this._instance._send_request({url:this._instance.requestRouter.endpointFor("api","/api/early_access_features/?token="+this._instance.config.token+s),method:"GET",callback:o=>{var c,d;if(o.json){var f=o.json.earlyAccessFeatures;return(c=this._instance.persistence)==null||c.unregister(jc),(d=this._instance.persistence)==null||d.register({[jc]:f}),t(f)}}})}xi(){var t=this.getFlags(),n=this.getFlagVariants();return{flags:t.filter((r=>n[r])),flagVariants:Object.keys(n).filter((r=>n[r])).reduce(((r,i)=>(r[i]=n[i],r)),{})}}wi(t){var{flags:n,flagVariants:r}=this.xi();this.featureFlagEventHandlers.forEach((i=>i(n,r,{errorsLoading:t})))}setPersonPropertiesForFlags(t,n){n===void 0&&(n=!0);var r=this._instance.get_property(qc)||{};this._instance.register({[qc]:Ve({},r,t)}),n&&this._instance.reloadFeatureFlags()}resetPersonPropertiesForFlags(){this._instance.unregister(qc)}setGroupPropertiesForFlags(t,n){n===void 0&&(n=!0);var r=this._instance.get_property(zl)||{};Object.keys(r).length!==0&&Object.keys(r).forEach((i=>{r[i]=Ve({},r[i],t[i]),delete t[i]})),this._instance.register({[zl]:Ve({},r,t)}),n&&this._instance.reloadFeatureFlags()}resetGroupPropertiesForFlags(t){if(t){var n=this._instance.get_property(zl)||{};this._instance.register({[zl]:Ve({},n,{[t]:{}})})}else this._instance.unregister(zl)}reset(){this.ai=!1,this.li=!1,this.ui=!1,this.hi=!1,this.di=!1,this.vi=!1,this.$anon_distinct_id=void 0,this.yi(),this.oi=!1}}var _V=["cookie","localstorage","localstorage+cookie","sessionstorage","memory"];class Rg{constructor(t,n){this.R=t,this.props={},this.Ei=!1,this.$i=(r=>{var i="";return r.token&&(i=r.token.replace(/\+/g,"PL").replace(/\//g,"SL").replace(/=/g,"EQ")),r.persistence_name?"ph_"+r.persistence_name:"ph_"+i+"_posthog"})(t),this.Y=this.Si(t),this.load(),t.debug&&je.info("Persistence loaded",t.persistence,Ve({},this.props)),this.update_config(t,t,n),this.save()}isDisabled(){return!!this.ki}Si(t){_V.indexOf(t.persistence.toLowerCase())===-1&&(je.critical("Unknown persistence type "+t.persistence+"; falling back to localStorage+cookie"),t.persistence="localStorage+cookie");var n=(function(i){i===void 0&&(i=[]);var s=[...FY,...i];return Ve({},Pn,{W:function(o){try{var c={};try{c=ua.W(o)||{}}catch{}var d=Vn(c,JSON.parse(Pn.q(o)||"{}"));return Pn.G(o,d),d}catch{}return null},G:function(o,c,d,f,m,p){try{Pn.G(o,c,void 0,void 0,p);var v={};s.forEach((_=>{c[_]&&(v[_]=c[_])})),Object.keys(v).length&&ua.G(o,v,d,f,m,p)}catch(_){Pn.B(_)}},V:function(o,c){try{ge==null||ge.localStorage.removeItem(o),ua.V(o,c)}catch(d){Pn.B(d)}}})})(t.cookie_persisted_properties||[]),r=t.persistence.toLowerCase();return r==="localstorage"&&Pn.H()?Pn:r==="localstorage+cookie"&&n.H()?n:r==="sessionstorage"&&Er.H()?Er:r==="memory"?HY:r==="cookie"?ua:n.H()?n:ua}properties(){var t={};return _n(this.props,(function(n,r){if(r===Jo&&fr(n))for(var i=Object.keys(n),s=0;s<i.length;s++)t["$feature/"+i[s]]=n[i[s]];else c=r,d=!1,(Qi(o=yY)?d:$6&&o.indexOf===$6?o.indexOf(c)!=-1:(_n(o,(function(f){if(d||(d=f===c))return bf})),d))||(t[r]=n);var o,c,d})),t}load(){if(!this.ki){var t=this.Y.W(this.$i);t&&(this.props=Vn({},t))}}save(){this.ki||this.Y.G(this.$i,this.props,this.Pi,this.Ti,this.Ii,this.R.debug)}remove(){this.Y.V(this.$i,!1),this.Y.V(this.$i,!0)}clear(){this.remove(),this.props={}}register_once(t,n,r){if(fr(t)){He(n)&&(n="None"),this.Pi=He(r)?this.Ci:r;var i=!1;if(_n(t,((s,o)=>{this.props.hasOwnProperty(o)&&this.props[o]!==n||(this.props[o]=s,i=!0)})),i)return this.save(),!0}return!1}register(t,n){if(fr(t)){this.Pi=He(n)?this.Ci:n;var r=!1;if(_n(t,((i,s)=>{t.hasOwnProperty(s)&&this.props[s]!==i&&(this.props[s]=i,r=!0)})),r)return this.save(),!0}return!1}unregister(t){t in this.props&&(delete this.props[t],this.save())}update_campaign_params(){if(!this.Ei){var t=s9(this.R.custom_campaign_params,this.R.mask_personal_data_properties,this.R.custom_personal_data_properties);Zo(lv(t))||this.register(t),this.Ei=!0}}update_search_keyword(){var t;this.register((t=qe==null?void 0:qe.referrer)?o9(t):{})}update_referrer_info(){var t;this.register_once({$referrer:u9(),$referring_domain:qe!=null&&qe.referrer&&((t=xf(qe.referrer))==null?void 0:t.host)||"$direct"},void 0)}set_initial_person_info(){this.props[Hb]||this.props[jb]||this.register_once({[yf]:c9(this.R.mask_personal_data_properties,this.R.custom_personal_data_properties)},void 0)}get_initial_props(){var t={};_n([jb,Hb],(o=>{var c=this.props[o];c&&_n(c,(function(d,f){t["$initial_"+Cb(f)]=d}))}));var n,r,i=this.props[yf];if(i){var s=(n=d9(i),r={},_n(n,(function(o,c){r["$initial_"+Cb(c)]=o})),r);Vn(t,s)}return t}safe_merge(t){return _n(this.props,(function(n,r){r in t||(t[r]=n)})),t}update_config(t,n,r){if(this.Ci=this.Pi=t.cookie_expiration,this.set_disabled(t.disable_persistence||!!r),this.set_cross_subdomain(t.cross_subdomain_cookie),this.set_secure(t.secure_cookie),t.persistence!==n.persistence||!((o,c)=>{if(o.length!==c.length)return!1;var d=[...o].sort(),f=[...c].sort();return d.every(((m,p)=>m===f[p]))})(t.cookie_persisted_properties||[],n.cookie_persisted_properties||[])){var i=this.Si(t),s=this.props;this.clear(),this.Y=i,this.props=s,this.save()}}set_disabled(t){this.ki=t,this.ki?this.remove():this.save()}set_cross_subdomain(t){t!==this.Ti&&(this.Ti=t,this.remove(),this.save())}set_secure(t){t!==this.Ii&&(this.Ii=t,this.remove(),this.save())}set_event_timer(t,n){var r=this.props[Hc]||{};r[t]=n,this.props[Hc]=r,this.save()}remove_event_timer(t){var n=(this.props[Hc]||{})[t];return He(n)||(delete this.props[Hc][t],this.save()),n}get_property(t){return this.props[t]}set_property(t,n){this.props[t]=n,this.save()}}var I5=Hn("[Product Tours]"),Mg="ph_product_tours";class yV{constructor(t){this.Ri=null,this.Fi=null,this._instance=t}onRemoteConfig(t){this._instance.persistence&&this._instance.persistence.register({[s5]:!(t==null||!t.productTours)}),this.loadIfEnabled()}loadIfEnabled(){var t,n;this.Ri||(t=this._instance).config.disable_product_tours||(n=t.persistence)==null||!n.get_property(s5)||this.it((()=>this.Mi()))}it(t){var n,r;(n=it.__PosthogExtensions__)!=null&&n.generateProductTours?t():(r=it.__PosthogExtensions__)==null||r.loadExternalDependency==null||r.loadExternalDependency(this._instance,"product-tours",(i=>{i?I5.error("Could not load product tours script",i):t()}))}Mi(){var t;!this.Ri&&(t=it.__PosthogExtensions__)!=null&&t.generateProductTours&&(this.Ri=it.__PosthogExtensions__.generateProductTours(this._instance,!0))}getProductTours(t,n){if(n===void 0&&(n=!1),!Qt(this.Fi)||n){var r=this._instance.persistence;if(r){var i=r.props[Mg];if(Qt(i)&&!n)return this.Fi=i,void t(i,{isLoaded:!0})}this._instance._send_request({url:this._instance.requestRouter.endpointFor("api","/api/product_tours/?token="+this._instance.config.token),method:"GET",callback:s=>{var o=s.statusCode;if(o!==200||!s.json){var c="Product Tours API could not be loaded, status: "+o;return I5.error(c),void t([],{isLoaded:!1,error:c})}var d=Qt(s.json.product_tours)?s.json.product_tours:[];this.Fi=d,r&&r.register({[Mg]:d}),t(d,{isLoaded:!0})}})}else t(this.Fi,{isLoaded:!0})}getActiveProductTours(t){Wt(this.Ri)?t([],{isLoaded:!1,error:"Product tours not loaded"}):this.Ri.getActiveProductTours(t)}showProductTour(t){var n;(n=this.Ri)==null||n.showTourById(t)}previewTour(t){this.Ri?this.Ri.previewTour(t):this.it((()=>{var n;this.Mi(),(n=this.Ri)==null||n.previewTour(t)}))}dismissProductTour(){var t;(t=this.Ri)==null||t.dismissTour("user_clicked_skip")}nextStep(){var t;(t=this.Ri)==null||t.nextStep()}previousStep(){var t;(t=this.Ri)==null||t.previousStep()}clearCache(){var t;this.Fi=null,(t=this._instance.persistence)==null||t.unregister(Mg)}resetTour(t){var n;(n=this.Ri)==null||n.resetTour(t)}resetAllTours(){var t;(t=this.Ri)==null||t.resetAllTours()}cancelPendingTour(t){var n;(n=this.Ri)==null||n.cancelPendingTour(t)}}var Dc=(function(e){return e.Activation="events",e.Cancellation="cancelEvents",e})({});(function(e){return e.Button="button",e.Tab="tab",e.Selector="selector",e})({});(function(e){return e.TopLeft="top_left",e.TopRight="top_right",e.TopCenter="top_center",e.MiddleLeft="middle_left",e.MiddleRight="middle_right",e.MiddleCenter="middle_center",e.Left="left",e.Center="center",e.Right="right",e.NextToTrigger="next_to_trigger",e})({});(function(e){return e.Top="top",e.Left="left",e.Right="right",e.Bottom="bottom",e})({});var Ig=(function(e){return e.Popover="popover",e.API="api",e.Widget="widget",e.ExternalSurvey="external_survey",e})({});(function(e){return e.Open="open",e.MultipleChoice="multiple_choice",e.SingleChoice="single_choice",e.Rating="rating",e.Link="link",e})({});(function(e){return e.NextQuestion="next_question",e.End="end",e.ResponseBased="response_based",e.SpecificQuestion="specific_question",e})({});(function(e){return e.Once="once",e.Recurring="recurring",e.Always="always",e})({});var Gc=(function(e){return e.SHOWN="survey shown",e.DISMISSED="survey dismissed",e.SENT="survey sent",e.ABANDONED="survey abandoned",e})({}),Dg=(function(e){return e.SURVEY_ID="$survey_id",e.SURVEY_NAME="$survey_name",e.SURVEY_RESPONSE="$survey_response",e.SURVEY_ITERATION="$survey_iteration",e.SURVEY_ITERATION_START_DATE="$survey_iteration_start_date",e.SURVEY_PARTIALLY_COMPLETED="$survey_partially_completed",e.SURVEY_SUBMISSION_ID="$survey_submission_id",e.SURVEY_QUESTIONS="$survey_questions",e.SURVEY_COMPLETED="$survey_completed",e.PRODUCT_TOUR_ID="$product_tour_id",e.SURVEY_LAST_SEEN_DATE="$survey_last_seen_date",e})({}),Vb=(function(e){return e.Popover="popover",e.Inline="inline",e})({}),hn=Hn("[Surveys]"),y9="seenSurvey_",EV=(e,t)=>{var n="$survey_"+t+"/"+e.id;return e.current_iteration&&e.current_iteration>0&&(n="$survey_"+t+"/"+e.id+"/"+e.current_iteration),n},D5=e=>((t,n)=>{var r=""+t+n.id;return n.current_iteration&&n.current_iteration>0&&(r=""+t+n.id+"_"+n.current_iteration),r})(y9,e),TV=[Ig.Popover,Ig.Widget,Ig.API],xV={ignoreConditions:!1,ignoreDelay:!1,displayType:Vb.Popover};class fv{constructor(){this.Oi={},this.Oi={}}on(t,n){return this.Oi[t]||(this.Oi[t]=[]),this.Oi[t].push(n),()=>{this.Oi[t]=this.Oi[t].filter((r=>r!==n))}}emit(t,n){for(var r of this.Oi[t]||[])r(n);for(var i of this.Oi["*"]||[])i(t,n)}}function jo(e,t,n){if(Wt(e))return!1;switch(n){case"exact":return e===t;case"contains":var r=t.replace(/[.*+?^${}()|[\]\\]/g,"\\$&").replace(/_/g,".").replace(/%/g,".*");return new RegExp(r,"i").test(e);case"regex":try{return new RegExp(t).test(e)}catch{return!1}default:return!1}}class SV{constructor(t){this.Ai=new fv,this.Di=(n,r)=>this.ji(n,r)&&this.Li(n,r)&&this.Ni(n,r)&&this.Ui(n,r),this.ji=(n,r)=>r==null||!r.event||(n==null?void 0:n.event)===(r==null?void 0:r.event),this._instance=t,this.zi=new Set,this.Hi=new Set}init(){var t;if(!He((t=this._instance)==null?void 0:t.Bi)){var n;(n=this._instance)==null||n.Bi(((r,i)=>{this.on(r,i)}))}}register(t){var n,r;if(!He((n=this._instance)==null?void 0:n.Bi)&&(t.forEach((o=>{var c,d;(c=this.Hi)==null||c.add(o),(d=o.steps)==null||d.forEach((f=>{var m;(m=this.zi)==null||m.add((f==null?void 0:f.event)||"")}))})),(r=this._instance)!=null&&r.autocapture)){var i,s=new Set;t.forEach((o=>{var c;(c=o.steps)==null||c.forEach((d=>{d!=null&&d.selector&&s.add(d==null?void 0:d.selector)}))})),(i=this._instance)==null||i.autocapture.setElementSelectors(s)}}on(t,n){var r;n!=null&&t.length!=0&&(this.zi.has(t)||this.zi.has(n==null?void 0:n.event))&&this.Hi&&((r=this.Hi)==null?void 0:r.size)>0&&this.Hi.forEach((i=>{this.qi(n,i)&&this.Ai.emit("actionCaptured",i.name)}))}Wi(t){this.onAction("actionCaptured",(n=>t(n)))}qi(t,n){if((n==null?void 0:n.steps)==null)return!1;for(var r of n.steps)if(this.Di(t,r))return!0;return!1}onAction(t,n){return this.Ai.on(t,n)}Li(t,n){if(n!=null&&n.url){var r,i=t==null||(r=t.properties)==null?void 0:r.$current_url;if(!i||typeof i!="string"||!jo(i,n.url,n.url_matching||"contains"))return!1}return!0}Ni(t,n){return!!this.Gi(t,n)&&!!this.Vi(t,n)&&!!this.Ji(t,n)}Gi(t,n){var r;if(n==null||!n.href)return!0;var i=this.Ki(t);if(i.length>0)return i.some((c=>jo(c.href,n.href,n.href_matching||"exact")));var s,o=(t==null||(r=t.properties)==null?void 0:r.$elements_chain)||"";return!!o&&jo((s=o.match(/(?::|")href="(.*?)"/))?s[1]:"",n.href,n.href_matching||"exact")}Vi(t,n){var r;if(n==null||!n.text)return!0;var i=this.Ki(t);if(i.length>0)return i.some((f=>jo(f.text,n.text,n.text_matching||"exact")||jo(f.$el_text,n.text,n.text_matching||"exact")));var s,o,c,d=(t==null||(r=t.properties)==null?void 0:r.$elements_chain)||"";return!!d&&(s=(function(f){for(var m,p=[],v=/(?::|")text="(.*?)"/g;!Wt(m=v.exec(f));)p.includes(m[1])||p.push(m[1]);return p})(d),o=n.text,c=n.text_matching||"exact",s.some((f=>jo(f,o,c))))}Ji(t,n){var r,i;if(n==null||!n.selector)return!0;var s=t==null||(r=t.properties)==null?void 0:r.$element_selectors;if(s!=null&&s.includes(n.selector))return!0;var o=(t==null||(i=t.properties)==null?void 0:i.$elements_chain)||"";if(n.selector_regex&&o)try{return new RegExp(n.selector_regex).test(o)}catch{return!1}return!1}Ki(t){var n;return(t==null||(n=t.properties)==null?void 0:n.$elements)==null?[]:t==null?void 0:t.properties.$elements}Ui(t,n){return n==null||!n.properties||n.properties.length===0||_9(n.properties.reduce(((r,i)=>{var s=Qt(i.value)?i.value.map(String):i.value!=null?[String(i.value)]:[];return r[i.key]={values:s,operator:i.operator||"exact"},r}),{}),t==null?void 0:t.properties)}}class wV{constructor(t){this._instance=t,this.Yi=new Map,this.Xi=new Map,this.Qi=new Map}Zi(t,n){return!!t&&_9(t.propertyFilters,n==null?void 0:n.properties)}te(t,n){var r=new Map;return t.forEach((i=>{var s;(s=i.conditions)==null||(s=s[n])==null||(s=s.values)==null||s.forEach((o=>{if(o!=null&&o.name){var c=r.get(o.name)||[];c.push(i.id),r.set(o.name,c)}}))})),r}ie(t,n,r){var i=(r===Dc.Activation?this.Yi:this.Xi).get(t),s=[];return this.ee((o=>{s=o.filter((c=>i==null?void 0:i.includes(c.id)))})),s.filter((o=>{var c,d=(c=o.conditions)==null||(c=c[r])==null||(c=c.values)==null?void 0:c.find((f=>f.name===t));return this.Zi(d,n)}))}register(t){var n;He((n=this._instance)==null?void 0:n.Bi)||(this.re(t),this.se(t))}se(t){var n=t.filter((r=>{var i,s;return((i=r.conditions)==null?void 0:i.actions)&&((s=r.conditions)==null||(s=s.actions)==null||(s=s.values)==null?void 0:s.length)>0}));n.length!==0&&(this.ne==null&&(this.ne=new SV(this._instance),this.ne.init(),this.ne.Wi((r=>{this.onAction(r)}))),n.forEach((r=>{var i,s,o,c,d;r.conditions&&(i=r.conditions)!=null&&i.actions&&(s=r.conditions)!=null&&(s=s.actions)!=null&&s.values&&((o=r.conditions)==null||(o=o.actions)==null||(o=o.values)==null?void 0:o.length)>0&&((c=this.ne)==null||c.register(r.conditions.actions.values),(d=r.conditions)==null||(d=d.actions)==null||(d=d.values)==null||d.forEach((f=>{if(f&&f.name){var m=this.Qi.get(f.name);m&&m.push(r.id),this.Qi.set(f.name,m||[r.id])}})))})))}re(t){var n,r=t.filter((s=>{var o,c;return((o=s.conditions)==null?void 0:o.events)&&((c=s.conditions)==null||(c=c.events)==null||(c=c.values)==null?void 0:c.length)>0})),i=t.filter((s=>{var o,c;return((o=s.conditions)==null?void 0:o.cancelEvents)&&((c=s.conditions)==null||(c=c.cancelEvents)==null||(c=c.values)==null?void 0:c.length)>0}));(r.length!==0||i.length!==0)&&((n=this._instance)==null||n.Bi(((s,o)=>{this.onEvent(s,o)})),this.Yi=this.te(t,Dc.Activation),this.Xi=this.te(t,Dc.Cancellation))}onEvent(t,n){var r,i=this.oe(),s=this.ae(),o=this.le(),c=((r=this._instance)==null||(r=r.persistence)==null?void 0:r.props[s])||[];if(o===t&&n&&c.length>0){var d,f;i.info("event matched, removing item from activated items",{event:t,eventPayload:n,existingActivatedItems:c});var m=(n==null||(d=n.properties)==null?void 0:d.$survey_id)||(n==null||(f=n.properties)==null?void 0:f.$product_tour_id);if(m){var p=c.indexOf(m);p>=0&&(c.splice(p,1),this.ue(c))}}else{if(this.Xi.has(t)){var v=this.ie(t,n,Dc.Cancellation);v.length>0&&(i.info("cancel event matched, cancelling items",{event:t,itemsToCancel:v.map((T=>T.id))}),v.forEach((T=>{var x=c.indexOf(T.id);x>=0&&c.splice(x,1),this.he(T.id)})),this.ue(c))}if(this.Yi.has(t)){i.info("event name matched",{event:t,eventPayload:n,items:this.Yi.get(t)});var _=this.ie(t,n,Dc.Activation);this.ue(c.concat(_.map((T=>T.id))||[]))}}}onAction(t){var n,r=this.ae(),i=((n=this._instance)==null||(n=n.persistence)==null?void 0:n.props[r])||[];this.Qi.has(t)&&this.ue(i.concat(this.Qi.get(t)||[]))}ue(t){var n,r=this.oe(),i=this.ae(),s=[...new Set(t)].filter((o=>!this.de(o)));r.info("updating activated items",{activatedItems:s}),(n=this._instance)==null||(n=n.persistence)==null||n.register({[i]:s})}getActivatedIds(){var t,n=this.ae(),r=(t=this._instance)==null||(t=t.persistence)==null?void 0:t.props[n];return r||[]}getEventToItemsMap(){return this.Yi}ve(){return this.ne}}class AV extends wV{constructor(t){super(t)}ae(){return"$surveys_activated"}le(){return Gc.SHOWN}ee(t){var n;(n=this._instance)==null||n.getSurveys(t)}he(t){var n;(n=this._instance)==null||n.cancelPendingSurvey(t)}oe(){return hn}de(){return!1}getSurveys(){return this.getActivatedIds()}getEventToSurveys(){return this.getEventToItemsMap()}}class kV{constructor(t){this.ce=void 0,this._surveyManager=null,this.fe=!1,this.pe=[],this.ge=null,this._instance=t,this._surveyEventReceiver=null}onRemoteConfig(t){if(!this._instance.config.disable_surveys){var n=t.surveys;if(Wt(n))return hn.warn("Flags not loaded yet. Not loading surveys.");var r=Qt(n);this.ce=r?n.length>0:n,hn.info("flags response received, isSurveysEnabled: "+this.ce),this.loadIfEnabled()}}reset(){localStorage.removeItem("lastSeenSurveyDate");for(var t=[],n=0;n<localStorage.length;n++){var r=localStorage.key(n);(r!=null&&r.startsWith(y9)||r!=null&&r.startsWith("inProgressSurvey_"))&&t.push(r)}t.forEach((i=>localStorage.removeItem(i)))}loadIfEnabled(){if(!this._surveyManager)if(this.fe)hn.info("Already initializing surveys, skipping...");else if(this._instance.config.disable_surveys)hn.info("Disabled. Not loading surveys.");else if(this._instance.config.cookieless_mode&&this._instance.consent.isOptedOut())hn.info("Not loading surveys in cookieless mode without consent.");else{var t=it==null?void 0:it.__PosthogExtensions__;if(t){if(!He(this.ce)||this._instance.config.advanced_enable_surveys){var n=this.ce||this._instance.config.advanced_enable_surveys;this.fe=!0;try{var r=t.generateSurveys;if(r)return void this._e(r,n);var i=t.loadExternalDependency;if(!i)return void this.me("PostHog loadExternalDependency extension not found.");i(this._instance,"surveys",(s=>{s||!t.generateSurveys?this.me("Could not load surveys script",s):this._e(t.generateSurveys,n)}))}catch(s){throw this.me("Error initializing surveys",s),s}finally{this.fe=!1}}}else hn.error("PostHog Extensions not found.")}}_e(t,n){this._surveyManager=t(this._instance,n),this._surveyEventReceiver=new AV(this._instance),hn.info("Surveys loaded successfully"),this.ye({isLoaded:!0})}me(t,n){hn.error(t,n),this.ye({isLoaded:!1,error:t})}onSurveysLoaded(t){return this.pe.push(t),this._surveyManager&&this.ye({isLoaded:!0}),()=>{this.pe=this.pe.filter((n=>n!==t))}}getSurveys(t,n){if(n===void 0&&(n=!1),this._instance.config.disable_surveys)return hn.info("Disabled. Not loading surveys."),t([]);var r,i=this._instance.get_property(Ub);if(i&&!n)return t(i,{isLoaded:!0});typeof Promise<"u"&&this.ge?this.ge.then((s=>{var{surveys:o,context:c}=s;return t(o,c)})):(typeof Promise<"u"&&(this.ge=new Promise((s=>{r=s}))),this._instance._send_request({url:this._instance.requestRouter.endpointFor("api","/api/surveys/?token="+this._instance.config.token),method:"GET",timeout:this._instance.config.surveys_request_timeout_ms,callback:s=>{var o;this.ge=null;var c=s.statusCode;if(c!==200||!s.json){var d="Surveys API could not be loaded, status: "+c;hn.error(d);var f={isLoaded:!1,error:d};return t([],f),void(r==null||r({surveys:[],context:f}))}var m,p=s.json.surveys||[],v=p.filter((T=>(function(x){return!(!x.start_date||x.end_date)})(T)&&((function(x){var k;return!((k=x.conditions)==null||(k=k.events)==null||(k=k.values)==null||!k.length)})(T)||(function(x){var k;return!((k=x.conditions)==null||(k=k.actions)==null||(k=k.values)==null||!k.length)})(T))));v.length>0&&((m=this._surveyEventReceiver)==null||m.register(v)),(o=this._instance.persistence)==null||o.register({[Ub]:p});var _={isLoaded:!0};t(p,_),r==null||r({surveys:p,context:_})}}))}ye(t){for(var n of this.pe)try{if(!t.isLoaded)return n([],t);this.getSurveys(n)}catch(r){hn.error("Error in survey callback",r)}}getActiveMatchingSurveys(t,n){if(n===void 0&&(n=!1),!Wt(this._surveyManager))return this._surveyManager.getActiveMatchingSurveys(t,n);hn.warn("init was not called")}be(t){var n=null;return this.getSurveys((r=>{var i;n=(i=r.find((s=>s.id===t)))!==null&&i!==void 0?i:null})),n}we(t){if(Wt(this._surveyManager))return{eligible:!1,reason:"SDK is not enabled or survey functionality is not yet loaded"};var n=typeof t=="string"?this.be(t):t;return n?this._surveyManager.checkSurveyEligibility(n):{eligible:!1,reason:"Survey not found"}}canRenderSurvey(t){if(Wt(this._surveyManager))return hn.warn("init was not called"),{visible:!1,disabledReason:"SDK is not enabled or survey functionality is not yet loaded"};var n=this.we(t);return{visible:n.eligible,disabledReason:n.reason}}canRenderSurveyAsync(t,n){return Wt(this._surveyManager)?(hn.warn("init was not called"),Promise.resolve({visible:!1,disabledReason:"SDK is not enabled or survey functionality is not yet loaded"})):new Promise((r=>{this.getSurveys((i=>{var s,o=(s=i.find((d=>d.id===t)))!==null&&s!==void 0?s:null;if(o){var c=this.we(o);r({visible:c.eligible,disabledReason:c.reason})}else r({visible:!1,disabledReason:"Survey not found"})}),n)}))}renderSurvey(t,n,r){var i;if(Wt(this._surveyManager))hn.warn("init was not called");else{var s=typeof t=="string"?this.be(t):t;if(s!=null&&s.id)if(TV.includes(s.type)){var o=qe==null?void 0:qe.querySelector(n);if(o)return(i=s.appearance)!=null&&i.surveyPopupDelaySeconds?(hn.info("Rendering survey "+s.id+" with delay of "+s.appearance.surveyPopupDelaySeconds+" seconds"),void setTimeout((()=>{var c,d;hn.info("Rendering survey "+s.id+" with delay of "+((c=s.appearance)==null?void 0:c.surveyPopupDelaySeconds)+" seconds"),(d=this._surveyManager)==null||d.renderSurvey(s,o,r),hn.info("Survey "+s.id+" rendered")}),1e3*s.appearance.surveyPopupDelaySeconds)):void this._surveyManager.renderSurvey(s,o,r);hn.warn("Survey element not found")}else hn.warn("Surveys of type "+s.type+" cannot be rendered in the app");else hn.warn("Survey not found")}}displaySurvey(t,n){var r;if(Wt(this._surveyManager))hn.warn("init was not called");else{var i=this.be(t);if(i){var s=i;if((r=i.appearance)!=null&&r.surveyPopupDelaySeconds&&n.ignoreDelay&&(s=Ve({},i,{appearance:Ve({},i.appearance,{surveyPopupDelaySeconds:0})})),n.displayType!==Vb.Popover&&n.initialResponses&&hn.warn("initialResponses is only supported for popover surveys. prefill will not be applied."),n.ignoreConditions===!1){var o=this.canRenderSurvey(i);if(!o.visible)return void hn.warn("Survey is not eligible to be displayed: ",o.disabledReason)}n.displayType!==Vb.Inline?this._surveyManager.handlePopoverSurvey(s,n):this.renderSurvey(s,n.selector,n.properties)}else hn.warn("Survey not found")}}cancelPendingSurvey(t){Wt(this._surveyManager)?hn.warn("init was not called"):this._surveyManager.cancelSurvey(t)}handlePageUnload(){var t;(t=this._surveyManager)==null||t.handlePageUnload()}}var qa=Hn("[Conversations]");class CV{constructor(t){this.xe=void 0,this._conversationsManager=null,this.Ee=!1,this.$e=null,this._instance=t}onRemoteConfig(t){if(!this._instance.config.disable_conversations){var n=t.conversations;Wt(n)||(ns(n)?this.xe=n:(this.xe=n.enabled,this.$e=n),this.loadIfEnabled())}}reset(){var t;(t=this._conversationsManager)==null||t.reset(),this._conversationsManager=null,this.xe=void 0,this.$e=null}loadIfEnabled(){if(!this._conversationsManager&&!this.Ee&&!(this._instance.config.disable_conversations||this._instance.config.cookieless_mode&&this._instance.consent.isOptedOut())){var t=it==null?void 0:it.__PosthogExtensions__;if(t&&!He(this.xe)&&this.xe)if(this.$e&&this.$e.token){this.Ee=!0;try{var n=t.initConversations;if(n)return this.Se(n),void(this.Ee=!1);var r=t.loadExternalDependency;if(!r)return void this.ke("PostHog loadExternalDependency extension not found.");r(this._instance,"conversations",(i=>{i||!t.initConversations?this.ke("Could not load conversations script",i):this.Se(t.initConversations),this.Ee=!1}))}catch(i){this.ke("Error initializing conversations",i),this.Ee=!1}}else qa.error("Conversations enabled but missing token in remote config.")}}Se(t){if(this.$e)try{this._conversationsManager=t(this.$e,this._instance),qa.info("Conversations loaded successfully")}catch(n){this.ke("Error completing conversations initialization",n)}else qa.error("Cannot complete initialization: remote config is null")}ke(t,n){qa.error(t,n),this._conversationsManager=null,this.Ee=!1}show(){this._conversationsManager?this._conversationsManager.show():qa.warn("Conversations not loaded yet.")}hide(){this._conversationsManager&&this._conversationsManager.hide()}isAvailable(){return this.xe===!0&&!Qi(this._conversationsManager)}isVisible(){var t,n;return(t=(n=this._conversationsManager)==null?void 0:n.isVisible())!==null&&t!==void 0&&t}sendMessage(t,n,r){var i=this;return Qo((function*(){return i._conversationsManager?i._conversationsManager.sendMessage(t,n,r):(qa.warn("Conversations not available yet."),null)}))()}getMessages(t,n){var r=this;return Qo((function*(){return r._conversationsManager?r._conversationsManager.getMessages(t,n):(qa.warn("Conversations not available yet."),null)}))()}markAsRead(t){var n=this;return Qo((function*(){return n._conversationsManager?n._conversationsManager.markAsRead(t):(qa.warn("Conversations not available yet."),null)}))()}getTickets(t){var n=this;return Qo((function*(){return n._conversationsManager?n._conversationsManager.getTickets(t):(qa.warn("Conversations not available yet."),null)}))()}getCurrentTicketId(){var t,n;return(t=(n=this._conversationsManager)==null?void 0:n.getCurrentTicketId())!==null&&t!==void 0?t:null}getWidgetSessionId(){var t,n;return(t=(n=this._conversationsManager)==null?void 0:n.getWidgetSessionId())!==null&&t!==void 0?t:null}}class NV{constructor(t){var n;this.Pe=!1,this.Te=!1,this._instance=t,this._instance&&(n=this._instance.config.logs)!=null&&n.captureConsoleLogs&&(this.Pe=!0)}onRemoteConfig(t){var n,r=(n=t.logs)==null?void 0:n.captureConsoleLogs;!Wt(r)&&r&&(this.Pe=!0,this.loadIfEnabled())}reset(){}loadIfEnabled(){if(this.Pe&&!this.Te){var t=Hn("[logs]"),n=it==null?void 0:it.__PosthogExtensions__;if(n){var r=n.loadExternalDependency;r?r(this._instance,"logs",(i=>{var s;i||(s=n.logs)==null||!s.initializeLogs?t.error("Could not load logs script",i):(n.logs.initializeLogs(this._instance),this.Te=!0)})):t.error("PostHog loadExternalDependency extension not found.")}else t.error("PostHog Extensions not found.")}}}var L5=Hn("[RateLimiter]");class OV{constructor(t){this.serverLimits={},this.lastEventRateLimited=!1,this.checkForLimiting=n=>{var r=n.text;if(r&&r.length)try{(JSON.parse(r).quota_limited||[]).forEach((i=>{L5.info((i||"events")+" is quota limited."),this.serverLimits[i]=new Date().getTime()+6e4}))}catch(i){return void L5.warn('could not rate limit - continuing. Error: "'+(i==null?void 0:i.message)+'"',{text:r})}},this.instance=t,this.lastEventRateLimited=this.clientRateLimitContext(!0).isRateLimited}get captureEventsPerSecond(){var t;return((t=this.instance.config.rate_limiting)==null?void 0:t.events_per_second)||10}get captureEventsBurstLimit(){var t;return Math.max(((t=this.instance.config.rate_limiting)==null?void 0:t.events_burst_limit)||10*this.captureEventsPerSecond,this.captureEventsPerSecond)}clientRateLimitContext(t){var n,r,i;t===void 0&&(t=!1);var{captureEventsBurstLimit:s,captureEventsPerSecond:o}=this,c=new Date().getTime(),d=(n=(r=this.instance.persistence)==null?void 0:r.get_property(Fb))!==null&&n!==void 0?n:{tokens:s,last:c};d.tokens+=(c-d.last)/1e3*o,d.last=c,d.tokens>s&&(d.tokens=s);var f=d.tokens<1;return f||t||(d.tokens=Math.max(0,d.tokens-1)),!f||this.lastEventRateLimited||t||this.instance.capture("$$client_ingestion_warning",{$$client_ingestion_warning_message:"posthog-js client rate limited. Config is set to "+o+" events per second and "+s+" events burst limit."},{skip_client_rate_limiting:!0}),this.lastEventRateLimited=f,(i=this.instance.persistence)==null||i.set_property(Fb,d),{isRateLimited:f,remainingTokens:d.tokens}}isServerRateLimited(t){var n=this.serverLimits[t||"events"]||!1;return n!==!1&&new Date().getTime()<n}}var Ul=Hn("[RemoteConfig]");class RV{constructor(t){this._instance=t}get remoteConfig(){var t;return(t=it._POSTHOG_REMOTE_CONFIG)==null||(t=t[this._instance.config.token])==null?void 0:t.config}Ie(t){var n,r;(n=it.__PosthogExtensions__)!=null&&n.loadExternalDependency?(r=it.__PosthogExtensions__)==null||r.loadExternalDependency==null||r.loadExternalDependency(this._instance,"remote-config",(()=>t(this.remoteConfig))):(Ul.error("PostHog Extensions not found. Cannot load remote config."),t())}Ce(t){this._instance._send_request({method:"GET",url:this._instance.requestRouter.endpointFor("assets","/array/"+this._instance.config.token+"/config"),callback:n=>{t(n.json)}})}load(){try{if(this.remoteConfig)return Ul.info("Using preloaded remote config",this.remoteConfig),void this.bi(this.remoteConfig);if(this._instance.O())return void Ul.warn("Remote config is disabled. Falling back to local config.");this.Ie((t=>{if(!t)return Ul.info("No config found after loading remote JS config. Falling back to JSON."),void this.Ce((n=>{this.bi(n)}));this.bi(t)}))}catch(t){Ul.error("Error loading remote config",t)}}bi(t){t?this._instance.config.__preview_remote_config?(this._instance.bi(t),t.hasFeatureFlags!==!1&&this._instance.featureFlags.ensureFlagsLoaded()):Ul.info("__preview_remote_config is disabled. Logging config instead",t):Ul.error("Failed to fetch remote config from PostHog.")}}var Kb=3e3;class MV{constructor(t,n){this.Re=!0,this.Fe=[],this.Me=fa((n==null?void 0:n.flush_interval_ms)||Kb,250,5e3,je.createLogger("flush interval"),Kb),this.Oe=t}enqueue(t){this.Fe.push(t),this.Ae||this.De()}unload(){this.je();var t=this.Fe.length>0?this.Le():{},n=Object.values(t);[...n.filter((r=>r.url.indexOf("/e")===0)),...n.filter((r=>r.url.indexOf("/e")!==0))].map((r=>{this.Oe(Ve({},r,{transport:"sendBeacon"}))}))}enable(){this.Re=!1,this.De()}De(){var t=this;this.Re||(this.Ae=setTimeout((()=>{if(this.je(),this.Fe.length>0){var n=this.Le(),r=function(){var s=n[i],o=new Date().getTime();s.data&&Qt(s.data)&&_n(s.data,(c=>{c.offset=Math.abs(c.timestamp-o),delete c.timestamp})),t.Oe(s)};for(var i in n)r()}}),this.Me))}je(){clearTimeout(this.Ae),this.Ae=void 0}Le(){var t={};return _n(this.Fe,(n=>{var r,i=n,s=(i?i.batchKey:null)||i.url;He(t[s])&&(t[s]=Ve({},i,{data:[]})),(r=t[s].data)==null||r.push(i.data)})),this.Fe=[],t}}var IV=["retriesPerformedSoFar"];class DV{constructor(t){this.Ne=!1,this.Ue=3e3,this.Fe=[],this._instance=t,this.Fe=[],this.ze=!0,!He(ge)&&"onLine"in ge.navigator&&(this.ze=ge.navigator.onLine,this.He=()=>{this.ze=!0,this.Lt()},this.Be=()=>{this.ze=!1},rr(ge,"online",this.He),rr(ge,"offline",this.Be))}get length(){return this.Fe.length}retriableRequest(t){var{retriesPerformedSoFar:n}=t,r=pS(t,IV);Ko(n)&&(r.url=Cf(r.url,{retry_count:n})),this._instance._send_request(Ve({},r,{callback:i=>{i.statusCode!==200&&(i.statusCode<400||i.statusCode>=500)&&(n??0)<10?this.qe(Ve({retriesPerformedSoFar:n},r)):r.callback==null||r.callback(i)}}))}qe(t){var n=t.retriesPerformedSoFar||0;t.retriesPerformedSoFar=n+1;var r=(function(o){var c=3e3*Math.pow(2,o),d=c/2,f=Math.min(18e5,c),m=(Math.random()-.5)*(f-d);return Math.ceil(f+m)})(n),i=Date.now()+r;this.Fe.push({retryAt:i,requestOptions:t});var s="Enqueued failed request for retry in "+r;navigator.onLine||(s+=" (Browser is offline)"),je.warn(s),this.Ne||(this.Ne=!0,this.We())}We(){if(this.Ge&&clearTimeout(this.Ge),this.Fe.length===0)return this.Ne=!1,void(this.Ge=void 0);this.Ge=setTimeout((()=>{this.ze&&this.Fe.length>0&&this.Lt(),this.We()}),this.Ue)}Lt(){var t=Date.now(),n=[],r=this.Fe.filter((s=>s.retryAt<t||(n.push(s),!1)));if(this.Fe=n,r.length>0)for(var{requestOptions:i}of r)this.retriableRequest(i)}unload(){for(var{requestOptions:t}of(this.Ge&&(clearTimeout(this.Ge),this.Ge=void 0),this.Ne=!1,He(ge)||(this.He&&(ge.removeEventListener("online",this.He),this.He=void 0),this.Be&&(ge.removeEventListener("offline",this.Be),this.Be=void 0)),this.Fe))try{this._instance._send_request(Ve({},t,{transport:"sendBeacon"}))}catch(n){je.error(n)}this.Fe=[]}}class LV{constructor(t){this.Ve=()=>{var n,r,i,s;this.Je||(this.Je={});var o=this.scrollElement(),c=this.scrollY(),d=o?Math.max(0,o.scrollHeight-o.clientHeight):0,f=c+((o==null?void 0:o.clientHeight)||0),m=(o==null?void 0:o.scrollHeight)||0;this.Je.lastScrollY=Math.ceil(c),this.Je.maxScrollY=Math.max(c,(n=this.Je.maxScrollY)!==null&&n!==void 0?n:0),this.Je.maxScrollHeight=Math.max(d,(r=this.Je.maxScrollHeight)!==null&&r!==void 0?r:0),this.Je.lastContentY=f,this.Je.maxContentY=Math.max(f,(i=this.Je.maxContentY)!==null&&i!==void 0?i:0),this.Je.maxContentHeight=Math.max(m,(s=this.Je.maxContentHeight)!==null&&s!==void 0?s:0)},this._instance=t}getContext(){return this.Je}resetContext(){var t=this.Je;return setTimeout(this.Ve,0),t}startMeasuringScrollPosition(){rr(ge,"scroll",this.Ve,{capture:!0}),rr(ge,"scrollend",this.Ve,{capture:!0}),rr(ge,"resize",this.Ve)}scrollElement(){if(!this._instance.config.scroll_root_selector)return ge==null?void 0:ge.document.documentElement;var t=Qt(this._instance.config.scroll_root_selector)?this._instance.config.scroll_root_selector:[this._instance.config.scroll_root_selector];for(var n of t){var r=ge==null?void 0:ge.document.querySelector(n);if(r)return r}}scrollY(){if(this._instance.config.scroll_root_selector){var t=this.scrollElement();return t&&t.scrollTop||0}return ge&&(ge.scrollY||ge.pageYOffset||ge.document.documentElement.scrollTop)||0}scrollX(){if(this._instance.config.scroll_root_selector){var t=this.scrollElement();return t&&t.scrollLeft||0}return ge&&(ge.scrollX||ge.pageXOffset||ge.document.documentElement.scrollLeft)||0}}var PV=e=>c9(e==null?void 0:e.config.mask_personal_data_properties,e==null?void 0:e.config.custom_personal_data_properties);class P5{constructor(t,n,r,i){this.Ke=s=>{var o=this.Ye();if(!o||o.sessionId!==s){var c={sessionId:s,props:this.Xe(this._instance)};this.Qe.register({[zb]:c})}},this._instance=t,this.Ze=n,this.Qe=r,this.Xe=i||PV,this.Ze.onSessionId(this.Ke)}Ye(){return this.Qe.props[zb]}getSetOnceProps(){var t,n=(t=this.Ye())==null?void 0:t.props;return n?"r"in n?d9(n):{$referring_domain:n.referringDomain,$pathname:n.initialPathName,utm_source:n.utm_source,utm_campaign:n.utm_campaign,utm_medium:n.utm_medium,utm_content:n.utm_content,utm_term:n.utm_term}:{}}getSessionProps(){var t={};return _n(lv(this.getSetOnceProps()),((n,r)=>{r==="$current_url"&&(r="url"),t["$session_entry_"+Cb(r)]=n})),t}}var Lg=Hn("[SessionId]");class B5{on(t,n){return this.tr.on(t,n)}constructor(t,n,r){var i;if(this.ir=[],this.er=void 0,this.tr=new fv,this.rr=(m,p)=>!(!Ko(m)||!Ko(p))&&Math.abs(m-p)>this.sessionTimeoutMs,!t.persistence)throw new Error("SessionIdManager requires a PostHogPersistence instance");if(t.config.cookieless_mode==="always")throw new Error('SessionIdManager cannot be used with cookieless_mode="always"');this.R=t.config,this.Qe=t.persistence,this.sr=void 0,this.nr=void 0,this._sessionStartTimestamp=null,this._sessionActivityTimestamp=null,this.ar=n||tl,this.lr=r||tl;var s=this.R.persistence_name||this.R.token,o=this.R.session_idle_timeout_seconds||1800;if(this._sessionTimeoutMs=1e3*fa(o,60,36e3,Lg.createLogger("session_idle_timeout_seconds"),1800),t.register({$configured_session_timeout_ms:this._sessionTimeoutMs}),this.ur(),this.hr="ph_"+s+"_window_id",this.dr="ph_"+s+"_primary_window_exists",this.vr()){var c=Er.W(this.hr),d=Er.W(this.dr);c&&!d?this.sr=c:Er.V(this.hr),Er.G(this.dr,!0)}if((i=this.R.bootstrap)!=null&&i.sessionID)try{var f=(m=>{var p=m.replace(/-/g,"");if(p.length!==32)throw new Error("Not a valid UUID");if(p[12]!=="7")throw new Error("Not a UUIDv7");return parseInt(p.substring(0,12),16)})(this.R.bootstrap.sessionID);this.cr(this.R.bootstrap.sessionID,new Date().getTime(),f)}catch(m){Lg.error("Invalid sessionID in bootstrap",m)}this.pr()}get sessionTimeoutMs(){return this._sessionTimeoutMs}onSessionId(t){return He(this.ir)&&(this.ir=[]),this.ir.push(t),this.nr&&t(this.nr,this.sr),()=>{this.ir=this.ir.filter((n=>n!==t))}}vr(){return this.R.persistence!=="memory"&&!this.Qe.ki&&Er.H()}gr(t){t!==this.sr&&(this.sr=t,this.vr()&&Er.G(this.hr,t))}_r(){return this.sr?this.sr:this.vr()?Er.W(this.hr):null}cr(t,n,r){t===this.nr&&n===this._sessionActivityTimestamp&&r===this._sessionStartTimestamp||(this._sessionStartTimestamp=r,this._sessionActivityTimestamp=n,this.nr=t,this.Qe.register({[vf]:[n,t,r]}))}mr(){var t=this.Qe.props[vf];return Qt(t)&&t.length===2&&t.push(t[0]),t||[0,null,0]}resetSessionId(){this.cr(null,null,null)}destroy(){clearTimeout(this.yr),this.yr=void 0,this.er&&ge&&(ge.removeEventListener("beforeunload",this.er,{capture:!1}),this.er=void 0),this.ir=[]}pr(){this.er=()=>{this.vr()&&Er.V(this.dr)},rr(ge,"beforeunload",this.er,{capture:!1})}checkAndGetSessionAndWindowId(t,n){if(t===void 0&&(t=!1),n===void 0&&(n=null),this.R.cookieless_mode==="always")throw new Error('checkAndGetSessionAndWindowId should not be called with cookieless_mode="always"');var r=n||new Date().getTime(),[i,s,o]=this.mr(),c=this._r(),d=Ko(o)&&Math.abs(r-o)>864e5,f=!1,m=!s,p=!m&&!t&&this.rr(r,i);m||p||d?(s=this.ar(),c=this.lr(),Lg.info("new session ID generated",{sessionId:s,windowId:c,changeReason:{noSessionId:m,activityTimeout:p,sessionPastMaximumLength:d}}),o=r,f=!0):c||(c=this.lr(),f=!0);var v=Ko(i)&&t&&!d?i:r,_=Ko(o)?o:new Date().getTime();return this.gr(c),this.cr(s,v,_),t||this.ur(),f&&this.ir.forEach((T=>T(s,c,f?{noSessionId:m,activityTimeout:p,sessionPastMaximumLength:d}:void 0))),{sessionId:s,windowId:c,sessionStartTimestamp:_,changeReason:f?{noSessionId:m,activityTimeout:p,sessionPastMaximumLength:d}:void 0,lastActivityTimestamp:i}}ur(){clearTimeout(this.yr),this.yr=setTimeout((()=>{var[t]=this.mr();if(this.rr(new Date().getTime(),t)){var n=this.nr;this.resetSessionId(),this.tr.emit("forcedIdleReset",{idleSessionId:n})}}),1.1*this.sessionTimeoutMs)}}var BV=["$set_once","$set"],Gs=Hn("[SiteApps]");class UV{constructor(t){this._instance=t,this.br=[],this.apps={}}get isEnabled(){return!!this._instance.config.opt_in_site_apps}wr(t,n){if(n){var r=this.globalsForEvent(n);this.br.push(r),this.br.length>1e3&&(this.br=this.br.slice(10))}}get siteAppLoaders(){var t;return(t=it._POSTHOG_REMOTE_CONFIG)==null||(t=t[this._instance.config.token])==null?void 0:t.siteApps}init(){if(this.isEnabled){var t=this._instance.Bi(this.wr.bind(this));this.Er=()=>{t(),this.br=[],this.Er=void 0}}}globalsForEvent(t){var n,r,i,s,o,c,d;if(!t)throw new Error("Event payload is required");var f={},m=this._instance.get_property("$groups")||[],p=this._instance.get_property("$stored_group_properties")||{};for(var[v,_]of Object.entries(p))f[v]={id:m[v],type:v,properties:_};var{$set_once:T,$set:x}=t;return{event:Ve({},pS(t,BV),{properties:Ve({},t.properties,x?{$set:Ve({},(n=(r=t.properties)==null?void 0:r.$set)!==null&&n!==void 0?n:{},x)}:{},T?{$set_once:Ve({},(i=(s=t.properties)==null?void 0:s.$set_once)!==null&&i!==void 0?i:{},T)}:{}),elements_chain:(o=(c=t.properties)==null?void 0:c.$elements_chain)!==null&&o!==void 0?o:"",distinct_id:(d=t.properties)==null?void 0:d.distinct_id}),person:{properties:this._instance.get_property("$stored_person_properties")},groups:f}}setupSiteApp(t){var n=this.apps[t.id],r=()=>{var c;!n.errored&&this.br.length&&(Gs.info("Processing "+this.br.length+" events for site app with id "+t.id),this.br.forEach((d=>n.processEvent==null?void 0:n.processEvent(d))),n.processedBuffer=!0),Object.values(this.apps).every((d=>d.processedBuffer||d.errored))&&((c=this.Er)==null||c.call(this))},i=!1,s=c=>{n.errored=!c,n.loaded=!0,Gs.info("Site app with id "+t.id+" "+(c?"loaded":"errored")),i&&r()};try{var{processEvent:o}=t.init({posthog:this._instance,callback:c=>{s(c)}});o&&(n.processEvent=o),i=!0}catch(c){Gs.error("Error while initializing PostHog app with config id "+t.id,c),s(!1)}if(i&&n.loaded)try{r()}catch(c){Gs.error("Error while processing buffered events PostHog app with config id "+t.id,c),n.errored=!0}}$r(){var t=this.siteAppLoaders||[];for(var n of t)this.apps[n.id]={id:n.id,loaded:!1,errored:!1,processedBuffer:!1};for(var r of t)this.setupSiteApp(r)}Sr(t){if(Object.keys(this.apps).length!==0){var n=this.globalsForEvent(t);for(var r of Object.values(this.apps))try{r.processEvent==null||r.processEvent(n)}catch(i){Gs.error("Error while processing event "+t.event+" for site app "+r.id,i)}}}onRemoteConfig(t){var n,r,i,s=this;if((n=this.siteAppLoaders)!=null&&n.length)return this.isEnabled?(this.$r(),void this._instance.on("eventCaptured",(f=>this.Sr(f)))):void Gs.error('PostHog site apps are disabled. Enable the "opt_in_site_apps" config to proceed.');if((r=this.Er)==null||r.call(this),(i=t.siteApps)!=null&&i.length)if(this.isEnabled){var o=function(f){var m;it["__$$ph_site_app_"+f]=s._instance,(m=it.__PosthogExtensions__)==null||m.loadSiteApp==null||m.loadSiteApp(s._instance,d,(p=>{if(p)return Gs.error("Error while initializing PostHog app with config id "+f,p)}))};for(var{id:c,url:d}of t.siteApps)o(c)}else Gs.error('PostHog site apps are disabled. Enable the "opt_in_site_apps" config to proceed.')}}var E9=function(e,t){if(!e)return!1;var n=e.userAgent;if(n&&V6(n,t))return!0;try{var r=e==null?void 0:e.userAgentData;if(r!=null&&r.brands&&r.brands.some((i=>V6(i==null?void 0:i.brand,t))))return!0}catch{}return!!e.webdriver},Yc=(function(e){return e.US="us",e.EU="eu",e.CUSTOM="custom",e})({}),U5="i.posthog.com";class zV{constructor(t){this.kr={},this.instance=t}get apiHost(){var t=this.instance.config.api_host.trim().replace(/\/$/,"");return t==="https://app.posthog.com"?"https://us.i.posthog.com":t}get flagsApiHost(){var t=this.instance.config.flags_api_host;return t?t.trim().replace(/\/$/,""):this.apiHost}get uiHost(){var t,n=(t=this.instance.config.ui_host)==null?void 0:t.replace(/\/$/,"");return n||(n=this.apiHost.replace("."+U5,".posthog.com")),n==="https://app.posthog.com"?"https://us.posthog.com":n}get region(){return this.kr[this.apiHost]||(/https:\/\/(app|us|us-assets)(\.i)?\.posthog\.com/i.test(this.apiHost)?this.kr[this.apiHost]=Yc.US:/https:\/\/(eu|eu-assets)(\.i)?\.posthog\.com/i.test(this.apiHost)?this.kr[this.apiHost]=Yc.EU:this.kr[this.apiHost]=Yc.CUSTOM),this.kr[this.apiHost]}endpointFor(t,n){if(n===void 0&&(n=""),n&&(n=n[0]==="/"?n:"/"+n),t==="ui")return this.uiHost+n;if(t==="flags")return this.flagsApiHost+n;if(this.region===Yc.CUSTOM)return this.apiHost+n;var r=U5+n;switch(t){case"assets":return"https://"+this.region+"-assets."+r;case"api":return"https://"+this.region+"."+r}}}var FV={icontains:(e,t)=>!!ge&&t.href.toLowerCase().indexOf(e.toLowerCase())>-1,not_icontains:(e,t)=>!!ge&&t.href.toLowerCase().indexOf(e.toLowerCase())===-1,regex:(e,t)=>!!ge&&Nf(t.href,e),not_regex:(e,t)=>!!ge&&!Nf(t.href,e),exact:(e,t)=>t.href===e,is_not:(e,t)=>t.href!==e};class kr{constructor(t){var n=this;this.getWebExperimentsAndEvaluateDisplayLogic=function(r){r===void 0&&(r=!1),n.getWebExperiments((i=>{kr.Pr("retrieved web experiments from the server"),n.Tr=new Map,i.forEach((s=>{if(s.feature_flag_key){var o;n.Tr&&(kr.Pr("setting flag key ",s.feature_flag_key," to web experiment ",s),(o=n.Tr)==null||o.set(s.feature_flag_key,s));var c=n._instance.getFeatureFlag(s.feature_flag_key);or(c)&&s.variants[c]&&n.Ir(s.name,c,s.variants[c].transforms)}else if(s.variants)for(var d in s.variants){var f=s.variants[d];kr.Cr(f)&&n.Ir(s.name,d,f.transforms)}}))}),r)},this._instance=t,this._instance.onFeatureFlags((r=>{this.onFeatureFlags(r)}))}onFeatureFlags(t){if(this._is_bot())kr.Pr("Refusing to render web experiment since the viewer is a likely bot");else if(!this._instance.config.disable_web_experiments){if(Wt(this.Tr))return this.Tr=new Map,this.loadIfEnabled(),void this.previewWebExperiment();kr.Pr("applying feature flags",t),t.forEach((n=>{var r;if(this.Tr&&(r=this.Tr)!=null&&r.has(n)){var i,s=this._instance.getFeatureFlag(n),o=(i=this.Tr)==null?void 0:i.get(n);s&&o!=null&&o.variants[s]&&this.Ir(o.name,s,o.variants[s].transforms)}}))}}previewWebExperiment(){var t=kr.getWindowLocation();if(t!=null&&t.search){var n=Sf(t==null?void 0:t.search,"__experiment_id"),r=Sf(t==null?void 0:t.search,"__experiment_variant");n&&r&&(kr.Pr("previewing web experiments "+n+" && "+r),this.getWebExperiments((i=>{this.Rr(parseInt(n),r,i)}),!1,!0))}}loadIfEnabled(){this._instance.config.disable_web_experiments||this.getWebExperimentsAndEvaluateDisplayLogic()}getWebExperiments(t,n,r){if(this._instance.config.disable_web_experiments&&!r)return t([]);var i=this._instance.get_property("$web_experiments");if(i&&!n)return t(i);this._instance._send_request({url:this._instance.requestRouter.endpointFor("api","/api/web_experiments/?token="+this._instance.config.token),method:"GET",callback:s=>{if(s.statusCode!==200||!s.json)return t([]);var o=s.json.experiments||[];return t(o)}})}Rr(t,n,r){var i=r.filter((s=>s.id===t));i&&i.length>0&&(kr.Pr("Previewing web experiment ["+i[0].name+"] with variant ["+n+"]"),this.Ir(i[0].name,n,i[0].variants[n].transforms))}static Cr(t){return!Wt(t.conditions)&&kr.Fr(t)&&kr.Mr(t)}static Fr(t){var n;if(Wt(t.conditions)||Wt((n=t.conditions)==null?void 0:n.url))return!0;var r,i,s,o=kr.getWindowLocation();return!!o&&((r=t.conditions)==null||!r.url||FV[(i=(s=t.conditions)==null?void 0:s.urlMatchType)!==null&&i!==void 0?i:"icontains"](t.conditions.url,o))}static getWindowLocation(){return ge==null?void 0:ge.location}static Mr(t){var n;if(Wt(t.conditions)||Wt((n=t.conditions)==null?void 0:n.utm))return!0;var r=s9();if(r.utm_source){var i,s,o,c,d,f,m,p,v=(i=t.conditions)==null||(i=i.utm)==null||!i.utm_campaign||((s=t.conditions)==null||(s=s.utm)==null?void 0:s.utm_campaign)==r.utm_campaign,_=(o=t.conditions)==null||(o=o.utm)==null||!o.utm_source||((c=t.conditions)==null||(c=c.utm)==null?void 0:c.utm_source)==r.utm_source,T=(d=t.conditions)==null||(d=d.utm)==null||!d.utm_medium||((f=t.conditions)==null||(f=f.utm)==null?void 0:f.utm_medium)==r.utm_medium,x=(m=t.conditions)==null||(m=m.utm)==null||!m.utm_term||((p=t.conditions)==null||(p=p.utm)==null?void 0:p.utm_term)==r.utm_term;return v&&T&&x&&_}return!1}static Pr(t){for(var n=arguments.length,r=new Array(n>1?n-1:0),i=1;i<n;i++)r[i-1]=arguments[i];je.info("[WebExperiments] "+t,r)}Ir(t,n,r){this._is_bot()?kr.Pr("Refusing to render web experiment since the viewer is a likely bot"):n!=="control"?r.forEach((i=>{if(i.selector){var s;kr.Pr("applying transform of variant "+n+" for experiment "+t+" ",i);var o=(s=document)==null?void 0:s.querySelectorAll(i.selector);o==null||o.forEach((c=>{var d=c;i.html&&(d.innerHTML=i.html),i.css&&d.setAttribute("style",i.css)}))}})):kr.Pr("Control variants leave the page unmodified.")}_is_bot(){return yi&&this._instance?E9(yi,this._instance.config.custom_blocked_useragents):void 0}}var HV=Hn("[PostHog ExternalIntegrations]"),jV={intercom:"intercom-integration",crispChat:"crisp-chat-integration"};class qV{constructor(t){this._instance=t}it(t,n){var r;(r=it.__PosthogExtensions__)==null||r.loadExternalDependency==null||r.loadExternalDependency(this._instance,t,(i=>{if(i)return HV.error("failed to load script",i);n()}))}startIfEnabledOrStop(){var t=this,n=function(o){var c,d,f;!i||(c=it.__PosthogExtensions__)!=null&&(c=c.integrations)!=null&&c[o]||t.it(jV[o],(()=>{var m;(m=it.__PosthogExtensions__)==null||(m=m.integrations)==null||(m=m[o])==null||m.start(t._instance)})),!i&&(d=it.__PosthogExtensions__)!=null&&(d=d.integrations)!=null&&d[o]&&((f=it.__PosthogExtensions__)==null||(f=f.integrations)==null||(f=f[o])==null||f.stop())};for(var[r,i]of Object.entries((s=this._instance.config.integrations)!==null&&s!==void 0?s:{})){var s;n(r)}}}var Wb="[SessionRecording]",Lc=Hn(Wb);class z5{get started(){var t;return!((t=this.Or)==null||!t.isStarted)}get status(){return this.Or?this.Or.status:this.Ar&&!this.Dr?"disabled":"lazy_loading"}constructor(t){if(this._forceAllowLocalhostNetworkCapture=!1,this.Ar=!1,this.jr=void 0,this._instance=t,!this._instance.sessionManager)throw Lc.error("started without valid sessionManager"),new Error(Wb+" started without valid sessionManager. This is a bug.");if(this._instance.config.cookieless_mode==="always")throw new Error(Wb+' cannot be used with cookieless_mode="always"')}get Dr(){var t,n=!((t=this._instance.get_property(Eg))==null||!t.enabled),r=!this._instance.config.disable_session_recording,i=this._instance.config.disable_session_recording||this._instance.consent.isOptedOut();return ge&&n&&r&&!i}startIfEnabledOrStop(t){var n;if(!this.Dr||(n=this.Or)==null||!n.isStarted){var r=!He(Object.assign)&&!He(Array.from);this.Dr&&r?(this.Lr(t),Lc.info("starting")):this.stopRecording()}}Lr(t){var n,r,i;this.Dr&&(it!=null&&(n=it.__PosthogExtensions__)!=null&&(n=n.rrweb)!=null&&n.record&&(r=it.__PosthogExtensions__)!=null&&r.initSessionRecording?this.Nr(t):(i=it.__PosthogExtensions__)==null||i.loadExternalDependency==null||i.loadExternalDependency(this._instance,this.Ur,(s=>{if(s)return Lc.error("could not load recorder",s);this.Nr(t)})))}stopRecording(){var t,n;(t=this.jr)==null||t.call(this),this.jr=void 0,(n=this.Or)==null||n.stop()}zr(){var t;(t=this._instance.persistence)==null||t.unregister(HS)}Hr(t){if(this._instance.persistence){var n,r,i=this._instance.persistence,s=()=>{var o=t.sessionRecording===!1?void 0:t.sessionRecording,c=o==null?void 0:o.sampleRate,d=Wt(c)?null:parseFloat(c);Wt(d)&&this.zr();var f=o==null?void 0:o.minimumDurationMilliseconds;i.register({[Eg]:Ve({enabled:!!o},o,{networkPayloadCapture:Ve({capturePerformance:t.capturePerformance},o==null?void 0:o.networkPayloadCapture),canvasRecording:{enabled:o==null?void 0:o.recordCanvas,fps:o==null?void 0:o.canvasFps,quality:o==null?void 0:o.canvasQuality},sampleRate:d,minimumDurationMilliseconds:He(f)?null:f,endpoint:o==null?void 0:o.endpoint,triggerMatchType:o==null?void 0:o.triggerMatchType,masking:o==null?void 0:o.masking,urlTriggers:o==null?void 0:o.urlTriggers})})};s(),(n=this.jr)==null||n.call(this),this.jr=(r=this._instance.sessionManager)==null?void 0:r.onSessionId(s)}}onRemoteConfig(t){"sessionRecording"in t?t.sessionRecording!==!1?(this.Hr(t),this.Ar=!0,this.startIfEnabledOrStop()):this.Ar=!0:Lc.info("skipping remote config with no sessionRecording",t)}log(t,n){var r;n===void 0&&(n="log"),(r=this.Or)!=null&&r.log?this.Or.log(t,n):Lc.warn("log called before recorder was ready")}get Ur(){var t,n,r=(t=this._instance)==null||(t=t.persistence)==null?void 0:t.get_property(Eg);return(r==null||(n=r.scriptConfig)==null?void 0:n.script)||"lazy-recorder"}Nr(t){var n,r;if((n=it.__PosthogExtensions__)==null||!n.initSessionRecording)throw Error("Called on script loaded before session recording is available");this.Or||(this.Or=(r=it.__PosthogExtensions__)==null?void 0:r.initSessionRecording(this._instance),this.Or._forceAllowLocalhostNetworkCapture=this._forceAllowLocalhostNetworkCapture),this.Or.start(t)}onRRwebEmit(t){var n;(n=this.Or)==null||n.onRRwebEmit==null||n.onRRwebEmit(t)}overrideLinkedFlag(){var t,n;this.Or||(n=this._instance.persistence)==null||n.register({$replay_override_linked_flag:!0}),(t=this.Or)==null||t.overrideLinkedFlag()}overrideSampling(){var t,n;this.Or||(n=this._instance.persistence)==null||n.register({$replay_override_sampling:!0}),(t=this.Or)==null||t.overrideSampling()}overrideTrigger(t){var n,r;this.Or||(r=this._instance.persistence)==null||r.register({[t==="url"?"$replay_override_url_trigger":"$replay_override_event_trigger"]:!0}),(n=this.Or)==null||n.overrideTrigger(t)}get sdkDebugProperties(){var t;return((t=this.Or)==null?void 0:t.sdkDebugProperties)||{$recording_status:this.status}}tryAddCustomEvent(t,n){var r;return!((r=this.Or)==null||!r.tryAddCustomEvent(t,n))}}var a0={},Xb=()=>{},Wo="posthog",T9=!mV&&(ni==null?void 0:ni.indexOf("MSIE"))===-1&&(ni==null?void 0:ni.indexOf("Mozilla"))===-1,F5=e=>{var t;return Ve({api_host:"https://us.i.posthog.com",flags_api_host:null,ui_host:null,token:"",autocapture:!0,cross_subdomain_cookie:_Y(qe==null?void 0:qe.location),persistence:"localStorage+cookie",persistence_name:"",cookie_persisted_properties:[],loaded:Xb,save_campaign_params:!0,custom_campaign_params:[],custom_blocked_useragents:[],save_referrer:!0,capture_pageleave:"if_capture_pageview",defaults:e??"unset",__preview_deferred_init_extensions:!1,debug:ii&&or(ii==null?void 0:ii.search)&&ii.search.indexOf("__posthog_debug=true")!==-1||!1,cookie_expiration:365,upgrade:!1,disable_session_recording:!1,disable_persistence:!1,disable_web_experiments:!0,disable_surveys:!1,disable_surveys_automatic_display:!1,disable_conversations:!1,disable_product_tours:!0,disable_external_dependency_loading:!1,enable_recording_console_log:void 0,secure_cookie:(ge==null||(t=ge.location)==null?void 0:t.protocol)==="https:",ip:!1,opt_out_capturing_by_default:!1,opt_out_persistence_by_default:!1,opt_out_useragent_filter:!1,opt_out_capturing_persistence_type:"localStorage",consent_persistence_name:null,opt_out_capturing_cookie_prefix:null,opt_in_site_apps:!1,property_denylist:[],respect_dnt:!1,sanitize_properties:null,request_headers:{},request_batching:!0,properties_string_max_length:65535,mask_all_element_attributes:!1,mask_all_text:!1,mask_personal_data_properties:!1,custom_personal_data_properties:[],advanced_disable_flags:!1,advanced_disable_decide:!1,advanced_disable_feature_flags:!1,advanced_disable_feature_flags_on_first_load:!1,advanced_only_evaluate_survey_feature_flags:!1,advanced_enable_surveys:!1,advanced_disable_toolbar_metrics:!1,feature_flag_request_timeout_ms:3e3,surveys_request_timeout_ms:1e4,on_request_error:n=>{var r="Bad HTTP status: "+n.statusCode+" "+n.text;je.error(r)},get_device_id:n=>n,capture_performance:void 0,name:"posthog",bootstrap:{},disable_compression:!1,session_idle_timeout_seconds:1800,person_profiles:"identified_only",before_send:void 0,request_queue_config:{flush_interval_ms:Kb},error_tracking:{},_onCapture:Xb,__preview_eager_load_replay:!1},(n=>({rageclick:!(n&&n>="2025-11-30")||{content_ignorelist:!0},capture_pageview:!(n&&n>="2025-05-24")||"history_change",session_recording:n&&n>="2025-11-30"?{strictMinimumDuration:!0}:{}}))(e))},H5=e=>{var t={};He(e.process_person)||(t.person_profiles=e.process_person),He(e.xhr_headers)||(t.request_headers=e.xhr_headers),He(e.cookie_name)||(t.persistence_name=e.cookie_name),He(e.disable_cookie)||(t.disable_persistence=e.disable_cookie),He(e.store_google)||(t.save_campaign_params=e.store_google),He(e.verbose)||(t.debug=e.verbose);var n=Vn({},t,e);return Qt(e.property_blacklist)&&(He(e.property_denylist)?n.property_denylist=e.property_blacklist:Qt(e.property_denylist)?n.property_denylist=[...e.property_blacklist,...e.property_denylist]:je.error("Invalid value for property_denylist config: "+e.property_denylist)),n};class $V{constructor(){this.__forceAllowLocalhost=!1}get Br(){return this.__forceAllowLocalhost}set Br(t){je.error("WebPerformanceObserver is deprecated and has no impact on network capture. Use `_forceAllowLocalhostNetworkCapture` on `posthog.sessionRecording`"),this.__forceAllowLocalhost=t}}class lm{get decideEndpointWasHit(){var t,n;return(t=(n=this.featureFlags)==null?void 0:n.hasLoadedFlags)!==null&&t!==void 0&&t}get flagsEndpointWasHit(){var t,n;return(t=(n=this.featureFlags)==null?void 0:n.hasLoadedFlags)!==null&&t!==void 0&&t}constructor(){this.webPerformance=new $V,this.qr=!1,this.version=$a.LIB_VERSION,this.Wr=new fv,this._calculate_event_properties=this.calculateEventProperties.bind(this),this.config=F5(),this.SentryIntegration=KY,this.sentryIntegration=t=>(function(n,r){var i=a9(n,r);return{name:i9,processEvent:s=>i(s)}})(this,t),this.__request_queue=[],this.__loaded=!1,this.analyticsDefaultEndpoint="/e/",this.Gr=!1,this.Vr=null,this.Jr=null,this.Kr=null,this.featureFlags=new vV(this),this.toolbar=new XY(this),this.scrollManager=new LV(this),this.pageViewManager=new T5(this),this.surveys=new kV(this),this.conversations=new CV(this),this.logs=new NV(this),this.experiments=new kr(this),this.exceptions=new pV(this),this.rateLimiter=new OV(this),this.requestRouter=new zV(this),this.consent=new jY(this),this.externalIntegrations=new qV(this),this.people={set:(t,n,r)=>{var i=or(t)?{[t]:n}:t;this.setPersonProperties(i),r==null||r({})},set_once:(t,n,r)=>{var i=or(t)?{[t]:n}:t;this.setPersonProperties(void 0,i),r==null||r({})}},this.on("eventCaptured",(t=>je.info('send "'+(t==null?void 0:t.event)+'"',t)))}init(t,n,r){if(r&&r!==Wo){var i,s=(i=a0[r])!==null&&i!==void 0?i:new lm;return s._init(t,n,r),a0[r]=s,a0[Wo][r]=s,s}return this._init(t,n,r)}_init(t,n,r){var i;if(n===void 0&&(n={}),He(t)||Nb(t))return je.critical("PostHog was initialized without a token. This likely indicates a misconfiguration. Please check the first argument passed to posthog.init()"),this;if(this.__loaded)return console.warn("[PostHog.js]","You have already initialized PostHog! Re-initializing is a no-op"),this;this.__loaded=!0,this.config={},n.debug=this.Yr(n.debug),this.Xr=n,this.Qr=[],n.person_profiles&&(this.Jr=n.person_profiles),this.set_config(Vn({},F5(n.defaults),H5(n),{name:r,token:t})),this.config.on_xhr_error&&je.error("on_xhr_error is deprecated. Use on_request_error instead"),this.compression=n.disable_compression?void 0:Xa.GZipJS;var s=this.Zr();this.persistence=new Rg(this.config,s),this.sessionPersistence=this.config.persistence==="sessionStorage"||this.config.persistence==="memory"?this.persistence:new Rg(Ve({},this.config,{persistence:"sessionStorage"}),s);var o=Ve({},this.persistence.props),c=Ve({},this.sessionPersistence.props);this.register({$initialization_time:new Date().toISOString()}),this.ts=new MV((O=>this.es(O)),this.config.request_queue_config),this.rs=new DV(this),this.__request_queue=[];var d=this.config.cookieless_mode==="always"||this.config.cookieless_mode==="on_reject"&&this.consent.isExplicitlyOptedOut();if(d||(this.sessionManager=new B5(this),this.sessionPropsManager=new P5(this,this.sessionManager,this.persistence)),this.config.__preview_deferred_init_extensions?(je.info("Deferring extension initialization to improve startup performance"),setTimeout((()=>{this.ss(d)}),0)):(je.info("Initializing extensions synchronously"),this.ss(d)),$a.DEBUG=$a.DEBUG||this.config.debug,$a.DEBUG&&je.info("Starting in debug mode",{this:this,config:n,thisC:Ve({},this.config),p:o,s:c}),((i=n.bootstrap)==null?void 0:i.distinctID)!==void 0){var f,m,p=this.config.get_device_id(tl()),v=(f=n.bootstrap)!=null&&f.isIdentifiedID?p:n.bootstrap.distinctID;this.persistence.set_property(Ga,(m=n.bootstrap)!=null&&m.isIdentifiedID?"identified":"anonymous"),this.register({distinct_id:n.bootstrap.distinctID,$device_id:v})}if(this.ns()){var _,T,x=Object.keys(((_=n.bootstrap)==null?void 0:_.featureFlags)||{}).filter((O=>{var I;return!((I=n.bootstrap)==null||(I=I.featureFlags)==null||!I[O])})).reduce(((O,I)=>{var $;return O[I]=(($=n.bootstrap)==null||($=$.featureFlags)==null?void 0:$[I])||!1,O}),{}),k=Object.keys(((T=n.bootstrap)==null?void 0:T.featureFlagPayloads)||{}).filter((O=>x[O])).reduce(((O,I)=>{var $,V;return($=n.bootstrap)!=null&&($=$.featureFlagPayloads)!=null&&$[I]&&(O[I]=(V=n.bootstrap)==null||(V=V.featureFlagPayloads)==null?void 0:V[I]),O}),{});this.featureFlags.receivedFeatureFlags({featureFlags:x,featureFlagPayloads:k})}if(d)this.register_once({distinct_id:kc,$device_id:null},"");else if(!this.get_distinct_id()){var A=this.config.get_device_id(tl());this.register_once({distinct_id:A,$device_id:A},""),this.persistence.set_property(Ga,"anonymous")}return rr(ge,"onpagehide"in self?"pagehide":"unload",this._handle_unload.bind(this),{passive:!1}),this.toolbar.maybeLoadToolbar(),n.segment?VY(this,(()=>this.os())):this.os(),nl(this.config._onCapture)&&this.config._onCapture!==Xb&&(je.warn("onCapture is deprecated. Please use `before_send` instead"),this.on("eventCaptured",(O=>this.config._onCapture(O.event,O)))),this.config.ip&&je.warn('The `ip` config option has NO EFFECT AT ALL and has been deprecated. Use a custom transformation or "Discard IP data" project setting instead. See https://posthog.com/tutorials/web-redact-properties#hiding-customer-ip-address for more information.'),this}ss(t){var n=performance.now();this.historyAutocapture=new YY(this),this.historyAutocapture.startIfEnabled();var r=[];r.push((()=>{new ZY(this).startIfEnabledOrStop()})),r.push((()=>{var i;this.siteApps=new UV(this),(i=this.siteApps)==null||i.init()})),t||r.push((()=>{this.sessionRecording=new z5(this),this.sessionRecording.startIfEnabledOrStop()})),this.config.disable_scroll_properties||r.push((()=>{this.scrollManager.startMeasuringScrollPosition()})),r.push((()=>{this.autocapture=new DY(this),this.autocapture.startIfEnabled()})),r.push((()=>{this.surveys.loadIfEnabled()})),r.push((()=>{this.logs.loadIfEnabled()})),r.push((()=>{this.conversations.loadIfEnabled()})),r.push((()=>{this.productTours=new yV(this),this.productTours.loadIfEnabled()})),r.push((()=>{this.heatmaps=new aV(this),this.heatmaps.startIfEnabled()})),r.push((()=>{this.webVitalsAutocapture=new rV(this)})),r.push((()=>{this.exceptionObserver=new GY(this),this.exceptionObserver.startIfEnabledOrStop()})),r.push((()=>{this.deadClicksAutocapture=new r9(this,$Y),this.deadClicksAutocapture.startIfEnabled()})),r.push((()=>{if(this.ls){var i=this.ls;this.ls=void 0,this.bi(i)}})),this.us(r,n)}us(t,n){for(;t.length>0;){if(this.config.__preview_deferred_init_extensions&&performance.now()-n>=30&&t.length>0)return void setTimeout((()=>{this.us(t,n)}),0);var r=t.shift();if(r)try{r()}catch(s){je.error("Error initializing extension:",s)}}var i=Math.round(performance.now()-n);this.register_for_session({$sdk_debug_extensions_init_method:this.config.__preview_deferred_init_extensions?"deferred":"synchronous",$sdk_debug_extensions_init_time_ms:i}),this.config.__preview_deferred_init_extensions&&je.info("PostHog extensions initialized ("+i+"ms)")}bi(t){var n,r,i,s,o,c,d,f,m;if(!qe||!qe.body)return je.info("document not ready yet, trying again in 500 milliseconds..."),void setTimeout((()=>{this.bi(t)}),500);this.config.__preview_deferred_init_extensions&&(this.ls=t),this.compression=void 0,t.supportedCompression&&!this.config.disable_compression&&(this.compression=Dt(t.supportedCompression,Xa.GZipJS)?Xa.GZipJS:Dt(t.supportedCompression,Xa.Base64)?Xa.Base64:void 0),(n=t.analytics)!=null&&n.endpoint&&(this.analyticsDefaultEndpoint=t.analytics.endpoint),this.set_config({person_profiles:this.Jr?this.Jr:"identified_only"}),(r=this.siteApps)==null||r.onRemoteConfig(t),(i=this.sessionRecording)==null||i.onRemoteConfig(t),(s=this.autocapture)==null||s.onRemoteConfig(t),(o=this.heatmaps)==null||o.onRemoteConfig(t),this.surveys.onRemoteConfig(t),this.logs.onRemoteConfig(t),this.conversations.onRemoteConfig(t),(c=this.productTours)==null||c.onRemoteConfig(t),(d=this.webVitalsAutocapture)==null||d.onRemoteConfig(t),(f=this.exceptionObserver)==null||f.onRemoteConfig(t),this.exceptions.onRemoteConfig(t),(m=this.deadClicksAutocapture)==null||m.onRemoteConfig(t)}os(){try{this.config.loaded(this)}catch(t){je.critical("`loaded` function failed",t)}this.hs(),this.config.capture_pageview&&setTimeout((()=>{(this.consent.isOptedIn()||this.config.cookieless_mode==="always")&&this.ds()}),1),new RV(this).load(),this.featureFlags.flags()}hs(){var t;this.is_capturing()&&this.config.request_batching&&((t=this.ts)==null||t.enable())}_dom_loaded(){this.is_capturing()&&rl(this.__request_queue,(t=>this.es(t))),this.__request_queue=[],this.hs()}_handle_unload(){var t,n;this.surveys.handlePageUnload(),this.config.request_batching?(this.vs()&&this.capture("$pageleave"),(t=this.ts)==null||t.unload(),(n=this.rs)==null||n.unload()):this.vs()&&this.capture("$pageleave",null,{transport:"sendBeacon"})}_send_request(t){this.__loaded&&(T9?this.__request_queue.push(t):this.rateLimiter.isServerRateLimited(t.batchKey)||(t.transport=t.transport||this.config.api_transport,t.url=Cf(t.url,{ip:this.config.ip?1:0}),t.headers=Ve({},this.config.request_headers,t.headers),t.compression=t.compression==="best-available"?this.compression:t.compression,t.disableXHRCredentials=this.config.__preview_disable_xhr_credentials,this.config.__preview_disable_beacon&&(t.disableTransport=["sendBeacon"]),t.fetchOptions=t.fetchOptions||this.config.fetch_options,(n=>{var r,i,s,o=Ve({},n);o.timeout=o.timeout||6e4,o.url=Cf(o.url,{_:new Date().getTime().toString(),ver:$a.LIB_VERSION,compression:o.compression});var c=(r=o.transport)!==null&&r!==void 0?r:"fetch",d=Vh.filter((m=>!o.disableTransport||!m.transport||!o.disableTransport.includes(m.transport))),f=(i=(s=US(d,(m=>m.transport===c)))==null?void 0:s.method)!==null&&i!==void 0?i:d[0].method;if(!f)throw new Error("No available transport method");f(o)})(Ve({},t,{callback:n=>{var r,i;this.rateLimiter.checkForLimiting(n),n.statusCode>=400&&((r=(i=this.config).on_request_error)==null||r.call(i,n)),t.callback==null||t.callback(n)}}))))}es(t){this.rs?this.rs.retriableRequest(t):this._send_request(t)}_execute_array(t){var n,r=[],i=[],s=[];rl(t,(c=>{c&&(n=c[0],Qt(n)?s.push(c):nl(c)?c.call(this):Qt(c)&&n==="alias"?r.push(c):Qt(c)&&n.indexOf("capture")!==-1&&nl(this[n])?s.push(c):i.push(c))}));var o=function(c,d){rl(c,(function(f){if(Qt(f[0])){var m=d;_n(f,(function(p){m=m[p[0]].apply(m,p.slice(1))}))}else this[f[0]].apply(this,f.slice(1))}),d)};o(r,this),o(i,this),o(s,this)}ns(){var t,n;return((t=this.config.bootstrap)==null?void 0:t.featureFlags)&&Object.keys((n=this.config.bootstrap)==null?void 0:n.featureFlags).length>0||!1}push(t){this._execute_array([t])}capture(t,n,r){var i;if(this.__loaded&&this.persistence&&this.sessionPersistence&&this.ts){if(this.is_capturing())if(!He(t)&&or(t)){var s=!this.config.opt_out_useragent_filter&&this._is_bot();if(!(s&&!this.config.__preview_capture_bot_pageviews)){var o=r!=null&&r.skip_client_rate_limiting?void 0:this.rateLimiter.clientRateLimitContext();if(o==null||!o.isRateLimited){n!=null&&n.$current_url&&!or(n==null?void 0:n.$current_url)&&(je.error("Invalid `$current_url` property provided to `posthog.capture`. Input must be a string. Ignoring provided value."),n==null||delete n.$current_url),this.sessionPersistence.update_search_keyword(),this.config.save_campaign_params&&this.sessionPersistence.update_campaign_params(),this.config.save_referrer&&this.sessionPersistence.update_referrer_info(),(this.config.save_campaign_params||this.config.save_referrer)&&this.persistence.set_initial_person_info();var c=new Date,d=(r==null?void 0:r.timestamp)||c,f=tl(),m={uuid:f,event:t,properties:this.calculateEventProperties(t,n||{},d,f)};t==="$pageview"&&this.config.__preview_capture_bot_pageviews&&s&&(m.event="$bot_pageview",m.properties.$browser_type="bot"),o&&(m.properties.$lib_rate_limit_remaining_tokens=o.remainingTokens),r!=null&&r.$set&&(m.$set=r==null?void 0:r.$set);var p,v=t!=="$groupidentify",_=this.cs(r==null?void 0:r.$set_once,v);if(_&&(m.$set_once=_),(m=bY(m,r!=null&&r._noTruncate?null:this.config.properties_string_max_length)).timestamp=d,He(r==null?void 0:r.timestamp)||(m.properties.$event_time_override_provided=!0,m.properties.$event_time_override_system_time=c),t===Gc.DISMISSED||t===Gc.SENT){var T=n==null?void 0:n[Dg.SURVEY_ID],x=n==null?void 0:n[Dg.SURVEY_ITERATION];p={id:T,current_iteration:x},localStorage.getItem(D5(p))||localStorage.setItem(D5(p),"true"),m.$set=Ve({},m.$set,{[EV({id:T,current_iteration:x},t===Gc.SENT?"responded":"dismissed")]:!0})}else t===Gc.SHOWN&&(m.$set=Ve({},m.$set,{[Dg.SURVEY_LAST_SEEN_DATE]:new Date().toISOString()}));var k=Ve({},m.properties.$set,m.$set);if(Zo(k)||this.setPersonPropertiesForFlags(k),!Wt(this.config.before_send)){var A=this.fs(m);if(!A)return;m=A}this.Wr.emit("eventCaptured",m);var O={method:"POST",url:(i=r==null?void 0:r._url)!==null&&i!==void 0?i:this.requestRouter.endpointFor("api",this.analyticsDefaultEndpoint),data:m,compression:"best-available",batchKey:r==null?void 0:r._batchKey};return!this.config.request_batching||r&&(r==null||!r._batchKey)||r!=null&&r.send_instantly?this.es(O):this.ts.enqueue(O),m}je.critical("This capture call is ignored due to client rate limiting.")}}else je.error("No event name provided to posthog.capture")}else je.uninitializedWarning("posthog.capture")}Bi(t){return this.on("eventCaptured",(n=>t(n.event,n)))}calculateEventProperties(t,n,r,i,s){if(r=r||new Date,!this.persistence||!this.sessionPersistence)return n;var o=s?void 0:this.persistence.remove_event_timer(t),c=Ve({},n);if(c.token=this.config.token,c.$config_defaults=this.config.defaults,(this.config.cookieless_mode=="always"||this.config.cookieless_mode=="on_reject"&&this.consent.isExplicitlyOptedOut())&&(c.$cookieless_mode=!0),t==="$snapshot"){var d=Ve({},this.persistence.properties(),this.sessionPersistence.properties());return c.distinct_id=d.distinct_id,(!or(c.distinct_id)&&!os(c.distinct_id)||Nb(c.distinct_id))&&je.error("Invalid distinct_id for replay event. This indicates a bug in your implementation"),c}var f,m=nV(this.config.mask_personal_data_properties,this.config.custom_personal_data_properties);if(this.sessionManager){var{sessionId:p,windowId:v}=this.sessionManager.checkAndGetSessionAndWindowId(s,r.getTime());c.$session_id=p,c.$window_id=v}this.sessionPropsManager&&Vn(c,this.sessionPropsManager.getSessionProps());try{var _;this.sessionRecording&&Vn(c,this.sessionRecording.sdkDebugProperties),c.$sdk_debug_retry_queue_size=(_=this.rs)==null?void 0:_.length}catch(A){c.$sdk_debug_error_capturing_properties=String(A)}if(this.requestRouter.region===Yc.CUSTOM&&(c.$lib_custom_api_host=this.config.api_host),f=t!=="$pageview"||s?t!=="$pageleave"||s?this.pageViewManager.doEvent():this.pageViewManager.doPageLeave(r):this.pageViewManager.doPageView(r,i),c=Vn(c,f),t==="$pageview"&&qe&&(c.title=qe.title),!He(o)){var T=r.getTime()-o;c.$duration=parseFloat((T/1e3).toFixed(3))}ni&&this.config.opt_out_useragent_filter&&(c.$browser_type=this._is_bot()?"bot":"browser"),(c=Vn({},m,this.persistence.properties(),this.sessionPersistence.properties(),c)).$is_identified=this._isIdentified(),Qt(this.config.property_denylist)?_n(this.config.property_denylist,(function(A){delete c[A]})):je.error("Invalid value for property_denylist config: "+this.config.property_denylist+" or property_blacklist config: "+this.config.property_blacklist);var x=this.config.sanitize_properties;x&&(je.error("sanitize_properties is deprecated. Use before_send instead"),c=x(c,t));var k=this.ps();return c.$process_person_profile=k,k&&!s&&this.gs("_calculate_event_properties"),c}cs(t,n){var r;if(n===void 0&&(n=!0),!this.persistence||!this.ps()||this.qr)return t;var i=this.persistence.get_initial_props(),s=(r=this.sessionPropsManager)==null?void 0:r.getSetOnceProps(),o=Vn({},i,s||{},t||{}),c=this.config.sanitize_properties;return c&&(je.error("sanitize_properties is deprecated. Use before_send instead"),o=c(o,"$set_once")),n&&(this.qr=!0),Zo(o)?void 0:o}register(t,n){var r;(r=this.persistence)==null||r.register(t,n)}register_once(t,n,r){var i;(i=this.persistence)==null||i.register_once(t,n,r)}register_for_session(t){var n;(n=this.sessionPersistence)==null||n.register(t)}unregister(t){var n;(n=this.persistence)==null||n.unregister(t)}unregister_for_session(t){var n;(n=this.sessionPersistence)==null||n.unregister(t)}_s(t,n){this.register({[t]:n})}getFeatureFlag(t,n){return this.featureFlags.getFeatureFlag(t,n)}getFeatureFlagPayload(t){var n=this.featureFlags.getFeatureFlagPayload(t);try{return JSON.parse(n)}catch{return n}}isFeatureEnabled(t,n){return this.featureFlags.isFeatureEnabled(t,n)}reloadFeatureFlags(){this.featureFlags.reloadFeatureFlags()}updateFlags(t,n,r){var i=r!=null&&r.merge?this.featureFlags.getFlagVariants():{},s=r!=null&&r.merge?this.featureFlags.getFlagPayloads():{},o=Ve({},i,t),c=Ve({},s,n),d={};for(var[f,m]of Object.entries(o)){var p=typeof m=="string";d[f]={key:f,enabled:!!p||!!m,variant:p?m:void 0,reason:void 0,metadata:He(c==null?void 0:c[f])?void 0:{id:0,version:void 0,description:void 0,payload:c[f]}}}this.featureFlags.receivedFeatureFlags({flags:d})}updateEarlyAccessFeatureEnrollment(t,n,r){this.featureFlags.updateEarlyAccessFeatureEnrollment(t,n,r)}getEarlyAccessFeatures(t,n,r){return n===void 0&&(n=!1),this.featureFlags.getEarlyAccessFeatures(t,n,r)}on(t,n){return this.Wr.on(t,n)}onFeatureFlags(t){return this.featureFlags.onFeatureFlags(t)}onSurveysLoaded(t){return this.surveys.onSurveysLoaded(t)}onSessionId(t){var n,r;return(n=(r=this.sessionManager)==null?void 0:r.onSessionId(t))!==null&&n!==void 0?n:()=>{}}getSurveys(t,n){n===void 0&&(n=!1),this.surveys.getSurveys(t,n)}getActiveMatchingSurveys(t,n){n===void 0&&(n=!1),this.surveys.getActiveMatchingSurveys(t,n)}renderSurvey(t,n){this.surveys.renderSurvey(t,n)}displaySurvey(t,n){n===void 0&&(n=xV),this.surveys.displaySurvey(t,n)}cancelPendingSurvey(t){this.surveys.cancelPendingSurvey(t)}canRenderSurvey(t){return this.surveys.canRenderSurvey(t)}canRenderSurveyAsync(t,n){return n===void 0&&(n=!1),this.surveys.canRenderSurveyAsync(t,n)}identify(t,n,r){if(!this.__loaded||!this.persistence)return je.uninitializedWarning("posthog.identify");if(os(t)&&(t=t.toString(),je.warn("The first argument to posthog.identify was a number, but it should be a string. It has been converted to a string.")),t)if(["distinct_id","distinctid"].includes(t.toLowerCase()))je.critical('The string "'+t+'" was set in posthog.identify which indicates an error. This ID should be unique to the user and not a hardcoded string.');else if(t!==kc){if(this.gs("posthog.identify")){var i=this.get_distinct_id();if(this.register({$user_id:t}),!this.get_property("$device_id")){var s=i;this.register_once({$had_persisted_distinct_id:!0,$device_id:s},"")}t!==i&&t!==this.get_property(Fc)&&(this.unregister(Fc),this.register({distinct_id:t}));var o=(this.persistence.get_property(Ga)||"anonymous")==="anonymous";t!==i&&o?(this.persistence.set_property(Ga,"identified"),this.setPersonPropertiesForFlags(Ve({},r||{},n||{}),!1),this.capture("$identify",{distinct_id:t,$anon_distinct_id:i},{$set:n||{},$set_once:r||{}}),this.Kr=C5(t,n,r),this.featureFlags.setAnonymousDistinctId(i)):(n||r)&&this.setPersonProperties(n,r),t!==i&&(this.reloadFeatureFlags(),this.unregister(_f))}}else je.critical('The string "'+kc+'" was set in posthog.identify which indicates an error. This ID is only used as a sentinel value.');else je.error("Unique user id has not been set in posthog.identify")}setPersonProperties(t,n){if((t||n)&&this.gs("posthog.setPersonProperties")){var r=C5(this.get_distinct_id(),t,n);this.Kr!==r?(this.setPersonPropertiesForFlags(Ve({},n||{},t||{})),this.capture("$set",{$set:t||{},$set_once:n||{}}),this.Kr=r):je.info("A duplicate setPersonProperties call was made with the same properties. It has been ignored.")}}group(t,n,r){if(t&&n){var i=this.getGroups();i[t]!==n&&this.resetGroupPropertiesForFlags(t),this.register({$groups:Ve({},i,{[t]:n})}),r&&(this.capture("$groupidentify",{$group_type:t,$group_key:n,$group_set:r}),this.setGroupPropertiesForFlags({[t]:r})),i[t]===n||r||this.reloadFeatureFlags()}else je.error("posthog.group requires a group type and group key")}resetGroups(){this.register({$groups:{}}),this.resetGroupPropertiesForFlags(),this.reloadFeatureFlags()}setPersonPropertiesForFlags(t,n){n===void 0&&(n=!0),this.featureFlags.setPersonPropertiesForFlags(t,n)}resetPersonPropertiesForFlags(){this.featureFlags.resetPersonPropertiesForFlags()}setGroupPropertiesForFlags(t,n){n===void 0&&(n=!0),this.gs("posthog.setGroupPropertiesForFlags")&&this.featureFlags.setGroupPropertiesForFlags(t,n)}resetGroupPropertiesForFlags(t){this.featureFlags.resetGroupPropertiesForFlags(t)}reset(t){var n,r,i,s;if(je.info("reset"),!this.__loaded)return je.uninitializedWarning("posthog.reset");var o=this.get_property("$device_id");if(this.consent.reset(),(n=this.persistence)==null||n.clear(),(r=this.sessionPersistence)==null||r.clear(),this.surveys.reset(),this.featureFlags.reset(),(i=this.persistence)==null||i.set_property(Ga,"anonymous"),(s=this.sessionManager)==null||s.resetSessionId(),this.Kr=null,this.config.cookieless_mode==="always")this.register_once({distinct_id:kc,$device_id:null},"");else{var c=this.config.get_device_id(tl());this.register_once({distinct_id:c,$device_id:t?c:o},"")}this.register({$last_posthog_reset:new Date().toISOString()},1)}get_distinct_id(){return this.get_property("distinct_id")}getGroups(){return this.get_property("$groups")||{}}get_session_id(){var t,n;return(t=(n=this.sessionManager)==null?void 0:n.checkAndGetSessionAndWindowId(!0).sessionId)!==null&&t!==void 0?t:""}get_session_replay_url(t){if(!this.sessionManager)return"";var{sessionId:n,sessionStartTimestamp:r}=this.sessionManager.checkAndGetSessionAndWindowId(!0),i=this.requestRouter.endpointFor("ui","/project/"+this.config.token+"/replay/"+n);if(t!=null&&t.withTimestamp&&r){var s,o=(s=t.timestampLookBack)!==null&&s!==void 0?s:10;if(!r)return i;i+="?t="+Math.max(Math.floor((new Date().getTime()-r)/1e3)-o,0)}return i}alias(t,n){return t===this.get_property(zS)?(je.critical("Attempting to create alias for existing People user - aborting."),-2):this.gs("posthog.alias")?(He(n)&&(n=this.get_distinct_id()),t!==n?(this._s(Fc,t),this.capture("$create_alias",{alias:t,distinct_id:n})):(je.warn("alias matches current distinct_id - skipping api call."),this.identify(t),-1)):void 0}set_config(t){var n=Ve({},this.config);if(fr(t)){var r,i,s,o,c,d,f;Vn(this.config,H5(t));var m=this.Zr();(r=this.persistence)==null||r.update_config(this.config,n,m),this.sessionPersistence=this.config.persistence==="sessionStorage"||this.config.persistence==="memory"?this.persistence:new Rg(Ve({},this.config,{persistence:"sessionStorage"}),m);var p=this.Yr(this.config.debug);ns(p)&&(this.config.debug=p),ns(this.config.debug)&&(this.config.debug?($a.DEBUG=!0,Pn.H()&&Pn.G("ph_debug","true"),je.info("set_config",{config:t,oldConfig:n,newConfig:Ve({},this.config)})):($a.DEBUG=!1,Pn.H()&&Pn.V("ph_debug"))),(i=this.exceptionObserver)==null||i.onConfigChange(),(s=this.sessionRecording)==null||s.startIfEnabledOrStop(),(o=this.autocapture)==null||o.startIfEnabled(),(c=this.heatmaps)==null||c.startIfEnabled(),(d=this.exceptionObserver)==null||d.startIfEnabledOrStop(),this.surveys.loadIfEnabled(),this.ys(),(f=this.externalIntegrations)==null||f.startIfEnabledOrStop()}}startSessionRecording(t){var n=t===!0,r={sampling:n||!(t==null||!t.sampling),linked_flag:n||!(t==null||!t.linked_flag),url_trigger:n||!(t==null||!t.url_trigger),event_trigger:n||!(t==null||!t.event_trigger)};if(Object.values(r).some(Boolean)){var i,s,o,c,d;(i=this.sessionManager)==null||i.checkAndGetSessionAndWindowId(),r.sampling&&((s=this.sessionRecording)==null||s.overrideSampling()),r.linked_flag&&((o=this.sessionRecording)==null||o.overrideLinkedFlag()),r.url_trigger&&((c=this.sessionRecording)==null||c.overrideTrigger("url")),r.event_trigger&&((d=this.sessionRecording)==null||d.overrideTrigger("event"))}this.set_config({disable_session_recording:!1})}stopSessionRecording(){this.set_config({disable_session_recording:!0})}sessionRecordingStarted(){var t;return!((t=this.sessionRecording)==null||!t.started)}captureException(t,n){var r=new Error("PostHog syntheticException"),i=this.exceptions.buildProperties(t,{handled:!0,syntheticException:r});return this.exceptions.sendExceptionEvent(Ve({},i,n))}startExceptionAutocapture(t){this.set_config({capture_exceptions:t==null||t})}stopExceptionAutocapture(){this.set_config({capture_exceptions:!1})}loadToolbar(t){return this.toolbar.loadToolbar(t)}get_property(t){var n;return(n=this.persistence)==null?void 0:n.props[t]}getSessionProperty(t){var n;return(n=this.sessionPersistence)==null?void 0:n.props[t]}toString(){var t,n=(t=this.config.name)!==null&&t!==void 0?t:Wo;return n!==Wo&&(n=Wo+"."+n),n}_isIdentified(){var t,n;return((t=this.persistence)==null?void 0:t.get_property(Ga))==="identified"||((n=this.sessionPersistence)==null?void 0:n.get_property(Ga))==="identified"}ps(){var t,n;return!(this.config.person_profiles==="never"||this.config.person_profiles==="identified_only"&&!this._isIdentified()&&Zo(this.getGroups())&&((t=this.persistence)==null||(t=t.props)==null||!t[Fc])&&((n=this.persistence)==null||(n=n.props)==null||!n[Ef]))}vs(){return this.config.capture_pageleave===!0||this.config.capture_pageleave==="if_capture_pageview"&&(this.config.capture_pageview===!0||this.config.capture_pageview==="history_change")}createPersonProfile(){this.ps()||this.gs("posthog.createPersonProfile")&&this.setPersonProperties({},{})}gs(t){return this.config.person_profiles==="never"?(je.error(t+' was called, but process_person is set to "never". This call will be ignored.'),!1):(this._s(Ef,!0),!0)}Zr(){if(this.config.cookieless_mode==="always")return!0;var t=this.consent.isOptedOut(),n=this.config.opt_out_persistence_by_default||this.config.cookieless_mode==="on_reject";return this.config.disable_persistence||t&&!!n}ys(){var t,n,r,i,s=this.Zr();return((t=this.persistence)==null?void 0:t.ki)!==s&&((r=this.persistence)==null||r.set_disabled(s)),((n=this.sessionPersistence)==null?void 0:n.ki)!==s&&((i=this.sessionPersistence)==null||i.set_disabled(s)),s}opt_in_capturing(t){var n;if(this.config.cookieless_mode!=="always"){var r,i,s;this.config.cookieless_mode==="on_reject"&&this.consent.isExplicitlyOptedOut()&&(this.reset(!0),(r=this.sessionManager)==null||r.destroy(),(i=this.pageViewManager)==null||i.destroy(),this.sessionManager=new B5(this),this.pageViewManager=new T5(this),this.persistence&&(this.sessionPropsManager=new P5(this,this.sessionManager,this.persistence)),this.sessionRecording=new z5(this),this.sessionRecording.startIfEnabledOrStop()),this.consent.optInOut(!0),this.ys(),this.hs(),(n=this.sessionRecording)==null||n.startIfEnabledOrStop(),this.config.cookieless_mode=="on_reject"&&this.surveys.loadIfEnabled(),(He(t==null?void 0:t.captureEventName)||t!=null&&t.captureEventName)&&this.capture((s=t==null?void 0:t.captureEventName)!==null&&s!==void 0?s:"$opt_in",t==null?void 0:t.captureProperties,{send_instantly:!0}),this.config.capture_pageview&&this.ds()}else je.warn('Consent opt in/out is not valid with cookieless_mode="always" and will be ignored')}opt_out_capturing(){var t,n,r;this.config.cookieless_mode!=="always"?(this.config.cookieless_mode==="on_reject"&&this.consent.isOptedIn()&&this.reset(!0),this.consent.optInOut(!1),this.ys(),this.config.cookieless_mode==="on_reject"&&(this.register({distinct_id:kc,$device_id:null}),(t=this.sessionManager)==null||t.destroy(),(n=this.pageViewManager)==null||n.destroy(),this.sessionManager=void 0,this.sessionPropsManager=void 0,(r=this.sessionRecording)==null||r.stopRecording(),this.sessionRecording=void 0,this.ds())):je.warn('Consent opt in/out is not valid with cookieless_mode="always" and will be ignored')}has_opted_in_capturing(){return this.consent.isOptedIn()}has_opted_out_capturing(){return this.consent.isOptedOut()}get_explicit_consent_status(){var t=this.consent.consent;return t===Ya.GRANTED?"granted":t===Ya.DENIED?"denied":"pending"}is_capturing(){return this.config.cookieless_mode==="always"||(this.config.cookieless_mode==="on_reject"?this.consent.isExplicitlyOptedOut()||this.consent.isOptedIn():!this.has_opted_out_capturing())}clear_opt_in_out_capturing(){this.consent.reset(),this.ys()}_is_bot(){return yi?E9(yi,this.config.custom_blocked_useragents):void 0}ds(){qe&&(qe.visibilityState==="visible"?this.Gr||(this.Gr=!0,this.capture("$pageview",{title:qe.title},{send_instantly:!0}),this.Vr&&(qe.removeEventListener("visibilitychange",this.Vr),this.Vr=null)):this.Vr||(this.Vr=this.ds.bind(this),rr(qe,"visibilitychange",this.Vr)))}debug(t){t===!1?(ge==null||ge.console.log("You've disabled debug mode."),this.set_config({debug:!1})):(ge==null||ge.console.log("You're now in debug mode. All calls to PostHog will be logged in your console.\nYou can disable this with `posthog.debug(false)`."),this.set_config({debug:!0}))}O(){var t,n,r,i,s,o,c,d=this.Xr||{};return"advanced_disable_flags"in d?!!d.advanced_disable_flags:this.config.advanced_disable_flags!==!1?!!this.config.advanced_disable_flags:this.config.advanced_disable_decide===!0?(je.warn("Config field 'advanced_disable_decide' is deprecated. Please use 'advanced_disable_flags' instead. The old field will be removed in a future major version."),!0):(r="advanced_disable_decide",i=!1,s=je,o=(n="advanced_disable_flags")in(t=d)&&!He(t[n]),c=r in t&&!He(t[r]),o?t[n]:c?(s&&s.warn("Config field '"+r+"' is deprecated. Please use '"+n+"' instead. The old field will be removed in a future major version."),t[r]):i)}fs(t){if(Wt(this.config.before_send))return t;var n=Qt(this.config.before_send)?this.config.before_send:[this.config.before_send],r=t;for(var i of n){if(r=i(r),Wt(r)){var s="Event '"+t.event+"' was rejected in beforeSend function";return DG(t.event)?je.warn(s+". This can cause unexpected behavior."):je.info(s),null}r.properties&&!Zo(r.properties)||je.warn("Event '"+t.event+"' has no properties after beforeSend function, this is likely an error.")}return r}getPageViewId(){var t;return(t=this.pageViewManager.Kt)==null?void 0:t.pageViewId}captureTraceFeedback(t,n){this.capture("$ai_feedback",{$ai_trace_id:String(t),$ai_feedback_text:n})}captureTraceMetric(t,n,r){this.capture("$ai_metric",{$ai_trace_id:String(t),$ai_metric_name:n,$ai_metric_value:String(r)})}Yr(t){var n=ns(t)&&!t,r=Pn.H()&&Pn.q("ph_debug")==="true";return!n&&(!!r||t)}}(function(e,t){for(var n=0;n<t.length;n++)e.prototype[t[n]]=gY(e.prototype[t[n]])})(lm,["identify"]);var j5,F0=(j5=a0[Wo]=new lm,(function(){function e(){e.done||(e.done=!0,T9=!1,_n(a0,(function(t){t._dom_loaded()})))}qe!=null&&qe.addEventListener?qe.readyState==="complete"?e():rr(qe,"DOMContentLoaded",e,{capture:!1}):ge&&je.error("Browser doesn't support `document.addEventListener` so PostHog couldn't be initialized")})(),j5);let du=!1;function GV(){du||(F0.init("phc_2qafhOCTgCnygXsPEHOA0RBtJf5nvVsi7yIene4DWaF",{api_host:"https://us.i.posthog.com",person_profiles:"identified_only",capture_pageview:!0,capture_pageleave:!0,autocapture:!1,persistence:"localStorage",loaded:e=>{var t,n;(n=(t=import.meta)==null?void 0:t.env)!=null&&n.DEV&&console.log("[PostHog] Initialized in development mode")}}),du=!0)}function YV(e,t={}){var i,s,o,c,d;if(!e||!du)return;const n={email:((i=e.primaryEmailAddress)==null?void 0:i.emailAddress)||((o=(s=e.emailAddresses)==null?void 0:s[0])==null?void 0:o.emailAddress),name:e.fullName||`${e.firstName||""} ${e.lastName||""}`.trim(),first_name:e.firstName,last_name:e.lastName,avatar_url:e.imageUrl,created_at:e.createdAt,...t},r=Object.fromEntries(Object.entries(n).filter(([f,m])=>m!=null&&m!==""));F0.identify(e.id,r),(d=(c=import.meta)==null?void 0:c.env)!=null&&d.DEV&&console.log("[PostHog] User identified:",e.id,r)}function VV(){var e,t;du&&(F0.reset(),(t=(e=import.meta)==null?void 0:e.env)!=null&&t.DEV&&console.log("[PostHog] User reset"))}function x9(){return typeof window>"u"?"unknown":window.location.hostname}function KV(){var t,n;if(!du)return;const e=x9();F0.register({agent_domain:e,agent_subdomain:e.split(".")[0]}),(n=(t=import.meta)==null?void 0:t.env)!=null&&n.DEV&&console.log("[PostHog] Agent domain set:",e)}function ar(e,t={}){var n,r;du&&(F0.capture(e,{...t,agent_domain:x9()}),(r=(n=import.meta)==null?void 0:n.env)!=null&&r.DEV&&console.log("[PostHog] Event:",e,t))}function WV(){ar("user_signed_in")}function XV(){ar("user_signed_out")}function QV(e={}){ar("message_sent",{has_attachments:e.hasAttachments||!1,attachment_count:e.attachmentCount||0,message_length:e.messageLength||0,chat_id:e.chatId,is_new_chat:e.isNewChat||!1})}function ZV(e){ar("chat_created",{chat_id:e})}function JV(e){ar("chat_selected",{chat_id:e})}function eK(e){ar("chat_deleted",{chat_id:e})}function tK(){ar("new_chat_started")}function nK(e){ar("message_regenerated",{message_index:e})}function rK(e){ar("message_retried",{message_index:e})}function Qb(){ar("generation_stopped")}function iK(e,t){ar("file_upload_started",{file_name:e,file_type:t})}function aK(e,t){ar("file_upload_completed",{file_name:e,file_type:t})}function sK(e,t){ar("file_upload_failed",{file_name:e,error_message:t})}function q5(e){ar("tier_modal_shown",{tier:e})}function lK(e){ar("tier_modal_dismissed",{tier:e})}function oK(e){ar("upgrade_clicked",{tier:e})}function uK(e){ar("free_limit_reached",{message_count:e})}function Pg(e,t,n={}){ar("error_occurred",{error_type:e,error_message:t,...n})}function cK(){ar("sidebar_opened")}function $5(){ar("sidebar_closed")}const dK=({messages:e,setMessages:t,setShouldFocus:n,setIsLoading:r,setUploadProgress:i,setIsUserScrolled:s,onFirstSend:o,auth:c,org:d,getToken:f,setActive:m,activeChatId:p,setActiveChatId:v,onMessageSuccess:_,analyticsEnabled:T})=>{const x=F.useRef(null),k=F.useCallback(async O=>{const I=typeof O=="object"&&O!==null,$=I?O.text||"":String(O||""),V=I?O.files||[]:[];if(!$.trim()&&V.length===0){n(!0);return}if($===":clear"&&V.length===0){t([]),v(null),lr.setActiveChat(""),window.scrollTo(0,0);return}e.length===0&&o(),r(!0),s(!1);const B=[];for(let H=0;H<V.length;H++){const ie=V[H];try{i({fileName:ie.name,progress:0}),T&&iK(ie.name,ie.type);const ve=await X$(ie);i({fileName:ie.name,progress:100}),T&&aK(ie.name,ie.type),B.push(ve),setTimeout(()=>i(null),500)}catch(ve){console.error("Upload error:",ve),T&&sK(ie.name,ve.message),i(null),r(!1),t(xe=>[...xe,{role:"user",content:$},{role:"assistant",parts:[],error:{type:"server",message:"Failed to upload "+ie.name+": "+ve.message,status:null}}]);return}}let Z=$;if(B.length>0){const H=`<!--cycls:attachments
`+JSON.stringify(B)+`
cycls:attachments-->`;Z=$+`

`+H}const ee={role:"user",content:Z},te={role:"assistant",parts:[]};t(H=>[...H,ee,te]);const Y=[...e,ee];let oe=p;const he=!oe;oe?lr.updateChat(oe,Y):(oe=lr.createChat(Y).id,v(oe),T&&ZV(oe)),T&&QV({hasAttachments:B.length>0,attachmentCount:B.length,messageLength:$.length,chatId:oe,isNewChat:he}),x.current=new AbortController;let Se=!1,fe=null;const de=()=>{fe&&clearTimeout(fe),fe=setTimeout(()=>{x.current&&(Se=!0,x.current.abort())},12e4)};de();try{let H=null,ie=null;await wb({messages:Y,auth:c,getToken:f,setActive:m,org:d,onPart:xe=>{de(),t(P=>{const z=[...P],J=z[z.length-1];return J.parts||(J.parts=[]),xe.type==="step"?(ie||(ie={type:"steps",steps:[]},J.parts.push(ie)),(xe.step||xe.data!==void 0)&&ie.steps.push({step:xe.step||"",data:xe.data!==void 0?xe.data:null,result:xe.result,_complete:!0}),H=null,z):(ie=null,H&&H.type===xe.type?xe.row?H.rows.push(xe.row):xe.type==="text"&&xe.text?H.text+=xe.text:xe.type==="thinking"&&xe.thinking?H.thinking+=xe.thinking:xe.type==="code"&&xe.code&&(H.code+=xe.code):(H&&H.type==="thinking"&&(H._complete=!0,H._startTime&&(H._duration=Math.round((Date.now()-H._startTime)/1e3))),H={...xe},xe.headers&&(H.rows=[]),xe.type==="thinking"&&(H._startTime=Date.now()),J.parts.push(H)),z)})},signal:x.current.signal}),fe&&clearTimeout(fe),t(xe=>{const P=[...xe],z=P[P.length-1];return z!=null&&z.parts&&z.parts.forEach(J=>{J.type==="thinking"&&!J._complete&&(J._complete=!0,J._startTime&&(J._duration=Math.round((Date.now()-J._startTime)/1e3)))}),P});const ve=[...Y,te];lr.updateChat(oe,ve),_&&_(),r(!1),n(!0)}catch(H){fe&&clearTimeout(fe);let ie={type:"server",message:"An unexpected error occurred",status:null};if(H.name==="AbortError")if(Se)ie={type:"timeout",message:"Request timed out. The server took too long to respond."},T&&Pg("timeout",ie.message);else{console.log("Generation stopped by user"),T&&Qb(),t(ve=>{const xe=[...ve],P=xe[xe.length-1];if((P==null?void 0:P.role)==="assistant"&&P.parts){P.parts.push({type:"text",text:`

*[Generation stopped]*`});const z=e.concat([ee,P]);oe&&lr.updateChat(oe,z)}return xe}),r(!1),n(!0);return}else H instanceof TypeError&&H.message.includes("fetch")?(ie={type:"network",message:"Network error. Please check your connection and try again."},T&&Pg("network",ie.message)):H.type&&(ie=H,T&&Pg(H.type,H.message,{status:H.status}));console.error("Request error:",H),t(ve=>{const xe=[...ve],P=xe[xe.length-1];return(P==null?void 0:P.role)==="assistant"&&(P.error=ie),xe}),r(!1),n(!0)}},[e,c,d,f,m,p,v,_,T,t,n,r,i,s,o]),A=F.useCallback(()=>{x.current&&(x.current.abort(),x.current=null)},[]);return{send:k,handleStop:A}},hK=e=>{const[t,n]=F.useState(!1);return F.useEffect(()=>{const r=()=>n(window.innerWidth<768);return r(),window.addEventListener("resize",r),()=>window.removeEventListener("resize",r)},[]),t?0:e?mf.expanded:mf.collapsed},fK=(e,t,n=null,r=!0)=>{const i=F.useRef(null);F.useEffect(()=>{!t||!r||(n?i.current!==n.id&&(YV(n,{subscription_status:e?"paid":"free"}),i.current===null&&WV(),i.current=n.id):i.current!==null&&(XV(),VV(),i.current=null))},[n,r,e,t])},mK=({HEADER:e,INTRO:t,AUTH:n,ORG:r,TITLE:i,TIER:s})=>C.jsx(S9,{HEADER:e,INTRO:t,AUTH:n,ORG:r,TITLE:i,TIER:s,authApi:null,clerkApi:null,userApi:{user:null,isLoaded:!0},subscription:null,isSubscriptionLoading:!1,subscriptionError:null}),pK=({HEADER:e,INTRO:t,AUTH:n,ORG:r,TITLE:i,TIER:s})=>{const o=x0(),c=wN(),d=AN(),{subscription:f,isLoading:m,error:p}=SG();return C.jsx(S9,{HEADER:e,INTRO:t,AUTH:n,ORG:r,TITLE:i,TIER:s,authApi:o,clerkApi:c,userApi:d,subscription:f,isSubscriptionLoading:m,subscriptionError:p})},G5=e=>e.AUTH?C.jsx(pK,{...e}):C.jsx(mK,{...e}),S9=({HEADER:e,INTRO:t,AUTH:n,ORG:r,TITLE:i,TIER:s,authApi:o,clerkApi:c,userApi:d,subscription:f,isSubscriptionLoading:m,subscriptionError:p})=>{const v=UA(),[_,T]=F.useState([]),[x,k]=F.useState(!1),[A,O]=F.useState(!1),[I,$]=F.useState(null),[V,B]=F.useState(!1),[Z,ee]=F.useState(!1),[te,Y]=F.useState(null),oe=F.useRef(null),[he,Se]=F.useState(!1),[fe,de]=F.useState([]),[H,ie]=F.useState(null),ve=hK(he),[xe,P]=F.useState(!1),[z,J]=F.useState(0),D=5,Ae=F.useCallback(()=>{P(!1),v&&lK(s)},[s,v]),Le=F.useMemo(()=>{var Ge,gn,In;return f?((In=(gn=(Ge=f==null?void 0:f.subscriptionItems)==null?void 0:Ge[0])==null?void 0:gn.plan)==null?void 0:In.name)==="Cycls Pass":!1},[f]),ze=F.useMemo(()=>{var Ge,gn,In;return f&&((In=(gn=(Ge=f==null?void 0:f.subscriptionItems)==null?void 0:Ge[0])==null?void 0:gn.plan)==null?void 0:In.name)||null},[f]);fK(n&&Le,v&&n,(d==null?void 0:d.user)||null,(d==null?void 0:d.isLoaded)??!0);const at=F.useMemo(()=>!n||s!=="cycls_pass"||Le?!1:z>=D,[n,s,Le,z,D]);F.useEffect(()=>{Le&&(NG(),J(0),P(!1))},[Le]),F.useEffect(()=>{const Ge=lr.getAllChats();de(Ge),J(fS())},[]),F.useEffect(()=>{_.length>0&&H&&(lr.updateChat(H,_),de(lr.getAllChats()))},[_,H]),F.useEffect(()=>{document.title=i},[i]),F.useEffect(()=>{const Ge=()=>{const gn=window.scrollY||document.documentElement.scrollTop,In=document.documentElement.scrollHeight,Xt=window.innerHeight,En=In-gn-Xt<100;ee(!En)};return window.addEventListener("scroll",Ge),()=>window.removeEventListener("scroll",Ge)},[]),F.useEffect(()=>{!Z&&oe.current&&oe.current.scrollIntoView({behavior:"smooth"})},[_,Z]),F.useEffect(()=>{if(x){const Ge=document.querySelector("textarea");Ge==null||Ge.focus(),k(!1)}},[x]);const _t=F.useCallback(()=>{if(!n||s!=="cycls_pass"||Le)return;const Ge=CG();J(Ge),Ge>=D&&(P(!0),v&&uK(Ge),v&&q5(s))},[n,s,Le,D,v]),{send:pt,handleStop:Tt}=dK({messages:_,setMessages:T,setShouldFocus:k,setIsLoading:O,setUploadProgress:$,setIsUserScrolled:ee,onFirstSend:()=>B(!0),auth:n,org:r,getToken:o==null?void 0:o.getToken,setActive:c==null?void 0:c.setActive,activeChatId:H,setActiveChatId:ie,onMessageSuccess:_t,analyticsEnabled:v}),kn=F.useCallback(()=>{T([]),ie(null),B(!1),lr.setActiveChat(""),window.scrollTo(0,0),v&&tK()},[v]),pr=F.useCallback(Ge=>{const gn=lr.getChat(Ge);gn&&(T(gn.messages),ie(Ge),B(gn.messages.length>0),lr.setActiveChat(Ge),window.innerWidth<768&&Se(!1),window.scrollTo(0,0),v&&JV(Ge))},[v]),yt=F.useCallback(Ge=>{lr.deleteChat(Ge),de(lr.getAllChats()),v&&eK(Ge),Ge===H&&kn()},[H,kn,v]),ct=F.useCallback(()=>{const Ge=!he;Se(Ge),v&&(Ge?cK():$5())},[he,v]),Ft=F.useCallback(()=>{Se(!1),v&&$5()},[v]),Xe=F.useCallback(async Ge=>{const gn=Ge-1;if(gn<0)return;v&&nK(Ge),T(Ue=>{const bt=[...Ue],Re=bt[Ge];return((Re==null?void 0:Re.type)==="response"||(Re==null?void 0:Re.role)==="assistant")&&(bt[Ge]={role:"assistant",parts:[]}),bt});const In=_[gn];if(!(In.type==="request"||In.role==="user"))return;const En=_.slice(0,Ge);O(!0),ee(!1);const me=new AbortController;let Ce=!1,Ye=null;const dt=()=>{Ye&&clearTimeout(Ye),Ye=setTimeout(()=>{Ce=!0,me.abort()},12e4)};dt();try{let Ue=null,bt=null;await wb({messages:En,auth:n,getToken:o==null?void 0:o.getToken,setActive:c==null?void 0:c.setActive,org:r,onPart:Re=>{dt(),T(Rt=>{const At=[...Rt],kt=At[Ge];return kt.parts||(kt.parts=[]),Re.type==="step"?(bt||(bt={type:"steps",steps:[]},kt.parts.push(bt)),(Re.step||Re.data!==void 0)&&bt.steps.push({step:Re.step||"",data:Re.data!==void 0?Re.data:null,result:Re.result,_complete:!0}),Ue=null,At):(bt=null,Ue&&Ue.type===Re.type?Re.row?Ue.rows.push(Re.row):Re.type==="text"&&Re.text?Ue.text+=Re.text:Re.type==="thinking"&&Re.thinking?Ue.thinking+=Re.thinking:Re.type==="code"&&Re.code&&(Ue.code+=Re.code):(Ue&&Ue.type==="thinking"&&(Ue._complete=!0,Ue._startTime&&(Ue._duration=Math.round((Date.now()-Ue._startTime)/1e3))),Ue={...Re},Re.headers&&(Ue.rows=[]),Re.type==="thinking"&&(Ue._startTime=Date.now()),kt.parts.push(Ue)),At)})},signal:me.signal}),Ye&&clearTimeout(Ye),T(Re=>{const Rt=[...Re],At=Rt[Ge];return At!=null&&At.parts&&At.parts.forEach(kt=>{kt.type==="thinking"&&!kt._complete&&(kt._complete=!0,kt._startTime&&(kt._duration=Math.round((Date.now()-kt._startTime)/1e3)))}),Rt}),H&&T(Re=>(lr.updateChat(H,Re),de(lr.getAllChats()),Re)),O(!1),k(!0)}catch(Ue){if(Ye&&clearTimeout(Ye),Ue.name==="AbortError"&&!Ce){v&&Qb(),T(bt=>{const Re=[...bt],Rt=Re[Ge];return Rt!=null&&Rt.parts&&Rt.parts.push({type:"text",text:`

*[Generation stopped]*`}),H&&lr.updateChat(H,Re),Re}),O(!1),k(!0);return}console.error("Regeneration error:",Ue),T(bt=>{const Re=[...bt];return Re[Ge].error={type:"server",message:Ue.message||"Error"},Re}),O(!1)}},[_,n,r,o==null?void 0:o.getToken,c==null?void 0:c.setActive,H,v]),jt=F.useCallback(async Ge=>{const gn=Ge-1;if(gn<0)return;v&&rK(Ge),Y(Ge),T(Ue=>{const bt=[...Ue],Re=bt[Ge];return((Re==null?void 0:Re.type)==="response"||(Re==null?void 0:Re.role)==="assistant")&&(bt[Ge]={role:"assistant",parts:[]}),bt});const In=_[gn];if(!(In.type==="request"||In.role==="user")){Y(null);return}const En=_.slice(0,Ge);O(!0),ee(!1);const me=new AbortController;let Ce=!1,Ye=null;const dt=()=>{Ye&&clearTimeout(Ye),Ye=setTimeout(()=>{Ce=!0,me.abort()},12e4)};dt();try{let Ue=null,bt=null;await wb({messages:En,auth:n,getToken:o==null?void 0:o.getToken,setActive:c==null?void 0:c.setActive,org:r,onPart:Re=>{dt(),T(Rt=>{const At=[...Rt],kt=At[Ge];return kt.parts||(kt.parts=[]),Re.type==="step"?(bt||(bt={type:"steps",steps:[]},kt.parts.push(bt)),(Re.step||Re.data!==void 0)&&bt.steps.push({step:Re.step||"",data:Re.data!==void 0?Re.data:null,result:Re.result,_complete:!0}),Ue=null,At):(bt=null,Ue&&Ue.type===Re.type?Re.row?Ue.rows.push(Re.row):Re.type==="text"&&Re.text?Ue.text+=Re.text:Re.type==="thinking"&&Re.thinking?Ue.thinking+=Re.thinking:Re.type==="code"&&Re.code&&(Ue.code+=Re.code):(Ue&&Ue.type==="thinking"&&(Ue._complete=!0,Ue._startTime&&(Ue._duration=Math.round((Date.now()-Ue._startTime)/1e3))),Ue={...Re},Re.headers&&(Ue.rows=[]),Re.type==="thinking"&&(Ue._startTime=Date.now()),kt.parts.push(Ue)),At)})},signal:me.signal}),Ye&&clearTimeout(Ye),T(Re=>{const Rt=[...Re],At=Rt[Ge];return At!=null&&At.parts&&At.parts.forEach(kt=>{kt.type==="thinking"&&!kt._complete&&(kt._complete=!0,kt._startTime&&(kt._duration=Math.round((Date.now()-kt._startTime)/1e3)))}),Rt}),H&&T(Re=>(lr.updateChat(H,Re),de(lr.getAllChats()),Re)),O(!1),Y(null),k(!0)}catch(Ue){if(Ye&&clearTimeout(Ye),Ue.name==="AbortError"&&!Ce){v&&Qb(),T(bt=>{const Re=[...bt],Rt=Re[Ge];return Rt!=null&&Rt.parts&&Rt.parts.push({type:"text",text:`

*[Generation stopped]*`}),H&&lr.updateChat(H,Re),Re}),O(!1),Y(null),k(!0);return}console.error("Retry error:",Ue),T(bt=>{const Re=[...bt];return Re[Ge].error={type:"server",message:Ue.message||"Error"},Re}),O(!1),Y(null)}},[_,n,r,o==null?void 0:o.getToken,c==null?void 0:c.setActive,H,v]),pn=F.useCallback(()=>{P(!0),v&&(oK(s),q5(s))},[s,v]),Pt=_.length===0,un=n?C.jsx(TO,{appearance:{elements:{avatarBox:"w-6 h-6",userButtonTrigger:"focus:shadow-none"}}}):null;return C.jsxs("div",{className:"min-h-screen theme-transition",style:{backgroundColor:"var(--bg-primary)"},children:[C.jsx(dS,{isAuthenticated:n&&(o==null?void 0:o.isSignedIn),isPublic:!n,meta:{title:i,description:e}}),C.jsx(yG,{isOpen:he,onClose:Ft,onToggle:ct,chats:fe,activeChat:H,onSelectChat:pr,onNewChat:kn,onDeleteChat:yt,user:d==null?void 0:d.user,isOnPaidPlan:Le,tierName:ze,UserButtonComponent:un,isAuthenticated:n}),C.jsx(EG,{open:xe&&s==="cycls_pass",onClose:Ae,tier:s||"Pro"}),C.jsxs("main",{className:"min-h-screen transition-all duration-300 ease-in-out",style:{marginLeft:`${ve}px`},children:[C.jsx("div",{className:"p-10",children:C.jsxs("div",{className:"fixed max-sm:top-[2%] max-sm:right-1 top-1 right-4 flex items-center gap-1 z-20",children:[C.jsx(X5,{}),n&&C.jsxs("a",{href:"https://cycls.ai/",type:"button",className:`
                inline-flex items-center gap-2
                rounded-xl px-3 py-2
                text-sm font-medium
                hover:bg-[var(--bg-hover)]
                active:bg-[var(--bg-active)]
                transition-colors
                focus:outline-none focus-visible:ring-2 focus-visible:ring-[var(--text-primary)]/20
              `,style:{color:"var(--text-primary)"},children:[C.jsxs("svg",{xmlns:"http://www.w3.org/2000/svg",width:"18",height:"18",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.7",strokeLinecap:"round",strokeLinejoin:"round",children:[C.jsx("path",{d:"M15 21v-8a1 1 0 0 0-1-1h-4a1 1 0 0 0-1 1v8"}),C.jsx("path",{d:"M3 10a2 2 0 0 1 .709-1.528l7-6a2 2 0 0 1 2.582 0l7 6A2 2 0 0 1 21 10v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z"})]}),C.jsx("span",{children:"Home"})]})]})}),C.jsxs("div",{className:"mx-auto max-w-3xl min-h-screen px-4 pb-[200px] md:pb-[180px]",children:[I&&C.jsx(cG,{fileName:I.fileName,progress:I.progress}),C.jsx("div",{className:"prose m-2 mx-auto max-w-3xl p-2 prose-pre:p-0 pt-14 md:pt-2",children:C.jsx($l,{markdown:e,onSend:pt})}),!Pt&&C.jsxs("div",{className:`transition-opacity duration-500 ${V?"opacity-100":"opacity-0"}`,children:[C.jsx(cS,{messages:_,onSend:pt,onRegenerate:Xe,onRetry:jt,retryingIndex:te,isGenerating:A}),C.jsx("div",{ref:oe})]}),Pt&&!V&&t&&t.trim()!==""&&C.jsx("div",{className:"mx-auto max-w-3xl prose prose-sm prose-pre:p-0",children:C.jsx($l,{markdown:t,onSend:pt})})]})]}),C.jsx(uG,{onSend:pt,isLoading:A,onStop:Tt,disabled:at,onUpgradeClick:pn,sidebarWidth:ve})]})},Y5=({meta:e})=>{const t=!!e.prod,n=!!e.auth,r=String(e.header??""),i=String(e.intro??""),s=String(e.title??"AI Agent"),o=e.tier||null,c=e.pk,d=e.org||void 0,f=typeof window<"u"?window.location.origin+"/":"/";if(!n)return C.jsx(G5,{HEADER:r,INTRO:i,AUTH:n,ORG:d,TITLE:s,TIER:o});const m=t?{isSatellite:!1,domain:"cycls.ai",fallbackRedirectUrl:f,forceRedirectUrl:f}:{fallbackRedirectUrl:f,forceRedirectUrl:f};return C.jsx(e7,{publishableKey:c,...m,children:C.jsx(wG,{tier:o,children:C.jsx(aC,{children:C.jsxs(Lk,{children:[C.jsx(Dh,{path:"/auth",element:C.jsx(TG,{afterUrl:f})}),C.jsx(Dh,{path:"/",element:C.jsx(xG,{children:C.jsx(G5,{HEADER:r,INTRO:i,AUTH:n,ORG:d,TITLE:s,TIER:o})})}),C.jsx(Dh,{path:"*",element:C.jsx(h8,{to:"/",replace:!0})})]})})})})};function gK(){const[e,t]=ue.useState({status:"loading"});return ue.useEffect(()=>{const n=new AbortController;return(async()=>{try{const r=await kG(n.signal);t({status:"ready",data:r})}catch(r){t({status:"error",error:r})}})(),()=>n.abort()},[]),e}const bK=()=>{var n,r,i,s;const e=gK();if(F.useEffect(()=>{var o;e.status==="ready"&&((o=e.data)==null?void 0:o.analytics)===!0&&(GV(),KV())},[e.status,(n=e.data)==null?void 0:n.analytics]),e.status==="loading")return C.jsx(p1,{children:C.jsx("div",{className:"min-h-screen grid place-items-center text-sm",style:{backgroundColor:"var(--bg-primary)",color:"var(--text-tertiary)"},children:"Loading…"})});if(e.status==="error"){console.error("Failed to load /metadata:",e.error);const o={header:"",intro:"",prod:((i=(r=import.meta)==null?void 0:r.env)==null?void 0:i.PROD)||!1,auth:!1,title:"AI Agent",tier:null,analytics:!1};return C.jsx(p1,{children:C.jsx(Ug.Provider,{value:!1,children:C.jsx(Y5,{meta:o})})})}const t=((s=e.data)==null?void 0:s.analytics)===!0;return C.jsx(p1,{children:C.jsx(Ug.Provider,{value:t,children:C.jsx(Y5,{meta:e.data})})})},Kh=document.getElementById("root");Kh._reactRoot||(Kh._reactRoot=BA.createRoot(Kh));Kh._reactRoot.render(C.jsx(bK,{}));
